<?php


add_action( 'ninetheme_single_post', 'ninetheme_single_post_thumbnail', 5 );
add_action( 'ninetheme_single_post', 'ninetheme_single_post_meta_top', 10 );
add_action( 'ninetheme_single_post', 'ninetheme_single_post_title', 15 );
add_action( 'ninetheme_single_post', 'ninetheme_single_post_content', 20 );
add_action( 'ninetheme_single_post', 'ninetheme_single_post_bottom_meta', 25 );

add_action( 'ninetheme_after_single_post', 'ninetheme_single_navigation', 5 );
add_action( 'ninetheme_after_single_post', 'ninetheme_single_post_author_box', 10 );

add_action( 'ninetheme_single_post_comment', 'ninetheme_single_post_comment_template' );
add_action( 'ninetheme_single_post_related', 'ninetheme_single_post_related_template' );

add_action( 'ninetheme_single', 'ninetheme_single_layout' );

if ( ! function_exists( 'ninetheme_single_layout' ) ) {
    function ninetheme_single_layout()
    {
        $hero_template     = apply_filters( 'ninetheme_single_post_hero_template', ninetheme_settings( 'single_hero_elementor_templates', null ) );
        $ninetheme_layout  = ninetheme_settings( 'single_layout', 'full-width' );
        $column            = 'full-width' == $ninetheme_layout ? ninetheme_settings( 'single_content_column', 10 ) : '';
        $ninetheme_sidebar = ninetheme_sidebar( 'ninetheme-single-sidebar', 'sidebar-1' );
        $ninetheme_column  = ( !empty( ninetheme_settings( 'blog_sidebar_templates', null ) ) || $ninetheme_sidebar ) && ( 'full-width' != $ninetheme_layout ) ? 'col-lg-9' : 'col-lg-'.$column;
        $row_reverse       = ( ! empty( ninetheme_settings( 'blog_sidebar_templates', null ) ) || $ninetheme_sidebar ) && 'left-sidebar' == $ninetheme_layout ? ' flex-lg-row-reverse' : '';

        ?>
        <!-- Single page general div -->
        <div id="nt-single" class="nt-single">

            <?php
            if ( $hero_template ) {

                echo ninetheme_print_elementor_templates( $hero_template, 'custom-single-hero' );

            } else {

                ninetheme_hero_section();

            }
            ?>

            <div class="ninetheme-blog-details-area section-padding">
                <div class="container-xl ninetheme-container-xl">

                    <div class="row justify-content-center<?php echo esc_attr( $row_reverse ); ?>">

                        <div class="<?php echo esc_attr( $ninetheme_column ); ?>">
                            <div <?php post_class( 'ninetheme-blog-post-details', get_the_ID() ); ?>>
                                <div class="ninetheme-content">
                                    <?php

                                    do_action( 'ninetheme_before_single_post' );

                                    while ( have_posts() ) : the_post();

                                    if ( 'custom' == ninetheme_settings( 'single_content_layouts_type', 'default' ) ) {
                                        single_post_layouts_manager();
                                    } else {
                                        /**
                                        * Hook: ninetheme_single_post.
                                        *
                                        * @hooked ninetheme_single_post_thumbnail', 5 );
                                        * @hooked ninetheme_single_post_meta_top', 10 );
                                        * @hooked ninetheme_single_post_title', 15 );
                                        * @hooked ninetheme_single_post_content', 20 );
                                        * @hooked ninetheme_single_post_bottom_meta', 25 );
                                        */
                                        do_action( 'ninetheme_single_post' );
                                    }
                                    endwhile;
                                    /**
                                    * Hook: ninetheme_after_single_post.
                                    *
                                    * @hooked ninetheme_single_post_author_box', 5 );
                                    * @hooked ninetheme_single_navigation', 10 );
                                    */
                                    do_action( 'ninetheme_after_single_post' );

                                    ?>
                                </div>
                                <?php do_action( 'ninetheme_single_post_comment' ); ?>
                            </div>
                        </div>

                        <?php
                        if ( 'full-width' != $ninetheme_layout ) {
                            if ( ! empty( ninetheme_settings( 'blog_sidebar_templates', null ) ) ) {

                                get_sidebar();

                            } elseif ( $ninetheme_sidebar ) {
                                ?>
                                <div id="nt-sidebar" class="col-lg-3 col-md-3">
                                    <div class="blog-sidebar nt-sidebar-inner">

                                        <?php dynamic_sidebar( $ninetheme_sidebar ); ?>

                                    </div>
                                </div>
                                <?php
                            }
                        }
                        ?>

                    </div>
                </div>
            </div>
            <?php
            /**
            * Hook: ninetheme_single_post_related.
            *
            * @hooked ninetheme_single_post_related_template' );
            */
            do_action( 'ninetheme_single_post_related' );
            ?>
        </div>
        <?php
    }
}

/*************************************************
##  POST FORMAT
*************************************************/

if ( ! function_exists( 'ninetheme_single_post_title' ) ) {
    function ninetheme_single_post_title()
    {
        if ( '0' != ninetheme_settings( 'single_post_title_visibility', '1' ) ) {
            $tag = ninetheme_settings( 'single_post_title_tag', 'h2' );
            the_title('<'.$tag.' class="ninetheme-post-title">', '</'.$tag.'>' );
        }
    }
}

if ( ! function_exists( 'ninetheme_single_post_thumbnail' ) ) {
    function ninetheme_single_post_thumbnail()
    {
        if ( has_post_thumbnail() && '0' != ninetheme_settings( 'single_post_thumb_visibility', '1' ) ) {
            $size = ninetheme_settings( 'single_post_thumb_size' );
            $size = '' != $size ? $size : 'large';
            ?>
            <div class="ninetheme-post-thumb-wrapper mb-25"><?php the_post_thumbnail( $size ); ?></div>
            <?php
        }
    }
}

if ( ! function_exists( 'ninetheme_single_post_content' ) ) {
    function ninetheme_single_post_content()
    {
        $content = get_the_content();
        if ( '' != $content ) {
            echo '<div class="ninetheme-post-content-wrapper">';
                the_content();
                ninetheme_wp_link_pages();
            echo '</div>';
        }
    }
}

if ( ! function_exists( 'ninetheme_single_post_bottom_meta' ) ) {
    function ninetheme_single_post_bottom_meta()
    {
        if ( has_tag() || has_category() ) {
        ?>
        <div class="ninetheme-blog-post-meta-bottom">
            <?php ninetheme_single_post_categories(); ?>
            <?php ninetheme_single_post_tags(); ?>
        </div>
        <?php
        }
    }
}

if ( ! function_exists( 'ninetheme_single_post_categories' ) ) {
    function ninetheme_single_post_categories()
    {
        if ( has_category() && '0' != ninetheme_settings( 'single_postmeta_category_visibility', '1' ) ) {
            ?>
            <div class="ninetheme-post-categories-wrapper ninetheme-post-meta">
                <span class="ninetheme-meta-label"><?php esc_html_e( 'Categories:', 'crisop' ); ?></span> <?php the_category(', ',''); ?>
            </div>
            <?php
        }
    }
}

if ( ! function_exists( 'ninetheme_single_post_tags' ) ) {
    function ninetheme_single_post_tags()
    {
        if ( '0' != ninetheme_settings('single_postmeta_tags_visibility', '1' ) && has_tag() ) {
            ?>
            <div class="ninetheme-post-tags-wrapper ninetheme-post-meta">
                <span class="ninetheme-meta-label"><?php esc_html_e( 'Tags:', 'crisop' ); ?></span> <?php the_tags( '', ', ' ); ?>
            </div>
            <?php
        }
    }
}


if ( ! function_exists( 'ninetheme_single_post_meta_top' ) ) {
    function ninetheme_single_post_meta_top()
    {
        if ( '0' != ninetheme_settings( 'single_postmeta_author_visibility', '1' ) || '0' != ninetheme_settings( 'single_postmeta_date_visibility', '1' ) ) {
            $archive_year = get_the_time( 'Y' );
            $archive_month = get_the_time( 'm' );
            $archive_day = get_the_time( 'd' );
            ?>
            <div class="ninetheme-blog-post-meta-top ninetheme-inline-two-block">
                <?php ninetheme_single_post_author(); ?>
                <?php ninetheme_single_post_date(); ?>
            </div>
            <?php
        }
    }
}

if ( ! function_exists( 'ninetheme_single_post_date' ) ) {
    function ninetheme_single_post_date()
    {
        if ( '0' != ninetheme_settings( 'single_postmeta_date_visibility', '1' ) ) {
            $archive_year  = get_the_time( 'Y' );
            $archive_month = get_the_time( 'm' );
            $archive_day   = get_the_time( 'd' );
            ?>
            <a href="<?php echo esc_url( get_day_link( $archive_year, $archive_month, $archive_day ) ); ?>"><?php the_time( get_option( 'date_format' ) ); ?></a>
            <?php
        }
    }
}

if ( ! function_exists( 'ninetheme_single_post_author' ) ) {
    function ninetheme_single_post_author()
    {
        global $post;
        $author_id   = $post->post_author;
        $author_link = get_author_posts_url( $author_id );
        if ( '0' != ninetheme_settings( 'single_postmeta_author_visibility', '1' ) ) {
            ?>
            <a href="<?php echo esc_url( $author_link ); ?>"><?php the_author_meta( 'display_name', $post->post_author ); ?></a>
            <?php
        }
    }
}

if ( ! function_exists( 'ninetheme_single_post_comment_number' ) ) {
    function ninetheme_single_post_comment_number()
    {
        if ( comments_open() && '0' != get_comments_number() && '0' != ninetheme_settings( 'single_postmeta_comments_visibility', '1' ) ) {
            ?>
            <a href="<?php echo get_comments_link( get_the_ID() ); ?>"><?php printf( _nx( 'One Comment', '%1$s Comments', get_comments_number(), 'comments title', 'crisop' ), number_format_i18n( get_comments_number() ) ); ?></a>
            <?php
        }
    }
}


if ( ! function_exists( 'ninetheme_single_post_comment_template' ) ) {
    function ninetheme_single_post_comment_template()
    {
        if ( comments_open() && '0' != ninetheme_settings( 'single_comments_visibility', '1' ) ) {
            ?>
            <div class="ninetheme-post-comments">
                <?php echo comments_template(); ?>
            </div>
            <?php
        }
    }
}


/*************************************************
## SINGLE POST AUTHOR BOX FUNCTION
*************************************************/

if ( ! function_exists( 'ninetheme_single_post_author_box' ) ) {
    function ninetheme_single_post_author_box()
    {
        global $post;

        if ( '0' != ninetheme_settings('single_post_author_box_visibility', '0') ) {
            // Get author's display name
            $display_name     = get_the_author_meta('display_name', $post->post_author);
            // If display name is not available then use nickname as display name
            $display_name     = empty( $display_name ) ? get_the_author_meta('nickname', $post->post_author) : $display_name ;
            // Get author's biographical information or description
            $user_description = get_the_author_meta('user_description', $post->post_author);
            // Get author's website URL
            $user_website     = get_the_author_meta('url', $post->post_author);
            // Get link to the author archive page
            $user_posts       = get_author_posts_url(get_the_author_meta('ID', $post->post_author));
            // Get the rest of the author links. These are stored in the
            // wp_usermeta table by the key assigned in wpse_user_contactmethods()
            $author_facebook  = get_the_author_meta('facebook', $post->post_author);
            $author_twitter   = get_the_author_meta('twitter', $post->post_author);
            $author_instagram = get_the_author_meta('instagram', $post->post_author);
            $author_linkedin  = get_the_author_meta('linkedin', $post->post_author);
            $author_youtube   = get_the_author_meta('youtube', $post->post_author);

            if ( '' != $user_description ) {
                ?>
                <div class="avatar-post mt-50 mb-50">

                    <div class="post-avatar-img">
                        <?php
                        if ( function_exists( 'get_avatar' ) ) {
                            echo get_avatar( get_the_author_meta( 'email' ), '150');
                        }
                        ?>
                    </div>

                    <div class="post-avatar-content">

                        <h5><?php echo esc_html( $display_name ); ?></h5>
                        <p class="mb-0"><?php echo esc_html($user_description); ?></p>

                        <div class="post-avatar-social mt-20">
                            <ul>
                                <?php if ('' != $author_facebook) { ?>
                                    <li><a href="<?php echo esc_url($author_facebook); ?>" target="_blank"><i class="fab fa-facebook-f"></i></a></li>
                                <?php } ?>
                                <?php if ('' != $author_twitter) { ?>
                                    <li><a href="<?php echo esc_url($author_twitter); ?>" target="_blank"><i class="fab fa-twitter"></i></a></li>
                                <?php } ?>
                                <?php if ('' != $author_instagram) { ?>
                                    <li><a href="<?php echo esc_url($author_instagram); ?>" target="_blank"><i class="fab fa-instagram"></i></a></li>
                                <?php } ?>
                                <?php if ('' != $author_linkedin) { ?>
                                    <li><a href="<?php echo esc_url($author_linkedin); ?>" target="_blank"><i class="fab fa-linkedin"></i></a></li>
                                <?php } ?>
                                <?php if ('' != $author_youtube) { ?>
                                    <li><a href="<?php echo esc_url($author_youtube); ?>" target="_blank"><i class="ifab fa-youtube"></i></a></li>
                                <?php } ?>

                            </ul>
                        </div>

                    </div>
                </div>
                <?php
            }
        }
    }
}

/*************************************************
## SINGLE POST RELATED POSTS
*************************************************/

if ( ! function_exists( 'ninetheme_single_post_related_template' ) ) {
    function ninetheme_single_post_related_template()
    {
        if ( '0' == ninetheme_settings( 'single_related_visibility', '0' ) ) {
            return;
        }

        if ( ! empty( ninetheme_settings( 'blog_sidebar_templates', null ) ) ) {

            echo ninetheme_print_elementor_templates( 'single_related_elementor_templates', true );

        } else {

            global $post;
            $ninetheme_post_type = get_post_type( $post->ID );

            $slider_options = json_encode(array(
                "loop"          => '1' == ninetheme_settings( 'related_loop', '0' ) ? true : false,
                "loopedSlides"  => '1' == ninetheme_settings( 'related_loop', '0' ) ? 1 : null,
                "speed"         => intval(ninetheme_settings( 'related_speed', 800 )),
                "spaceBetween"  => intval(ninetheme_settings( 'related_gap', 20 )),
                "slidesPerView" => 1,
                "grabCursor"    => true,
                "autoplay"      => '1' == ninetheme_settings( 'related_autoplay', 1 ) ? ["pauseOnMouseEnter" => true,"disableOnInteraction" => false] : false,
                "navigation"    => [
                    "nextEl" => ".ninetheme-related-post-area .swiper-button-next",
                    "prevEl" => ".ninetheme-related-post-area .swiper-button-prev"
                ],
                "breakpoints"   => [
                    "0" => [
                        "slidesPerView" => intval(ninetheme_settings( 'related_xsperview', 2 ))
                    ],
                    "768" => [
                        "slidesPerView" => intval(ninetheme_settings( 'related_smperview', 3 ))
                    ],
                    "992" => [
                        "slidesPerView" => intval(ninetheme_settings( 'related_mdperview', 3 ))
                    ],
                    "1200" => [
                        "slidesPerView" => intval(ninetheme_settings( 'related_perview', 5 ))
                    ]
                ]
            ));

            $imgsize    = ninetheme_settings( 'related_imgsize', 'ninetheme-square' );
            $imgsize2   = ninetheme_settings( 'related_custom_imgsize' );
            $imgsize    = '' == $imgsize && !empty( $imgsize2 ) ? array($imgsize2['width'],$imgsize2['height'] ) : $imgsize;
            $ttag       = ninetheme_settings( 'related_title_tag', 'h3' );
            $subtag     = ninetheme_settings( 'related_subtitle_tag', 'p' );
            $style      = ninetheme_settings( 'related_post_style', ninetheme_settings( 'post_style', 'classic' ) );

            $cats = get_the_category( $post->ID );
            $args = array(
                'post__not_in' => array( $post->ID ),
                'posts_per_page' => ninetheme_settings( 'related_perpage', 6 )
            );

            $related_query = new WP_Query( $args );

            if ( $related_query->have_posts() ) {
                ?>
                <div class="ninetheme-related-post-area ninetheme-bg section-padding">
                    <div class="container-xl ninetheme-container-xl">
                        <div class="row justify-content-center">

                            <?php if ( '' != ninetheme_settings( 'related_subtitle' ) || '' != ninetheme_settings( 'related_title' ) ) { ?>
                                <div class="col-lg-8">
                                    <div class="section-title text-center mb-40">
                                        <?php if ( '' != ninetheme_settings( 'related_subtitle' ) ) { ?>
                                            <<?php echo esc_attr( $subtag ); ?> class="sub-title"><?php echo esc_html( ninetheme_settings( 'related_subtitle' ) ); ?></<?php echo esc_attr( $subtag ); ?>>
                                        <?php } ?>
                                        <?php if ( '' != ninetheme_settings( 'related_title' ) ) { ?>
                                            <<?php echo esc_attr( $ttag ); ?> class="title"><?php echo esc_html( ninetheme_settings( 'related_title' ) ); ?></<?php echo esc_attr( $ttag ); ?>>
                                        <?php } ?>
                                    </div>
                                </div>
                            <?php } ?>

                            <div class="col-lg-12">
                                <div class="ninetheme-related-slider ninetheme-swiper-theme-style swiper-container nav-show-hover"  data-swiper-options="<?php echo esc_attr( $slider_options ); ?>">
                                    <div class="swiper-wrapper">
                                        <?php
                                        while ( $related_query->have_posts() ) {
                                            $related_query->the_post();
                                            ?>
                                            <div class="swiper-slide">
                                                <?php get_template_part( 'blog/style/'. $style ); ?>
                                            </div>
                                            <?php
                                        }
                                        ?>
                                    </div>

                                    <div class="swiper-pagination ninetheme-related-pagination"></div>
                                    <div class="related-nav swiper-button-prev nav-medium"></div>
                                    <div class="related-nav swiper-button-next nav-medium"></div>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
                <?php
                wp_reset_postdata();
            }
        }
    }
}

if ( !function_exists( 'single_post_layouts_manager' ) ) {
    function single_post_layouts_manager()
    {
        $defaults = [
            'show'=> [
                'thumbnail'   => '',
                'title'       => '',
                'meta'        => '',
                'content'     => '',
                'meta-bottom' => ''
            ]
        ];
        $layouts = ninetheme_settings( 'single_content_layouts', $defaults );

        if ( $layouts ) {

            unset( $layouts['show']['placebo'] );

            foreach ( $layouts['show'] as $key => $value ) {
                switch ( $key ) {
                    case 'thumbnail':
                        ninetheme_single_post_thumbnail();
                    break;
                    case 'title':
                        ninetheme_single_post_title();
                    break;
                    case 'meta':
                        ninetheme_single_post_meta_top();
                    break;
                    case 'content':
                        ninetheme_single_post_content();
                    break;
                    case 'meta-bottom':
                        ninetheme_single_post_bottom_meta();
                    break;
                }
            }
        }
    }
}
