<?php


/**
 * Custom template parts for this theme.
 *
 * preloader, backtotop, conten-none
 *
 * Eventually, some of the functionality here could be replaced by core features.
 *
 * @package crisop
*/


/*************************************************
## START PRELOADER
*************************************************/

if ( ! function_exists( 'ninetheme_preloader' ) ) {
    function ninetheme_preloader()
    {
        $type = ninetheme_settings('pre_type', 'default');

        if ( '0' != ninetheme_settings('preloader_visibility', '1') ) {

            if ( 'default' == $type && '' != ninetheme_settings( 'pre_img', '' ) ) {
                ?>
                <div class="preloader">
                    <img class="preloader__image" width="55" src="<?php echo esc_url( ninetheme_settings( 'pre_img' )[ 'url' ] ); ?>" alt="<?php echo esc_attr( get_bloginfo( 'name' ) ); ?>" />
                </div>
                <?php
            } else {
                ?>
                <div id="nt-preloader" class="preloader">
                    <div class="loader<?php echo esc_attr( $type );?>"></div>
                </div>
                <?php
            }
        }
    }
}
add_action( 'ninetheme_after_body_open', 'ninetheme_preloader', 10 );
add_action( 'elementor/page_templates/canvas/before_content', 'ninetheme_preloader', 10 );

/*************************************************
##  BACKTOP
*************************************************/

if ( ! function_exists( 'ninetheme_backtop' ) ) {
    add_action( 'ninetheme_before_wp_footer', 'ninetheme_backtop', 10 );
    function ninetheme_backtop() {
        if ( '1' == ninetheme_settings('backtotop_visibility', '1') ) { ?>
            <a href="#" data-target="html" class="scroll-to-target scroll-to-top"><i class="fa fa-angle-up"></i></a>
            <?php
        }
    }
}


/*************************************************
##  CONTENT NONE
*************************************************/

if ( ! function_exists( 'ninetheme_content_none' ) ) {
    function ninetheme_content_none() {
        ?>
        <div class="content-none-container">
            <h3 class="ninetheme-nothing-title mb-20"><?php esc_html_e( 'Nothing Found', 'crisop' ); ?></h3>
            <?php
                if ( is_home() && current_user_can( 'publish_posts' ) ) :

                    printf( '<p>%s</p> <a class="thm-btn" href="%s">%s</a>',
                    esc_html__( 'Ready to publish your first post?', 'crisop' ),
                    esc_url( admin_url( 'post-new.php' ) ),
                    esc_html__( 'Get started here', 'crisop' )
                );
                elseif ( is_search() ) :
                ?>
                <p class="__nothing"><?php esc_html_e( 'Sorry, but nothing matched your search terms. Please try again with some different keywords.', 'crisop' ); ?></p>

                <?php printf( '<a href="%1$s" class="ninetheme-btn-medium ninetheme-btn ninetheme-btn-dark mt-30"><span>%2$s</span></a>',
                        esc_url( home_url('/') ),
                        esc_html__( 'Go to home page', 'crisop' )
                    );
                ?>

            <?php else : ?>
                <p><?php esc_html_e( 'It seems we can&rsquo;t find what you&rsquo;re looking for. Perhaps searching can help.', 'crisop' ); ?></p>


            <?php printf( '<a href="%1$s" class="ninetheme-btn-medium ninetheme-btn ninetheme-btn-dark mt-30"><span>%2$s</span></a>',
                    esc_url( home_url('/') ),
                    esc_html__( 'Go to home page', 'crisop' )
                );
            ?>
            <?php endif; ?>
        </div>
        <?php
    }
}
