<?php
/**
* Cart Page
*
* This template can be overridden by copying it to yourtheme/woocommerce/cart/cart.php.
*
* HOWEVER, on occasion WooCommerce will need to update template files and you
* (the theme developer) will need to copy the new files to your theme to
* maintain compatibility. We try to do this as little as possible, but it does
* happen. When this occurs the version of the template file will be bumped and
* the readme will list any important changes.
*
* @see     https://docs.woocommerce.com/document/template-structure/
* @package WooCommerce\Templates
* @version 7.4.0
*/

defined( 'ABSPATH' ) || exit;

do_action( 'woocommerce_before_cart' );
remove_action( 'woocommerce_cart_collaterals', 'woocommerce_cart_totals', 10 );
?>

<div class="row">
    <div class="col-lg-8">
        <div class="ninetheme-before-cart-table">
            <?php do_action( 'ninetheme_before_cart_table' ); ?>
        </div>
        <form class="woocommerce-cart-form ninetheme-woocommerce-cart-form" action="<?php echo esc_url( wc_get_cart_url() ); ?>" method="post">
            <?php do_action( 'woocommerce_before_cart_table' ); ?>

            <div class="shop_table shop_table_responsive cart woocommerce-cart-form__contents">
                <?php do_action( 'woocommerce_before_cart_contents' ); ?>

                <?php
                foreach ( WC()->cart->get_cart() as $cart_item_key => $cart_item ) {
                    $_product   = apply_filters( 'woocommerce_cart_item_product', $cart_item['data'], $cart_item, $cart_item_key );
                    $product_id = apply_filters( 'woocommerce_cart_item_product_id', $cart_item['product_id'], $cart_item, $cart_item_key );
                    $img_size   = apply_filters( 'ninetheme_cart_item_img_size', [80,80] );

                    if ( $_product && $_product->exists() && $cart_item['quantity'] > 0 && apply_filters( 'woocommerce_cart_item_visible', true, $cart_item, $cart_item_key ) ) {
                        $product_permalink = apply_filters( 'woocommerce_cart_item_permalink', $_product->is_visible() ? $_product->get_permalink( $cart_item ) : '', $cart_item, $cart_item_key );
                        ?>
                        <div class="row ninetheme-cart-item ninetheme-align-center woocommerce-cart-form__cart-item <?php echo esc_attr( apply_filters( 'woocommerce_cart_item_class', 'cart_item', $cart_item, $cart_item_key ) ); ?>">
                            <div class="col-12 col-sm-6">
                                <div class="row ninetheme-meta-left ninetheme-flex ninetheme-align-center">
                                    <div class="col-3 product-thumbnail">
                                        <?php
                                        $thumbnail = apply_filters( 'woocommerce_cart_item_thumbnail', $_product->get_image( $img_size ), $cart_item, $cart_item_key );

                                        if ( ! $product_permalink ) {
                                            echo apply_filters( 'woocommerce_cart_item_thumbnail', $_product->get_image( $img_size ), $cart_item, $cart_item_key );
                                        } else {
                                            printf( '<a href="%s">%s</a>', esc_url( $product_permalink ), $thumbnail ); // PHPCS: XSS ok.
                                        }
                                        ?>
                                    </div>
                                    <div class="col-9 product-name ninetheme-small-title" data-title="<?php esc_attr_e( 'Product', 'crisop' ); ?>">
                                        <?php
                                        if ( ! $product_permalink ) {
                                            echo wp_kses_post( apply_filters( 'woocommerce_cart_item_name', $_product->get_name(), $cart_item, $cart_item_key ) . '&nbsp;' );
                                        } else {
                                            echo wp_kses_post( apply_filters( 'woocommerce_cart_item_name', sprintf( '<a href="%s">%s</a>', esc_url( $product_permalink ), $_product->get_name() ), $cart_item, $cart_item_key ) );
                                        }

                                        do_action( 'woocommerce_after_cart_item_name', $cart_item, $cart_item_key );

                                        // Meta data.
                                        echo wc_get_formatted_cart_item_data( $cart_item ); // PHPCS: XSS ok.

                                        // Backorder notification.
                                        if ( $_product->backorders_require_notification() && $_product->is_on_backorder( $cart_item['quantity'] ) ) {
                                            echo wp_kses_post( apply_filters( 'woocommerce_cart_item_backorder_notification', '<p class="backorder_notification">' . esc_html__( 'Available on backorder', 'crisop' ) . '</p>', $product_id ) );
                                        }
                                        ?>
                                        <div class="product-price ninetheme-price" data-title="<?php esc_attr_e( 'Price', 'crisop' ); ?>">
                                            <span class="price">
                                                <?php echo apply_filters( 'woocommerce_cart_item_price', WC()->cart->get_product_price( $_product ), $cart_item, $cart_item_key ); // PHPCS: XSS ok.?>
                                            </span>
                                            <span class="cart-quantity"><?php printf( esc_html__( 'X %1$s', 'crisop' ), $cart_item['quantity'] ); ?></span>
                                        </div>
                                    </div>
                                </div>
                            </div>

                            <div class="col-12 col-sm-6">
                                <div class="row ninetheme-meta-right ninetheme-align-center">
                                    <div class="col-auto product-quantity ninetheme-quantity-small" data-title="<?php esc_attr_e( 'Quantity', 'crisop' ); ?>">
                                        <?php
                                        if ( $_product->is_sold_individually() ) {
                                            $min_quantity = 1;
                                            $max_quantity = 1;
                                        } else {
                                            $min_quantity = 0;
                                            $max_quantity = $_product->get_max_purchase_quantity();
                                        }

                                        $product_quantity = woocommerce_quantity_input(
                                            array(
                                                'input_name'   => "cart[{$cart_item_key}][qty]",
                                                'input_value'  => $cart_item['quantity'],
                                                'max_value'    => $max_quantity,
                                                'min_value'    => $min_quantity,
                                                'product_name' => $_product->get_name(),
                                            ),
                                            $_product,
                                            false
                                        );

                                        echo apply_filters( 'woocommerce_cart_item_quantity', $product_quantity, $cart_item_key, $cart_item ); // PHPCS: XSS ok.
                                        ?>
                                    </div>
                                    <div class="col-auto product-subtotal ninetheme-price" data-title="<?php esc_attr_e( 'Subtotal', 'crisop' ); ?>">
                                        <?php echo apply_filters( 'woocommerce_cart_item_subtotal', WC()->cart->get_product_subtotal( $_product, $cart_item['quantity'] ), $cart_item, $cart_item_key ); // PHPCS: XSS ok.?>
                                    </div>
                                    <div class="col-auto product-remove">
                                        <?php
                                        echo apply_filters( // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
                                            'woocommerce_cart_item_remove_link',
                                            sprintf(
                                                '<a href="%s" class="remove del-icon" aria-label="%s" data-product_id="%s" data-product_sku="%s">'.ninetheme_svg_lists( 'trash', 'ninetheme-svg-icon mini-icon' ).'</a>',
                                                esc_url( wc_get_cart_remove_url( $cart_item_key ) ),
                                                esc_html__( 'Remove this item', 'crisop' ),
                                                esc_attr( $product_id ),
                                                esc_attr( $_product->get_sku() )
                                            ),
                                            $cart_item_key
                                        );
                                        ?>
                                        <span class="loading-wrapper"><span class="ajax-loading"></span></span>
                                    </div>
                                </div>
                            </div>

                        </div>
                        <?php
                    }
                }

                do_action( 'woocommerce_cart_contents' );

                ?>
                <div class="ninetheme-cart-item ninetheme-actions">
                    <div class="row">

                        <?php if ( wc_coupons_enabled() ) { ?>
                            <div class="col col-lg-8">
                                <div class="ninetheme-flex ninetheme-flex-nowrap">
                                    <input type="text" name="coupon_code" class="input-text ninetheme-input ninetheme-input-small" id="coupon_code" value="" placeholder="<?php esc_attr_e( 'Coupon code', 'crisop' ); ?>" />
                                    <button type="submit" class="ninetheme-btn ninetheme-btn-primary ninetheme-btn-medium cart-apply-button" name="apply_coupon" value="<?php esc_attr_e( 'Apply coupon', 'crisop' ); ?>"><?php esc_html_e( 'Apply coupon', 'crisop' ); ?></button>
                                    <?php do_action( 'woocommerce_cart_coupon' ); ?>
                                </div>
                            </div>
                        <?php } ?>
                        <div class="col col-lg-4">
                            <div class="ninetheme-hidden ninetheme-flex ninetheme-flex-right">
                                <button type="submit" class="ninetheme-btn ninetheme-btn-primary ninetheme-btn-large cart-update-button" name="update_cart" value="<?php esc_attr_e( 'Update cart', 'crisop' ); ?>"><?php esc_html_e( 'Update cart', 'crisop' ); ?></button>
                                <?php do_action( 'woocommerce_cart_actions' ); ?>
                                <?php wp_nonce_field( 'woocommerce-cart', 'woocommerce-cart-nonce' ); ?>
                            </div>
                        </div>
                    </div>
                </div>

                <?php do_action( 'woocommerce_after_cart_contents' ); ?>

            </div>
            <?php do_action( 'woocommerce_after_cart_table' ); ?>
        </form>
    </div>

    <div class="col-lg-4">
        <?php woocommerce_cart_totals(); ?>
    </div>

    <div class="col-lg-12">
        <?php do_action( 'woocommerce_before_cart_collaterals' ); ?>
        <?php
        /**
        * Cart collaterals hook.
        *
        * @hooked woocommerce_cross_sell_display
        * @hooked woocommerce_cart_totals - 10
        */
        do_action( 'woocommerce_cart_collaterals' );
        ?>
    </div>

</div>


<?php do_action( 'woocommerce_after_cart' ); ?>
