<?php
/**
* Checkout Form
*/

if ( ! defined( 'ABSPATH' ) ) {
    //exit;
}


$labels = apply_filters( 'ninetheme_checkout_multisteps_strings', array(
    'billing'  => _x( 'Billing & Shipping', 'Checkout: user multisteps', 'crisop' ),
    'order'    => _x( 'Order & Payment', 'Checkout: user multisteps', 'crisop' ),
    'next'     => esc_html__( 'Next', 'crisop' ),
    'prev'     => esc_html__( 'Previous', 'crisop' )
));

$checkout_url = apply_filters( 'woocommerce_get_checkout_url', wc_get_checkout_url() );
$checkout = new WC_Checkout();

// If checkout registration is disabled and not logged in, the user cannot checkout.
if ( ! $checkout->is_registration_enabled() && $checkout->is_registration_required() && ! is_user_logged_in() ) {
    echo esc_html( apply_filters( 'woocommerce_checkout_must_be_logged_in_message', __( 'You must be logged in to checkout.', 'crisop' ) ) );
    return;
}
?>
<div class="ninetheme-panel-checkout-content-wrapper">
    <div class="ninetheme-panel-checkout-labels">
        <div class="ninetheme-panel-checkout-labels-inner">
            <div class="ninetheme-step-item ninetheme-step-item-1 active-step">
                <span class="ninetheme-step">1</span>
                <span class="ninetheme-step-label"><?php echo esc_html( $labels['billing'] ); ?></span>
            </div>
            <div class="ninetheme-step-item ninetheme-step-item-2">
                <span class="ninetheme-step">2</span>
                <span class="ninetheme-step-label"><?php echo esc_html( $labels['order'] ); ?></span>
            </div>
        </div>
    </div>

    <div class="ninetheme-panel-checkout-form-wrapper ninetheme-scrollbar">
        <div id="checkout_coupon" class="ninetheme-woocommerce-checkout-coupon">
            <?php woocommerce_checkout_coupon_form(); ?>
        </div>

        <form name="checkout" method="post" class="checkout woocommerce-checkout" action="<?php echo esc_url( $checkout_url ); ?>" enctype="multipart/form-data">
            <div class="ninetheme-panel-checkout-content">
                <?php if ( $checkout->get_checkout_fields() ) : ?>
                    <div class="ninetheme-panel-checkout-content-inner active-step" data-target-name="billing">

                        <?php do_action( 'woocommerce_checkout_before_customer_details' ); ?>

                        <div class="check-form-required">
                            <div class="ninetheme-customer-billing-details <?php echo is_user_logged_in() ? 'logged-in' : 'not-logged-in'; ?>" id="ninetheme-customer-billing-details">
                                <?php do_action( 'woocommerce_checkout_billing' ); ?>
                            </div>
                            <div class="ninetheme-customer-shipping-details" id="ninetheme-customer-shipping-details">
                                <?php do_action( 'woocommerce_checkout_shipping' ); ?>
                            </div>
                        </div>

                        <?php do_action( 'woocommerce_checkout_after_customer_details' ); ?>

                    </div>
                <?php endif; ?>

                <div class="ninetheme-panel-checkout-content-inner" data-target-name="order">
                    <div class="ninetheme-order-review">
                        <?php do_action( 'woocommerce_checkout_before_order_review' ); ?>
                        <div id="order_review">
                            <h4 class="ninetheme-form-title"><?php esc_html_e( 'Your order', 'crisop' ); ?></h4>
                            <?php do_action( 'woocommerce_checkout_order_review' ); ?>
                        </div>
                        <?php do_action( 'woocommerce_checkout_after_order_review' ); ?>
                    </div>
                </div>

            </div>
        </form>
    </div>
    <div class="ninetheme-panel-checkout-button-wrapper">
        <div class="ninetheme-panel-checkout-button-prev ninetheme-btn-medium ninetheme-btn ninetheme-btn-primary"><?php echo esc_html( $labels['prev'] ) ?></div>
        <div class="ninetheme-panel-checkout-button-next ninetheme-btn-medium ninetheme-btn ninetheme-btn-secondary"><?php echo esc_html( $labels['next'] ) ?></div>
    </div>

</div>

<?php wp_enqueue_script( 'wc-checkout' ); ?>
<?php do_action( 'woocommerce_after_checkout_form', $checkout );
