<?php

if ( ! function_exists( 'ninetheme_header_cart_totals_fragment' ) ) {
    add_filter('woocommerce_add_to_cart_fragments', 'ninetheme_header_cart_totals_fragment');
    function ninetheme_header_cart_totals_fragment( $fragments )
    {
        global $woocommerce;
        $total = $count = $shipping = $minicart = '';
        ob_start();
        if ( WC()->cart->cart_contents_total ) {
            $total = '<span class="ninetheme-cart-total">'.WC()->cart->get_cart_subtotal().'</span>';
        }
        $total .= ob_get_clean();

        ob_start();
        $count = '<span class="ninetheme-cart-count ninetheme-wc-count">'.esc_html( $woocommerce->cart->cart_contents_count ).'</span>';
        $count .= ob_get_clean();

        ob_start();
        $shipping = ninetheme_free_shipping_goal_content();
        $shipping .= ob_get_clean();

        ob_start();
        get_template_part('woocommerce/minicart/minicart');
        $minicart .= ob_get_clean();

        $all_notices  = WC()->session->get( 'wc_notices', array() );
        $notice_types = apply_filters( 'woocommerce_notice_types', array( 'error', 'success', 'notice' ) );

        ob_start();
        foreach ( $notice_types as $notice_type ) {
            if ( wc_notice_count( $notice_type ) > 0 ) {
                wc_get_template( "notices/{$notice_type}.php", array(
                    'notices' => array_filter( $all_notices[ $notice_type ] ),
                ) );
            }
        }

        $fragments['notices_html'] = ob_get_clean();

        wc_clear_notices();

        $fragments['div.ninetheme-cart-goal-text'] = $shipping;
        $fragments['span.ninetheme-cart-total']    = $total;
        $fragments['span.ninetheme-cart-count']    = $count;
        $fragments['div.minicart-panel']           = $minicart;

        return $fragments;
    }
}

if ( ! function_exists( 'ninetheme_free_shipping_goal_content' ) ) {
    function ninetheme_free_shipping_goal_content()
    {
		$amount = round( ninetheme_settings( 'free_shipping_progressbar_amount', 500 ), wc_get_price_decimals() );

		if ( !( $amount > 0 ) || '1' != ninetheme_settings( 'free_shipping_progressbar_visibility', 1 ) ) {
			return;
		}

		$message_initial = ninetheme_settings( 'free_shipping_progressbar_message_initial' );
		$message_success = ninetheme_settings( 'free_shipping_progressbar_message_success' );

		$total     = WC()->cart->get_displayed_subtotal();
		$remainder = ( $amount - $total );
		$value     = $total <= $amount ? ( $total / $amount ) * 100 : 100;

		if ( $total == 0 ) {
			$value = 0;
		}

		echo '<div class="ninetheme-cart-goal-text">';
			if ( $total >= $amount ) {
				if ( $message_success ) {
					echo sprintf('%s', $message_success );
				} else {
					echo sprintf('%s <strong>%s</strong>',
						esc_html__('Congrats! You are eligible for', 'crisop'),
						esc_html__('more to enjoy FREE Shipping', 'crisop')
					);
				}
			} else {
				if ( $message_initial ) {
					echo sprintf('%s', str_replace( '[remainder]', wc_price( $remainder ), $message_initial ) );
				} else {
					echo sprintf('%s %s <strong>%s</strong>',
						esc_html__('Buy', 'ninetheme'),
						wc_price( $remainder ),
						esc_html__('more to enjoy FREE Shipping', 'crisop')
					);
				}
			}
			echo'<input type="hidden" name="ninetheme-cart-goal-percent" value="'.esc_attr( $value ).'" class="ninetheme-cart-goal-percent">';
		echo'</div>';
    }
}



if ( ! function_exists( 'ninetheme_side_panel_cart_content' ) ) {
    add_action( 'ninetheme_before_wp_footer', 'ninetheme_side_panel_cart_content' );
    function ninetheme_side_panel_cart_content()
    {
        $autoopen      = '1' == ninetheme_settings('disable_right_panel_auto', '0' ) ? ' disable-auto-open' : '';
        $counter_attr  = 'counter-'.ninetheme_settings( 'header_buttons_counter_position', 'right' );
        $counter_attr .= ' counter-'.ninetheme_settings( 'header_buttons_counter_bgcolor_type', 'primary' );
        $counter_attr .= ' counter-'.ninetheme_settings( 'header_buttons_counter_radius_type', 'radius' );
        ?>
        <div class="ninetheme-side-panel<?php echo esc_attr( $autoopen ); ?>">
            <div class="panel-header <?php echo esc_attr( $counter_attr ); ?>">
                <div class="ninetheme-panel-close ninetheme-panel-close-button"></div>
                <div class="panel-header-actions">

                    <div class="panel-header-cart">
                        <span class="ninetheme-cart-total"></span>
                        <div class="panel-header-btn" data-name="cart">
                            <span class="ninetheme-cart-count ninetheme-wc-count"></span>
                            <?php echo ninetheme_svg_lists( 'bag', 'ninetheme-svg-icon' ); ?>
                        </div>
                    </div>

                    <?php if ( class_exists( 'WPCleverWoosw' ) ) { ?>
                        <div class="panel-header-wishlist panel-header-btn open-wishlist-btn">
                            <div class="woosw-menu-item ninetheme-hidden"><span class="woosw-menu-item-inner"></span></div>
                            <span class="ninetheme-wishlist-count ninetheme-wc-count"></span>
                            <?php echo ninetheme_svg_lists( 'love', 'ninetheme-svg-icon' ); ?>
                        </div>
                    <?php } ?>

                    <?php if ( class_exists( 'WPCleverWoosc' ) ) { ?>
                        <div class="panel-header-compare panel-header-btn open-compare-btn">
                            <span class="ninetheme-compare-count ninetheme-wc-count"></span>
                            <?php echo ninetheme_svg_lists( 'compare', 'ninetheme-svg-icon' ); ?>
                        </div>
                    <?php } ?>

                    <?php do_action( 'ninetheme_side_panel_header_after_cart' ); ?>

                </div>
            </div>

            <?php do_action( 'ninetheme_side_panel_after_header' ); ?>

            <div class="panel-content">

                <div class="cart-area panel-content-item active" data-name="cart">
                    <div class="cart-content">
                        <?php get_template_part('woocommerce/minicart/minicart'); ?>
                    </div>
                </div>

                <?php do_action( 'ninetheme_side_panel_content_after_cart' ); ?>

            </div>
            <div class="panel-footer"></div>
        </div>
        <?php
    }
}
