<?php
/**
* Mini-cart
*
* Contains the markup for the mini-cart, used by the cart widget.
*
* This template can be overridden by copying it to yourtheme/woocommerce/cart/mini-cart.php.
*
* HOWEVER, on occasion WooCommerce will need to update template files and you
* (the theme developer) will need to copy the new files to your theme to
* maintain compatibility. We try to do this as little as possible, but it does
* happen. When this occurs the version of the template file will be bumped and
* the readme will list any important changes.
*
*/

if ( ! defined( 'ABSPATH' ) ) {
    exit; // Exit if accessed directly
}
if ( ! class_exists('WooCommerce') ) {
    return;
}

global $woocommerce;

do_action( 'woocommerce_before_mini_cart' );

$checkout_url = apply_filters( 'woocommerce_get_checkout_url', wc_get_checkout_url() );

?>

<div class="minicart-panel">

    <?php if ( ! WC()->cart->is_empty() ) : ?>

        <div class="ninetheme-header-cart-details ninetheme-minicart">

            <div class="woocommerce-mini-cart has-product <?php echo !empty($args['list_class']) ? ' '.esc_attr( $args['list_class'] ) : ''; ?>">
                <div class="ninetheme-scrollbar">

                    <?php do_action( 'woocommerce_before_mini_cart_contents' ); ?>

                    <?php foreach ( WC()->cart->get_cart() as $cart_item_key => $cart_item ) : ?>
                        <?php
                        $_product   = apply_filters( 'woocommerce_cart_item_product', $cart_item['data'], $cart_item, $cart_item_key );
                        $type       = $_product->get_type();
                        $product_id = apply_filters( 'woocommerce_cart_item_product_id', $cart_item['product_id'], $cart_item, $cart_item_key );
                        if ( $_product && $_product->exists() && $cart_item['quantity'] > 0 && apply_filters( 'woocommerce_widget_cart_item_visible', true, $cart_item, $cart_item_key ) ) :
                            $product_name      = apply_filters( 'woocommerce_cart_item_name', $_product->get_name(), $cart_item, $cart_item_key );
                            $thumbnail         = apply_filters( 'woocommerce_cart_item_thumbnail', $_product->get_image(), $cart_item, $cart_item_key );
                            $product_price     = apply_filters( 'woocommerce_cart_item_price', WC()->cart->get_product_price( $_product ), $cart_item, $cart_item_key );
                            $product_permalink = apply_filters( 'woocommerce_cart_item_permalink', $_product->is_visible() ? $_product->get_permalink( $cart_item ) : '', $cart_item, $cart_item_key );
                            $imgurl = get_the_post_thumbnail_url($cart_item['product_id'],'ninetheme-panel');
                            $imgsrc = $imgurl ? $imgurl : wc_placeholder_img_src();
                            $img    = '<img width="80" height="80" src="'.$imgsrc.'" alt="'.esc_attr( $product_name ).'"/>';
                            ?>
                            <div class="woocommerce-mini-cart-item <?php echo esc_attr( apply_filters( 'woocommerce_mini_cart_item_class', 'mini-cart-item product-type-'.$type, $cart_item, $cart_item_key ) ); ?>">

                                <div class="cart-item-details">
                                    <a class="product-link" href="<?php echo esc_url( get_permalink( $cart_item['product_id'] ) ) ?>">
                                        <?php printf( '%s', $img ); ?>
                                    </a>
                                    <div class="cart-item-title ninetheme-small-title">
                                        <a class="product-link" href="<?php echo esc_url( get_permalink( $cart_item['product_id'] ) ) ?>">
                                            <?php printf( '<span class="cart-name">%s</span>', $product_name ); ?>
                                        </a>
                                        <?php if ( 'simple' == $type ) { ?>
                                            <div class="cart-quantity-wrapper ajax-quantity" data-product_id="<?php echo esc_attr( $cart_item['product_id'] ); ?>">
                                                <?php if ( $_product->is_sold_individually() ) : ?>
                                                <?php echo apply_filters( 'woocommerce_widget_cart_item_quantity', '<span class="quantity">' . esc_html__( 'Qty', 'crisop' ) . ': ' . $cart_item['quantity'] . '</span>', $cart_item, $cart_item_key ); // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped ?>
                                                <?php else: ?>
                                                <?php
                                                $product_quantity = woocommerce_quantity_input( array(
                                                'input_name'  => "cart[{$cart_item_key}][qty]",
                                                'input_value' => $cart_item['quantity'],
                                                'max_value'   => $_product->backorders_allowed() ? '' : $_product->get_stock_quantity(),
                                                'min_value'   => '1',
                                                ), $_product, false );

                                                echo apply_filters( 'woocommerce_widget_cart_item_quantity', $product_quantity, $cart_item, $cart_item_key );
                                                ?>
                                                <?php endif; ?>
                                                <span class="ninetheme-price price">
                                                    <?php echo apply_filters( 'woocommerce_widget_cart_item_quantity', '<span class="new">' . sprintf( '%s', $product_price ) . '</span>', $cart_item, $cart_item_key ); ?>
                                                    <span class="cart-quantity"><?php printf( esc_html__( 'X %1$s', 'crisop' ), $cart_item['quantity'] ); ?></span>
                                                </span>
                                            </div>
                                        <?php } else {
                                            echo do_shortcode('[add_to_cart style="" show_price="false" id="'.$product_id.'"]');
                                        }
                                        ?>
                                    </div>
                                </div>
                                <div class="del-icon" data-id="<?php echo esc_attr( $product_id ); ?>">
                                    <?php
                                    echo apply_filters( // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
                                        'woocommerce_cart_item_remove_link',
                                        sprintf(
                                            '<a href="%s" class="remove_from_cart_button" aria-label="%s" data-product_id="%s" data-cart_item_key="%s" data-product_sku="%s">'.ninetheme_svg_lists( 'trash', 'ninetheme-svg-icon mini-icon' ).'</a>',
                                            esc_url( wc_get_cart_remove_url( $cart_item_key ) ),
                                            esc_attr__( 'Remove this item', 'crisop' ),
                                            esc_attr( $product_id ),
                                            esc_attr( $cart_item_key ),
                                            esc_attr( $_product->get_sku() )
                                        ),
                                        $cart_item_key
                                    );
                                    ?>

                                    <?php echo wc_get_formatted_cart_item_data( $cart_item ); ?>
                                </div>
                            </div>
                        <?php endif; ?>
                    <?php endforeach; ?>

                    <?php do_action( 'woocommerce_mini_cart_contents' ); ?>
                    <div class="ninetheme-mini-cart-item-loading loading"><span class="loading-wrapper"><span class="ajax-loading"></span></span></div>
                </div>
            </div>

            <div class="header-cart-footer">

                <div class="cart-total">
                    <div class="cart-total-price">
                        <div class="cart-total-price-left"><?php echo esc_html_e( 'Subtotal: ', 'crisop' ); ?></div>
                        <div class="cart-total-price-right"><?php printf( '%s', $woocommerce->cart->get_cart_subtotal() ); ?></div>
                    </div>
                </div>

                <?php do_action( 'woocommerce_widget_shopping_cart_before_buttons' ); ?>

                <div class="cart-bottom-btn">
                    <a class="ninetheme-btn-medium ninetheme-btn ninetheme-btn-yellow ninetheme-view-shop-link" href="<?php echo esc_url( apply_filters( 'woocommerce_return_to_shop_redirect', wc_get_page_permalink( 'shop' ) ) ); ?>"><?php esc_html_e( 'Continue Shopping', 'crisop' ); ?></a>
                    <a class="ninetheme-btn-medium ninetheme-btn ninetheme-btn-primary ninetheme-view-cart-link" href="<?php echo esc_url( wc_get_cart_url() ); ?>"><?php echo esc_html_e( 'View Cart', 'crisop' ); ?></a>
                    <a class="ninetheme-btn-medium ninetheme-btn ninetheme-btn-primary ninetheme-view-checkout-link" href="<?php echo esc_url( $checkout_url ); ?>"><?php echo esc_html_e( 'Checkout', 'crisop' ); ?></a>
                </div>

                <?php do_action( 'woocommerce_widget_shopping_cart_after_buttons' ); ?> 
            </div>
        </div>

    <?php else : ?>

        <div class="ninetheme-header-cart-details ninetheme-minicart">
            <div class="cart-empty-content">
                <?php echo ninetheme_svg_lists( 'bag' ); ?>
                <?php if ( '' != ninetheme_settings('sidebar_panel_cart_custom_title') ) { ?>
                    <span class="minicart-title"><?php echo esc_html( ninetheme_settings('sidebar_panel_cart_custom_title') ); ?></span>
                <?php } else { ?>
                    <span class="minicart-title"><?php esc_html_e( 'Your Cart', 'crisop' ); ?></span>
                <?php } ?>
                <p class="empty-title ninetheme-small-title"><?php esc_html_e( 'No products in the cart.', 'crisop' ); ?></p>

                <?php do_action( 'woocommerce_widget_shopping_cart_before_buttons' ); ?>

                <div class="cart-empty-actions cart-bottom-btn">
                    <a class="ninetheme-btn-medium ninetheme-btn ninetheme-btn-yellow" href="<?php echo esc_url( apply_filters( 'woocommerce_return_to_shop_redirect', wc_get_page_permalink( 'shop' ) ) ); ?>"><?php esc_html_e( 'Start Shopping', 'crisop' ); ?></a>
                    <a class="ninetheme-btn-medium ninetheme-btn ninetheme-btn-primary" href="<?php echo esc_url( get_permalink( get_option( 'wp_page_for_privacy_policy' ) ) ); ?>"><?php esc_html_e( 'Return Policy', 'crisop' ); ?></a>
                </div>
                <?php do_action( 'woocommerce_widget_shopping_cart_after_buttons' ); ?>
            </div>
        </div>

    <?php endif; ?>
</div>
<?php do_action( 'woocommerce_after_mini_cart' ); ?>
