<?php
/**
 * The Template for displaying all single products
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/single-product.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see         https://docs.woocommerce.com/document/template-structure/
 * @package     WooCommerce\Templates
 * @version     1.6.4
 */

get_header();

do_action( "ninetheme_before_wc_single" );

$is_elementor   = apply_filters('ninetheme_single_shop_elementor', ninetheme_settings( 'product_page_elementor', null ) );
$layout         = apply_filters('ninetheme_single_shop_layout', ninetheme_settings( 'single_shop_layout', 'full-width' ) );
$order_column   = 'right-sidebar' == $layout && is_active_sidebar( 'shop-single-sidebar' ) ? ' order-1' : ' order-1 order-lg-2';
$order_sidebar  = 'right-sidebar' == $layout && is_active_sidebar( 'shop-single-sidebar' ) ? ' order-2' : ' order-2 order-lg-1';
$sticky_sidebar = is_active_sidebar( 'shop-single-sidebar' ) && '1' == ninetheme_settings( 'single_shop_sticky_sidebar', '0' ) ? ' ninetheme-is-sticky' : '';
$bread_off      = '0' == ninetheme_settings( 'breadcrumbs_visibility', '1' ) || 'summary' == ninetheme_settings( 'single_shop_nav_bread_position', 'summary' ) ? ' ninetheme-bread-off' : '';
$column         = ( 'left-sidebar' == $layout || 'right-sidebar' == $layout ) && is_active_sidebar( 'shop-single-sidebar' ) ? 'col-lg-9 shop-has-sidebar ninetheme-sidebar-'.$layout.$order_column : 'col-lg-12';

wp_enqueue_style( 'fancybox' );
wp_enqueue_script( 'fancybox' );

// Elementor `single` location
if ( ! function_exists( 'elementor_theme_do_location' ) || ! elementor_theme_do_location( 'single' ) ) {

    if ( ninetheme_check_is_elementor() || $is_elementor ) {

        while ( have_posts() ) {

            the_post();
            $product = wc_get_product();
            ?>
            <div id="product-<?php the_ID(); ?>" <?php wc_product_class( '', $product ); ?>>
                <?php the_content(); ?>
            </div>
            <?php
        }

    } else {

        if ( 'stretch' == $layout ) {

            while ( have_posts() ) {
                the_post();
                wc_get_template_part( 'content', 'single-product-showcase-stretch' );
            }
            
        } elseif ( 'showcase' == $layout ) {

            while ( have_posts() ) {
                the_post();
                wc_get_template_part( 'content', 'single-product-showcase-full' );
            }

        } else {

            ?>
            <!-- WooCommerce product page container -->
            <div id="nt-woo-single" class="nt-woo-single">

                <div class="ninetheme-inner-container pt-30 pb-60">
                    <div class="container-xl ninetheme-container-xl">
                    
                        <?php if ( 'summary' != ninetheme_settings( 'single_shop_nav_bread_position', 'summary' ) || 'bottom' != ninetheme_settings( 'single_shop_nav_position', 'bottom' ) ) { ?>
                            <div class="row">
                                <div class="col-12">
                                    <div class="ninetheme-product-top-nav ninetheme-flex ninetheme-align-center<?php echo esc_attr( $bread_off ); ?>">
                                        <?php 
                                        if ( 'summary' != ninetheme_settings( 'single_shop_nav_bread_position', 'summary' ) ) {
                                            echo ninetheme_breadcrumbs();
                                        }
                                        ?>
                                        <?php ninetheme_single_product_nav_two(); ?>
                                    </div>
                                </div>
                            </div>
                        <?php } ?>
                        
                        <div class="row ninetheme-shop-single-row shop-layout-<?php echo esc_attr( $layout ); ?>">

                            <!-- Left sidebar -->
                            <?php
                            if ( ( 'right-sidebar' == $layout || 'left-sidebar' == $layout ) && is_active_sidebar( 'shop-single-sidebar' ) ) {
                                echo '<div id="nt-sidebar" class="nt-sidebar col-lg-3'.$order_sidebar.'">';
                                    echo '<div class="ninetheme-shop-sidebar nt-sidebar-inner'.$sticky_sidebar.'">';
                                        dynamic_sidebar( 'shop-single-sidebar' );
                                    echo '</div>';
                                echo '</div>';
                            }
                            ?>

                            <div class="<?php echo esc_attr( $column ); ?>">
                                <div class="content-container">

                                    <?php
                                    while ( have_posts() ) {
                                        the_post();
                                        wc_get_template_part( 'content', 'single-product' );
                                    }
                                    ?>

                                </div>
                            </div>

                        </div>
                    </div>
                </div>
            </div>
            <?php
        }
    }
}

do_action( "ninetheme_after_wc_single" );

get_footer();

?>
