<?php
/**
 * Variable product add to cart
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/single-product/add-to-cart/variable.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see https://docs.woocommerce.com/document/template-structure/
 * @package WooCommerce\Templates
 * @version 6.1.0
 */

defined( 'ABSPATH' ) || exit;

global $product;

$attribute_keys  = array_keys( $attributes );
$variations_json = wp_json_encode( $available_variations );
$variations_attr = function_exists( 'wc_esc_json' ) ? wc_esc_json( $variations_json ) : _wp_specialchars( $variations_json, ENT_QUOTES, 'UTF-8', true );

do_action( 'woocommerce_before_add_to_cart_form' ); ?>

<form class="ninetheme-summary-item ninetheme-flex variations_form cart" action="<?php echo esc_url( apply_filters( 'woocommerce_add_to_cart_form_action', $product->get_permalink() ) ); ?>" method="post" enctype='multipart/form-data' data-product_id="<?php echo absint( $product->get_id() ); ?>" data-product_variations="<?php echo esc_attr( $variations_attr ); // WPCS: XSS ok. ?>">
    <?php do_action( 'woocommerce_before_variations_form' ); ?>

    <?php if ( empty( $available_variations ) && false !== $available_variations ) : ?>
        <p class="stock out-of-stock"><?php echo esc_html( apply_filters( 'woocommerce_out_of_stock_message', __( 'This product is currently out of stock and unavailable.', 'crisop' ) ) ); ?></p>
    <?php else : ?>
        <div class="ninetheme-variations variations">
            <?php if ( '1' == ninetheme_settings('selected_variations_terms_visibility', '1' ) ) : ?>
                <div class="ninetheme-selected-variations-terms-wrapper">
                    <?php if ( '' != ninetheme_settings('selected_variations_terms_title', '' ) ) : ?>
                        <span class="ninetheme-selected-variations-terms-title"><?php echo ninetheme_settings('selected_variations_terms_title'); ?></span>
                    <?php else : ?>
                        <span class="ninetheme-selected-variations-terms-title"><?php esc_html_e( 'Selected Features', 'goldsmith' ); ?></span>
                    <?php endif; ?>
                    <div class="ninetheme-selected-variations-terms"></div>
                </div>
            <?php endif; ?>
            <?php foreach ( $attributes as $attribute_name => $options ) : ?>
                <div class="ninetheme-variations-items variations-items">
                    <div class="ninetheme-flex ninetheme-align-center">
                        <span class="ninetheme-small-title"><?php echo wc_attribute_label( $attribute_name ); // WPCS: XSS ok. ?></span>
                        <div class="ninetheme-flex value">
                            <?php
                            wc_dropdown_variation_attribute_options(
                                array(
                                    'options'   => $options,
                                    'attribute' => $attribute_name,
                                    'product'   => $product,
                                )
                            );
                            echo end( $attribute_keys ) === $attribute_name ? wp_kses_post( apply_filters( 'woocommerce_reset_variations_link', '<a class="ninetheme-btn-reset reset_variations" href="#">' . esc_html__( 'Clear', 'crisop' ) . '</a>' ) ) : '';
                            ?>
                        </div>
                    </div>
                </div>
            <?php endforeach; ?>
        </div>

        <?php do_action( 'woocommerce_after_variations_table' ); ?>

        <div class="single_variation_wrap">
            <?php
            /**
            * Hook: woocommerce_before_single_variation.
            */
            do_action( 'woocommerce_before_single_variation' );

            /**
            * Hook: woocommerce_single_variation. Used to output the cart button and placeholder for variation data.
            *
            * @since 2.4.0
            * @hooked woocommerce_single_variation - 10 Empty div for variation data.
            * @hooked woocommerce_single_variation_add_to_cart_button - 20 Qty and cart button.
            */
            do_action( 'woocommerce_single_variation' );

            /**
            * Hook: woocommerce_after_single_variation.
            */
           
            ?>
        </div>
    <?php endif; ?>

    <?php 
        do_action( 'woocommerce_after_single_variation' );
        do_action( 'woocommerce_after_variations_form' ); 
    ?>
</form>

<?php
do_action( 'woocommerce_after_add_to_cart_form' );
