<?php
/**
* Single Product Up-Sells
*
* This template can be overridden by copying it to yourtheme/woocommerce/single-product/up-sells.php.
*
* HOWEVER, on occasion WooCommerce will need to update template files and you
* (the theme developer) will need to copy the new files to your theme to
* maintain compatibility. We try to do this as little as possible, but it does
* happen. When this occurs the version of the template file will be bumped and
* the readme will list any important changes.
*
* @see         https://docs.woocommerce.com/document/template-structure/
* @package     WooCommerce\Templates
* @version     3.0.0
*/

if ( ! defined( 'ABSPATH' ) ) {
    exit;
}

$heading = ninetheme_settings( 'shop_upsells_title', '' );
$heading = $heading ? esc_html( $heading ) : apply_filters( 'woocommerce_product_upsells_products_heading', esc_html__( 'You may also like', 'crisop' ) );
$type    = apply_filters( 'ninetheme_wc_product_upsells_type', ninetheme_settings( 'shop_upsells_type', 'slider' ) );

if ( $upsells ) {

    if ( 'slider' == $type ) {
        $slider_options = json_encode(array(
            "loop"          => '1' == ninetheme_settings( 'shop_upsells_speed', '0' ) ? true : false,
            "speed"         => intval(ninetheme_settings( 'shop_upsells_speed', 800 )),
            "spaceBetween"  => intval(ninetheme_settings( 'shop_upsells_gap', 20 )),
            "slidesPerView" => 1,
            "grabCursor"    => true,
            "autoHeight"    => true,
            "watchSlidesProgress" => true,
            "autoplay"      => '1' == ninetheme_settings( 'shop_upsells_autoplay', 1 ) ? ["pauseOnMouseEnter"=> true,"disableOnInteraction"=> false] : false,
            "navigation"    => [
                "nextEl" => ".upsells-slider-nav .ninetheme-slide-next",
                "prevEl" => ".upsells-slider-nav .ninetheme-slide-prev"
            ],
            "breakpoints"   => [
                "0" => [
                    "slidesPerView" => intval(ninetheme_settings( 'shop_upsells_smperview', 2 ))
                ],
                "768" => [
                    "slidesPerView" => intval(ninetheme_settings( 'shop_upsells_mdperview', 3 ))
                ],
                "1024" => [
                    "slidesPerView" => intval(ninetheme_settings( 'shop_upsells_perview', 6 ))
                ]
            ]
        ));

        wp_enqueue_script( 'swiper' );
        ?>
        <div class="up-sells upsells ninetheme-section">
            <div class="section-title-wrapper">
                <?php if ( $heading ) : ?>
                    <h6 class="section-title"><?php echo esc_html( $heading ); ?></h6>
                <?php endif; ?>
                <div class="upsells-slider-nav slider-nav-top">
                    <div class="ninetheme-slide-prev swiper-button-prev"></div>
                    <div class="ninetheme-slide-next swiper-button-next"></div>
                </div>
            </div>
            <div class="ninetheme-wc-swipper-wrapper woocommerce style-1">
                <div class="ninetheme-upsells-slider swiper-container" data-swiper-options="<?php echo esc_attr( $slider_options ); ?>">
                    <div class="swiper-wrapper">

                        <?php foreach ( $upsells as $upsell ) : ?>
                            <div class="swiper-slide">
                                <?php
                                    $post_object = get_post( $upsell->get_id() );

                                    setup_postdata( $GLOBALS['post'] =& $post_object ); // phpcs:ignore WordPress.WP.GlobalVariablesOverride.Prohibited, Squiz.PHP.DisallowMultipleAssignments.Found

                                    wc_get_template_part( 'content', 'product' );
                                ?>
                            </div>

                        <?php endforeach; ?>
                    </div>
                </div>
            </div>
        </div>
        <?php
        wp_reset_postdata();

    } else {

    ?>
    <div class="up-sells upsells ninetheme-section">
        <?php
        if ( $heading ) {
            ?>
            <div class="section-title-wrapper">
                <h6 class="section-title"><?php echo esc_html( $heading ); ?></h6>
            </div>
            <?php
        }
        woocommerce_product_loop_start();

        foreach ( $upsells as $upsell ) {

            $post_object = get_post( $upsell->get_id() );

            setup_postdata( $GLOBALS['post'] =& $post_object ); // phpcs:ignore WordPress.WP.GlobalVariablesOverride.Prohibited, Squiz.PHP.DisallowMultipleAssignments.Found

            wc_get_template_part( 'content', 'product' );

        }

        woocommerce_product_loop_end();
        ?>
    </div>
    <?php
    }
}
wp_reset_postdata();
