<?php

if( !defined( 'ABSPATH' ) ) exit;

use Elementor\Utils;
use Elementor\Repeater;
use Elementor\Element_Base;
use Elementor\Elementor_Base;
use Elementor\Controls_Manager;
use Elementor\Core\Responsive\Responsive;
use Elementor\Widget_Base;
use Elementor\Group_Control_Background;
use Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Image_Size;

class Ninetheme_Section_Settings {

    private static $instance = null;

    public function __construct(){
        // section register settings
        add_action('elementor/element/section/section_structure/after_section_end',array($this,'lazyload_background_controls'), 10 );
        add_action('elementor/element/column/layout/after_section_end',array($this,'column_lazyload_background_controls'), 10 );
        add_action('elementor/element/section/section_structure/after_section_end',array($this,'section_parallax_controls'), 10 );
        //add_action('elementor/element/section/section_structure/after_section_end',array($this,'ninetheme_add_particle_effect_to_section'), 10 );
        add_action('elementor/element/section/section_structure/after_section_end',array($this,'ninetheme_add_vegas_slider_to_section'), 10 );
        add_action('elementor/element/section/section_layout/before_section_end',array($this,'register_change_section_indent_structure'), 10 );
        add_action('elementor/element/section/section_background_overlay/before_section_end',array($this,'register_add_section_overlay_width'), 10 );
        add_action('elementor/frontend/section/before_render',array($this,'ninetheme_custom_attr_to_section'), 10);
        add_action('elementor/frontend/column/before_render',array($this,'ninetheme_custom_attr_to_column'), 10);
        add_action('elementor/element/section/section_structure/before_section_end',array($this,'change_elementor_section_column_gap_default'), 10);

        // column register settings and before render column functions
        //add_action('elementor/element/column/layout/after_section_end',array($this,'add_tilt_effect_to_column'), 10 );
    }
    /*****   START PARALLAX CONTROLS   ******/
    public function change_elementor_section_column_gap_default( $element ) {
        
        $controls = $element->get_controls();
        $controls['gap']['default'] = 'extended';
        $element->update_control('gap', $controls['gap']);
    }
    /*****   START PARALLAX CONTROLS   ******/
    public function lazyload_background_controls( $element ) {
        
        $element->start_controls_section( 'ninetheme_lazyload_section',
            [
                'label' => esc_html__( 'Crisop LazyLoad Background', 'crisop' ),
                'tab' => Controls_Manager::TAB_LAYOUT
            ]
        );
        $element->add_responsive_control( 'ninetheme_lazy_bg_image',
            [
                'label' => esc_html__( 'Image', 'crisop' ),
                'type' => Controls_Manager::MEDIA
            ]
        );
        $element->add_group_control(
            Group_Control_Background::get_type(),
            [
                'name' => 'ninetheme_lazy_bg',
                'label' => esc_html__( 'Background', 'crisop' ),
                'types' => ['classic'],
                'exclude' => ['image']
            ]
        );
        $element->end_controls_section();
    }
    public function column_lazyload_background_controls( $element ) {
        
		$is_dome_optimization_active = \Elementor\Plugin::$instance->experiments->is_feature_active( 'e_dom_optimization' );
		$main_selector_element = $is_dome_optimization_active ? 'widget' : 'column';
        
        $element->start_controls_section( 'ninetheme_lazyload_section',
            [
                'label' => esc_html__( 'Crisop LazyLoad Background', 'crisop' ),
                'tab' => Controls_Manager::TAB_LAYOUT
            ]
        );
        $element->add_responsive_control( 'ninetheme_lazy_bg_image',
            [
                'label' => esc_html__( 'Image', 'crisop' ),
                'type' => Controls_Manager::MEDIA
            ]
        );
        $element->add_group_control(
            Group_Control_Background::get_type(),
            [
                'name' => 'ninetheme_lazy_bg',
                'label' => esc_html__( 'Background', 'crisop' ),
                'types' => ['classic'],
                'exclude' => ['image'],
				'selector' => '{{WRAPPER}}:not(.elementor-motion-effects-element-type-background) > .elementor-' . $main_selector_element . '-wrap, {{WRAPPER}} > .elementor-' . $main_selector_element . '-wrap > .elementor-motion-effects-container > .elementor-motion-effects-layer',
				'fields_options' => [
					'background' => [
						'frontend_available' => true,
					],
				],
            ]
        );
        $element->end_controls_section();
    }

    /*****   START PARALLAX CONTROLS   ******/
    public function section_parallax_controls( $element ) {
        
        $template = basename( get_page_template() );

        $element->start_controls_section( 'ninetheme_parallax_section',
            [
                'label' => esc_html__( 'Crisop Parallax', 'crisop' ),
                'tab' => Controls_Manager::TAB_LAYOUT
            ]
        );
        $element->add_control( 'ninetheme_parallax_switcher',
            [
                'label' => esc_html__( 'Enable Parallax', 'crisop' ),
                'type' => Controls_Manager::SWITCHER,
                'prefix_class' => 'ninetheme-parallax jarallax parallax-',
            ]
        );
        $element->add_control( 'ninetheme_parallax_update',
            [
                'label' => '<div class="elementor-update-preview" style="background-color: #fff;display: block;"><div class="elementor-update-preview-button-wrapper" style="display:block;"><button class="elementor-update-preview-button elementor-button elementor-button-success" style="background: #d30c5c; margin: 0 auto; display:block;">Apply Changes</button></div><div class="elementor-update-preview-title" style="display:block;text-align:center;margin-top: 10px;">Update changes to pages</div></div>',
                'type' => Controls_Manager::RAW_HTML,
                'condition' => ['ninetheme_parallax_switcher' => 'yes'],
            ]
        );
        $element->add_control( 'ninetheme_parallax_type',
            [
                'label' => esc_html__( 'Type', 'crisop' ),
                'type' => Controls_Manager::SELECT,
                'label_block' => 'true',
                'condition' => ['ninetheme_parallax_switcher' => 'yes'],
                'default' => 'scroll',
                'options' => [
                    'scroll' => esc_html__( 'Scroll', 'crisop' ),
                    'scroll-opacity' => esc_html__( 'Scroll with Opacity', 'crisop' ),
                    'opacity' => esc_html__( 'Fade', 'crisop' ),
                    'scale' => esc_html__( 'Zoom', 'crisop' ),
                    'scale-opacity' => esc_html__( 'Zoom with Fade', 'crisop' )
                ]
            ]
        );
        $element->add_control( 'ninetheme_parallax_bg_size',
            [
                'label' => esc_html__( 'Image Size', 'crisop' ),
                'type' => Controls_Manager::SELECT,
                'default' => 'auto',
                'condition' => ['ninetheme_parallax_switcher' => 'yes'],
                'options' => [
                    'auto' => esc_html__( 'Auto', 'crisop' ),
                    'cover' => esc_html__( 'Cover', 'crisop' ),
                    'contain' => esc_html__( 'Contain', 'crisop' )
                ]
            ]
        );
        $element->add_control( 'ninetheme_parallax_speed',
            [
                'label' => esc_html__( 'Parallax Speed', 'crisop' ),
                'type' => Controls_Manager::NUMBER,
                'min' => -1,
                'max' => 2,
                'step' => 0.1,
                'default' => 0.2,
                'condition' => ['ninetheme_parallax_switcher' => 'yes']
            ]
        );
        $element->add_control( 'ninetheme_parallax_mobile_support',
            [
                'label' => esc_html__( 'Parallax on Mobile Devices', 'crisop' ),
                'type' => Controls_Manager::SWITCHER,
                'prefix_class' => 'ninetheme-mobile-parallax-',
                'condition' => ['ninetheme_parallax_switcher' => 'yes']
            ]
        );
        $element->add_control( 'ninetheme_add_parallax_video',
            [
                'label' => esc_html__( 'Use Background Video', 'crisop' ),
                'type' => Controls_Manager::SWITCHER,
                'prefix_class' => 'ninetheme-parallax-video-',
                'condition' => ['ninetheme_parallax_switcher' => 'yes']
            ]
        );
        $element->add_control( 'ninetheme_local_video_format',
            [
                'label' => esc_html__( 'Video Format', 'crisop' ),
                'type' => Controls_Manager::SELECT,
                'label_block' => 'true',
                'default' => 'external',
                'options' => [
                    'external' => esc_html__( 'External (Youtube,Vimeo)', 'crisop' ),
                    'mp4' => esc_html__( 'Local MP4', 'crisop' ),
                    'webm' => esc_html__( 'Local Webm', 'crisop' ),
                    'ogv' => esc_html__( 'Local Ogv', 'crisop' ),
                ],
                'conditions' => [
                    'relation' => 'and',
                    'terms' => [
                        [
                            'name' => 'ninetheme_parallax_switcher',
                            'operator' => '==',
                            'value' => 'yes'
                        ],
                        [
                            'name' => 'ninetheme_add_parallax_video',
                            'operator' => '==', // it accepts:  =,==, !=,!==,  in, !in etc.
                            'value' => 'yes'
                        ]
                    ]
                ]
            ]
        );
        $element->add_control( 'ninetheme_parallax_video_url',
            [
                'label' => esc_html__( 'Video URL', 'crisop' ),
                'type' => Controls_Manager::TEXTAREA,
                'label_block' => true,
                'placeholder' => 'https://www.youtube.com/watch?v=AeeE6PyU-dQ',
                'description' => esc_html__( 'YouTube/Vimeo link, or link to video file (mp4 is recommended).', 'crisop' ),
                'conditions' => [
                    'relation' => 'and',
                    'terms' => [
                        [
                            'name' => 'ninetheme_parallax_switcher',
                            'operator' => '==',
                            'value' => 'yes'
                        ],
                        [
                            'name' => 'ninetheme_add_parallax_video',
                            'operator' => '==', // it accepts:  =,==, !=,!==,  in, !in etc.
                            'value' => 'yes'
                        ]
                    ]
                ]
            ]
        );
        $element->add_control( 'ninetheme_parallax_video_start_time',
            [
                'label' => esc_html__( 'Start Time', 'crisop' ),
                'type' => Controls_Manager::NUMBER,
                'min' => 0,
                'placeholder' => '10',
                'conditions' => [
                    'relation' => 'and',
                    'terms' => [
                        [
                            'name' => 'ninetheme_parallax_switcher',
                            'operator' => '==',
                            'value' => 'yes'
                        ],
                        [
                            'name' => 'ninetheme_add_parallax_video',
                            'operator' => '==', // it accepts:  =,==, !=,!==,  in, !in etc.
                            'value' => 'yes'
                        ]
                    ]
                ]
            ]
        );
        $element->add_control( 'ninetheme_parallax_video_end_time',
            [
                'label' => esc_html__( 'End Time', 'crisop' ),
                'type' => Controls_Manager::NUMBER,
                'min' => 0,
                'placeholder' => '70',
                'conditions' => [
                    'relation' => 'and',
                    'terms' => [
                        [
                            'name' => 'ninetheme_parallax_switcher',
                            'operator' => '==',
                            'value' => 'yes'
                        ],
                        [
                            'name' => 'ninetheme_add_parallax_video',
                            'operator' => '==', // it accepts:  =,==, !=,!==,  in, !in etc.
                            'value' => 'yes'
                        ]
                    ]
                ]
            ]
        );
        $element->add_control( 'ninetheme_parallax_video_volume',
            [
                'label' => esc_html__( 'Video Volume', 'crisop' ),
                'type' => Controls_Manager::NUMBER,
                'min' => 0,
                'max' => 100,
                'step' => 1,
                'default' => '',
                'placeholder' => '0',
                'conditions' => [
                    'relation' => 'and',
                    'terms' => [
                        [
                            'name' => 'ninetheme_parallax_switcher',
                            'operator' => '==',
                            'value' => 'yes'
                        ],
                        [
                            'name' => 'ninetheme_add_parallax_video',
                            'operator' => '==', // it accepts:  =,==, !=,!==,  in, !in etc.
                            'value' => 'yes'
                        ]
                    ]
                ]
            ]
        );
        $element->add_control( 'ninetheme_parallax_video_play_once',
            [
                'label' => esc_html__( 'Play Once', 'crisop' ),
                'type' => Controls_Manager::SWITCHER,
                'label_on' => esc_html__( 'Yes', 'crisop' ),
                'label_off' => esc_html__( 'No', 'crisop' ),
                'return_value' => 'yes',
                'default' => 'no',
                'conditions' => [
                    'relation' => 'and',
                    'terms' => [
                        [
                            'name' => 'ninetheme_parallax_switcher',
                            'operator' => '==',
                            'value' => 'yes'
                        ],
                        [
                            'name' => 'ninetheme_add_parallax_video',
                            'operator' => '==', // it accepts:  =,==, !=,!==,  in, !in etc.
                            'value' => 'yes'
                        ]
                    ]
                ]
            ]
        );
        $element->end_controls_section();
    }

    /*****   START COLUMN CONTROLS   ******/
    public function add_tilt_effect_to_column( $element ) {
        $element->start_controls_section( 'ninetheme_tilt_effect_section',
            [
                'label' => esc_html__( 'Crisop Tilt Effect', 'crisop' ),
                'tab' => Controls_Manager::TAB_LAYOUT,
            ]
        );
        $element->add_control( 'ninetheme_tilt_effect_switcher',
            [
                'label' => esc_html__( 'Enable Tilt Effect', 'crisop' ),
                'type' => Controls_Manager::SWITCHER,
                'description' => esc_html__( 'You can use this option if you want to use tilt effect for the elementor heading and image in the column when the mouse is over the column.', 'crisop' ),
            ]
        );
        $element->add_control( 'ninetheme_tilt_effect_maxtilt',
            [
                'label' => esc_html__( 'Max Tilt', 'crisop' ),
                'type' => Controls_Manager::NUMBER,
                'min' => 0,
                'max' => 500,
                'step' => 1,
                'default' => 20,
                'condition' => ['ninetheme_tilt_effect_switcher' => 'yes']
            ]
        );
        $element->add_control( 'ninetheme_tilt_effect_perspective',
            [
                'label' => esc_html__( 'Perspective', 'crisop' ),
                'type' => Controls_Manager::NUMBER,
                'min' => 0,
                'max' => 10000,
                'step' => 100,
                'default' => 1000,
                'description' => esc_html__( 'Transform perspective, the lower the more extreme the tilt gets.', 'crisop' ),
                'condition' => ['ninetheme_tilt_effect_switcher' => 'yes']
            ]
        );
        $element->add_control( 'ninetheme_tilt_effect_easing',
            [
                'label' => esc_html__( 'Custom Easing', 'crisop' ),
                'type' => Controls_Manager::TEXT,
                'placeholder' => 'cubic-bezier(.03,.98,.52,.99)',
                'label_block' => true,
                'condition' => ['ninetheme_tilt_effect_switcher' => 'yes']
            ]
        );
        $element->add_control( 'ninetheme_tilt_effect_scale',
            [
                'label' => esc_html__( 'Scale', 'crisop' ),
                'type' => Controls_Manager::NUMBER,
                'min' => 0,
                'max' => 10,
                'step' => 1,
                'default' => 1,
                'description' => esc_html__( '2 = 200%, 1.5 = 150%, etc..', 'crisop' ),
                'condition' => ['ninetheme_tilt_effect_switcher' => 'yes']
            ]
        );
        $element->add_control( 'ninetheme_tilt_effect_speed',
            [
                'label' => esc_html__( 'Speed', 'crisop' ),
                'type' => Controls_Manager::NUMBER,
                'min' => 0,
                'max' => 5000,
                'step' => 10,
                'default' => 300,
                'description' => esc_html__( 'Speed of the enter/exit transition.', 'crisop' ),
                'condition' => ['ninetheme_tilt_effect_switcher' => 'yes']
            ]
        );
        $element->add_control( 'ninetheme_tilt_effect_transition',
            [
                'label' => esc_html__( 'Transition', 'crisop' ),
                'type' => Controls_Manager::SWITCHER,
                'description' => esc_html__( 'Set a transition on enter/exit.', 'crisop' ),
                'condition' => ['ninetheme_tilt_effect_switcher' => 'yes']
            ]
        );
        $element->add_control( 'ninetheme_tilt_effect_disableaxis',
            [
                'label' => esc_html__( 'Disable Axis', 'crisop' ),
                'description' => esc_html__( 'What axis should be disabled. Can be X or Y.', 'crisop' ),
                'type' => Controls_Manager::SELECT,
                'default' => '',
                'options' => [
                    '' => esc_html__( 'None', 'crisop' ),
                    'vertical' => esc_html__( 'X Axis', 'crisop' ),
                    'horizontal' => esc_html__( 'Y Axis', 'crisop' ),
                ],
                'condition' => [ 'ninetheme_tilt_effect_switcher' => 'yes' ],
            ]
        );
        $element->add_control( 'ninetheme_tilt_effect_reset',
            [
                'label' => esc_html__( 'Reset', 'crisop' ),
                'description' => esc_html__( 'If the tilt effect has to be reset on exit.', 'crisop' ),
                'type' => Controls_Manager::SWITCHER,
                'condition' => ['ninetheme_tilt_effect_switcher' => 'yes']
            ]
        );
        $element->add_control( 'ninetheme_tilt_effect_glare',
            [
                'label' => esc_html__( 'Glare Effect', 'crisop' ),
                'description' => esc_html__( 'Enables glare effect', 'crisop' ),
                'type' => Controls_Manager::SWITCHER,
                'condition' => ['ninetheme_tilt_effect_switcher' => 'yes']
            ]
        );
        $element->add_control( 'ninetheme_tilt_effect_maxglare',
            [
                'label' => esc_html__( 'Max Glare', 'crisop' ),
                'type' => Controls_Manager::NUMBER,
                'min' => 0,
                'max' => 1,
                'step' => 0.1,
                'default' => 1,
                'description' => esc_html__( 'From 0 - 1.', 'crisop' ),
                'conditions' => [
                    'relation' => 'and',
                    'terms' => [
                        [
                            'name' => 'ninetheme_tilt_effect_switcher',
                            'operator' => '==',
                            'value' => 'yes'
                        ],
                        [
                            'name' => 'ninetheme_tilt_effect_glare',
                            'operator' => '==',
                            'value' => 'yes'
                        ]
                    ]
                ]
            ]
        );
        $element->add_group_control(
            Group_Control_Background::get_type(),
            [
                'name' => 'ninetheme_tilt_effect_glareclr',
                'label' => esc_html__( 'Background', 'crisop' ),
                'types' => ['gradient'],
                'selector' => '{{WRAPPER}} .js-tilt-glare-inner',
                'conditions' => [
                    'relation' => 'and',
                    'terms' => [
                        [
                            'name' => 'ninetheme_tilt_effect_switcher',
                            'operator' => '==',
                            'value' => 'yes'
                        ],
                        [
                            'name' => 'ninetheme_tilt_effect_glare',
                            'operator' => '==',
                            'value' => 'yes'
                        ]
                    ]
                ]
            ]
        );
        $element->end_controls_section();
    }
    /*****   END COLUMN CONTROLS   ******/

    /*****   START CONTROLS SECTION   ******/
    public function register_change_section_indent_structure( $element ) {
        $breakpoints = \Elementor\Plugin::$instance->breakpoints->get_active_breakpoints();
        if ( !empty( $breakpoints ) ) {
            $breakpoints = array_reverse($breakpoints);
            $databg = [];
            foreach ( $breakpoints as $point ) {
                $label = strtolower( $point->get_label() );
                $databg[$point->get_value()] = $point->get_label();
            }
        }
        $element->add_control( 'ninetheme_custom_header_type',
            [
                'label' => esc_html__( 'Header Type', 'crisop' ),
                'type' => Controls_Manager::SELECT,
                'label_block' => 'true',
                'prefix_class' => 'ninetheme-elementor-header-',
                'options' => [
                    'desktop' => esc_html__( 'Desktop Main Header', 'crisop' ),
                    'mobile' => esc_html__( 'Mobile Header', 'crisop' ),
                    'mobile-menu' => esc_html__( 'Mobile Menu', 'crisop' )
                ],
                'condition' => [
                    'html_tag' => [ 'nav','header' ]
                ]
            ]
        );
        $element->add_control( 'ninetheme_custom_mobile_header_breakpoint',
            [
                'label' => esc_html__( 'Mobile Header/Menu Breakpoint', 'crisop' ),
                'type' => Controls_Manager::SELECT,
                'label_block' => 'true',
                'prefix_class' => 'ninetheme-elementor-mobile-header-',
                'options' => $databg,
                'condition' => [
                    'html_tag' => [ 'nav','header' ],
                    'ninetheme_custom_header_type' => [ 'mobile','mobile-menu' ]
                ]
            ]
        );
        $element->add_control( 'ninetheme_make_fixed_section_switcher',
            [
                'label' => esc_html__( 'Sticky On Scroll', 'crisop' ),
                'type' => Controls_Manager::SWITCHER,
                'default' => 'no',
                'prefix_class' => 'ninetheme-section-sticky-',
                'condition' => [
                    'html_tag' => [ 'nav','header' ]
                ]
            ]
        );
        $element->add_group_control(
            Group_Control_Box_Shadow::get_type(),
            [
                'name' => 'ninethem_fixed_section_box_shadow',
                'label' => esc_html__( 'Box Shadow', 'crisop' ),
                'selector' => 'body.scroll-start {{WRAPPER}}.ninetheme-section-sticky-yes',
                'condition' => [
                    'html_tag' => [ 'nav','header' ],
                    'ninetheme_make_fixed_section_switcher' => 'yes'
                ]
            ]
        );
        $element->add_control( 'ninetheme_section_indent',
            [
                'label' => esc_html__( 'Section Indent', 'crisop' ),
                'type' => Controls_Manager::SELECT,
                'label_block' => 'true',
                'default' => '',
                'prefix_class' => 'nt-section ',
                'separator' => 'before',
                'options' => [
                    '' => esc_html__( 'Default', 'crisop' ),
                    'section-padding' => esc_html__( 'Indent Top and Bottom', 'crisop' ),
                    'section-padding pt-0' => esc_html__( 'Indent Bottom No Top', 'crisop' ),
                    'section-padding pb-0' => esc_html__( 'Indent Top No Bottom', 'crisop' ),
                ]
            ]
        );
    }

    /*****   START CONTROLS SECTION   ******/
    public function register_add_section_overlay_width( $element )
    {
        $element->add_responsive_control( 'ninetheme_section_overlay_width',
            [
                'label' => esc_html__( 'Crisop Overlay Width', 'crisop' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => [ 'px', '%' ],
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 4000,
                        'step' => 5
                    ],
                    '%' => [
                        'min' => 0,
                        'max' => 100
                    ]
                ],
                'default' => [
                    'unit' => '%',
                    'size' => 100
                ],
                'selectors' => [
                    '{{WRAPPER}} .elementor-background-overlay' => 'width: {{SIZE}}{{UNIT}};',
                ],
                'separator' => 'before'
            ]
        );

        $element->add_responsive_control( 'ninetheme_section_overlay_height',
            [
                'label' => esc_html__( 'Crisop Overlay Height', 'crisop' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => [ 'px', '%' ],
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 4000,
                        'step' => 5
                    ],
                    '%' => [
                        'min' => 0,
                        'max' => 100
                    ]
                ],
                'default' => [
                    'unit' => '%',
                    'size' => 100
                ],
                'selectors' => [
                    '{{WRAPPER}} .elementor-background-overlay' => 'height: {{SIZE}}{{UNIT}};',
                ],
                'separator' => 'before'
            ]
        );
    }

    // Registering Controls
    public function ninetheme_add_particle_effect_to_section( $element ) {
        $element->start_controls_section('ninetheme_particles_settings',
            [
                'label' => esc_html__( 'Crisop Particles Effect', 'crisop' ),
                'tab' => Controls_Manager::TAB_LAYOUT,
            ]
        );
        $element->add_control( 'ninetheme_particles_type',
            [
                'label' => esc_html__( 'Type', 'crisop' ),
                'type' => Controls_Manager::SELECT,
                'default' => 'none',
                'options' => [
                    'none' => esc_html__( 'None', 'crisop' ),
                    'default' => esc_html__( 'default', 'crisop' ),
                    'nasa' => esc_html__( 'nasa', 'crisop' ),
                    'bubble' => esc_html__( 'bubble', 'crisop' ),
                    'snow' => esc_html__( 'snow', 'crisop' ),
                ]
            ]
        );
        $element->add_control( 'ninetheme_particles_options_heading',
            [
                'label' => esc_html__( 'Particles Options', 'crisop' ),
                'type' => Controls_Manager::HEADING,
                'separator' => 'before',
                'condition' => ['ninetheme_particles_type!' => 'none']
            ]
        );

        $element->add_control( 'ninetheme_particles_shape',
            [
                'label' => esc_html__( 'Shape Type', 'crisop' ),
                'type' => Controls_Manager::SELECT,
                'default' => 'circle',
                'options' => [
                    'circle' => esc_html__( 'circle', 'crisop' ),
                    'edge' => esc_html__( 'edge', 'crisop' ),
                    'triangle' => esc_html__( 'triangle', 'crisop' ),
                    'polygon' => esc_html__( 'polygon', 'crisop' ),
                    'star' => esc_html__( 'star', 'crisop' ),
                ],
                'condition' => ['ninetheme_particles_type!' => 'none']
            ]
        );
        $element->add_control( 'ninetheme_particles_number',
            [
                'label' => esc_html__( 'Number', 'crisop' ),
                'type' => Controls_Manager::NUMBER,
                'default' => 60,
                'condition' => ['ninetheme_particles_type!' => 'none']
            ]
        );
        $element->add_control( 'ninetheme_particles_color',
            [
                'label' => esc_html__( 'Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '#fff',
                'condition' => ['ninetheme_particles_type!' => 'none']
            ]
        );
        $element->add_control( 'ninetheme_particles_opacity',
            [
                'label' => esc_html__( 'Opacity', 'crisop' ),
                'type' => Controls_Manager::NUMBER,
                'min' => 0.1,
                'max' => 1,
                'step' => 0.1,
                'default' => 0.4,
                'condition' => ['ninetheme_particles_type!' => 'none']
            ]
        );
        $element->add_control( 'ninetheme_particles_size',
            [
                'label' => esc_html__( 'Size', 'crisop' ),
                'type' => Controls_Manager::NUMBER,
                'min' => 1,
                'max' => 1000,
                'step' => 1,
                'default' => 6,
                'condition' => ['ninetheme_particles_type!' => 'none']
            ]
        );
        $element->end_controls_section();
    }

    // Registering Controls
    public function ninetheme_add_vegas_slider_to_section( $element ) {
        $element->start_controls_section('ninetheme_vegas_settings',
            [
                'label' => esc_html__( 'Crisop Vegas Slider', 'crisop' ),
                'tab' => Controls_Manager::TAB_LAYOUT,
            ]
        );
        $element->add_control( 'ninetheme_vegas_switcher',
            [
                'label' => esc_html__( 'Enable Background Slider', 'crisop' ),
                'type' => Controls_Manager::SWITCHER,
            ]
        );
        $element->add_control( 'ninetheme_vegas_images',
            [
                'label' => __( 'Add Images', 'crisop' ),
                'type' => Controls_Manager::GALLERY,
                'default' => [],
                'condition' => ['ninetheme_vegas_switcher' => 'yes']
            ]
        );
        $element->add_control( 'ninetheme_vegas_options_heading',
            [
                'label' => esc_html__( 'Slider Options', 'crisop' ),
                'type' => Controls_Manager::HEADING,
                'separator' => 'before',
                'condition' => ['ninetheme_vegas_images!' => '']
            ]
        );
        $element->add_control( 'ninetheme_vegas_animation_type',
            [
                'label' => esc_html__( 'Animation Type', 'crisop' ),
                'type' => Controls_Manager::SELECT2,
                'multiple' => true,
                'default' => ['kenburns'],
                'options' => [
                    'kenburns' => esc_html__( 'kenburns', 'crisop' ),
                    'kenburnsUp' => esc_html__( 'kenburnsUp', 'crisop' ),
                    'kenburnsDown' => esc_html__( 'kenburnsDown', 'crisop' ),
                    'kenburnsLeft' => esc_html__( 'kenburnsLeft', 'crisop' ),
                    'kenburnsRight' => esc_html__( 'kenburnsRight', 'crisop' ),
                    'kenburnsUpLeft' => esc_html__( 'kenburnsUpLeft', 'crisop' ),
                    'kenburnsUpRight' => esc_html__( 'kenburnsUpRight', 'crisop' ),
                    'kenburnsDownLeft' => esc_html__( 'kenburnsDownLeft', 'crisop' ),
                    'kenburnsDownRight' => esc_html__( 'kenburnsDownRight', 'crisop' ),
                ],
                'condition' => ['ninetheme_vegas_switcher' => 'yes']
            ]
        );
        $element->add_control( 'ninetheme_vegas_transition_type',
            [
                'label' => esc_html__( 'Transition Type', 'crisop' ),
                'type' => Controls_Manager::SELECT2,
                'multiple' => true,
                'default' => ['zoomIn','slideLeft','slideRight'],
                'options' => [
                    'fade' => esc_html__( 'fade', 'crisop' ),
                    'fade2' => esc_html__( 'fade2', 'crisop' ),
                    'slideLeft' => esc_html__( 'slideLeft', 'crisop' ),
                    'slideLeft2' => esc_html__( 'slideLeft2', 'crisop' ),
                    'slideRight' => esc_html__( 'slideRight', 'crisop' ),
                    'slideRight2' => esc_html__( 'slideRight2', 'crisop' ),
                    'slideUp' => esc_html__( 'slideUp', 'crisop' ),
                    'slideUp2' => esc_html__( 'slideUp2', 'crisop' ),
                    'slideDown' => esc_html__( 'slideDown', 'crisop' ),
                    'slideDown2' => esc_html__( 'slideDown2', 'crisop' ),
                    'zoomIn' => esc_html__( 'zoomIn', 'crisop' ),
                    'zoomIn2' => esc_html__( 'zoomIn2', 'crisop' ),
                    'zoomOut' => esc_html__( 'zoomOut', 'crisop' ),
                    'zoomOut2' => esc_html__( 'zoomOut2', 'crisop' ),
                    'swirlLeft' => esc_html__( 'swirlLeft', 'crisop' ),
                    'swirlLeft2' => esc_html__( 'swirlLeft2', 'crisop' ),
                    'swirlRight' => esc_html__( 'swirlRight', 'crisop' ),
                    'swirlRight2' => esc_html__( 'swirlRight2', 'crisop' ),
                    'burn' => esc_html__( 'burn', 'crisop' ),
                    'burn2' => esc_html__( 'burn2', 'crisop' ),
                    'blur' => esc_html__( 'blur', 'crisop' ),
                    'blur2' => esc_html__( 'blur2', 'crisop' ),
                    'flash' => esc_html__( 'flash', 'crisop' ),
                    'flash2' => esc_html__( 'flash2', 'crisop' ),
                ],
                'condition' => ['ninetheme_vegas_switcher' => 'yes']
            ]
        );
        $element->add_control( 'ninetheme_vegas_overlay_type',
            [
                'label' => esc_html__( 'Overlay Image Type', 'crisop' ),
                'type' => Controls_Manager::SELECT,
                'default' => '',
                'prefix_class' => 'ninetheme-vegas-overlay vegas-overlay-',
                'options' => [
                    'none' => esc_html__( 'None', 'crisop' ),
                    '01' => esc_html__( 'Overlay 1', 'crisop' ),
                    '02' => esc_html__( 'Overlay 2', 'crisop' ),
                    '03' => esc_html__( 'Overlay 3', 'crisop' ),
                    '04' => esc_html__( 'Overlay 4', 'crisop' ),
                    '05' => esc_html__( 'Overlay 5', 'crisop' ),
                    '06' => esc_html__( 'Overlay 6', 'crisop' ),
                    '07' => esc_html__( 'Overlay 7', 'crisop' ),
                    '08' => esc_html__( 'Overlay 8', 'crisop' ),
                    '09' => esc_html__( 'Overlay 9', 'crisop' ),
                ],
                'condition' => ['ninetheme_vegas_switcher' => 'yes']
            ]
        );
        $element->add_control( 'ninetheme_vegas_delay',
            [
                'label' => esc_html__( 'Delay', 'crisop' ),
                'type' => Controls_Manager::NUMBER,
                'default' => 7000,
                'condition' => ['ninetheme_vegas_switcher' => 'yes']
            ]
        );
        $element->add_control( 'ninetheme_vegas_duration',
            [
                'label' => esc_html__( 'Transition Duration', 'crisop' ),
                'type' => Controls_Manager::NUMBER,
                'default' => 2000,
                'condition' => ['ninetheme_vegas_switcher' => 'yes']
            ]
        );
        $element->add_control( 'ninetheme_vegas_shuffle',
            [
                'label' => esc_html__( 'Enable Shuffle', 'crisop' ),
                'type' => Controls_Manager::SWITCHER,
                'condition' => ['ninetheme_vegas_switcher' => 'yes']
            ]
        );
        $element->add_control( 'ninetheme_vegas_timer',
            [
                'label' => esc_html__( 'Enable Timer', 'crisop' ),
                'type' => Controls_Manager::SWITCHER,
                'condition' => ['ninetheme_vegas_switcher' => 'yes'],
                'selectors' => ['{{WRAPPER}} .vegas-timer' => 'display:block!important;'],
            ]
        );
        $element->add_control( 'ninetheme_vegas_timer_size',
            [
                'label' => esc_html__( 'Timer Height', 'crisop' ),
                'type' => Controls_Manager::NUMBER,
                'min' => 0,
                'max' => 100,
                'step' => 1,
                'default' => 5,
                'selectors' => ['{{WRAPPER}} .vegas-timer' => 'height:{{VALUE}};'],
                'conditions' => [
                    'relation' => 'and',
                    'terms' => [
                        [
                            'name' => 'ninetheme_vegas_switcher',
                            'operator' => '==',
                            'value' => 'yes'
                        ],
                        [
                            'name' => 'ninetheme_vegas_timer',
                            'operator' => '==',
                            'value' => 'yes'
                        ]
                    ]
                ]
            ]
        );
        $element->add_control( 'ninetheme_vegas_timer_color',
            [
                'label' => esc_html__( 'Timer Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '#000',
                'selectors' => ['{{WRAPPER}} .vegas-timer-progress' => 'background-color:{{VALUE}};'],
                'conditions' => [
                    'relation' => 'and',
                    'terms' => [
                        [
                            'name' => 'ninetheme_vegas_switcher',
                            'operator' => '==',
                            'value' => 'yes'
                        ],
                        [
                            'name' => 'ninetheme_vegas_timer',
                            'operator' => '==',
                            'value' => 'yes'
                        ]
                    ]
                ]
            ]
        );
        $element->end_controls_section();
    }

    public function ninetheme_custom_attr_to_column( $element ) {
        $data     = $element->get_data();
        $type     = $data['elType'];
        $settings = $data['settings'];
        $isInner  = $data['isInner'];// inner section
        
		$is_dom_optimization_active = \Elementor\Plugin::$instance->experiments->is_feature_active( 'e_dom_optimization' );
		$wrapper_attribute_string = $is_dom_optimization_active ? '_widget_wrapper' : '_inner_wrapper';
        
        // Section LazyLoad Bg image
        $wrapper = 'column' === $type ? '_widget_wrapper' : '_wrapper';
        $deskbg = $element->get_settings('ninetheme_lazy_bg_image');

        if ( !empty( $deskbg['url'] ) ) {
            
            $element->add_render_attribute( $wrapper_attribute_string, 'data-bg', $deskbg['url']);
        }
        
        $breakpoints = \Elementor\Plugin::$instance->breakpoints->get_active_breakpoints();
        if ( !empty( $breakpoints ) ) {
            $breakpoints = array_reverse($breakpoints);
            if ( !empty( $deskbg['url'] ) ) {
                $databg['desktop'] = $deskbg['url'];
            }
            foreach ( $breakpoints as $point ) {
                $label = strtolower( $point->get_label() );
                $resbg = $element->get_settings('ninetheme_lazy_bg_image_'.$label);
                if ( !empty( $resbg['url'] ) ) {
                    $databg[$label] = $resbg['url'];
                }
            }
            if ( !empty( $databg ) ) {
                $element->add_render_attribute( '_widget_wrapper', 'data-bg-responsive', json_encode($databg));
            }
        }
    }
    
    public function ninetheme_custom_attr_to_section( $element ) {
        $data     = $element->get_data();
        $type     = $data['elType'];
        $settings = $data['settings'];
        $isInner  = $data['isInner'];// inner section

        $template = basename( get_page_template() );
        
        if ( 'section' === $element->get_name() ) {
            // Section LazyLoad Bg image
            $wrapper         = 'column' === $type ? ' _widget_wrapper' : '_wrapper';
            $deskbg          = $element->get_settings('ninetheme_lazy_bg_image');
            $data_breakpoint = $element->get_settings('ninetheme_custom_mobile_header_breakpoint');
            $header_type     = $element->get_settings('ninetheme_custom_header_type');
            $html_tag        = $element->get_settings('html_tag');
            
            if ( 'header' == $html_tag || 'nav' == $html_tag ) {
                if ( 'desktop' != $header_type && !empty( $data_breakpoint ) ) {
                    $data_breakpoint = $data_breakpoint ? $data_breakpoint : 1280;
                    $element->add_render_attribute( $wrapper, 'data-header-mobile-breakpoint', $data_breakpoint);
                    $element->add_render_attribute( $wrapper, 'class', 'hidden-on-dektop' );
                }
                if ( 'mobile-menu' == $header_type ) {
                    $element->add_render_attribute( $wrapper, 'class', 'ninetheme-scrollbar' );
                }
                if ( 'desktop' == $header_type ) {
                    $element->add_render_attribute( $wrapper, 'class', 'hidden-on-mobile' );
                }
            }
            
            if ( !empty( $deskbg['url'] ) ) {
                
                $element->add_render_attribute( $wrapper, 'data-bg', $deskbg['url']);
                $element->add_render_attribute( $wrapper, 'data-bg', $deskbg['url']);
            }
            
            $breakpoints = \Elementor\Plugin::$instance->breakpoints->get_active_breakpoints();
            if ( !empty( $breakpoints ) ) {
                $breakpoints = array_reverse($breakpoints);
                if ( !empty( $deskbg['url'] ) ) {
                    $databg['desktop'] = $deskbg['url'];
                }
                foreach ( $breakpoints as $point ) {
                    $label = strtolower( $point->get_label() );
                    $resbg = $element->get_settings('ninetheme_lazy_bg_image_'.$label);
                    if ( !empty( $resbg['url'] ) ) {
                        $databg[$label] = $resbg['url'];
                    }
                }
                if ( !empty( $databg ) ) {
                    $element->add_render_attribute( $wrapper, 'data-bg-responsive', json_encode($databg));
                }
            }
        }
        
        if ( 'section' === $element->get_name() ) {
            $gap = $element->get_settings('gap');
            $element->add_render_attribute( 'wrapper', 'class', $element->get_settings('ninetheme_section_indent') );
            $element->add_render_attribute( '_wrapper', 'class', 'gap-'.$gap );

            // Vegas Slider Options
            if ( 'yes' === $element->get_settings('ninetheme_vegas_switcher') ) {
                $delay = $element->get_settings('ninetheme_vegas_delay');
                $duration = $element->get_settings('ninetheme_vegas_duration');
                $timer = $element->get_settings('ninetheme_vegas_timer');
                $shuffle = $element->get_settings('ninetheme_vegas_shuffle');
                $overlay = $element->get_settings('ninetheme_vegas_overlay_type');
                $images = $element->get_settings('ninetheme_vegas_images');

                $transitions = $element->get_settings('ninetheme_vegas_transition_type');
                $transition = array();
                foreach ( $transitions as $trans ) {
                    $transition[] =  '"'.$trans.'"';
                }
                $transition = implode(',', $transition);

                $animations = $element->get_settings('ninetheme_vegas_animation_type');
                $animation = array();
                foreach ( $animations as $anim ) {
                    $animation[] =  '"'.$anim.'"';
                }
                $animation = implode(',', $animation);

                $slides = array();
                foreach ( $images as $image ) {
                    $slides[] =  '{"src":"'.$image['url'].'"}';
                }

                $element->add_render_attribute( '_wrapper', 'data-vegas-settings',  '{"slides":['.implode(',', $slides).'],"animation":['.$animation.'],"transition":['.$transition.'],"delay":'.$delay.',"duration":'.$duration.',"timer":"'.$timer.'","shuffle":"'.$shuffle.'","overlay":"'.$overlay.'"}' );

                $element->add_render_attribute( '_wrapper', 'data-vegas-id', $data['id'] );

            }

            // Parallax Effect Options
            if ( 'yes' === $element->get_settings('ninetheme_parallax_switcher') && $template != 'locomotive-page.php' ) {

                // Parallax attr
                $type = $element->get_settings('ninetheme_parallax_type');
                $speed = $element->get_settings('ninetheme_parallax_speed');
                $bgsize = $element->get_settings('ninetheme_parallax_bg_size');
                $mobile = $element->get_settings('ninetheme_parallax_mobile_support');
                $bgimg = $element->get_settings('background_image');
                $bgimg = $bgimg['url'];

                if ( 'yes' === $element->get_settings('ninetheme_add_parallax_video') && $element->get_settings('ninetheme_parallax_video_url') ) {

                    if ( 'mp4' === $element->get_settings('ninetheme_local_video_format')) {
                        $videosrc = 'mp4:'.$element->get_settings('ninetheme_parallax_video_url');
                    } elseif ( 'webm' === $element->get_settings('ninetheme_local_video_format')) {
                        $videosrc = 'webm:'.$element->get_settings('ninetheme_parallax_video_url');
                    } elseif ( 'ogv' === $element->get_settings('ninetheme_local_video_format')) {
                        $videosrc = 'ogv:'.$element->get_settings('ninetheme_parallax_video_url');
                    } else {
                        //$settings['background_video_link'] // elementor background video link
                        $videosrc = $element->get_settings('ninetheme_parallax_video_url');
                    }

                    $element->add_render_attribute( '_wrapper', 'data-jarallax data-video-src', $videosrc);

                    if ( $element->get_settings('ninetheme_parallax_video_start_time') ) {
                        $element->add_render_attribute( '_wrapper', 'data-video-start-time', $element->get_settings('ninetheme_parallax_video_start_time'));
                    }
                    if ( $element->get_settings('ninetheme_parallax_video_end_time') ) {
                        $element->add_render_attribute( '_wrapper', 'data-video-end-time', $element->get_settings('ninetheme_parallax_video_end_time'));
                    }
                    if ( 'yes' === $element->get_settings('ninetheme_parallax_video_play_once') ) {
                        $element->add_render_attribute( '_wrapper', 'data-jarallax-video-loop', 'false' );
                    }
                    if ( $element->get_settings('ninetheme_parallax_video_volume') ) {
                        $element->add_render_attribute( '_wrapper', 'data-video-volume', $element->get_settings('ninetheme_parallax_video_volume') );
                    }

                } else {
                    $parallaxattr = '{"type":"'.$type.'","speed":"'.$speed.'","imgsize":"'.$bgsize.'","imgsrc":"'.$bgimg.'","mobile":"'.$mobile.'"}';
                    $element->add_render_attribute( '_wrapper', 'data-ninetheme-parallax', $parallaxattr);
                }
            }

        } // end if section
    }

    public static function get_instance() {
        if ( null == self::$instance ) {
            self::$instance = new self;
        }
        return self::$instance;
    }
}
Ninetheme_Section_Settings::get_instance();
