<?php

namespace Elementor;

use Elementor\Controls_Manager;
use Elementor\Core\Base\Document;
use Elementor\Core\Base\Module as BaseModule;
use Elementor\Plugin;
use Elementor\Utils;
use Elementor\Core\DocumentTypes\PageBase as PageBase;
use Elementor\Modules\Library\Documents\Page as LibraryPageDocument;

if( !defined( 'ABSPATH' ) ) exit;

class Ninetheme_Customizing_Page_Settings {
    use Ninetheme_Helper;
    private static $instance = null;

    public static function get_instance() {
        if ( null == self::$instance ) {
            self::$instance = new Ninetheme_Customizing_Page_Settings();
        }
        return self::$instance;
    }

    public function __construct(){
        add_action( 'elementor/documents/register_controls',[ $this,'ninetheme_page_footer_settings'], 10 );
    }

    public function ninetheme_page_footer_settings( $document )
    {
        $document->start_controls_section( 'ninetheme_page_header_settings',
            [
                'label' => esc_html__( 'CRISOP FOOTER', 'crisop' ),
                'tab' => Controls_Manager::TAB_SETTINGS
            ]
        );
        $document->add_control( 'ninetheme_page_footer_template',
            [
                'label' => esc_html__( 'Select Footer Template', 'crisop' ),
                'type' => Controls_Manager::SELECT2,
                'default' => '',
                'multiple' => false,
                'options' => $this->ninetheme_get_elementor_templates()
            ]
        );
        $document->end_controls_section();
    }

    public function ninetheme_page_settings( $document )
    {
        $document->start_controls_section( 'ninetheme_page_header_settings',
            [
                'label' => esc_html__( 'CRISOP PAGE HEADER', 'crisop' ),
                'tab' => Controls_Manager::TAB_SETTINGS
            ]
        );
        $document->add_control( 'ninetheme_page_header_settings_heading',
            [
                'label' => esc_html__( 'CRISOP PAGE HEADER', 'crisop' ),
                'type' => Controls_Manager::HEADING,
                'separator' => 'before'
            ]
        );
        $document->add_control( 'ninetheme_page_header_bg_type',
            [
                'label' => esc_html__( 'Header Background Type', 'crisop' ),
                'type' => Controls_Manager::SELECT,
                'default' => '',
                'multiple' => false,
                'options' => array(
                    '' => esc_html__( 'Select an option', 'crisop' ),
                    'default' => esc_html__( 'Deafult', 'crisop' ),
                    'dark' => esc_html__( 'Dark', 'crisop' ),
                    'trans-light' => esc_html__( 'Transparent Light', 'crisop' ),
                    'trans-dark' => esc_html__( 'Transparent Dark', 'crisop' )
                )
            ]
        );
        $document->add_control( 'ninetheme_page_header_width',
            [
                'label' => esc_html__( 'Header Container Width', 'crisop' ),
                'type' => Controls_Manager::SELECT,
                'default' => '',
                'multiple' => false,
                'options' => array(
                    'default' => esc_html__( 'Deafult', 'crisop' ),
                    'stretch' => esc_html__( 'Stretch', 'crisop' )
                ),
            ]
        );
        $document->end_controls_section();

        $document->start_controls_section( 'ninetheme_page_header_logo_settings',
            [
                'label' => esc_html__( 'CRISOP PAGE HEADER LOGO', 'crisop' ),
                'tab' => Controls_Manager::TAB_SETTINGS
            ]
        );
        $document->add_control( 'ninetheme_page_header_logo_update',
            [
                'label' => '<div class="elementor-update-preview" style="background-color: #fff;display: block;"><div class="elementor-update-preview-button-wrapper" style="display:block;"><button class="elementor-update-preview-button elementor-button elementor-button-success" style="background: #d30c5c; margin: 0 auto; display:block;">Apply Changes</button></div><div class="elementor-update-preview-title" style="display:block;text-align:center;margin-top: 10px;">Update changes to pages</div></div>',
                'type' => Controls_Manager::RAW_HTML
            ]
        );
        $document->add_control( 'ninetheme_page_header_logo',
            [
                'label' => esc_html__( 'Logo', 'crisop' ),
                'type' => Controls_Manager::MEDIA,
                'default' => ['url' => '']
            ]
        );
        $document->add_responsive_control( 'ninetheme_page_header_logo_max_width',
            [
                'label' => esc_html__( 'Image Max-Width', 'crisop' ),
                'type' => Controls_Manager::SLIDER,
                'range' => [
                    'px' => ['max' => 1000]
                ],
                'selectors' => [ '{{WRAPPER}} .nt-logo.header-logo .main-logo:not(.sticky-logo)' => 'max-width: {{SIZE}}{{UNIT}};' ]
            ]
        );
        $document->add_responsive_control( 'ninetheme_page_header_logo_max_height',
            [
                'label' => esc_html__( 'Image Max-Height', 'crisop' ),
                'type' => Controls_Manager::SLIDER,
                'range' => [
                    'px' => ['max' => 1000]
                ],
                'selectors' => [ '{{WRAPPER}} .nt-logo.header-logo .main-logo:not(.sticky-logo)' => 'max-height: {{SIZE}}{{UNIT}};' ]
            ]
        );
        $document->add_control( 'ninetheme_page_header_sticky_logo',
            [
                'label' => esc_html__( 'Sticky Logo', 'crisop' ),
                'type' => Controls_Manager::MEDIA,
                'default' => ['url' => '']
            ]
        );
        $document->add_responsive_control( 'ninetheme_page_header_sticky_logo_max_width',
            [
                'label' => esc_html__( 'Sticky Logo Max-Width', 'crisop' ),
                'type' => Controls_Manager::SLIDER,
                'range' => [
                    'px' => ['max' => 1000],
                ],
                'selectors' => [ '{{WRAPPER}} .nt-logo.header-logo .main-logo.sticky-logo' => 'max-width: {{SIZE}}{{UNIT}};' ]
            ]
        );
        $document->add_responsive_control( 'ninetheme_page_header_sticky_logo_max_height',
            [
                'label' => esc_html__( 'Sticky Logo Max-Height', 'crisop' ),
                'type' => Controls_Manager::SLIDER,
                'range' => [
                    'px' => ['max' => 1000]
                ],
                'selectors' => [ '{{WRAPPER}} .nt-logo.header-logo .main-logo.sticky-logo' => 'max-height: {{SIZE}}{{UNIT}};' ]
            ]
        );
        $document->add_control( 'ninetheme_page_header_text_logo_color',
            [
                'label' => esc_html__( 'Text Logo Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [ '{{WRAPPER}} .nt-logo.header-logo .header-text-logo' => 'color:{{VALUE}};' ]
            ]
        );
        $document->add_control( 'ninetheme_page_header_sticky_text_logo_color',
            [
                'label' => esc_html__( 'Sticky Text Logo Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [ '{{WRAPPER}}.scroll-start .nt-logo.header-logo .header-text-logo' => 'color:{{VALUE}};' ]
            ]
        );
        $document->end_controls_section();

        $document->start_controls_section( 'ninetheme_page_header_customize_settings',
            [
                'label' => esc_html__( 'CRISOP PAGE HEADER CUSTOMIZE', 'crisop' ),
                'tab' => Controls_Manager::TAB_SETTINGS
            ]
        );
        $document->add_control( 'ninetheme_page_header_bgcolor',
            [
                'label' => esc_html__( 'Header Background Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} header.ninetheme-header-default,
                    {{WRAPPER}} .ninetheme-header-top-menu-area ul li .submenu,
                    {{WRAPPER}} .ninetheme-header-top-menu-area ul li>.item-shortcode-wrapper,
                    {{WRAPPER}} .ninetheme-header-wc-categories .submenu,
                    {{WRAPPER}} .ninetheme-header-mobile-top,
                    {{WRAPPER}} .ninetheme-header-mobile,
                    {{WRAPPER}}.has-default-header-type-trans header.ninetheme-header-default' => 'background-color:{{VALUE}};'
                ]
            ]
        );
        $document->add_control( 'ninetheme_page_header_bottom_brdcolor',
            [
                'label' => esc_html__( 'Header Border Bottom Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} header.ninetheme-header-default,
                    {{WRAPPER}} .ninetheme-header-mobile-top,
                    {{WRAPPER}} .ninetheme-header-mobile,
                    {{WRAPPER}}.has-default-header-type-trans header.ninetheme-header-default' => 'border-bottom:1px solid {{VALUE}};'
                ]
            ]
        );
        $document->add_control( 'ninetheme_page_header_menu_settings',
            [
                'label' => esc_html__( 'Menu Items', 'crisop' ),
                'type' => Controls_Manager::HEADING
            ]
        );
        $document->add_control( 'ninetheme_page_header_menu_item_color',
            [
                'label' => esc_html__( 'Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .ninetheme-header-top-menu-area>ul>li.menu-item>a,
                    {{WRAPPER}}.has-default-header-type-trans:not(.scroll-start) .ninetheme-header-top-menu-area>ul>li.menu-item>a,
                    {{WRAPPER}} .ninetheme-header-wc-categories .product_cat,
                    {{WRAPPER}} .ninetheme-header-mobile .sliding-menu .sliding-menu-inner li a,
                    {{WRAPPER}} .ninetheme-header-mobile .sliding-menu li .sliding-menu__nav,
                    {{WRAPPER}} .ninetheme-header-mobile .sliding-menu li.current-menu-parent>.sliding-menu__nav,
                    {{WRAPPER}} .ninetheme-header-mobile .sliding-menu .sliding-menu__back:before,
                    {{WRAPPER}} .ninetheme-header-mobile .sliding-menu .sliding-menu__nav:before,
                    {{WRAPPER}} .ninetheme-header-top-menu-area ul li .submenu>li.menu-item>a' => 'color:{{VALUE}};'
                ]
            ]
        );
        $document->add_control( 'ninetheme_page_header_menu_item_hvrcolor',
            [
                'label' => esc_html__( 'Color ( Hover/Active )', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .ninetheme-header-top-menu-area>ul>li.menu-item:hover>a,
                    {{WRAPPER}}.has-default-header-type-trans:not(.scroll-start) .ninetheme-header-top-menu-area>ul>li.menu-item:hover>a,
                    {{WRAPPER}} .ninetheme-header-top-menu-area>ul>li.menu-item.active>a,
                    {{WRAPPER}}.has-default-header-type-trans:not(.scroll-start) .ninetheme-header-top-menu-area>ul>li.menu-item.active>a,
                    {{WRAPPER}} .current-menu-parent>a,
                    {{WRAPPER}} .current-menu-item>a,
                    {{WRAPPER}} .ninetheme-header-top-menu-area>ul>li.menu-item.active>a,
                    {{WRAPPER}} .ninetheme-header-top-menu-area>ul>li.menu-item>a:hover,
                    {{WRAPPER}} .ninetheme-header-wc-categories .product_cat:hover,
                    {{WRAPPER}} .ninetheme-header-mobile .sliding-menu li.current-menu-item>.sliding-menu__nav:hover,
                    {{WRAPPER}} .ninetheme-header-mobile .sliding-menu li.current-menu-item>a:hover,
                    {{WRAPPER}} .ninetheme-header-mobile .sliding-menu li a:hover,
                    {{WRAPPER}} .ninetheme-header-mobile .sliding-menu li.active a,
                    {{WRAPPER}} .ninetheme-header-mobile .sliding-menu li .sliding-menu__nav:hover,
                    {{WRAPPER}} .ninetheme-header-mobile .sliding-menu .sliding-menu__back:hover:before,
                    {{WRAPPER}} .ninetheme-header-mobile .sliding-menu .sliding-menu__nav:hover:before,
                    {{WRAPPER}} .ninetheme-header-top-menu-area ul li .submenu>li.menu-item>a:hover' => 'color:{{VALUE}};'
                ]
            ]
        );
        $document->add_control( 'ninetheme_page_sticky_header_settings',
            [
                'label' => esc_html__( 'STICKY HEADER', 'crisop' ),
                'type' => Controls_Manager::HEADING,
                'separator' => 'before'
            ]
        );
        $document->add_control( 'ninetheme_page_sticky_header_bgcolor',
            [
                'label' => esc_html__( 'Sticky Header Background Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}}.scroll-start header.ninetheme-header-default,
                    {{WRAPPER}}.scroll-start .ninetheme-header-top-menu-area ul li .submenu,
                    {{WRAPPER}}.scroll-start .ninetheme-header-top-menu-area ul li>.item-shortcode-wrapper,
                    {{WRAPPER}}.scroll-start .ninetheme-header-wc-categories .submenu,
                    {{WRAPPER}}.scroll-start .ninetheme-header-mobile-top,
                    {{WRAPPER}}.scroll-start .ninetheme-header-mobile,
                    {{WRAPPER}}.has-default-header-type-trans.scroll-start header.ninetheme-header-default' => 'background-color:{{VALUE}};'
                ]
            ]
        );
        $document->add_control( 'ninetheme_page_sticky_header_bottom_brdcolor',
            [
                'label' => esc_html__( 'Header Border Bottom Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}}.scroll-start header.ninetheme-header-default,
                    {{WRAPPER}}.scroll-start .ninetheme-header-mobile-top,
                    {{WRAPPER}}.scroll-start .ninetheme-header-mobile,
                    {{WRAPPER}}.has-default-header-type-trans.scroll-start header.ninetheme-header-default' => 'border-bottom:1px solid {{VALUE}};'
                ]
            ]
        );
        $document->add_control( 'ninetheme_page_sticky_header_menu_settings',
            [
                'label' => esc_html__( 'Sticky Menu Items', 'crisop' ),
                'type' => Controls_Manager::HEADING
            ]
        );
        $document->add_control( 'ninetheme_page_sticky_header_menu_item_color',
            [
                'label' => esc_html__( 'Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}}.scroll-start .ninetheme-header-top-menu-area>ul>li.menu-item>a,
                    {{WRAPPER}}.has-default-header-type-trans.scroll-start .ninetheme-header-top-menu-area>ul>li.menu-item>a,
                    {{WRAPPER}}.scroll-start .ninetheme-header-wc-categories .product_cat,
                    {{WRAPPER}}.scroll-start .ninetheme-header-mobile .sliding-menu .sliding-menu-inner li a,
                    {{WRAPPER}}.scroll-start .ninetheme-header-mobile .sliding-menu li .sliding-menu__nav,
                    {{WRAPPER}}.scroll-start .ninetheme-header-mobile .sliding-menu li.current-menu-parent>.sliding-menu__nav,
                    {{WRAPPER}}.scroll-start .ninetheme-header-mobile .sliding-menu .sliding-menu__back:before,
                    {{WRAPPER}}.scroll-start .ninetheme-header-mobile .sliding-menu .sliding-menu__nav:before,
                    {{WRAPPER}}.scroll-start .ninetheme-header-top-menu-area ul li .submenu>li.menu-item>a' => 'color:{{VALUE}};'
                ]
            ]
        );
        $document->add_control( 'ninetheme_page_sticky_header_menu_item_hvrcolor',
            [
                'label' => esc_html__( 'Color ( Hover/Active )', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}}.scroll-start .ninetheme-header-top-menu-area>ul>li.menu-item:hover>a,
                    {{WRAPPER}}.has-default-header-type-trans.scroll-start .ninetheme-header-top-menu-area>ul>li.menu-item:hover>a,
                    {{WRAPPER}}.scroll-start .ninetheme-header-top-menu-area>ul>li.menu-item.active>a,
                    {{WRAPPER}}.has-default-header-type-trans.scroll-start .ninetheme-header-top-menu-area>ul>li.menu-item.active>a,
                    {{WRAPPER}}.scroll-start .current-menu-parent>a,
                    {{WRAPPER}}.scroll-start .current-menu-item>a,
                    {{WRAPPER}}.scroll-start .ninetheme-header-top-menu-area>ul>li.menu-item.active>a,
                    {{WRAPPER}}.scroll-start .ninetheme-header-top-menu-area>ul>li.menu-item>a:hover,
                    {{WRAPPER}}.scroll-start .ninetheme-header-wc-categories .product_cat:hover,
                    {{WRAPPER}}.scroll-start .ninetheme-header-mobile .sliding-menu li.current-menu-item>.sliding-menu__nav:hover,
                    {{WRAPPER}}.scroll-start .ninetheme-header-mobile .sliding-menu li.current-menu-item>a:hover,
                    {{WRAPPER}}.scroll-start .ninetheme-header-mobile .sliding-menu li a:hover,
                    {{WRAPPER}}.scroll-start .ninetheme-header-mobile .sliding-menu li.active a,
                    {{WRAPPER}}.scroll-start .ninetheme-header-mobile .sliding-menu li .sliding-menu__nav:hover,
                    {{WRAPPER}}.scroll-start .ninetheme-header-mobile .sliding-menu .sliding-menu__back:hover:before,
                    {{WRAPPER}}.scroll-start .ninetheme-header-mobile .sliding-menu .sliding-menu__nav:hover:before,
                    {{WRAPPER}}.scroll-start .ninetheme-header-top-menu-area ul li .submenu>li.menu-item>a:hover' => 'color:{{VALUE}};'
                ]
            ]
        );
        $document->add_control( 'ninetheme_page_header_category_menu_settings',
            [
                'label' => esc_html__( 'HEADER CATEGORY MENU', 'crisop' ),
                'type' => Controls_Manager::HEADING,
                'separator' => 'before'
            ]
        );
        $document->add_control( 'ninetheme_page_header_category_menu_btn_bgcolor',
            [
                'label' => esc_html__( 'Button Background Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .ninetheme-header-wc-categories .ninetheme-vertical-catmenu-title' => 'background-color:{{VALUE}};'
                ]
            ]
        );
        $document->add_control( 'ninetheme_page_header_category_menu_btn_color',
            [
                'label' => esc_html__( 'Button Title Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .ninetheme-header-wc-categories .ninetheme-vertical-catmenu-title' => 'color:{{VALUE}};'
                ]
            ]
        );
        $document->add_control( 'ninetheme_page_header_category_submenu_bgcolor',
            [
                'label' => esc_html__( 'Submenu Background Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .ninetheme-header-wc-categories .submenu' => 'background-color:{{VALUE}};'
                ]
            ]
        );
        $document->add_control( 'ninetheme_page_header_category_menu_item_color',
            [
                'label' => esc_html__( 'Menu Item Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .ninetheme-header-wc-categories .product_cat' => 'color:{{VALUE}};'
                ]
            ]
        );
        $document->add_control( 'ninetheme_page_header_category_menu_item_hvrcolor',
            [
                'label' => esc_html__( 'Menu Item Color ( Hover )', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .ninetheme-header-wc-categories .product_cat:hover' => 'color:{{VALUE}};'
                ]
            ]
        );
        $document->add_control( 'ninetheme_page_sticky_header_category_menu_settings',
            [
                'label' => esc_html__( 'Sticky Header Color', 'crisop' ),
                'type' => Controls_Manager::HEADING
            ]
        );
        $document->add_control( 'ninetheme_page_sticky_header_category_menu_btn_bgcolor',
            [
                'label' => esc_html__( 'Sticky Button Background Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}}.scroll-start .ninetheme-header-wc-categories .ninetheme-vertical-catmenu-title' => 'background-color:{{VALUE}};'
                ]
            ]
        );
        $document->add_control( 'ninetheme_page_sticky_header_category_menu_btn_color',
            [
                'label' => esc_html__( 'Sticky Button Title Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}}.scroll-start .ninetheme-header-wc-categories .ninetheme-vertical-catmenu-title' => 'color:{{VALUE}};'
                ]
            ]
        );
        $document->add_control( 'ninetheme_page_sticky_header_category_submenu_bgcolor',
            [
                'label' => esc_html__( 'Sticky Submenu Background Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}}.scroll-start .ninetheme-header-wc-categories .submenu' => 'background-color:{{VALUE}};'
                ]
            ]
        );
        $document->add_control( 'ninetheme_page_sticky_header_category_menu_item_color',
            [
                'label' => esc_html__( 'Sticky Menu Item Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}}.scroll-start .ninetheme-header-wc-categories .product_cat' => 'color:{{VALUE}};'
                ]
            ]
        );
        $document->add_control( 'ninetheme_page_sticky_header_category_menu_item_hvrcolor',
            [
                'label' => esc_html__( 'Sticky Menu Item Color ( Hover )', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}}.scroll-start .ninetheme-header-wc-categories .product_cat:hover' => 'color:{{VALUE}};'
                ]
            ]
        );
        $document->add_control( 'ninetheme_page_header_svg_icons_settings',
            [
                'label' => esc_html__( 'HEADER SVG ICONS', 'crisop' ),
                'type' => Controls_Manager::HEADING,
                'separator' => 'before'
            ]
        );
        $document->add_control( 'ninetheme_page_header_svg_icons_color',
            [
                'label' => esc_html__( 'Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} header.ninetheme-header-default .ninetheme-svg-icon,
                    {{WRAPPER}} .ninetheme-header-mobile-top .ninetheme-svg-icon' => 'fill:{{VALUE}};'
                ]
            ]
        );
        $document->add_control( 'ninetheme_page_header_svg_counter_bgcolor',
            [
                'label' => esc_html__( 'Counter Background Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} header.ninetheme-header-default .ninetheme-wc-count,
                    {{WRAPPER}} .ninetheme-header-mobile-top .ninetheme-wc-count' => 'background-color:{{VALUE}};'
                ]
            ]
        );
        $document->add_control( 'ninetheme_page_header_svg_counter_color',
            [
                'label' => esc_html__( 'Counter Number Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} header.ninetheme-header-default .ninetheme-wc-count,
                    {{WRAPPER}} .ninetheme-header-mobile-top .ninetheme-wc-count' => 'color:{{VALUE}};'
                ]
            ]
        );
        $document->add_control( 'ninetheme_page_sticky_header_svg_icons_settings',
            [
                'label' => esc_html__( 'Sticky Header Color', 'crisop' ),
                'type' => Controls_Manager::HEADING
            ]
        );
        $document->add_control( 'ninetheme_page_sticky_header_svg_icons_color',
            [
                'label' => esc_html__( 'Sticky Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}}.scroll-start header.ninetheme-header-default .ninetheme-svg-icon,
                    {{WRAPPER}}.scroll-start .ninetheme-header-mobile-top .ninetheme-svg-icon' => 'fill:{{VALUE}};'
                ]
            ]
        );
        $document->add_control( 'ninetheme_page_sticky_header_svg_counter_bgcolor',
            [
                'label' => esc_html__( 'Sticky Counter Background Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}}.scroll-start header.ninetheme-header-default .ninetheme-wc-count,
                    {{WRAPPER}}.scroll-start .ninetheme-header-mobile-top .ninetheme-wc-count' => 'background-color:{{VALUE}};'
                ]
            ]
        );
        $document->add_control( 'ninetheme_page_sticky_header_svg_counter_color',
            [
                'label' => esc_html__( 'Sticky Counter Number Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}}.scroll-start header.ninetheme-header-default .ninetheme-wc-count,
                    {{WRAPPER}}.scroll-start .ninetheme-header-mobile-top .ninetheme-wc-count' => 'color:{{VALUE}};'
                ]
            ]
        );
        $document->end_controls_section();

        $document->start_controls_section( 'ninetheme_page_mobile_header_customize_settings',
            [
                'label' => esc_html__( 'CRISOP PAGE MOBILE HEADER', 'crisop' ),
                'tab' => Controls_Manager::TAB_SETTINGS
            ]
        );
        $document->add_control( 'ninetheme_page_mobile_header_bgcolor',
            [
                'label' => esc_html__( 'Header Background Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .ninetheme-header-mobile-top' => 'background-color:{{VALUE}};'
                ]
            ]
        );
        $document->add_control( 'ninetheme_page_mobile_header_toggle_btn_color',
            [
                'label' => esc_html__( 'Toggle Button Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .ninetheme-header-mobile-top .mobile-toggle' => 'color:{{VALUE}};'
                ]
            ]
        );
        $document->add_control( 'ninetheme_page_mobile_header_toggle_btn_hvrcolor',
            [
                'label' => esc_html__( 'Toggle Button Color ( Hover )', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .ninetheme-header-mobile-top .mobile-toggle:hover' => 'color:{{VALUE}};'
                ]
            ]
        );
        $document->add_control( 'ninetheme_page_sticky_mobile_header_settings',
            [
                'label' => esc_html__( 'Sticky Header Color', 'crisop' ),
                'type' => Controls_Manager::HEADING
            ]
        );
        $document->add_control( 'ninetheme_page_sticky_mobile_header_bgcolor',
            [
                'label' => esc_html__( 'Header Background Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}}.scroll-start .ninetheme-header-mobile-top' => 'background-color:{{VALUE}};'
                ]
            ]
        );
        $document->add_control( 'ninetheme_page_sticky_mobile_header_toggle_btn_color',
            [
                'label' => esc_html__( 'Toggle Button Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}}.scroll-start .ninetheme-header-mobile-top .mobile-toggle' => 'color:{{VALUE}};'
                ]
            ]
        );
        $document->add_control( 'ninetheme_page_sticky_mobile_header_toggle_btn_hvrcolor',
            [
                'label' => esc_html__( 'Toggle Button Color ( Hover )', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}}.scroll-start .ninetheme-header-mobile-top .mobile-toggle:hover' => 'color:{{VALUE}};'
                ]
            ]
        );
        $document->add_control( 'ninetheme_page_mobile_header_svg_icons_settings',
            [
                'label' => esc_html__( 'HEADER SVG ICONS', 'crisop' ),
                'type' => Controls_Manager::HEADING,
                'separator' => 'before'
            ]
        );
        $document->add_control( 'ninetheme_page_mobile_header_svg_icons_color',
            [
                'label' => esc_html__( 'Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .ninetheme-header-mobile-top .ninetheme-svg-icon' => 'fill:{{VALUE}};'
                ]
            ]
        );
        $document->add_control( 'ninetheme_page_mobile_header_svg_counter_bgcolor',
            [
                'label' => esc_html__( 'Counter Background Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .ninetheme-header-mobile-top .ninetheme-wc-count' => 'background-color:{{VALUE}};'
                ]
            ]
        );
        $document->add_control( 'ninetheme_page_mobile_header_svg_counter_color',
            [
                'label' => esc_html__( 'Counter Number Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .ninetheme-header-mobile-top .ninetheme-wc-count' => 'color:{{VALUE}};'
                ]
            ]
        );
        $document->add_control( 'ninetheme_page_sticky_mobile_header_svg_icons_settings',
            [
                'label' => esc_html__( 'Sticky Header Color', 'crisop' ),
                'type' => Controls_Manager::HEADING
            ]
        );
        $document->add_control( 'ninetheme_page_sticky_mobile_header_svg_icons_color',
            [
                'label' => esc_html__( 'Sticky Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}}.scroll-start .ninetheme-header-mobile-top .ninetheme-svg-icon' => 'fill:{{VALUE}};'
                ]
            ]
        );
        $document->add_control( 'ninetheme_page_sticky_mobile_header_svg_counter_bgcolor',
            [
                'label' => esc_html__( 'Sticky Counter Background Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}}.scroll-start .ninetheme-header-mobile-top .ninetheme-wc-count' => 'background-color:{{VALUE}};'
                ]
            ]
        );
        $document->add_control( 'ninetheme_page_sticky_mobile_header_svg_counter_color',
            [
                'label' => esc_html__( 'Sticky Counter Number Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}}.scroll-start .ninetheme-header-mobile-top .ninetheme-wc-count' => 'color:{{VALUE}};'
                ]
            ]
        );
        $document->end_controls_section();

        $document->start_controls_section( 'ninetheme_page_slide_menu_customize_settings',
            [
                'label' => esc_html__( 'CRISOP PAGE MOBILE SLIDE MENU', 'crisop' ),
                'tab' => Controls_Manager::TAB_SETTINGS
            ]
        );
        $document->add_control( 'ninetheme_page_slide_menu_close_btn_bgcolor',
            [
                'label' => esc_html__( 'Close Button Background Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .ninetheme-header-mobile .ninetheme-panel-close.no-bar,
                    {{WRAPPER}} .ninetheme-header-mobile .ninetheme-panel-close' => 'background-color:{{VALUE}};'
                ]
            ]
        );
        $document->add_control( 'ninetheme_page_slide_menu_close_btn_color',
            [
                'label' => esc_html__( 'Close Button Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .ninetheme-header-mobile .ninetheme-panel-close-button:before,
                    {{WRAPPER}} .ninetheme-header-mobile .ninetheme-panel-close-button:after,
                    {{WRAPPER}} .ninetheme-header-mobile .ninetheme-panel-close.no-bar:before,
                    {{WRAPPER}} .ninetheme-header-mobile .ninetheme-panel-close.no-bar:after' => 'background-color:{{VALUE}};'
                ]
            ]
        );

        $document->add_control( 'ninetheme_page_slide_menu_bgcolor',
            [
                'label' => esc_html__( 'Background Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .ninetheme-header-mobile' => 'background-color:{{VALUE}};'
                ]
            ]
        );
        $document->add_control( 'ninetheme_page_slide_menu_items_settings',
            [
                'label' => esc_html__( 'Menu Items', 'crisop' ),
                'type' => Controls_Manager::HEADING
            ]
        );
        $document->add_control( 'ninetheme_page_slide_menu_item_color',
            [
                'label' => esc_html__( 'Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .ninetheme-header-mobile .sliding-menu .sliding-menu-inner li a,
                    {{WRAPPER}} .ninetheme-header-mobile .sliding-menu li .sliding-menu__nav,
                    {{WRAPPER}} .ninetheme-header-mobile .sliding-menu li.current-menu-parent>.sliding-menu__nav,
                    {{WRAPPER}} .ninetheme-header-mobile .sliding-menu .sliding-menu__back:before,
                    {{WRAPPER}} .ninetheme-header-mobile .sliding-menu .sliding-menu__nav:before' => 'color:{{VALUE}};'
                ]
            ]
        );

        $document->add_control( 'ninetheme_page_slide_menu_item_hvrcolor',
            [
                'label' => esc_html__( 'Color ( Hover/Active )', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .ninetheme-header-mobile .sliding-menu li.current-menu-item>.sliding-menu__nav:hover,
                    {{WRAPPER}} .ninetheme-header-mobile .sliding-menu li.current-menu-item>a:hover,
                    {{WRAPPER}} .ninetheme-header-mobile .sliding-menu li a:hover,
                    {{WRAPPER}} .ninetheme-header-mobile .sliding-menu li.active a,
                    {{WRAPPER}} .ninetheme-header-mobile .sliding-menu li .sliding-menu__nav:hover,
                    {{WRAPPER}} .ninetheme-header-mobile .sliding-menu .sliding-menu__back:hover:before,
                    {{WRAPPER}} .ninetheme-header-mobile .sliding-menu .sliding-menu__nav:hover:before' => 'color:{{VALUE}};'
                ]
            ]
        );
        $document->add_control( 'ninetheme_page_sticky_slide_menu_settings',
            [
                'label' => esc_html__( 'STICKY HEADER', 'crisop' ),
                'type' => Controls_Manager::HEADING,
                'separator' => 'before'
            ]
        );
        $document->add_control( 'ninetheme_page_sticky_slide_menu_bgcolor',
            [
                'label' => esc_html__( 'Sticky Header Background Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}}.scroll-start .ninetheme-header-mobile' => 'background-color:{{VALUE}};'
                ]
            ]
        );
        $document->add_control( 'ninetheme_page_slide_menu_back_brdcolor',
            [
                'label' => esc_html__( 'Border Separator Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .sliding-menu .sliding-menu__back:after' => 'border-bottom-color:{{VALUE}};',
                    '{{WRAPPER}} .ninetheme-sidemenu-lang-switcher' => 'border-top-color:{{VALUE}};'
                ]
            ]
        );
        $document->add_control( 'ninetheme_page_sticky_slide_menu_items_settings',
            [
                'label' => esc_html__( 'Sticky Menu Items', 'crisop' ),
                'type' => Controls_Manager::HEADING
            ]
        );
        $document->add_control( 'ninetheme_page_sticky_slide_menu_item_color',
            [
                'label' => esc_html__( 'Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}}.scroll-start .ninetheme-header-mobile .sliding-menu .sliding-menu-inner li a,
                    {{WRAPPER}}.scroll-start .ninetheme-header-mobile .sliding-menu li .sliding-menu__nav,
                    {{WRAPPER}}.scroll-start .ninetheme-header-mobile .sliding-menu li.current-menu-parent>.sliding-menu__nav,
                    {{WRAPPER}}.scroll-start .ninetheme-header-mobile .sliding-menu .sliding-menu__back:before,
                    {{WRAPPER}}.scroll-start .ninetheme-header-mobile .sliding-menu .sliding-menu__nav:before' => 'color:{{VALUE}};'
                ]
            ]
        );
        $document->add_control( 'ninetheme_page_sticky_slide_menu_item_hvrcolor',
            [
                'label' => esc_html__( 'Color ( Hover/Active )', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}}.scroll-start .ninetheme-header-mobile .sliding-menu li.current-menu-item>.sliding-menu__nav:hover,
                    {{WRAPPER}}.scroll-start .ninetheme-header-mobile .sliding-menu li.current-menu-item>a:hover,
                    {{WRAPPER}}.scroll-start .ninetheme-header-mobile .sliding-menu li a:hover,
                    {{WRAPPER}}.scroll-start .ninetheme-header-mobile .sliding-menu li.active a,
                    {{WRAPPER}}.scroll-start .ninetheme-header-mobile .sliding-menu li .sliding-menu__nav:hover,
                    {{WRAPPER}}.scroll-start .ninetheme-header-mobile .sliding-menu .sliding-menu__back:hover:before,
                    {{WRAPPER}}.scroll-start .ninetheme-header-mobile .sliding-menu .sliding-menu__nav:hover:before' => 'color:{{VALUE}};'
                ]
            ]
        );
        $document->add_control( 'ninetheme_page_sticky_slide_menu_back_brdcolor',
            [
                'label' => esc_html__( 'Border Separator Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}}.scroll-start .sliding-menu .sliding-menu__back:after' => 'border-bottom-color:{{VALUE}};',
                    '{{WRAPPER}}.scroll-start .ninetheme-sidemenu-lang-switcher' => 'border-top-color:{{VALUE}};'
                ]
            ]
        );
        $document->end_controls_section();
    }

    public function ninetheme_add_custom_css_to_page_settings( $page )
    {

        if ( isset($page) && $page->get_id() > "" ){

            $nt_post_type = false;
            $nt_post_type = get_post_type($page->get_id());

            if ( $nt_post_type == 'page' || $nt_post_type == 'revision' ) {

                $page->start_controls_section( 'header_custom_css_controls_section',
                    [
                        'label' => esc_html__( 'CRISOP PAGE CUSTOM CSS', 'crisop' ),
                        'tab' => Controls_Manager::TAB_SETTINGS
                    ]
                );
                $page->add_control( 'ninetheme_page_custom_css',
                    [
                        'label' => esc_html__( 'Custom CSS', 'crisop' ),
                        'type' => Controls_Manager::CODE,
                        'language' => 'css',
                        'rows' => 20
                    ]
                );
                $page->end_controls_section();
            }
        }
    }

    public function ninetheme_page_registered_nav_menus()
    {
        $menus = wp_get_nav_menus();
        $options = array();
        if ( ! empty( $menus ) && ! is_wp_error( $menus ) ) {
            foreach ( $menus as $menu ) {
                $options[ $menu->slug ] = $menu->name;
            }
        }
        return $options;
    }
}
Ninetheme_Customizing_Page_Settings::get_instance();
