<?php
/**
* Taxonomy: Ninetheme Popup Builder
*/
if ( ! defined( 'ABSPATH' ) ) exit; // If this file is called directly, abort.
if ( ! class_exists( 'Ninetheme_Popup_Builder' ) ) {
    class Ninetheme_Popup_Builder {
        private static $instance = null;
        public static function get_instance() {
            if ( is_null( self::$instance ) ) {
                self::$instance = new self;
            }
            return self::$instance;
        }
        public function __construct() {
            
            //
            if ( ! get_option( 'disable_ninetheme_popups' ) == 1 ) {
                add_action( 'init', array( $this, 'ninetheme_register_popups' ) );
                

                $cpt_support = get_option( 'elementor_cpt_support' );
                if ( is_array( $cpt_support ) && ! in_array( 'ninetheme_popups', $cpt_support ) ) {
                    $cpt_support[] = 'ninetheme_popups';
                    update_option( 'elementor_cpt_support', $cpt_support );
                }
                // Add the custom columns to the book post type:
                add_filter( 'manage_ninetheme_popups_posts_columns', array( $this, 'set_custom_edit_ninetheme_popups_columns' ) );
                // Add the data to the custom columns for the book post type:
                add_action( 'manage_ninetheme_popups_posts_custom_column' , array( $this, 'custom_ninetheme_popups_column' ), 10, 2 );
                //add_filter( 'views_edit-ninetheme_popups', [ $this, 'admin_print_tabs' ] );
                //add_filter( 'views_edit-ninetheme_shop_build', [ $this, 'admin_print_tabs' ] );
            }
        }
        public function ninetheme_register_popups() {

            /**
            * Post Type: Popups Builder.
            */

            $labels = [
                "name"               => __( "Popups Builder", "decoraty" ),
                "singular_name"      => __( "Popup Builder", "decoraty" ),
                "menu_name"          => __( "Popups Builder", "decoraty" ),
                "all_items"          => __( "Popups Builder", "decoraty" ),
                "add_new"            => __( "Add Popup", "decoraty" ),
                "add_new_item"       => __( "Add new Popup", "decoraty" ),
                "edit_item"          => __( "Edit Popup", "decoraty" ),
                "new_item"           => __( "New Popup", "decoraty" ),
                "view_item"          => __( "View Popup", "decoraty" ),
                "view_items"         => __( "View Popups", "decoraty" ),
                "search_items"       => __( "Search Popups", "decoraty" ),
                "not_found"          => __( "No Popups found", "decoraty" ),
                "not_found_in_trash" => __( "No Popups found in trash", "decoraty" )
            ];

            $args = [
                "label"                 => __( "Crisop Popups", "decoraty" ),
                "labels"                => $labels,
                "description"           => "",
                "public"                => true,
                "publicly_queryable"    => true,
                "show_ui"               => true,
                "show_in_rest"          => true,
                "rest_base"             => "",
                "rest_controller_class" => "WP_REST_Posts_Controller",
                "has_archive"           => false,
                "show_in_menu"          => "ninetheme_theme_manage",
                "show_in_nav_menus"     => true,
                "delete_with_user"      => false,
                "exclude_from_search"   => true,
                "capability_type"       => "post",
                "map_meta_cap"          => true,
                "hierarchical"          => false,
                "rewrite"               => [ "slug" => "ninetheme_popups", "with_front" => true ],
                "query_var"             => true,
                "supports"              => [ "title", "editor", "author" ],
                "show_in_graphql"       => false
            ];
            register_post_type( "ninetheme_popups", $args );
        }
        
        public function set_custom_edit_ninetheme_popups_columns($columns) {
            $columns[ 'shortcode' ] = __( "Popups ID", "decoraty" );

            return $columns;
        }

        public function custom_ninetheme_popups_column( $column, $post_id ) {

            if ( 'shortcode' === $column ) {

                /** %s = shortcode tag, %d = post_id */
                $shortcode = esc_attr(
                    sprintf(
                        '#%s%d',
                        'ninetheme-popup-',
                        $post_id
                    )
                );
                printf(
                    '<input class="ninetheme-popup-input widefat" type="text" readonly onfocus="this.select()" value="%s" />',
                    $shortcode
                );
            }
        }
        /*
        public function admin_print_tabs( $views ) {
        	$shop_args = [
        		'post_type' => 'ninetheme_shop_build',
        		'tabs_group' => 'shop_builder',
        	];
        	$popup_args = [
        		'post_type' => 'ninetheme_popups',
        		'tabs_group' => 'popups_builder',
        	];
        	$tabs_group = isset( $_GET['tabs_group'] ) ? $_GET['tabs_group'] : 'shop_builder';
            ?>
    		<div id="elementor-template-library-tabs-wrapper" class="nav-tab-wrapper">
    			<a class="nav-tab<?php if ( $tabs_group == 'shop_builder' ) { ?> nav-tab-active<?php } ?>" href="<?php echo add_query_arg( $shop_args, admin_url( 'edit.php' ) ); ?>">Shop Templates</a>
    			<a class="nav-tab<?php if ( $tabs_group == 'popups_builder' ) { ?> nav-tab-active<?php } ?>" href="<?php echo add_query_arg( $popup_args, admin_url( 'edit.php' ) ); ?>">Popup Builder</a>
    			<a class="nav-tab<?php if ( $tabs_group == 'product_builder' ) { ?> nav-tab-active<?php } ?>" href="#0">Product Builder</a>
    			<a class="nav-tab<?php if ( $tabs_group == 'cat_builder' ) { ?> nav-tab-active<?php } ?>" href="#0">Shop Category Templates</a>
    			<a class="nav-tab<?php if ( $tabs_group == 'tax_builder' ) { ?> nav-tab-active<?php } ?>" href="#0">Shop Tag Templates</a>
    		</div>
    		<?php
    		return $views;
        }
        */
    }
    Ninetheme_Popup_Builder::get_instance();
}
