<?php
/**
* Plugin Name: NineTheme Elementor Addons
* Description: Premium & Advanced Essential Elements for Elementor
* Plugin URI:  http://themeforest.net/user/Ninetheme
* Version:     1.0.0
* Author:      Ninetheme
* Text Domain: crisop
* Domain Path: /languages/
* Author URI:  https://ninetheme.com/
*/

/*
* Exit if accessed directly.
*/

if ( ! defined( 'ABSPATH' ) ) exit;
define( 'NINETHEME_PLUGIN_VERSION', '1.0.4' );
define( 'NINETHEME_PLUGIN_FILE', __FILE__ );
define( 'NINETHEME_PLUGIN_BASENAME', plugin_basename(__FILE__) );
define( 'NINETHEME_PLUGIN_PATH', plugin_dir_path(__FILE__) );
define( 'NINETHEME_PLUGIN_URL', plugins_url('/', __FILE__) );

final class Ninetheme_Elementor_Addons
{

    /**
    * Plugin Version
    *
    * @since 1.0
    *
    * @var string The plugin version.
    */
    const VERSION = '1.0.4';

    /**
    * Minimum Elementor Version
    *
    * @since 1.0
    *
    * @var string Minimum Elementor version required to run the plugin.
    */
    const MINIMUM_ELEMENTOR_VERSION = '2.0.0';

    /**
    * Minimum PHP Version
    *
    * @since 1.0
    *
    * @var string Minimum PHP version required to run the plugin.
    */
    const MINIMUM_PHP_VERSION = '5.6';

    /**
    * Instance
    *
    * @since 1.0
    *
    * @access private
    * @static
    *
    * @var Ninetheme_Elementor_Addons The single instance of the class.
    */
    private static $_instance = null;

    /**
    * Instance
    *
    * Ensures only one instance of the class is loaded or can be loaded.
    *
    * @since 1.0
    *
    * @access public
    * @static
    *
    * @return Ninetheme_Elementor_Addons An instance of the class.
    */
    public static function instance()
    {

        if ( is_null( self::$_instance ) ) {
            self::$_instance = new self();
        }
        return self::$_instance;
    }

    /**
    * Constructor
    *
    * @since 1.0
    *
    * @access public
    */
    public function __construct()
    {
        add_action( 'init', [ $this, 'i18n' ] );

        add_action( 'plugins_loaded', [ $this, 'init' ] );

        function ninetheme_pjax()
        {
            $request_headers = function_exists( 'getallheaders') ? getallheaders() : array();

            $is_pjax = isset( $_REQUEST['_pjax'] ) && ( ( isset( $request_headers['X-Requested-With'] ) && 'xmlhttprequest' === strtolower( $request_headers['X-Requested-With'] ) ) || ( isset( $_SERVER['HTTP_X_REQUESTED_WITH'] ) && 'xmlhttprequest' === strtolower( $_SERVER['HTTP_X_REQUESTED_WITH'] ) ) );

            return $is_pjax ? true : false;
        }
    }

    /**
    * Load Textdomain
    *
    * Load plugin localization files.
    *
    * Fired by `init` action hook.
    *
    * @since 1.0
    *
    * @access public
    */
    public function i18n()
    {
        load_plugin_textdomain( 'crisop', false, basename( __DIR__ ) . '/languages/' );
    }

    /**
    * Initialize the plugin
    *
    * Load the plugin only after Elementor (and other plugins) are loaded.
    * Checks for basic plugin requirements, if one check fail don't continue,
    * if all check have passed load the files required to run the plugin.
    *
    * Fired by `plugins_loaded` action hook.
    *
    * @since 1.0
    *
    * @access public
    */
    public function init()
    {
        // Check if Elementor is installed and activated
        if ( ! did_action( 'elementor/loaded' ) ) {
            add_action( 'admin_notices', [ $this, 'ninetheme_admin_notice_missing_main_plugin' ] );
            return;
        }
        // Check for required Elementor version
        if ( ! version_compare( ELEMENTOR_VERSION, self::MINIMUM_ELEMENTOR_VERSION, '>=' ) ) {
            add_action( 'admin_notices', [ $this, 'ninetheme_admin_notice_minimum_elementor_version' ] );
            return;
        }
        // Check for required PHP version
        if ( version_compare( PHP_VERSION, self::MINIMUM_PHP_VERSION, '<' ) ) {
            add_action( 'admin_notices', [ $this, 'ninetheme_admin_notice_minimum_php_version' ] );
            return;
        }
        // register template name for the elementor saved templates
        add_filter( 'elementor/editor/localize_settings', [ $this,'ninetheme_register_template'],10,2 );
        add_filter( 'elementor/icons_manager/additional_tabs', [ $this,'ninetheme_add_custom_icons_tab'],10,2 );

        /* Custom plugin helper functions */
        require_once( NINETHEME_PLUGIN_PATH . '/classes/class-helpers-functions.php' );
        /* Add custom controls elementor section */
        require_once( NINETHEME_PLUGIN_PATH . '/classes/class-custom-elementor-section.php' );
        /* Add custom controls to default widgets */
        require_once( NINETHEME_PLUGIN_PATH . '/classes/class-customizing-default-widgets.php' );
        /* Add custom controls to page settings */
        require_once( NINETHEME_PLUGIN_PATH . '/classes/class-customizing-page-settings.php' );

        if ( is_user_logged_in() ) {
            include_once( NINETHEME_PLUGIN_PATH . '/templates/template-library/library-manager.php' );
            include_once( NINETHEME_PLUGIN_PATH . '/templates/template-library/library-source.php' );
        }

        /* includes/shortcodes/elementor */
        if ( ! get_option( 'disable_ninetheme_list_shortcodes' ) == 1 ) {
            require_once( NINETHEME_PLUGIN_PATH . '/classes/class-list-shortcodes.php' );
        }
        if ( class_exists('WooCommerce') ) {

            /* Add custom wp woocommerce widgets */
            require_once( NINETHEME_PLUGIN_PATH . '/widgets/woocommerce/wp-widgets/widget-product-status.php' );
            require_once( NINETHEME_PLUGIN_PATH . '/widgets/woocommerce/wp-widgets/widget-product-categories.php' );
            require_once( NINETHEME_PLUGIN_PATH . '/widgets/woocommerce/wp-widgets/widget-product-categories-slider.php' );

            if ( ! get_option( 'disable_ninetheme_wc_brands' ) == 1 ) {
                require_once( NINETHEME_PLUGIN_PATH . '/widgets/woocommerce/brands/brands.php' );
            }
            if ( ! get_option( 'disable_ninetheme_wc_campaigns' ) == 1 ) {
                require_once( NINETHEME_PLUGIN_PATH . '/widgets/woocommerce/campaigns/campaigns.php' );
            }
            if ( ! get_option( 'disable_ninetheme_wc_compare' ) == 1 ) {
                require_once( NINETHEME_PLUGIN_PATH . '/widgets/woocommerce/compare/class-compare.php' );
            }
            if ( ! get_option( 'disable_ninetheme_wc_wishlist' ) == 1 ) {
                require_once( NINETHEME_PLUGIN_PATH . '/widgets/woocommerce/wishlist/class-wishlist.php' );
            }
            if ( ! get_option( 'disable_ninetheme_wc_swatches' ) == 1 ) {
                require_once( NINETHEME_PLUGIN_PATH . '/widgets/woocommerce/swatches/class-swatches.php' );
            }
            if ( ! get_option( 'disable_ninetheme_wc_quickview' ) == 1 ) {
                require_once( NINETHEME_PLUGIN_PATH . '/widgets/woocommerce/quick-view/class-quick-view.php' );
            }
            if ( ! get_option( 'disable_ninetheme_product360_builder' ) == 1 ) {
                require_once( NINETHEME_PLUGIN_PATH . '/widgets/woocommerce/product360/product360.php' );
            }
            if ( ! get_option( 'disable_ninetheme_wc_ajax_search' ) == 1 ) {
                //require_once( NINETHEME_PLUGIN_PATH . '/widgets/woocommerce/ajax-search/class-ajax-search.php' );
                require_once( NINETHEME_PLUGIN_PATH . '/widgets/woocommerce/product-search/class-ajax-product-search.php' );
            }
            if ( ! get_option( 'disable_ninetheme_location_taxonomy' ) == 1 ) {
                require_once( NINETHEME_PLUGIN_PATH . '/widgets/woocommerce/location-taxonomy/class-location-taxonomy.php' );
            }

            //add_action( 'init', array( $this, 'register_shop_builder' ) );

            add_action( 'wp_ajax_ninetheme_ajax_tab_slider', [ $this, 'ninetheme_ajax_tab_slider_handler' ] );
            add_action( 'wp_ajax_nopriv_ninetheme_ajax_tab_slider', [ $this, 'ninetheme_ajax_tab_slider_handler' ] );
            add_action( 'woocommerce_single_product_summary', [ $this, 'ninetheme_product_share_buttons' ], 90 );
        }

        if ( ! get_option( 'disable_ninetheme_popups_builder' ) == 1 ) {
            require_once( NINETHEME_PLUGIN_PATH . '/classes/class-popup-builder.php' );
        }

        /* Admin template */
        require_once( NINETHEME_PLUGIN_PATH . '/templates/admin/admin.php' );
        // Categories registered
        add_action( 'elementor/elements/categories_registered', [ $this, 'ninetheme_add_widget_category' ] );
        // Widgets registered
        add_action( 'elementor/widgets/register', [ $this, 'init_widgets' ] );
        add_action( 'elementor/widgets/register', [ $this, 'init_single_widgets' ] );
        // Register Widget Styles
        add_action( 'elementor/frontend/after_enqueue_styles', [ $this, 'widget_styles' ] );
        add_action( 'elementor/frontend/after_enqueue_scripts', [ $this, 'widget_frontend_scripts' ] );
        // Register Widget Scripts
        add_action( 'wp_enqueue_scripts', [ $this, 'widget_scripts' ] );

        add_action('elementor/editor/after_enqueue_styles', [ $this, 'admin_custom_scripts' ]);
        // Register Widget Scripts

        //add_action( 'elementor/ajax/register_actions', [ $this, 'register_actions' ] );
    }

    public function register_actions() {}

    public function ninetheme_register_template( $localized_settings, $config )
    {
        $localized_settings = [
            'i18n' => [
                'my_templates' => esc_html__( 'Crisop Templates', 'crisop' )
            ]
        ];
        return $localized_settings;
    }

    public function admin_custom_scripts()
    {
        // Elementor Editor custom css
        wp_enqueue_style( 'ninetheme-custom-editor', NINETHEME_PLUGIN_URL. 'assets/front/css/plugin-editor.css' );
    }

    public function widget_styles()
    {
        // Plugin custom css
        $rtl = is_rtl() ? '-rtl' : '';
        wp_enqueue_style( 'ninetheme-custom', NINETHEME_PLUGIN_URL. 'assets/front/css/custom'.$rtl.'.css' );
    }

    public function widget_frontend_scripts()
    {
        // custom-scripts
        wp_enqueue_script( 'ninetheme-addons-custom-scripts', NINETHEME_PLUGIN_URL. 'assets/front/js/custom-scripts.js', array( 'jquery' ), self::VERSION, true );
    }

    public function widget_scripts()
    {
        $jquery = array( 'jquery' );
        $version = self::VERSION;

        // vegas slider
        wp_register_style( 'tooltipster', NINETHEME_PLUGIN_URL. 'assets/front/js/tooltip/tooltipster.bundle.css' );
        wp_register_script( 'tooltipster', NINETHEME_PLUGIN_URL. 'assets/front/js/tooltip/tooltipster.bundle.min.js', $jquery, $version, true );

        // vegas slider
        wp_register_style( 'vegas', NINETHEME_PLUGIN_URL. 'assets/front/js/vegas/vegas.css' );
        wp_register_script( 'vegas', NINETHEME_PLUGIN_URL. 'assets/front/js/vegas/vegas.min.js', $jquery, $version, true );

        // magnific-popup-lightbox
        wp_register_script( 'magnific', NINETHEME_PLUGIN_URL. 'assets/front/js/magnific/magnific-popup.min.js', $jquery, $version, true );

        // animated-headline
        wp_register_style( 'animated-headline', NINETHEME_PLUGIN_URL. 'assets/front/js/animated-headline/style.css' );
        wp_register_script( 'animated-headline', NINETHEME_PLUGIN_URL. 'assets/front/js/animated-headline/script.js', [ 'jquery','elementor-frontend' ], $version, true );

        // isotope
        wp_register_script( 'isotope', NINETHEME_PLUGIN_URL. 'assets/front/js/isotope/isotope.min.js', $jquery, $version, true );
        wp_register_script( 'imagesloaded', NINETHEME_PLUGIN_URL. 'assets/front/js/isotope/imagesloaded.pkgd.min.js', $jquery, $version, true );
        wp_register_script( 'anime', NINETHEME_PLUGIN_URL. 'assets/front/js/anime/anime.min.js', $jquery, $version, true );
        wp_register_script( 'wow', NINETHEME_PLUGIN_URL. 'assets/front/js/anime/wow.min.js', $jquery, $version, true );

        // splitting
        wp_register_style( 'splitting', NINETHEME_PLUGIN_URL. 'assets/front/js/splitting/splitting.css', '1.0' );
        wp_register_style( 'splitting-cells', NINETHEME_PLUGIN_URL. 'assets/front/js/splitting/splitting-cells.css' );
        wp_register_script( 'splitting', NINETHEME_PLUGIN_URL. 'assets/front/js/splitting/splitting.min.js', $jquery, $version, true );

        // isotope
        wp_register_style( 'cbp', NINETHEME_PLUGIN_URL . 'assets/front/js/cbp/cubeportfolio.min.css' );
        wp_register_style( 'cbp-custom', NINETHEME_PLUGIN_URL . 'assets/front/js/cbp/cubeportfolio-custom.css' );
        wp_register_script( 'cbp', NINETHEME_PLUGIN_URL. 'assets/front/js/cbp/cubeportfolio.min.js', $jquery, $version, true );

        // jarallax
        wp_register_script( 'jarallax', NINETHEME_PLUGIN_URL. 'assets/front/js/jarallax/jarallax.min.js', $jquery, $version, true );
        wp_register_script( 'particles', NINETHEME_PLUGIN_URL. 'assets/front/js/particles/particles.min.js', $jquery, $version, true );
        wp_register_script( 'tilt', NINETHEME_PLUGIN_URL. 'assets/front/js/tilt/tilt.jquery.min.js', $jquery, $version, true );
        wp_register_script( 'instafeed', NINETHEME_PLUGIN_URL. 'assets/front/js/instafeed/instafeed.min.js', $jquery, $version, true );

        // widget-tab-slider
        wp_register_script( 'widget-tab-slider', NINETHEME_PLUGIN_URL . 'assets/front/js/ajax-tab-slider/script.js', $jquery, $version, true );

        wp_enqueue_script( 'jarallax');
        wp_enqueue_script( 'particles');
        wp_enqueue_style( 'vegas');
        wp_enqueue_script( 'vegas');
    }

    /**
    * Admin notice
    *
    * Warning when the site doesn't have Elementor installed or activated.
    *
    * @since 1.0
    *
    * @access public
    */
    public function ninetheme_admin_notice_missing_main_plugin()
    {
        if ( isset( $_GET['activate'] ) ) {
            unset( $_GET['activate'] );
        }
        $message = sprintf(
            /* translators: 1: Plugin name 2: Elementor */
            esc_html__( '%1$s requires %2$s to be installed and activated.', 'crisop' ),
            '<strong>' . esc_html__( 'Crisop Elementor Addons', 'crisop' ) . '</strong>',
            '<strong>' . esc_html__( 'Elementor', 'crisop' ) . '</strong>'
        );
        printf( '<div class="notice notice-warning is-dismissible"><p>%1$s</p></div>', $message );
    }

    /**
    * Admin notice
    *
    * Warning when the site doesn't have a minimum required Elementor version.
    *
    * @since 1.0
    *
    * @access public
    */
    public function ninetheme_admin_notice_minimum_elementor_version()
    {
        if ( isset( $_GET['activate'] ) ) {
            unset( $_GET['activate'] );
        }
        $message = sprintf(
            /* translators: 1: Plugin name 2: Elementor 3: Required Elementor version */
            esc_html__( '%1$s requires %2$s version %3$s or greater.', 'crisop' ),
            '<strong>' . esc_html__( 'Crisop Elementor Addons', 'crisop' ) . '</strong>',
            '<strong>' . esc_html__( 'Elementor', 'crisop' ) . '</strong>',
             self::MINIMUM_ELEMENTOR_VERSION
        );
        printf( '<div class="notice notice-warning is-dismissible"><p>%1$s</p></div>', $message );
    }

    /**
    * Admin notice
    *
    * Warning when the site doesn't have a minimum required PHP version.
    *
    * @since 1.0
    *
    * @access public
    */
    public function ninetheme_admin_notice_minimum_php_version()
    {
        if ( isset( $_GET['activate'] ) ) {
            unset( $_GET['activate'] );
        }
        $message = sprintf(
            /* translators: 1: Plugin name 2: PHP 3: Required PHP version */
            esc_html__( '%1$s requires %2$s version %3$s or greater.', 'crisop' ),
            '<strong>' . esc_html__( 'Crisop Elementor Addons', 'crisop' ) . '</strong>',
            '<strong>' . esc_html__( 'PHP', 'crisop' ) . '</strong>',
             self::MINIMUM_PHP_VERSION
        );
        printf( '<div class="notice notice-warning is-dismissible"><p>%1$s</p></div>', $message );
    }

    /**
    * Register Widgets Category
    *
    */
    public function ninetheme_add_widget_category( $elements_manager )
    {
        $elements_manager->add_category( 'crisop', [ 'title' => esc_html__( 'Crisop Basic', 'crisop' ),'icon' => 'fa fa-smile-o' ] );
        $elements_manager->add_category( 'ninetheme-header', [ 'title' => esc_html__( 'Crisop Header Elements', 'crisop' ) ] );
        $elements_manager->add_category( 'ninetheme-post', [ 'title' => esc_html__( 'Crisop Post', 'crisop' ) ] );
        $elements_manager->add_category( 'ninetheme-woo', [ 'title' => esc_html__( 'Crisop WooCommerce', 'crisop' ) ] );
        $elements_manager->add_category( 'ninetheme-woo-product', [ 'title' => esc_html__( 'Crisop WooCommerce Product', 'crisop' ) ] );
    }

    public function ninetheme_widgets_list()
    {
        $list = array(
            array( 'name' => 'header-menu-simple',  'class' => 'Ninetheme_Header_Menu_Simple' ),
            array( 'name' => 'header-inline-menu',  'class' => 'Ninetheme_Header_Inline_Mini_Menu' ),
            array( 'name' => 'header-slide-menu',   'class' => 'Ninetheme_Header_Slide_Menu' ),
            array( 'name' => 'toggle-menu',         'class' => 'Ninetheme_Toggle_Menu' ),
            array( 'name' => 'menu-vertical',       'class' => 'Ninetheme_Vertical_Menu' ),
            array( 'name' => 'page-title',          'class' => 'Ninetheme_Page_Title' ),
            array( 'name' => 'button',              'class' => 'Ninetheme_Button' ),
            array( 'name' => 'label',               'class' => 'Ninetheme_Label' ),
            array( 'name' => 'pointer',             'class' => 'Ninetheme_Tooltip_Pointer' ),
            array( 'name' => 'animated-headline',   'class' => 'Ninetheme_Animated_Headline' ),
            array( 'name' => 'swiper-template',     'class' => 'Ninetheme_Template_Slider' ),
            array( 'name' => 'slide-show',          'class' => 'Ninetheme_Slide_Show' ),
            array( 'name' => 'posts-base',          'class' => 'Ninetheme_Posts_Base' ),
            array( 'name' => 'breadcrumbs',         'class' => 'Ninetheme_Breadcrumbs' ),
            array( 'name' => 'image-slider',        'class' => 'Ninetheme_Images_Slider' ),
            array( 'name' => 'instagram-slider',    'class' => 'Ninetheme_Instagram_Slider' ),
            array( 'name' => 'team-slider',         'class' => 'Ninetheme_Team' ),
            array( 'name' => 'fetatures-item',      'class' => 'Ninetheme_Features_Item' ),
            array( 'name' => 'timer',               'class' => 'Ninetheme_Timer' ),
            array( 'name' => 'contact-form-7',      'class' => 'Ninetheme_Contact_Form_7' ),
            array( 'name' => 'testimonials-slider', 'class' => 'Ninetheme_Testimonials' ),
            array( 'name' => 'sidebar-widgets',     'class' => 'Ninetheme_Sidebar_Widgets' ),
            array( 'name' => 'vegas-slider',        'class' => 'Ninetheme_Vegas_Slider' ),
            array( 'name' => 'vegas-template',      'class' => 'Ninetheme_Vegas_Template' ),
            array( 'name' => 'gallery-isotope',     'class' => 'Ninetheme_Gallery' ),
            array( 'name' => 'gallery-carousel',    'class' => 'Ninetheme_Gallery_Slider' ),
            // wocommerce widgets
            array( 'name' => 'woo-tab-slider',          'subfolder' => 'woocommerce', 'class' => 'Ninetheme_Woo_Ajax_Tab_Slider' ),
            array( 'name' => 'woo-grid',                'subfolder' => 'woocommerce', 'class' => 'Ninetheme_Woo_Grid' ),
            array( 'name' => 'woo-special-offer',       'subfolder' => 'woocommerce', 'class' => 'Ninetheme_Woo_Special_Offer' ),
            array( 'name' => 'woo-category-grid',       'subfolder' => 'woocommerce', 'class' => 'Ninetheme_Woo_Category_Grid' ),
            array( 'name' => 'woo-category-list',       'subfolder' => 'woocommerce', 'class' => 'Ninetheme_Woo_Category_List' ),
            array( 'name' => 'woo-list',                'subfolder' => 'woocommerce', 'class' => 'Ninetheme_Woo_Products_List' ),
            array( 'name' => 'woo-slider',              'subfolder' => 'woocommerce', 'class' => 'Ninetheme_Woo_Slider' ),
            array( 'name' => 'woo-slider-list',         'subfolder' => 'woocommerce', 'class' => 'Ninetheme_Woo_Slider_List' ),
            array( 'name' => 'woo-gallery',             'subfolder' => 'woocommerce', 'class' => 'Ninetheme_Woo_Gallery' ),
            array( 'name' => 'woo-banner',              'subfolder' => 'woocommerce', 'class' => 'Ninetheme_Woo_Banner' ),
            array( 'name' => 'woo-banner-slider',       'subfolder' => 'woocommerce', 'class' => 'Ninetheme_Woo_Banner_Slider' ),
            array( 'name' => 'woo-brands',              'subfolder' => 'woocommerce', 'class' => 'Ninetheme_Woo_Brands' ),
            array( 'name' => 'woo-campaigns',           'subfolder' => 'woocommerce', 'class' => 'Ninetheme_Woo_Campaigns' ),
            array( 'name' => 'woo-campaigns-tab',       'subfolder' => 'woocommerce', 'class' => 'Ninetheme_Woo_Campaigns_Tab' ),
            array( 'name' => 'woo-custom-reviews',      'subfolder' => 'woocommerce', 'class' => 'Ninetheme_Woo_Custom_Reviews' ),
            array( 'name' => 'woo-banner-hero-slider',  'subfolder' => 'woocommerce', 'class' => 'Ninetheme_Woo_Banner_Hero_Slider' ),
            array( 'name' => 'woo-header-actions',      'subfolder' => 'woocommerce', 'class' => 'Ninetheme_Woo_Header_Actions' ),
            array( 'name' => 'woo-header-products',     'subfolder' => 'woocommerce', 'class' => 'Ninetheme_Woo_Header_Products' ),
            array( 'name' => 'woo-header-locations',    'subfolder' => 'woocommerce', 'class' => 'Ninetheme_Woo_Header_Locations' ),
            array( 'name' => 'woo-ajax-search',         'subfolder' => 'woocommerce', 'class' => 'Ninetheme_Woo_Ajax_Search' ),
            array( 'name' => 'woo-archive-description', 'subfolder' => 'woocommerce', 'class' => 'Ninetheme_WC_Archive_Description' ),
            array( 'name' => 'woo-page-title',          'subfolder' => 'woocommerce', 'class' => 'Ninetheme_WC_Page_Title' ),
            array( 'name' => 'woo-shop-filter',         'subfolder' => 'woocommerce', 'class' => 'Ninetheme_Woo_Shop_Filter' ),
            array( 'name' => 'woo-categories',          'subfolder' => 'woocommerce', 'class' => 'Ninetheme_WC_Categories' ),
            array( 'name' => 'woo-product-item',        'subfolder' => 'woocommerce', 'class' => 'Ninetheme_Woo_Product_Item' ),
            array( 'name' => 'woo-deals-single',        'subfolder' => 'woocommerce', 'class' => 'Ninetheme_Woo_Deals_Single' )
        );
        return $list;
    }

    /**
    * Init Widgets
    */
    public function init_widgets()
    {
        $widgets = $this->ninetheme_widgets_list();

        if ( ! empty( $widgets ) ) {

            foreach ( $widgets as $widget ) {

                $option = 'disable_'.str_replace( '-', '_', $widget['name'] );
                $path = NINETHEME_PLUGIN_PATH . '/widgets/';
                $file = $widget['name'] . '.php';
                $file = isset( $widget['subfolder'] ) != '' ? $path.$widget['subfolder'] . '/' . $widget['name']. '.php' : $path.$file;
                $class = 'Elementor\\'.$widget['class'];

                if ( ! get_option( $option ) == 1 ) {

                    if ( file_exists( $file ) ) {
                        require_once( $file );
                        \Elementor\Plugin::instance()->widgets_manager->register( new $class() );
                    }
                }
            }
        }
    }

    /**
    * Register Single Post Widgets
    */
    public function ninetheme_single_widgets_list()
    {
        $list = array(
            // post widgets
            array( 'post-type' => 'post', 'name' => 'post-data', 'class' => 'Ninetheme_Post_Data' ),

            // wocommerce widgets
            array( 'post-type' => 'product','name' => 'add-to-cart',                    'subfolder' => 'woocommerce/product', 'class' => 'Ninetheme_WC_Add_To_Cart' ),
            array( 'post-type' => 'product','name' => 'breadcrumb',                     'subfolder' => 'woocommerce/product', 'class' => 'Ninetheme_WC_Breadcrumb' ),
            array( 'post-type' => 'product','name' => 'product-add-to-cart',            'subfolder' => 'woocommerce/product', 'class' => 'Ninetheme_WC_Product_Add_To_Cart' ),
            array( 'post-type' => 'product','name' => 'product-additional-information', 'subfolder' => 'woocommerce/product', 'class' => 'Ninetheme_WC_Product_Additional_Information' ),
            array( 'post-type' => 'product','name' => 'product-data-tabs',              'subfolder' => 'woocommerce/product', 'class' => 'Ninetheme_WC_Product_Data_Tabs' ),
            array( 'post-type' => 'product','name' => 'product-images',                 'subfolder' => 'woocommerce/product', 'class' => 'Ninetheme_WC_Product_Images' ),
            array( 'post-type' => 'product','name' => 'product-meta',                   'subfolder' => 'woocommerce/product', 'class' => 'Ninetheme_WC_Product_Meta' ),
            array( 'post-type' => 'product','name' => 'product-price',                  'subfolder' => 'woocommerce/product', 'class' => 'Ninetheme_WC_Product_Price' ),
            array( 'post-type' => 'product','name' => 'product-rating',                 'subfolder' => 'woocommerce/product', 'class' => 'Ninetheme_WC_Product_Rating' ),
            array( 'post-type' => 'product','name' => 'product-related',                'subfolder' => 'woocommerce/product', 'class' => 'Ninetheme_WC_Product_Related' ),
            array( 'post-type' => 'product','name' => 'product-short-description',      'subfolder' => 'woocommerce/product', 'class' => 'Ninetheme_WC_Product_Short_Description' ),
            array( 'post-type' => 'product','name' => 'product-stock',                  'subfolder' => 'woocommerce/product', 'class' => 'Ninetheme_WC_Product_Stock' ),
            array( 'post-type' => 'product','name' => 'product-title',                  'subfolder' => 'woocommerce/product', 'class' => 'Ninetheme_WC_Product_Title' ),
            array( 'post-type' => 'product','name' => 'product-upsell',                 'subfolder' => 'woocommerce/product', 'class' => 'Ninetheme_WC_Product_Upsell' ),
            array( 'post-type' => 'product','name' => 'single-elements',                'subfolder' => 'woocommerce/product', 'class' => 'Ninetheme_WC_Single_Elements' )
        );
        return $list;
    }

    /**
    * Init Single Post Widgets
    */
    public function init_single_widgets()
    {
        $widgets = $this->ninetheme_single_widgets_list();
        global $post;
        $ninetheme_post_type = false;

        if ( ! empty( $widgets ) && !is_404() && !is_archive() ) {

            $ninetheme_post_type = get_post_type( $post->ID );

            $count = 0;

            foreach ( $widgets as $widget ) {

                if ( $ninetheme_post_type == $widgets[$count]['post-type'] || $ninetheme_post_type == 'elementor_library' ) {

                    $option = 'disable_'.str_replace( '-', '_', $widget['name'] );
                    $path = NINETHEME_PLUGIN_PATH . '/widgets/';
                    $file = $widget['name'] . '.php';
                    $file = isset( $widget['subfolder'] ) != '' ? $path.$widget['subfolder'] . '/' . $widget['name']. '.php' : $path.$file;
                    $class = 'Elementor\\'.$widget['class'];

                    if ( ! get_option( $option ) == 1 ) {

                        if ( file_exists( $file ) ) {

                            require_once( $file );
                            \Elementor\Plugin::instance()->widgets_manager->register( new $class() );
                        }
                    }
                }
                $count++;
            }
        }
    }

    /*
    * List Icons
    */

    public function ninetheme_add_custom_icons_tab( $tabs = array() )
    {
        $new_icons = array(
            'shopping-bags',
            'magnifying-glass',
            'menu',
            'heart',
            'two-arrows',
            'shopping-bag',
            'user',
            'menu-1',
            'justification',
            'scroll',
            'shuffle',
            'shuffle-1',
            'supermarket',
            'witness',
            'quote-left',
            'list',
            'menu-2',
            'grid',
            'project',
            'revenue',
            'quality',
            'shuttle',
            'invoice',
            'secure-payment',
            '24-hours-support',
            'placeholder',
            'telephone',
            'mail',
            'zoom-in',
            'right-arrow',
            'left-arrow',
            'cancel',
            'cancel-1',
            'done',
            'check',
            'select',
            'cancel-2',
            'password',
            'scroll-1',
            'calendar',
            'exit',
            'plus',
            'crosshair',
            'loupe',
            'magnifying-glass-1',
            'right-quote',
            'plus-1',
            'lock',
            'copyright',
            'list-1'
        );

        $tabs['ninetheme-custom-icons'] = array(
            'name' => 'ninetheme-custom-icons',
            'label' => esc_html__( 'Crisop Icons', 'crisop' ),
            'labelIcon' => 'flaticon-heart',
            'prefix' => 'flaticon-',
            'displayPrefix' => 'ninetheme-icons',
            'url' => get_template_directory_uri() . '/css/flaticon/flaticon.css',
            'icons' => $new_icons,
            'ver' => '1.0.0',
        );

        return $tabs;
    }

    public function ninetheme_ajax_tab_slider_handler() {
        global $product;
        $args = array(
            'post_type'      => 'product',
            'posts_per_page' => $_POST['per_page'],
            'order'          => $_POST['order'],
            'orderby'        => $_POST['orderby']
        );

        $scenario = $_POST['scenario'];

        if ( 'featured' == $scenario ) {

            if ( $_POST['cat_id'] != null ) {
                $args['tax_query'] = array(
                    'relation' => 'AND',
                    array(
                        'taxonomy' => 'product_cat',
                        'field'    => 'id',
                        'terms'    => $_POST['cat_id']
                    ),
                    array(
                        'taxonomy' => 'product_visibility',
                        'field'    => 'name',
                        'terms'    => 'featured',
                        'operator' => 'IN'
                    )
                );
            }

        } elseif ( 'on-sale' == $scenario ) {

            $args['meta_query'] = array(
                'relation' => 'OR',
                array( // Simple products type
                    'key'     => '_sale_price',
                    'value'   => 0,
                    'compare' => '>',
                    'type'    => 'numeric'
                ),
                array( // Variable products type
                    'key'     => '_min_variation_sale_price',
                    'value'   => 0,
                    'compare' => '>',
                    'type'    => 'numeric'
                )
            );

        } elseif ( 'best' == $scenario ) {

            $args['orderby']  = 'meta_value_num';
            $args['meta_key'] = 'total_sales';

        } else {

            if ( $_POST['cat_id'] != null ) {
                $args['tax_query'] = array(
                    array(
                        'taxonomy' => 'product_cat',
                        'field'    => 'id',
                        'terms'    => $_POST['cat_id']
                    )
                );
            }
            $args['orderby'] = $settings['orderby'];
        }

        $the_query = new \WP_Query( $args );
        if ( $the_query->have_posts() && 1 == $counttwo ) {
            while ( $the_query->have_posts() ) {
                $the_query->the_post();
                $product = new \WC_Product(get_the_ID());
                $visibility = $product->get_catalog_visibility();

                if ( $visibility != 'hidden' ) {
                    echo '<div class="swiper-slide product_item visibility-'.$visibility.'">';
                        wc_get_template_part( 'content', 'product' );
                    echo '</div>';
                }
            }
        }


        $loop = new WP_Query( $args );
        if ( $loop->have_posts() ) {
            while ( $loop->have_posts() ) {
                $loop->the_post();
                $product = new WC_Product(get_the_ID());
                $visibility = $product->get_catalog_visibility();
                if ( $visibility != 'hidden' ) {
                    echo '<div class="swiper-slide product_item '.$_POST['img_size'].'">';
                        wc_get_template_part( 'content', 'product' );
                    echo '</div>';
                }
            }
        } else {
            echo esc_html__( 'No products found','crisop' );
        }
        wp_reset_postdata();

        wp_die();
    }

    /**
    * ------------------------------------------------------------------------------------------------
    * Single product share buttons
    * ------------------------------------------------------------------------------------------------
    */
    public function ninetheme_product_share_buttons()
    {
        if ( !function_exists( 'ninetheme_settings' ) || false == apply_filters( 'ninetheme_product_share_buttons', '__return_true' ) ) {
            return;
        }
        if ( '1' == ninetheme_settings( 'single_shop_share_visibility', '0' ) ) {

            $type = ninetheme_settings( 'single_shop_share_type' );
            $title = 'share' === $type ? esc_html__( 'Share', 'crisop' ) : esc_html__( 'Follow', 'crisop' );
            ?>
            <div class="ninetheme-summary-item ninetheme-product-share">
                <span class="share-title ninetheme-small-title"><?php echo esc_html( $title ); ?>: </span> <?php $this->ninetheme_shortcode_social( array( 'type' => $type ) ); ?>
            </div>
            <?php
        }
    }

    public function ninetheme_shortcode_social($args) {

        if ( !function_exists( 'ninetheme_settings' ) ) {
            return;
        }

        $def_args = array(
            'type' => 'share',
            'page_link' => false
        );

        $type      = !empty( $args ) ? $args['type'] : $def_args['type'];
        $page_link = !empty( $args ) && isset( $args['page_link'] ) ? $args['page_link'] : $def_args['page_link'];
        $target    = "_blank";

        $thumb_id   = get_post_thumbnail_id();
        $thumb_url  = wp_get_attachment_image_src($thumb_id, 'thumbnail-size', true);
        $page_title = get_the_title();

        if ( ! $page_link ) {
            $page_link = get_the_permalink();
        }

        if ( class_exists( 'WooCommerce' ) && is_shop() ) {
            $page_link = get_permalink( get_option( 'woocommerce_shop_page_id' ) );
        }
        if ( class_exists( 'WooCommerce' ) && ( is_product_category() || is_category() ) ) {
            $page_link = get_category_link( get_queried_object()->term_id );
        }
        if ( is_home() && ! is_front_page() ) {
            $page_link = get_permalink( get_option( 'page_for_posts' ) );
        }

        ?>
        <div class="ninetheme-social-icons">
            <?php if ( '1' == ninetheme_settings( 'share_facebook', '0' ) ) : ?>
                <a rel="noopener noreferrer nofollow" href="<?php echo 'follow' === $type ? esc_url(ninetheme_settings( 'fb_link' )) : 'https://www.facebook.com/sharer/sharer.php?u=' . $page_link; ?>" target="<?php echo esc_attr( $target ); ?>" class="social-facebook" data-title="facebook">
                    <i class="fab fa-facebook-f"></i>
                </a>
            <?php endif ?>

            <?php if ( '1' == ninetheme_settings('share_twitter', '0') ) : ?>
                <a rel="noopener noreferrer nofollow" href="<?php echo 'follow' === $type ? esc_url(ninetheme_settings( 'twitter_link' )) : 'https://twitter.com/share?url=' . $page_link; ?>" target="<?php echo esc_attr( $target ); ?>" class="social-twitter" data-title="twitter">
                    <i class="fab fa-twitter"></i>
                </a>
            <?php endif ?>

            <?php if ( '1' == ninetheme_settings('share_instagram', '0') && $type == 'follow' && '' != ninetheme_settings( 'instagram_link' ) ) : ?>
                <a rel="noopener noreferrer nofollow" href="<?php echo 'follow' === $type ? esc_url(ninetheme_settings( 'instagram_link' )) : '' . $page_link; ?>" target="<?php echo esc_attr( $target ); ?>" class="social-instagram" data-title="instagram">
                    <i class="fab fa-instagram"></i>
                </a>
            <?php endif ?>

            <?php if ( '1' == ninetheme_settings('share_youtube', '0') && $type == 'follow' && '' != ninetheme_settings( 'youtube_link' ) ) : ?>
                <a rel="noopener noreferrer nofollow" href="<?php echo 'follow' === $type ? esc_url(ninetheme_settings( 'youtube_link' )) : '' . $page_link; ?>" target="<?php echo esc_attr( $target ); ?>" class="social-youtube" data-title="youtube">
                    <i class="fab fa-youtube"></i>
                </a>
            <?php endif ?>

            <?php if ( '1' == ninetheme_settings('share_vimeo', '0') && $type == 'follow' && '' != ninetheme_settings( 'vimeo_link' ) ) : ?>
                <a rel="noopener noreferrer nofollow" href="<?php echo 'follow' === $type ? esc_url( ninetheme_settings( 'vimeo_link' ) ) : '' . $page_link; ?>" target="<?php echo esc_attr( $target ); ?>" class="social-vimeo" data-title="vimeo">
                    <i class="fab fa-vimeo-v"></i>
                </a>
            <?php endif ?>

            <?php if ( '1' == ninetheme_settings('share_pinterest', '0') ) : ?>
                <a rel="noopener noreferrer nofollow" href="<?php echo 'follow' === $type ? esc_url(ninetheme_settings( 'pinterest_link' )) : 'https://pinterest.com/pin/create/button/?url=' . $page_link . '&media=' . $thumb_url[0] . '&description=' . urlencode( $page_title ); ?>" target="<?php echo esc_attr( $target ); ?>" class="social-pinterest" data-title="pinterest">
                    <i class="fab fa-pinterest"></i>
                </a>
            <?php endif ?>

            <?php if ( '1' == ninetheme_settings('share_linkedin', '0') ) : ?>
                <a rel="noopener noreferrer nofollow" href="<?php echo 'follow' === $type ? esc_url(ninetheme_settings( 'linkedin_link' )) : 'https://www.linkedin.com/shareArticle?mini=true&url=' . $page_link; ?>" target="<?php echo esc_attr( $target ); ?>" class="social-linkedin" data-title="linkedin">
                    <i class="fab fa-linkedin"></i>
                </a>
            <?php endif ?>

            <?php if ( '1' == ninetheme_settings('share_tumblr', '0') && $type == 'follow' && '' != ninetheme_settings( 'tumblr_link' ) ) : ?>
                <a rel="noopener noreferrer nofollow" href="<?php echo 'follow' === $type ? esc_url(ninetheme_settings( 'tumblr_link' )) : '' . $page_link; ?>" target="<?php echo esc_attr( $target ); ?>" class="social-tumblr" data-title="tumblr">
                    <i class="fab fa-tumblr"></i>
                </a>
            <?php endif ?>

            <?php if ( '1' == ninetheme_settings('share_flickr', '0') && $type == 'follow' && '' != ninetheme_settings( 'flickr_link' ) ): ?>
                <a rel="noopener noreferrer nofollow" href="<?php echo 'follow' === $type ? esc_url(ninetheme_settings( 'flickr_link' )) : '' . $page_link; ?>" target="<?php echo esc_attr( $target ); ?>" class="social-flickr" data-title="flickr">
                    <i class="fab fa-flickr"></i>
                </a>
            <?php endif ?>

            <?php if ( '1' == ninetheme_settings('share_github', '0') && $type == 'follow' && '' != ninetheme_settings( 'github_link' ) ) : ?>
                <a rel="noopener noreferrer nofollow" href="<?php echo 'follow' === $type ? esc_url(ninetheme_settings( 'github_link' )) : '' . $page_link; ?>" target="<?php echo esc_attr( $target ); ?>" class="social-github" data-title="github">
                    <i class="fab fa-github"></i>
                </a>
            <?php endif ?>

            <?php if ( '1' == ninetheme_settings('share_behance', '0') && $type == 'follow' && '' != ninetheme_settings( 'behance_link' ) ): ?>
                <a rel="noopener noreferrer nofollow" href="<?php echo 'follow' === $type ? esc_url(ninetheme_settings( 'behance_link' )) : '' . $page_link; ?>" target="<?php echo esc_attr( $target ); ?>" class="social-behance" data-title="behance">
                    <i class="fab fa-behance"></i>
                </a>
            <?php endif ?>

            <?php if ( '1' == ninetheme_settings('share_dribbble', '0') && $type == 'follow' && '' != ninetheme_settings( 'dribbble_link' ) ) : ?>
                <a rel="noopener noreferrer nofollow" href="<?php echo 'follow' === $type ? esc_url(ninetheme_settings( 'dribbble_link' )) : '' . $page_link; ?>" target="<?php echo esc_attr( $target ); ?>" class="social-dribbble" data-title="dribbble">
                    <i class="fab fa-dribbble"></i>
                </a>
            <?php endif ?>

            <?php if ( '1' == ninetheme_settings('share_soundcloud', '0') && $type == 'follow' && '' != ninetheme_settings( 'soundcloud_link' ) ) : ?>
                <a rel="noopener noreferrer nofollow" href="<?php echo 'follow' === $type ? esc_url(ninetheme_settings( 'soundcloud_link' )) : '' . $page_link; ?>" target="<?php echo esc_attr( $target ); ?>" class="social-soundcloud" data-title="soundcloud">
                    <i class="fab fa-soundcloud"></i>
                </a>
            <?php endif ?>

            <?php if ( '1' == ninetheme_settings('share_spotify', '0') && $type == 'follow' && '' != ninetheme_settings( 'spotify_link' ) ) : ?>
                <a rel="noopener noreferrer nofollow" href="<?php echo 'follow' === $type ? esc_url(ninetheme_settings( 'spotify_link' )) : '' . $page_link; ?>" target="<?php echo esc_attr( $target ); ?>" class="social-spotify" data-title="spotify">
                    <i class="fab fa-spotify"></i>
                </a>
            <?php endif ?>

            <?php if ( '1' == ninetheme_settings('share_ok', '0') ) : ?>
                <a rel="noopener noreferrer nofollow" href="<?php echo 'follow' === $type ? esc_url(ninetheme_settings( 'ok_link' )) : 'https://connect.ok.ru/offer?url=' . $page_link; ?>" target="<?php echo esc_attr( $target ); ?>" class="social-ok" data-title="ok">
                    <i class="fab fa-odnoklassniki-square"></i>
                </a>
            <?php endif ?>

            <?php if ( '1' == ninetheme_settings('share_whatsapp', '0') ) : ?>
                <a rel="noopener noreferrer nofollow" href="<?php echo 'follow' === $type ? ( ninetheme_settings( 'whatsapp_link' )) : 'https://api.whatsapp.com/send?text=' . urlencode( $page_link ); ?>" target="<?php echo esc_attr( $target ); ?>" class="whatsapp-desktop social-whatsapp" data-title="whatsapp">
                    <i class="fab fa-whatsapp"></i>
                </a>

                <a rel="noopener noreferrer nofollow" href="<?php echo 'follow' === $type ? ( ninetheme_settings( 'whatsapp_link' ) ) : 'whatsapp://send?text=' . urlencode( $page_link ); ?>" target="<?php echo esc_attr( $target ); ?>" class="whatsapp-mobile social-whatsapp">
                    <i class="fab fa-whatsapp"></i>
                </a>
            <?php endif ?>

            <?php if ( '1' == ninetheme_settings('share_telegram', '0') ) : ?>
                <a rel="noopener noreferrer nofollow" href="<?php echo 'follow' === $type ? ( ninetheme_settings( 'tg_link' )) : 'https://telegram.me/share/url?url=' . $page_link; ?>" target="<?php echo esc_attr( $target ); ?>" class="social-telegram" data-title="telegram">
                    <i class="fab fa-telegram"></i>
                </a>
            <?php endif ?>

            <?php if ( '1' == ninetheme_settings('share_viber', '0') && $type == 'share' && ninetheme_settings( 'share_viber' ) ) : ?>
                <a rel="noopener noreferrer nofollow" href="<?php echo 'viber://forward?text=' . $page_link; ?>" target="<?php echo esc_attr( $target ); ?>" class="social-viber" data-title="viber">
                    <i class="fab fa-viber"></i>
                </a>
            <?php endif ?>

            <?php if ( '1' == ninetheme_settings('share_vk', '0') ) : ?>
                <a rel="noopener noreferrer nofollow" href="<?php echo 'follow' === $type ? ( ninetheme_settings( 'vk_link' )) : 'https://vk.com/share.php?url=' . $page_link . '&image=' . $thumb_url[0] . '&title=' . $page_title; ?>" target="<?php echo esc_attr( $target ); ?>" class="social-vk" data-title="vk">
                    <i class="fab fa-vk"></i>
                </a>
            <?php endif ?>

            <?php if ( '1' == ninetheme_settings('share_snapchat', '0') && $type == 'follow' && '' != ninetheme_settings( 'snapchat_link' ) ): ?>
                <a rel="noopener noreferrer nofollow" href="<?php echo ninetheme_settings( 'snapchat_link' ); ?>" target="<?php echo esc_attr( $target ); ?>" class="social-snapchat" data-title="snapchat">
                    <i class="fab fa-snapchat"></i>
                </a>
            <?php endif ?>

            <?php if ( '1' == ninetheme_settings('share_tiktok', '0') && $type == 'follow' && '' != ninetheme_settings( 'tiktok_link' ) ): ?>
                <a rel="noopener noreferrer nofollow" href="<?php echo ninetheme_settings( 'tiktok_link' ); ?>" target="<?php echo esc_attr( $target ); ?>" class="social-tiktok" data-title="tiktok">
                    <i class="fab fa-tiktok"></i>
                </a>
            <?php endif ?>

        </div>
        <?php
    }
    /*
    public function register_shop_builder() {

    	/**
    	 * Post Type: Shop Builder.
    	 */
    /*
    	$labels = [
    		"name" => __( "Shop Builder", "crisop" ),
    		"singular_name" => __( "Shop Builder", "crisop" ),
    		"menu_name" => __( "Shop Builder", "crisop" ),
    		"all_items" => __( "All Shop Builder", "crisop" ),
    		"add_new" => __( "Add new", "crisop" ),
    		"add_new_item" => __( "Add new Shop Builder", "crisop" ),
    		"edit_item" => __( "Edit Shop Builder", "crisop" ),
    		"new_item" => __( "New Shop Builder", "crisop" ),
    		"view_item" => __( "View Shop Builder", "crisop" ),
    		"view_items" => __( "View Shop Builder", "crisop" ),
    		"search_items" => __( "Search Shop Builder", "crisop" ),
    		"not_found" => __( "No Shop Builder found", "crisop" ),
    		"not_found_in_trash" => __( "No Shop Builder found in trash", "crisop" ),
    		"parent" => __( "Parent Shop Builder:", "crisop" ),
    		"featured_image" => __( "Featured image for this Shop Builder", "crisop" ),
    		"set_featured_image" => __( "Set featured image for this Shop Builder", "crisop" ),
    		"remove_featured_image" => __( "Remove featured image for this Shop Builder", "crisop" ),
    		"use_featured_image" => __( "Use as featured image for this Shop Builder", "crisop" ),
    		"archives" => __( "Shop Builder archives", "crisop" ),
    		"insert_into_item" => __( "Insert into Shop Builder", "crisop" ),
    		"uploaded_to_this_item" => __( "Upload to this Shop Builder", "crisop" ),
    		"filter_items_list" => __( "Filter Shop Builder list", "crisop" ),
    		"items_list_navigation" => __( "Shop Builder list navigation", "crisop" ),
    		"items_list" => __( "Shop Builder list", "crisop" ),
    		"attributes" => __( "Shop Builder attributes", "crisop" ),
    		"name_admin_bar" => __( "Shop Builder", "crisop" ),
    		"item_published" => __( "Shop Builder published", "crisop" ),
    		"item_published_privately" => __( "Shop Builder published privately.", "crisop" ),
    		"item_reverted_to_draft" => __( "Shop Builder reverted to draft.", "crisop" ),
    		"item_scheduled" => __( "Shop Builder scheduled", "crisop" ),
    		"item_updated" => __( "Shop Builder updated.", "crisop" ),
    		"parent_item_colon" => __( "Parent Shop Builder:", "crisop" ),
    	];

    	$args = [
    		"label" => __( "Shop Builder", "crisop" ),
    		"labels" => $labels,
    		"description" => "",
    		"public" => true,
    		"publicly_queryable" => true,
    		"show_ui" => true,
    		"show_in_rest" => true,
    		"rest_base" => "",
    		"rest_controller_class" => "WP_REST_Posts_Controller",
    		"rest_namespace" => "wp/v2",
    		"has_archive" => false,
    		"show_in_menu" => "'edit.php?post_type=ninetheme_popups&tabs_group=shop_builder'",
    		"show_in_nav_menus" => true,
    		"delete_with_user" => false,
    		"exclude_from_search" => false,
    		"capability_type" => "post",
    		"map_meta_cap" => true,
    		"hierarchical" => false,
    		"can_export" => true,
    		"rewrite" => [ "slug" => "elementor_library", "with_front" => true ],
    		"query_var" => true,
    		"menu_icon" => "dashicons-admin-home",
    		"supports" => [ "title", "editor", "thumbnail", "excerpt", "custom-fields", "comments", "revisions", "author", "page-attributes" ],
    		"show_in_graphql" => false,
    	];

    	register_post_type( "ninetheme_shop_build", $args );

    }
    */

}
Ninetheme_Elementor_Addons::instance();
