<?php

namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) exit; // If this file is called directly, abort.

class Ninetheme_Button extends Widget_Base {
    use Ninetheme_Helper;
    public function get_name() {
        return 'ninetheme-button';
    }
    public function get_title() {
        return 'Button (N)';
    }
    public function get_icon() {
        return 'eicon-button';
    }
    public function get_categories() {
        return [ 'crisop' ];
    }
    public function get_style_depends() {
        return [ 'tooltipster','magnific' ];
    }
    public function get_script_depends() {
        return [ 'tooltipster', 'magnific' ];
    }
    // Registering Controls
    protected function register_controls() {
        $is_left = is_rtl() ? 'left' : 'right';
        $is_right = is_rtl() ? 'right' : 'left';
        /*****   Button Options   ******/
        $this->start_controls_section('btn_settings',
            [
                'label' => esc_html__( 'Button', 'crisop' ),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );
        $this->add_control( 'btn_action',
            [
                'label' => esc_html__( 'Action Type', 'crisop' ),
                'type' => Controls_Manager::SELECT,
                'default' => 'link',
                'options' => [
                    'link' => esc_html__( 'Link', 'crisop' ),
                    'image' => esc_html__( 'Single Image', 'crisop' ),
                    'youtube' => esc_html__( 'Youtube', 'crisop' ),
                    'vimeo' => esc_html__( 'Vimeo', 'crisop' ),
                    'map' => esc_html__( 'Google Map', 'crisop' ),
                    'html5' => esc_html__( 'HTML5 Video', 'crisop' ),
                    'modal' => esc_html__( 'Modal Content', 'crisop' ),
                    'gallery' => esc_html__( 'Gallery Images', 'crisop' )
                ]
            ]
        );
        $this->add_control( 'link_type',
            [
                'label' => esc_html__( 'Link Type', 'crisop' ),
                'type' => Controls_Manager::SELECT,
                'default' => 'external',
                'options' => [
                    'external' => esc_html__( 'External', 'crisop' ),
                    'internal' => esc_html__( 'Internal', 'crisop' ),
                ],
                'condition' => ['btn_action' => 'link']
            ]
        );
        $this->add_control( 'text',
            [
                'label' => esc_html__( 'Button Text', 'crisop' ),
                'type' => Controls_Manager::TEXT,
                'label_block' => true,
                'default' => esc_html__( 'Button Text', 'crisop' )
            ]
        );
        $this->add_control( 'btn_id',
            [
                'label' => esc_html__( 'Button ID', 'crisop' ),
                'type' => Controls_Manager::TEXT,
                'label_block' => true,
                'default' => ''
            ]
        );
        $this->add_control( 'link',
            [
                'label' => esc_html__( 'Button Link', 'crisop' ),
                'type' => Controls_Manager::URL,
                'label_block' => true,
                'default' => [
                    'url' => '#',
                    'is_external' => ''
                ],
                'show_external' => true,
                'condition' => ['btn_action' => 'link']
            ]
        );
        $this->add_control( 'images',
            [
                'label' => esc_html__( 'Images', 'crisop' ),
                'type' => Controls_Manager::GALLERY,
                'condition' => ['btn_action' => 'gallery']
            ]
        );
        $this->add_control( 'image',
            [
                'label' => esc_html__( 'Image', 'crisop' ),
                'type' => Controls_Manager::MEDIA,
                'default' => ['url' => Utils::get_placeholder_image_src()],
                'condition' => ['btn_action' => 'image']
            ]
        );
        $this->add_control( 'ltitle',
            [
                'label' => esc_html__( 'Lightbox Title', 'crisop' ),
                'type' => Controls_Manager::TEXTAREA,
                'label_block' => true,
                'default' => 'Phone Name',
                'condition' => ['btn_action' => 'image']
            ]
        );
        $this->add_control( 'youtube',
            [
                'label' => esc_html__( 'Youtube Video URL', 'crisop' ),
                'type' => Controls_Manager::TEXTAREA,
                'label_block' => true,
                'default' => 'http://www.youtube.com/watch?v=AeeE6PyU-dQ',
                'condition' => ['btn_action' => 'youtube']
            ]
        );
        $this->add_control( 'vimeo',
            [
                'label' => esc_html__( 'Vimeo Video URL', 'crisop' ),
                'type' => Controls_Manager::TEXTAREA,
                'label_block' => true,
                'default' => 'https://vimeo.com/39493181',
                'condition' => ['btn_action' => 'vimeo']
            ]
        );
        $this->add_control( 'map',
            [
                'label' => esc_html__( 'Iframe Map URL', 'crisop' ),
                'type' => Controls_Manager::TEXTAREA,
                'label_block' => true,
                'default' => 'https://maps.google.com/maps?q=221B+Baker+Street,+London,+United+Kingdom&amp;hl=en&amp;t=v&amp;hnear=221B+Baker+St,+London+NW1+6XE,+United+Kingdom',
                'condition' => ['btn_action' => 'map']
            ]
        );
        $this->add_control( 'html5',
            [
                'label' => esc_html__( 'HTML5 Video URL', 'crisop' ),
                'type' => Controls_Manager::TEXTAREA,
                'label_block' => true,
                'default' => '',
                'pleaceholder' => esc_html__( 'Add your local video here', 'crisop' ),
                'condition' => ['btn_action' => 'html5']
            ]
        );
        $this->add_control( 'modal_content',
            [
                'label' => esc_html__( 'Modal Content', 'crisop' ),
                'type' => Controls_Manager::WYSIWYG,
                'label_block' => true,
                'default' => '<h3>Modal</h3><p>Lorem ipsum dolor sit amet, consectetur adipiscing elit. Nulla rhoncus pharetra dui, nec tempus tellus maximus et. Sed sed elementum ligula, id cursus leo. Duis imperdiet tortor id condimentum hendrerit.</p>',
                'pleaceholder' => esc_html__( 'Add html content here', 'crisop' ),
                'condition' => ['btn_action' => 'modal']
            ]
        );
        $this->add_control( 'modal_width',
            [
                'label' => esc_html__( 'Modal Content Width', 'crisop' ),
                'type' => Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'max' => 2000
                    ]
                ],
                'default' => [
                    'unit' => 'px',
                    'size' => 600,
                ],
                'condition' => ['btn_action' => 'modal']
            ]
        );
        $this->add_responsive_control( 'alignment',
            [
                'label' => esc_html__( 'Alignment', 'crisop' ),
                'type' => Controls_Manager::CHOOSE,
                'selectors' => ['{{WRAPPER}} .ninetheme-button-wrapper' => 'text-align: {{VALUE}};'],
                'options' => [
                    'left' => [
                        'title' => esc_html__( 'Left', 'crisop' ),
                        'icon' => 'eicon-h-align-left'
                    ],
                    'center' => [
                        'title' => esc_html__( 'Center', 'crisop' ),
                        'icon' => 'eicon-h-align-center'
                    ],
                    'right' => [
                        'title' => esc_html__( 'Right', 'crisop' ),
                        'icon' => 'eicon-h-align-right'
                    ]
                ],
                'toggle' => true,
                'default' => ''
            ]
        );
        $this->add_control( 'use_icon',
            [
                'label' => esc_html__( 'Use Icon', 'crisop' ),
                'type' => Controls_Manager::SWITCHER,
                'default' => 'no',
            ]
        );
        $this->add_control( 'icon',
            [
                'label' => esc_html__( 'Button Icon', 'crisop' ),
                'type' => Controls_Manager::ICONS,
                'default' => [
                    'value' => '',
                    'library' => 'solid'
                ],
                'condition' => ['use_icon' => 'yes']
            ]
        );
        $this->add_control( 'icon_pos',
            [
                'label' => esc_html__( 'Icon Position', 'crisop' ),
                'type' => Controls_Manager::SELECT,
                'default' => 'btn-icon-right',
                'options' => [
                    'btn-icon-'.$is_right => esc_html__( 'Before', 'crisop' ),
                    'btn-icon-'.$is_left => esc_html__( 'After', 'crisop' ),
                    'btn-icon-top' => esc_html__( 'Top', 'crisop' ),
                    'btn-icon-bottom' => esc_html__( 'Bottom', 'crisop' )
                ],
                'condition' => ['use_icon' => 'yes']
            ]
        );
        $this->add_control( 'icon_spacing',
            [
                'label' => esc_html__( 'Icon Spacing', 'crisop' ),
                'type' => Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'max' => 300
                    ]
                ],
                'selectors' => [
                    '{{WRAPPER}} .ninetheme-button-wrapper .btn-icon-left i' => 'margin-right: {{SIZE}}px;',
                    '{{WRAPPER}} .ninetheme-button-wrapper .btn-icon-right i' => 'margin-left: {{SIZE}}px;',
                    '{{WRAPPER}} .ninetheme-button-wrapper .btn-icon-top' => 'display:flex;align-items:center;justify-content:center;flex-direction:column;line-height:1;',
                    '{{WRAPPER}} .ninetheme-button-wrapper .btn-icon-bottom' => 'display:flex;align-items:center;justify-content:center;flex-direction:column;line-height:1;',
                    '{{WRAPPER}} .ninetheme-button-wrapper .btn-icon-top i' => 'margin-bottom: {{SIZE}}px;position:relative;display:inline-flex;',
                    '{{WRAPPER}} .ninetheme-button-wrapper .btn-icon-bottom i' => 'margin-top: {{SIZE}}px;position:relative;display:inline-flex;',
                ],
                'default' => [
                    'unit' => 'px',
                    'size' => 15
                ],
                'condition' => ['use_icon' => 'yes']
            ]
        );
        $this->add_control( 'icon_size',
            [
                'label' => esc_html__( 'Icon Size', 'crisop' ),
                'type' => Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'max' => 300
                    ]
                ],
                'selectors' => ['{{WRAPPER}} .ninetheme-button-wrapper .ninetheme-btn i' => 'font-size: {{SIZE}}px;'],
                'condition' => ['use_icon' => 'yes']
            ]
        );
        $this->add_control( 'full',
            [
                'label' => esc_html__( 'Full width', 'crisop' ),
                'type' => Controls_Manager::SWITCHER,
                'default' => 'no',
                'separator' => 'before'
            ]
        );
        $this->add_control( 'bg_type',
            [
                'label' => esc_html__( 'Background Type', 'crisop' ),
                'type' => Controls_Manager::SELECT,
                'default' => 'ninetheme-btn-solid',
                'options' => [
                    'ninetheme-btn-border' => esc_html__( 'Bordered', 'crisop' ),
                    'ninetheme-btn-solid' => esc_html__( 'Solid', 'crisop' ),
                    'ninetheme-btn-text' => esc_html__( 'Simple Text', 'crisop' )
                ]
            ]
        );
        $this->add_control( 'color_type',
            [
                'label' => esc_html__( 'Color Type', 'crisop' ),
                'type' => Controls_Manager::SELECT,
                'default' => 'ninetheme-btn-blue',
                'options' => [
                    'ninetheme-btn-primary' => esc_html__( 'Primary', 'crisop' ),
                    'ninetheme-btn-dark' => esc_html__( 'Black', 'crisop' ),
                    'ninetheme-btn-brown' => esc_html__( 'Brown', 'crisop' ),
                    'ninetheme-btn-red' => esc_html__( 'Red', 'crisop' ),
                    'ninetheme-btn-gray' => esc_html__( 'Gray', 'crisop' ),
                    'ninetheme-btn-gray-soft' => esc_html__( 'Gray Soft', 'crisop' ),
                    'ninetheme-btn-green' => esc_html__( 'Green', 'crisop' ),
                    'ninetheme-btn-green-soft' => esc_html__( 'Green Soft', 'crisop' ),
                    'ninetheme-btn-blue' => esc_html__( 'Blue', 'crisop' ),
                    'ninetheme-btn-blue-dark' => esc_html__( 'Blue Dark', 'crisop' ),
                    'ninetheme-btn-blue-soft' => esc_html__( 'Blue Soft', 'crisop' ),
                    'ninetheme-btn-purple' => esc_html__( 'Purple', 'crisop' ),
                    'ninetheme-btn-purple-soft' => esc_html__( 'Purple Soft', 'crisop' ),
                    'ninetheme-btn-yellow' => esc_html__( 'Yellow', 'crisop' ),
                    'ninetheme-btn-yellow-soft' => esc_html__( 'Yellow Soft', 'crisop' )
                ]
            ]
        );
        $this->add_control( 'radius_type',
            [
                'label' => esc_html__( 'Radius Type', 'crisop' ),
                'type' => Controls_Manager::SELECT,
                'default' => 'ninetheme-btn-radius-soft',
                'options' => [
                    'ninetheme-btn-radius' => esc_html__( 'Radius', 'crisop' ),
                    'ninetheme-btn-radius-soft' => esc_html__( 'Radius', 'crisop' ),
                    'ninetheme-btn-square' => esc_html__( 'Square', 'crisop' ),
                ],
                'condition' => ['bg_type!' => 'ninetheme-btn-text']
            ]
        );
        $this->add_control( 'size',
            [
                'label' => esc_html__( 'Size', 'crisop' ),
                'type' => Controls_Manager::SELECT,
                'default' => 'ninetheme-btn-medium',
                'options' => [
                    'ninetheme-btn-large' => esc_html__( 'Large', 'crisop' ),
                    'ninetheme-btn-medium' => esc_html__( 'Medium', 'crisop' ),
                    'ninetheme-btn-small' => esc_html__( 'Small', 'crisop' )
                ],
                'condition' => ['bg_type!' => 'ninetheme-btn-text']
            ]
        );
        $this->add_responsive_control( 'btn_minw',
            [
                'label' => esc_html__( 'Min Width ( px )', 'crisop' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => ['px','%'],
                'range' => [
                    'px' => [
                        'max' => 2000,
                        'min' => 0
                    ],
                    '%' => [
                        'max' => 100,
                        'min' => 0
                    ]
                ],
                'selectors' => [
                    '{{WRAPPER}} .ninetheme-button-wrapper' => 'display: block;width:100%;',
                    '{{WRAPPER}} .ninetheme-button-wrapper .ninetheme-btn' => 'min-width: {{SIZE}}px;padding-left: 0;padding-right: 0;'
                ],
                'condition' => ['bg_type!' => 'ninetheme-btn-text']
            ]
        );
        $this->add_responsive_control( 'btn_minh',
            [
                'label' => esc_html__( 'Min Height ( px )', 'crisop' ),
                'type' => Controls_Manager::SLIDER,
                'range' => [
                    'px' => ['max' => 1500]
                ],
                'selectors' => [
                    '{{WRAPPER}} .ninetheme-button-wrapper .ninetheme-btn' => 'min-height: {{SIZE}}px;line-height: {{SIZE}}px;padding-top: 0;padding-bottom: 0;',
                    '{{WRAPPER}} .ninetheme-button-wrapper .ninetheme-btn.btn-icon-top' => 'line-height: normal;',
                    '{{WRAPPER}} .ninetheme-button-wrapper .ninetheme-btn.btn-icon-bottom' => 'line-height: normal;'
                ],
                'condition' => ['bg_type!' => 'ninetheme-btn-text']
            ]
        );
        $this->add_control( 'btn_radius',
            [
                'label' => esc_html__( 'Border Radius ( px )', 'crisop' ),
                'type' => Controls_Manager::SLIDER,
                'range' => [
                    'px' => ['max' => 2000]
                ],
                'selectors' => ['{{WRAPPER}} .ninetheme-button-wrapper .ninetheme-btn' => 'border-radius: {{SIZE}}px;'],
                'condition' => ['bg_type!' => 'ninetheme-btn-text']
            ]
        );
        $this->end_controls_section();
        /*****   End Button Options   ******/

        /***** Tooltips Style ******/
        $this->start_controls_section('btn_tooltips_styling',
            [
                'label' => esc_html__( 'Tooltips', 'crisop' )
            ]
        );
        $this->add_control( 'tooltips',
            [
                'label' => esc_html__( 'Tooltips', 'crisop' ),
                'type' => Controls_Manager::SWITCHER,
                'default' => 'no',
                'separator' => 'before'
            ]
        );
        $this->add_control( 'tooltiptext',
            [
                'label' => esc_html__( 'Tooltip Text', 'crisop' ),
                'type' => Controls_Manager::TEXTAREA,
                'label_block' => true,
                'default' => esc_html__( 'Button Text', 'crisop' ),
                'condition' => ['tooltips' => 'yes']
            ]
        );
        $this->add_control( 'tooltip_pos',
            [
                'label' => esc_html__( 'Tooltip Position', 'crisop' ),
                'type' => Controls_Manager::SELECT,
                'default' => 'top',
                'options' => [
                    'top' => esc_html__( 'Top', 'crisop' ),
                    'right' => esc_html__( 'Right', 'crisop' ),
                    'bottom' => esc_html__( 'Bottom', 'crisop' ),
                    'left' => esc_html__( 'Left', 'crisop' )
                ],
                'condition' => ['tooltips' => 'yes']
            ]
        );
        $this->add_control( 'tooltip_trigger',
            [
                'label' => esc_html__( 'Tooltip Open Action', 'crisop' ),
                'type' => Controls_Manager::SELECT,
                'default' => 'click',
                'options' => [
                    'hover' => esc_html__( 'Hover', 'crisop' ),
                    'click' => esc_html__( 'Click', 'crisop' ),
                ],
                'condition' => ['tooltips' => 'yes']
            ]
        );
        $this->add_control( 'tooltip_animation',
            [
                'label' => esc_html__( 'Tooltip Animation', 'crisop' ),
                'type' => Controls_Manager::SELECT,
                'default' => 'fade',
                'options' => [
                    'fade' => esc_html__( 'fade', 'crisop' ),
                    'grow' => esc_html__( 'grow', 'crisop' ),
                    'swing' => esc_html__( 'swing', 'crisop' ),
                    'slide' => esc_html__( 'slide', 'crisop' ),
                    'fall' => esc_html__( 'fall', 'crisop' ),
                ],
                'condition' => ['tooltips' => 'yes']
            ]
        );
        $this->add_control( 'tooltip_theme',
            [
                'label' => esc_html__( 'Tooltip Theme', 'crisop' ),
                'type' => Controls_Manager::SELECT,
                'default' => 'default',
                'options' => [
                    'default' => esc_html__( 'default', 'crisop' ),
                    'light' => esc_html__( 'light', 'crisop' ),
                    'punk' => esc_html__( 'punk', 'crisop' ),
                    'noir' => esc_html__( 'noir', 'crisop' ),
                    'shadow' => esc_html__( 'shadow', 'crisop' ),
                ],
                'condition' => ['tooltips' => 'yes']
            ]
        );
        $this->add_control( 'tooltip_arrow',
            [
                'label' => esc_html__( 'Tooltips Arrow', 'crisop' ),
                'type' => Controls_Manager::SWITCHER,
                'default' => 'yes',
                'condition' => ['tooltips' => 'yes']
            ]
        );
        $this->add_control( 'tooltiptext_style_heading',
            [
                'label' => esc_html__( 'TOOLTIP STYLE', 'crisop' ),
                'type' => Controls_Manager::HEADING,
                'separator' => 'before',
                'condition' => ['tooltips' => 'yes']
            ]
        );
        $this->add_control( 'tooltip_maxWidth',
            [
                'label' => esc_html__( 'Max Width', 'crisop' ),
                'type' => Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 3000
                    ]
                ],
                'condition' => ['tooltips' => 'yes']
            ]
        );
        $this->add_control( 'tooltip_offsetx',
            [
                'label' => esc_html__( 'Spacing X', 'crisop' ),
                'type' => Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 300
                    ]
                ],
                'condition' => ['tooltips' => 'yes']
            ]
        );
        $this->add_control( 'tooltip_offsety',
            [
                'label' => esc_html__( 'Spacing Y', 'crisop' ),
                'type' => Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 300
                    ]
                ],
                'condition' => ['tooltips' => 'yes']
            ]
        );
        $this->add_control( 'tooltip_bgcolor',
            [
                'label' => esc_html__( 'Background Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
            ]
        );
        $this->add_control( 'tooltip_brdcolor',
            [
                'label' => esc_html__( 'Border Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
            ]
        );
        $this->end_controls_section();
        /*****   End Button Options   ******/

        /***** Button Style ******/
        $this->start_controls_section('btn_styling',
            [
                'label' => esc_html__( 'Button Style', 'crisop' ),
                'tab' => Controls_Manager::TAB_STYLE
            ]
        );
        $this->start_controls_tabs('btn_tabs');
        $this->start_controls_tab( 'btn_normal_tab',
            [ 'label' => esc_html__( 'Normal', 'crisop' ) ]
        );
        $this->add_control( 'btn_color',
            [
                'label' => esc_html__( 'Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => ['{{WRAPPER}} .ninetheme-btn' => 'color: {{VALUE}};']
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'btn_typo',
                'label' => esc_html__( 'Typography', 'crisop' ),
                'selector' => '{{WRAPPER}} .ninetheme-button-wrapper .ninetheme-btn'
            ]
        );
        $this->add_responsive_control( 'btn_padding',
            [
                'label' => esc_html__( 'Padding', 'crisop' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px' ],
                'selectors' => ['{{WRAPPER}} .ninetheme-btn' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};'],
                'default' => [
                    'top' => '',
                    'right' => '',
                    'bottom' => '',
                    'left' => '',
                ],
                'separator' => 'before'
            ]
        );
        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name' => 'btn_border',
                'label' => esc_html__( 'Border', 'crisop' ),
                'selector' => '{{WRAPPER}} .ninetheme-btn',
                'separator' => 'before'
            ]
        );
        $this->add_responsive_control( 'btn_border_radius',
            [
                'label' => esc_html__( 'Border Radius', 'crisop' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px' ],
                'selectors' => ['{{WRAPPER}} .ninetheme-btn' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};'],
                'separator' => 'before'
            ]
        );
        $this->add_group_control(
            Group_Control_Background::get_type(),
            [
                'name' => 'btn_background',
                'label' => esc_html__( 'Background', 'crisop' ),
                'types' => [ 'classic', 'gradient' ],
                'selector' => '{{WRAPPER}} .ninetheme-btn',
                'separator' => 'before'
            ]
        );
        $this->end_controls_tab();

        $this->start_controls_tab('btn_hover_tab',
            [ 'label' => esc_html__( 'Hover', 'crisop' ) ]
        );
        $this->add_control( 'btn_hvr_color',
            [
                'label' => esc_html__( 'Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => ['{{WRAPPER}} .ninetheme-btn:hover' => 'color: {{VALUE}};']
            ]
        );
        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name' => 'btn_hvr_border',
                'label' => esc_html__( 'Border', 'crisop' ),
                'selector' => '{{WRAPPER}} .ninetheme-btn:hover',
                'separator' => 'before'
            ]
        );
        $this->add_group_control(
            Group_Control_Background::get_type(),
            [
                'name' => 'btn_hvr_background',
                'label' => esc_html__( 'Background', 'crisop' ),
                'types' => [ 'classic', 'gradient' ],
                'selector' => '{{WRAPPER}} .ninetheme-btn:hover',
                'separator' => 'before'
            ]
        );
        $this->end_controls_tab();
        $this->end_controls_tabs();
        $this->add_control( 'btn_overlaycolor',
            [
                'label' => esc_html__( 'Background Image Overlay Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .ninetheme-btn' => 'position:relative;overflow:hidden;',
                    '{{WRAPPER}} .ninetheme-btn:before' => 'content:"";position:absolute;width:100%;height:100%;top:0;left:0;background-color: {{VALUE}};z-index:0;',
                    '{{WRAPPER}} .ninetheme-btn i' => 'position:relative;z-index:1;',
                    '{{WRAPPER}} .ninetheme-btn .btn-text' => 'position:relative;z-index:2;',
                ]
            ]
        );
        $this->end_controls_section();
        /***** End Button Styling *****/
    }

    protected function render() {
        $settings   = $this->get_settings_for_display();
        $settingsid = $this->get_id();
        $edit       = \Elementor\Plugin::$instance->editor->is_edit_mode() ? '-edit' : '';
        $iconpos    = isset( $settings['icon']['value'] ) != '' ? ' '.$settings['icon_pos'] : '';
        $btnicon    = $settings['use_icon'] == 'yes' ? ' has-icon' : '';
        $full       = $settings['full'] == 'yes' ? ' is-full' : '';
        $btn_id     = $settings['btn_id'] ? ' id="'.$settings['btn_id'].'"' : '';
        $target     = !empty( $settings['link']['is_external'] ) ? ' target="_blank"' : '';
        $nofollow   = !empty( $settings['link']['nofollow'] ) ? ' rel="nofollow"' : '';
        $href       = !empty( $settings['link']['url'] ) ? $settings['link']['url'] : '';
        $data       = $target.$nofollow;

        $tooltipsdata = json_encode(array(
            'position'  => $settings['tooltip_pos'],
            'arrow'     => 'yes' == $settings['tooltip_arrow'] ? true : false,
            'maxwidth'  => empty( $settings['tooltip_maxWidth']['size'] ) || 0 == $settings['tooltip_maxWidth']['size'] ? 'auto' : $settings['tooltip_maxWidth']['size'],
            'trigger'   => $settings['tooltip_trigger'],
            'theme'     => 'tooltipster-'.$settings['tooltip_theme'],
            'animation' => $settings['tooltip_animation'],
            'offsetx'   => !empty( $settings['tooltip_offsetx']['size'] ) ? $settings['tooltip_offsetx']['size'] : '',
            'offsety'   => !empty( $settings['tooltip_offsety']['size'] ) ? $settings['tooltip_offsety']['size'] : '',
            'bgcolor'   => $settings['tooltip_bgcolor'],
            'brdcolor'  => $settings['tooltip_brdcolor'],
            'content'   => do_shortcode($settings['tooltiptext'])
        ));
        $tooltips   = $settings['tooltips'] == 'yes' ? ' data-ninetheme-tooltip'.$edit.'=\''.$tooltipsdata.'\'' : '';

        $data_imgs = '';
        switch ($settings['btn_action']) {
            case 'image':
                $title = $settings['ltitle'] ? ' title="'.$settings['ltitle'].'"' : '';
                $data = ' data-ninetheme-lightbox'.$edit.'=\'{"type":"image"}\'';
                $href = $settings['image']['url'];
                break;
            case 'gallery':
                $title = $settings['ltitle'] ? ' title="'.$settings['ltitle'].'"' : '';
                $data = ' data-ninetheme-lightbox'.$edit.'=\'{"type":"gallery"}\'';
                $dataimgs = array();

                if ( !empty( $settings['images'] ) ){
            		foreach ( $settings['images'] as $image ) {
            			array_push($dataimgs, ["src" => $image['url'] ]);
            		}
                    $data_imgs = ' data-ninetheme-lightbox-gallery'.$edit.'=\''.json_encode($dataimgs).'\'';
                    $href = $settings['images'][0]['url'];
        		}
                break;
            case 'youtube':
                $data = ' data-ninetheme-lightbox'.$edit.'=\'{"type":"iframe"}\'';
                $href = $settings['youtube'] ? $settings['youtube'] : 'http://www.youtube.com/watch?v=AeeE6PyU-dQ';
                break;
            case 'vimeo':
                $data = ' data-ninetheme-lightbox'.$edit.'=\'{"type":"iframe"}\'';
                $href = $settings['vimeo'] ? $settings['vimeo'] : 'https://vimeo.com/39493181';
                break;
            case 'map':
                $data = ' data-ninetheme-lightbox'.$edit.'=\'{"type":"iframe"}\'';
                $href = $settings['map'] ? $settings['map'] : 'https://maps.google.com/maps?q=221B+Baker+Street,+London,+United+Kingdom&amp;hl=en&amp;t=v&amp;hnear=221B+Baker+St,+London+NW1+6XE,+United+Kingdom';
                break;
            case 'html5':
                $data = ' data-ninetheme-lightbox'.$edit.'=\'{"type":"iframe"}\'';
                $href = $settings['html5'] ? $settings['html5'] : '';
                break;
            case 'modal':
                $data = ' data-ninetheme-lightbox'.$edit.'=\'{"type":"inline"}\'';
                $href = '#modal_'.$settingsid;
                break;
            default:
                $data = $target.$nofollow;
                $href = $settings['link']['url'];
                break;
        }

        $text = $settings['icon_pos'] == 'btn-icon-bottom' || $settings['icon_pos'] == 'btn-icon-top' ? '<span class="btn-text">'.$settings['text'].'</span>' : $settings['text'];

        echo '<div class="ninetheme-button-wrapper'.$btnicon.$full.'">';
            if ( $settings['icon_pos'] == 'btn-icon-left' || $settings['icon_pos'] == 'btn-icon-top' ) {
                echo '<a'.$btn_id.' data-id="btn-'.$settingsid.'" class="ninetheme-btn '.$settings['color_type'].' '.$settings['bg_type'].' '.$settings['radius_type'].' '.$settings['size'].''.$iconpos.'" href="'.$href.'"'.$data.$tooltips.$data_imgs.'>'; if ( !empty( $settings['icon']['value'] ) ) { Icons_Manager::render_icon( $settings['icon'], [ 'aria-hidden' => 'true' ] ); } echo $text.'</a>';
            } else {
                echo '<a'.$btn_id.' data-id="btn-'.$settingsid.'" class="ninetheme-btn '.$settings['color_type'].' '.$settings['bg_type'].' '.$settings['radius_type'].' '.$settings['size'].''.$iconpos.'" href="'.$href.'"'.$data.$tooltips.$data_imgs.'>'.$text.' ';
                if ( !empty( $settings['icon']['value'] ) ) { Icons_Manager::render_icon( $settings['icon'], [ 'aria-hidden' => 'true' ] ); } echo '</a>';
            }
            if ( $settings['btn_action'] == 'modal' && $settings['modal_content'] ) {
                echo '<div id="modal_'.$settingsid.'" class="mfp-hide" style="position:relative; max-width:'.$settings['modal_width']['size'].'px; margin:auto; padding:30px; background-color:#ffffff;">';
                    echo do_shortcode($settings['modal_content']);
                echo '</div>';
            }
        echo '</div>';

        // in edit mode
        if ( \Elementor\Plugin::$instance->editor->is_edit_mode() ) {
            ?>
            <script>
            jQuery(document).ready(function($){

                var myButton  = $('.ninetheme-btn[data-id="btn-<?php echo $settingsid;?>"]'),
                    myData    = myButton.data('ninetheme-lightbox-edit'),
                    myTooltip = myButton.data('ninetheme-tooltip-edit');

                if (myData && myData.type) {
                    myButton.magnificPopup({
                        type: myData.type,
                        modal: false
                    });
                }

                if (myTooltip) {
                    myButton.tooltipster({
                        position      : myTooltip.position,
                        content       : myTooltip.content,
                        animation     : myTooltip.animation,
                        theme         : myTooltip.theme,
                        trigger       : myTooltip.trigger,
                        offsetX       : myTooltip.offsetx,
                        offsetY       : myTooltip.offsety,
                        arrow         : myTooltip.arrow,
                        maxWidth      : myTooltip.maxwidth,
                        contentAsHTML : true,
                        hideOnClick   : true,
                        interactive   : true,
                        touchDevices  : true,
                        functionReady : function(){
                            var id  = this.__namespace,
                                bg  = myTooltip.bgcolor != '' ? myTooltip.bgcolor : '',
                                brd = myTooltip.brdcolor != '' ? myTooltip.brdcolor : '',
                                pos = myData.position;

                            $('#'+id+' .tooltipster-box').css({
                                'background-color' : bg,
                                'border-color' : brd
                            });

                            if ( myTooltip.arrow ) {
                                $('#'+id+' .tooltipster-arrow-background').css('border-'+pos+'-color', bg);
                                $('#'+id+' .tooltipster-arrow-border').css('border-'+pos+'-color', brd);
                            }
                        }
                    });
                }
            });
            </script>
            <?php
        }
    }
}
