<?php

namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) exit; // If this file is called directly, abort.

class Ninetheme_Gallery extends Widget_Base {
    use Ninetheme_Helper;
    public function get_name() {
        return 'ninetheme-gallery';
    }
    public function get_title() {
        return 'Gallery (N)';
    }
    public function get_icon() {
        return 'eicon-gallery-grid';
    }
    public function get_categories() {
        return [ 'crisop' ];
    }
    public function get_script_depends() {
        return [ 'isotope', 'imagesloaded', 'wow' ];
    }
    // Registering Controls
    protected function register_controls() {
        /*****   START CONTROLS SECTION   ******/
        $this->start_controls_section( 'post_query_section',
            [
                'label' => esc_html__( 'Post Query', 'crisop' ),
                'tab' => Controls_Manager::TAB_CONTENT
            ]
        );
        
        $this->ninetheme_query_controls( 'post', false, true );
        
        $this->add_control( 'layout_heading',
            [
                'label' => esc_html__( 'LAYOUT', 'crisop' ),
                'type' => Controls_Manager::HEADING,
                'separator' => 'before'
            ]
        );
        $this->add_control( 'layoutmode',
            [
                'label' => esc_html__( 'Layout Mode', 'crisop' ),
                'type' => Controls_Manager::SELECT,
                'label_block' => 'true',
                'default' => 'fitRows',
                'options' => [
                    'fitRows' => esc_html__( 'Fit Rows', 'crisop' ),
                    'masonry' => esc_html__( 'masonry', 'crisop' ),
                ]
            ]
        );
        $this->add_responsive_control( 'col',
            [
                'label' => esc_html__( 'Column', 'crisop' ),
                'type' => Controls_Manager::NUMBER,
                'min' => 1,
                'max' => 12,
                'default' => 4,
                'selectors' => ['{{WRAPPER}} .ninetheme-gallery-item,{{WRAPPER}} .grid-sizer' => '-ms-flex: 0 0 calc(100% / {{VALUE}} );flex: 0 0 calc(100% / {{VALUE}} );width: calc(100% / {{VALUE}} );']
            ]
        );
		$this->add_control('column_gap',
			[
				'label' => __( 'Columns Gap', 'crisop' ),
				'type' => Controls_Manager::SLIDER,
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 100
					]
				],
				'selectors' => [ 
				    '{{WRAPPER}} .ninetheme-gallery-item' => 'padding: 0 calc({{SIZE}}px / 2 );margin-bottom: {{SIZE}}px;',
				    '{{WRAPPER}} .ninetheme-gallery-items' => 'margin: 0 calc(-{{SIZE}}px / 2 ) -{{SIZE}}px calc(-{{SIZE}}px / 2 );'
				]
			]
		);
        $this->add_control( 'onoff_heading',
            [
                'label' => esc_html__( 'OTHERS', 'crisop' ),
                'type' => Controls_Manager::HEADING,
                'separator' => 'before'
            ]
        );
        $this->add_control( 'hide_filters',
            [
                'label' => esc_html__( 'Hide Filters', 'crisop' ),
                'type' => Controls_Manager::SWITCHER,
                'default' => 'no'
            ]
        );
        $this->add_control( 'all_text',
            [
                'label' => esc_html__( 'All Text', 'crisop' ),
                'type' => Controls_Manager::TEXT,
                'default' => 'All',
                'label_block' => true,
                'condition' => [ 'hide_filters!' => 'yes' ]
            ]
        );
        
        $this->add_control( 'hidetitle',
            [
                'label' => esc_html__( 'Hide Post Title', 'crisop' ),
                'type' => Controls_Manager::SWITCHER
            ]
        );
        $this->add_control( 'hideexcerpt',
            [
                'label' => esc_html__( 'Hide Excerpt', 'crisop' ),
                'type' => Controls_Manager::SWITCHER
            ]
        );
        $this->add_control( 'excerpt_limit',
            [
                'label' => esc_html__( 'Excerpt Word Limit', 'crisop' ),
                'type' => Controls_Manager::NUMBER,
                'min' => 0,
                'max' => 100,
                'default' => 20,
                'condition' => [ 'hideexcerpt!' => 'yes' ]
            ]
        );
        $this->end_controls_section();
        /*****   END CONTROLS SECTION   ******/
        /*****   START CONTROLS SECTION   ******/
        $this->start_controls_section( 'style_section',
            [
                'label' => esc_html__( 'STYLE', 'crisop' ),
                'tab' => Controls_Manager::TAB_CONTENT
            ]
        );
        $this->add_control( 'filter_sdivider',
            [
                'label' => esc_html__( 'FILTER', 'crisop' ),
                'type' => Controls_Manager::HEADING,
            ]
        );
        $this->add_responsive_control( 'filter_alignment',
            [
                'label' => esc_html__( 'Alignment', 'crisop' ),
                'type' => Controls_Manager::CHOOSE,
                'selectors' => ['{{WRAPPER}} .ninetheme-gallery-wrapper .ninetheme-gallery-filtering' => 'text-align: {{VALUE}};'],
                'options' => [
                    'left' => [
                        'title' => esc_html__( 'Left', 'crisop' ),
                        'icon' => 'eicon-h-align-left'
                    ],
                    'center' => [
                        'title' => esc_html__( 'Center', 'crisop' ),
                        'icon' => 'eicon-h-align-center'
                    ],
                    'right' => [
                        'title' => esc_html__( 'Right', 'crisop' ),
                        'icon' => 'eicon-h-align-right'
                    ]
                ],
                'toggle' => true,
                'default' => 'center'
            ]
        );
		$this->add_control('filter_bottom_spacing',
			[
				'label' => esc_html__( 'Bottom Spacing', 'crisop' ),
				'type' => Controls_Manager::SLIDER,
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 500
					]
				],
				'selectors' => [ '{{WRAPPER}} .ninetheme-gallery-wrapper .ninetheme-gallery-filtering' => 'margin-bottom: {{SIZE}}px;' ]
			]
		);
		$this->add_control('filter_item_spacing',
			[
				'label' => esc_html__( 'Item Between Spacing', 'crisop' ),
				'type' => Controls_Manager::SLIDER,
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 100
					]
				],
				'selectors' => [ 
				    '{{WRAPPER}} .ninetheme-gallery-wrapper .ninetheme-gallery-filtering span:not(:first-child)' => 'padding-left: {{SIZE}}px;',
				    '{{WRAPPER}} .ninetheme-gallery-wrapper .ninetheme-gallery-filtering span:not(:first-child):before' => 'left: calc( {{SIZE}}px / 2 - 3px );',
				]
			]
		);
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'filter_typo',
                'label' => esc_html__( 'Typography', 'crisop' ),
                'selector' => '{{WRAPPER}} .ninetheme-gallery-wrapper .ninetheme-gallery-filtering span'
            ]
        );
        $this->add_control( 'filter_color',
            [
                'label' => esc_html__( 'Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => ['{{WRAPPER}} .ninetheme-gallery-wrapper .ninetheme-gallery-filtering span' => 'color: {{VALUE}};']
            ]
        );
        $this->add_control( 'filter_hvrcolor',
            [
                'label' => esc_html__( 'Hover/Active Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => ['{{WRAPPER}} .ninetheme-gallery-wrapper .ninetheme-gallery-filtering span:hover,{{WRAPPER}} .ninetheme-gallery-wrapper .ninetheme-gallery-filtering span.active' => 'color: {{VALUE}};']
            ]
        );
        $this->add_control( 'filter_point_color',
            [
                'label' => esc_html__( 'Point Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => ['{{WRAPPER}} .ninetheme-gallery-wrapper .ninetheme-gallery-filtering span + span:before' => 'background-color: {{VALUE}};']
            ]
        );
        $this->add_control( 'post_box_sdivider',
            [
                'label' => esc_html__( 'BOX', 'crisop' ),
                'type' => Controls_Manager::HEADING,
            ]
        );
        $this->add_control( 'boxanim',
            [
                'label' => esc_html__( 'Animation on Scroll', 'crisop' ),
                'type' => Controls_Manager::SWITCHER,
                'default' => 'yes'
            ]
        );
        $this->add_control( 'post_overlay_color',
            [
                'label' => esc_html__( 'Overlay Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => ['{{WRAPPER}} .ninetheme-gallery-wrapper .ninetheme-gallery-item-inner .ninetheme-gallery-item-info-wrapper' => 'background-color: {{VALUE}};']
            ]
        );
        $this->add_control( 'post_title_sdivider',
            [
                'label' => esc_html__( 'POST TITLE', 'crisop' ),
                'type' => Controls_Manager::HEADING,
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'post_title_typo',
                'label' => esc_html__( 'Typography', 'crisop' ),
                'selector' => '{{WRAPPER}} .ninetheme-gallery-wrapper .ninetheme-gallery-item-inner .ninetheme-gallery-item-title'
            ]
        );
        $this->add_control( 'post_title_color',
            [
                'label' => esc_html__( 'Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => ['{{WRAPPER}} .ninetheme-gallery-wrapper .ninetheme-gallery-item-inner .ninetheme-gallery-item-title' => 'color: {{VALUE}};']
            ]
        );
        $this->add_control( 'post_desc_sdivider',
            [
                'label' => esc_html__( 'POST EXCERPT', 'crisop' ),
                'type' => Controls_Manager::HEADING,
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'post_desc_typo',
                'label' => esc_html__( 'Typography', 'crisop' ),
                'selector' => '{{WRAPPER}} .ninetheme-gallery-wrapper .ninetheme-gallery-item-inner .ninetheme-gallery-item-info p'
            ]
        );
        $this->add_control( 'post_desc_color',
            [
                'label' => esc_html__( 'Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => ['{{WRAPPER}} .ninetheme-gallery-wrapper .ninetheme-gallery-item-inner .ninetheme-gallery-item-info p' => 'color: {{VALUE}};']
            ]
        );
        $this->end_controls_section();
        /*****   END CONTROLS SECTION   ******/
    }

    protected function render() {
        $settings = $this->get_settings_for_display();
        $settingsid = $this->get_id();

        $post_type = $settings['post_type'];

        $args['post_type']      = $settings['post_type'];
        $args['posts_per_page'] = $settings['posts_per_page'];
        $args['offset']         = $settings['offset'];
        $args['order']          = $settings['order'];
        $args['orderby']        = $settings['orderby'];
        $args[$settings['author_filter_type']] = $settings['author'];

        if ( ! empty( $settings[ $post_type . '_filter' ] ) ) {
            $args[ $settings[ $post_type . '_filter_type' ] ] = $settings[ $post_type . '_filter' ];
        }

        // Taxonomy Filter.
        $taxonomy = $this->get_post_taxonomies( $post_type );

        if ( ! empty( $taxonomy ) && ! is_wp_error( $taxonomy ) ) {

            foreach ( $taxonomy as $index => $tax ) {

                $tax_control_key = $index . '_' . $post_type;

                if ( $post_type == 'post' ) {
                    if ( $index == 'post_tag' ) {
                        $tax_control_key = 'tags';
                    } elseif ( $index == 'category' ) {
                        $tax_control_key = 'categories';
                    }
                }

                if ( ! empty( $settings[ $tax_control_key ] ) ) {

                    $operator = $settings[ $index . '_' . $post_type . '_filter_type' ];

                    $args['tax_query'][] = array(
                        'taxonomy' => $index,
                        'field'    => 'term_id',
                        'terms'    => $settings[ $tax_control_key ],
                        'operator' => $operator,
                    );
                }
            }
        }
        
        $the_query = new \WP_Query( $args );
        
        if ( $the_query->have_posts() ) {
            echo '<div class="ninetheme-gallery-wrapper" id="gallery-'.$settingsid.'" data-layout-mode="'.$settings['layoutmode'].'">';

               $exclude = array();
                $taxonomy = '';
                $post_type = $this->ninetheme_get_post_types();
                foreach ( $post_type as $slug => $label  ) {
                    if ( !empty($settings[ $slug.'_top_taxonomy' ]) ) {
                        
                        $taxonomy = $settings[ $slug.'_top_taxonomy' ];
                    }
                    if ( !empty($settings[ $slug.'_top_filter' ]) ) {
                        $exclude = $settings[ $slug.'_top_filter' ];
                    }
                }
                $cats = get_terms( array (
                    'taxonomy'   => $taxonomy,
                    'order'      => $settings['order'],
                    'orderby'    => $settings['orderby'],
                    'hide_empty' => true,
                    'parent'     => 0,
                    'exclude'    => $exclude
                ) );

                if ( 'yes' != $settings['hide_filters'] && $cats > 1 ) {
                    echo '<div class="ninetheme-gallery-filtering filter-aling-'.$settings['filter_alignment'].'">';
                        if ( $settings['all_text'] ) {
                            echo '<span data-filter=\'*\' class="ninetheme-gallery-filter active">'.$settings['all_text'].'</span>';
                        }
                        foreach ( $cats as $cat ) {
                            $filter = strtolower( str_replace(' ', '-', $cat->name ) );
                            echo '<span class="ninetheme-gallery-filter" data-filter=\'.'.$filter.'\'>'.$cat->name.'</span>';
                        }
                    echo '</div>';
                }

                echo '<div class="ninetheme-gallery-items">';
                    echo '<div class="grid-sizer col-md-4"></div>';
                    while ( $the_query->have_posts() ) {
                        $the_query->the_post();

                        foreach ( $taxonomy as $index => $tax ) {
                            $terms = get_the_terms( get_the_ID(), $tax );
                            if ( ! empty( $terms ) ) {
                                foreach ( $terms as $term ) {
                                    if ( ! empty( $term->name ) ) {
                                        $links[] = strtolower( $term->name );
                                    }
                                }
                            }
                        }
                        $links = str_replace(' ', '-', $links);
                        $tax = join( " ", array_unique($links) );

                        echo '<div class="ninetheme-gallery-item col-md-4 '.$tax.'">';
                        
                        if ( 'yes' == $settings['boxanim'] ) {
                            echo '<div class="ninetheme-gallery-item-inner wow fadeInUp2">';
                                echo '<div class="ninetheme-gallery-item-overlay wow"></div>';
                        } else {
                            echo '<div class="ninetheme-gallery-item-inner">';
                        }
                                echo '<a class="ninetheme-gallery-item-link" href="' . get_permalink() . '">';
                                    echo get_the_post_thumbnail( get_the_ID(), 'full' );
                                    echo '<div class="ninetheme-gallery-item-info-wrapper">';
                                        echo '<div class="ninetheme-gallery-item-info">';
                                            if ( 'yes' != $settings['hidetitle'] ) {
                                                echo '<h5 class="ninetheme-gallery-item-title">' . get_the_title() . '</h5>';
                                            }
                                            if ( has_excerpt() && 'yes' != $settings['hideexcerpt'] ) {
                                                echo wpautop( wp_trim_words( get_the_excerpt(), $settings['excerpt_limit'] ) );
                                            }
                                        echo '</div>';
                                    echo '</div>';
                                echo '</a>';
                            echo '</div>';
                        echo '</div>';
                    }
                    wp_reset_postdata();
                echo '</div>';
            echo '</div>';
            
            if ( \Elementor\Plugin::$instance->editor->is_edit_mode() ) { ?>
                <script>
                    var myGallery = jQuery( '#gallery-<?php echo esc_attr($settingsid); ?>' );
                    var myIsotope = myGallery.find(".ninetheme-gallery-items");
                    var myFilters = myGallery.find(".ninetheme-gallery-filtering");
                    if ( myGallery ) {
                        myGallery.isotope(
                            {
                                itemSelector: '.ninetheme-gallery-item',
                                layoutMode: '<?php echo $settings['layoutmode']; ?>'
                            }
                        );
                        var $gallery = myIsotope.isotope();
                        myFilters.on('click', 'span', function () {
                            var filterValue = jQuery(this).attr('data-filter');
                            $gallery.isotope({
                                filter: filterValue
                            });
                        });
                        myFilters.on('click', 'span', function () {
                            jQuery(this).addClass('active').siblings().removeClass('active');
                        });
                    }
                </script>
                <?php
            }
        } else {
            echo '<p class="text">'.esc_html__('No post found!','crisop').'</p>';
        }

    }
}
