<?php

namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) exit; // If this file is called directly, abort.

class Ninetheme_Header_Inline_Mini_Menu extends Widget_Base {
    use Ninetheme_Helper;
    public function get_name() {
        return 'ninetheme-inline-mini-menu';
    }
    public function get_title() {
        return 'Header Inline Mini Menu (N)';
    }
    public function get_icon() {
        return 'eicon-nav-menu';
    }
    public function get_categories() {
        return [ 'ninetheme-header' ];
    }
    public function get_keywords() {
        return [ 'header', 'menu', 'mini' ];
    }
    // Registering Controls
    protected function register_controls() {
        /*****   START CONTROLS SECTION   ******/
        $this->start_controls_section('menu_general_settings',
            [
                'label' => esc_html__( 'General', 'crisop' ),
                'tab' => Controls_Manager::TAB_CONTENT
            ]
        );
        $this->add_control( 'register_menus',
            [
                'label' => esc_html__( 'Select Menu', 'crisop' ),
                'type' => Controls_Manager::SELECT2,
                'multiple' => false,
                'label_block' => true,
                'options' => $this->registered_nav_menus(),
            ]
        );
        $this->end_controls_section();
        /*****   END CONTROLS SECTION   ******/

        /*****   START CONTROLS SECTION   ******/
        $this->start_controls_section( 'menu_item_style_section',
            [
                'label'=> esc_html__( 'MENU STYLE', 'crisop' ),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );
        $this->add_control( 'menu_item_color',
            [
                'label' => esc_html__( 'Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [ '{{WRAPPER}} .navigation-mini-inline li a' => 'color:{{VALUE}};' ]
            ]
        );
        $this->add_control( 'menu_item_hvrcolor',
            [
                'label' => esc_html__( 'Color ( Hover )', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [ '{{WRAPPER}} .navigation-mini-inline li a:hover' => 'color:{{VALUE}};' ]
            ]
        );
        $this->add_control( 'menu_item_sepcolor',
            [
                'label' => esc_html__( 'Separator Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [ 
                    '{{WRAPPER}} .ninetheme-header-widget-inline-mini-menu.has-rtl .navigation-mini-inline li + li:after,
                    {{WRAPPER}} .ninetheme-header-widget-inline-mini-menu:not(.has-rtl) .navigation-mini-inline li + li:before' => 'background-color:{{VALUE}};'
                ]
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'menu_item_typo',
                'label' => esc_html__( 'Typography', 'crisop' ),
                'selector' => '{{WRAPPER}} .navigation-mini-inline li a'
            ]
        );
        $rtl = is_rtl() ? 'right' : 'left';
        $this->add_responsive_control( 'menu_item_spacing',
            [
                'label' => esc_html__( 'Spacing Between Menu Items', 'crisop' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => [ 'px' ],
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 100,
                        'step' => 1
                    ]
                ],
                'selectors' => [ '{{WRAPPER}} .navigation-mini-inline li + li' => 'margin-'.$rtl.':{{SIZE}}{{UNIT}};padding-'.$rtl.':{{SIZE}}{{UNIT}};' ]
            ]
        );
        $this->end_controls_section();
        /*****   END CONTROLS SECTION   ******/
    }

    protected function render()
    {
        $settings = $this->get_settings_for_display();
        $id = $this->get_id();
        $rtl = is_rtl() ? ' has-rtl' : '';
        if ( !empty( $settings['register_menus'] ) ) {
            
            echo '<div class="ninetheme-header-widget-inline-mini-menu ninetheme-header-top-mini-menu-inline'.$rtl.'">';
                echo '<ul class="navigation-mini-inline">';
                    echo wp_nav_menu(
                        array(
                            'menu' => $settings['register_menus'],
                            'container' => '',
                            'container_class' => '',
                            'container_id' => '',
                            'menu_class' => '',
                            'menu_id' => '',
                            'items_wrap' => '%3$s',
                            'before' => '',
                            'after' => '',
                            'link_before' => '',
                            'link_after' => '',
                            'depth' => 4,
                            'echo' => true,
                            'fallback_cb' => 'Ninetheme_Wp_Bootstrap_Navwalker::fallback',
                            'walker' => new \Ninetheme_Wp_Bootstrap_Navwalker()
                        )
                    );
                echo '</ul>';
            echo '</div>';
        }
    }
}
