<?php

namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) exit; // If this file is called directly, abort.

class Ninetheme_Header_Menu_Simple extends Widget_Base {
    use Ninetheme_Helper;
    public function get_name() {
        return 'ninetheme-menu-simple';
    }
    public function get_title() {
        return 'Header Menu Simple (N)';
    }
    public function get_icon() {
        return 'eicon-nav-menu';
    }
    public function get_categories() {
        return [ 'ninetheme-header' ];
    }
    public function get_keywords() {
        return [ 'header', 'menu' ];
    }
    // Registering Controls
    protected function register_controls() {
        /*****   START CONTROLS SECTION   ******/
        $this->start_controls_section('menu_general_settings',
            [
                'label' => esc_html__( 'General', 'crisop' ),
                'tab' => Controls_Manager::TAB_CONTENT
            ]
        );
        $this->add_control( 'source',
            [
                'label' => esc_html__( 'Menu Source Type', 'crisop' ),
                'type' => Controls_Manager::SELECT,
                'default' => 'wp-menu',
                'options' => [
                    'wp-menu' => esc_html__( 'WP Menu', 'crisop' ),
                    'tax' => esc_html__( 'Taxonomy', 'crisop' ),
                    'custom' => esc_html__( 'Custom', 'crisop' ),
                ]
            ]
        );
        $this->add_control( 'display_type',
            [
                'label' => esc_html__( 'Menu Display Type', 'crisop' ),
                'type' => Controls_Manager::SELECT,
                'default' => 'inline',
                'options' => [
                    'inline' => esc_html__( 'Inline Menu', 'crisop' ),
                    'dropdown' => esc_html__( 'Dropdown', 'crisop' )
                ]
            ]
        );
        $this->add_control( 'taxonomies',
            [
                'label' => esc_html__( 'Select Taxonomy', 'crisop' ),
                'type' => Controls_Manager::SELECT2,
                'multiple' => false,
                'label_block' => true,
                'options' => $this->get_taxonomies_options(),
                'condition' => ['source' => 'tax']
            ]
        );
        $this->add_control( 'register_menus',
            [
                'label' => esc_html__( 'Select Menu', 'crisop' ),
                'type' => Controls_Manager::SELECT2,
                'multiple' => false,
                'label_block' => true,
                'options' => $this->registered_nav_menus(),
                'condition' => ['source' => 'wp-menu']
            ]
        );
        $this->add_control( 'btn_text',
            [
                'label' => esc_html__( 'Menu Button Title', 'crisop' ),
                'type' => Controls_Manager::TEXT,
                'default' => 'Menu Title',
                'condition' => ['display_type' => 'dropdown']
            ]
        );
        $this->add_control( 'submenu_action',
            [
                'label' => esc_html__( 'Open Submenu', 'crisop' ),
                'type' => Controls_Manager::SELECT,
                'default' => 'inline',
                'options' => [
                    'open-submenu-on-hover' => esc_html__( 'On Hover', 'crisop' ),
                    'open-submenu-on-click' => esc_html__( 'On Click', 'crisop' )
                ],
                'condition' => ['display_type' => 'dropdown']
            ]
        );
        $this->add_control( 'is_active',
            [
                'label' => esc_html__( 'Active', 'crisop' ),
                'type' => Controls_Manager::SWITCHER,
                'default' => 'no',
                'condition' => ['display_type' => 'dropdown']
            ]
        );
        $this->add_responsive_control( 'header_minheight',
            [
                'label' => esc_html__( 'Min Height', 'crisop' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => [ 'px' ],
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 300,
                        'step' => 1
                    ]
                ],
                'selectors' => [
                    '{{WRAPPER}} .ninetheme-header-menu-widget .ninetheme-default-menu-item-empty,
                    .ninetheme-header-menu-widget .ninetheme-header-top-menu-area>ul>li.menu-item' => 'height: auto;min-height:{{SIZE}}{{UNIT}};'
                ],
                'condition' => [
                    'source' => 'wp-menu',
                    'display_type' => 'inline'
                ]
            ]
        );
        $this->add_control( 'show_megasubmenu',
            [
                'label' => esc_html__( 'Show Mega Menu for edit?', 'crisop' ),
                'type' => Controls_Manager::SWITCHER,
                'default' => 'no',
                'condition' => [
                    'source' => 'wp-menu',
                    'display_type' => 'inline'
                ]
            ]
        );
        $this->add_control( 'show_submenu',
            [
                'label' => esc_html__( 'Show Submenu for edit?', 'crisop' ),
                'type' => Controls_Manager::SWITCHER,
                'default' => 'no',
                'condition' => [
                    'source' => 'wp-menu',
                    'display_type' => 'inline'
                ]
            ]
        );

        $this->end_controls_section();
        /*****   END CONTROLS SECTION   ******/

        /*****   START CONTROLS SECTION   ******/
        $this->start_controls_section( 'items_settings',
            [
                'label' => esc_html__('CUSTOM MENU ITEMS', 'crisop'),
                'tab' => Controls_Manager::TAB_CONTENT,
                'condition' => ['source' => 'custom']
            ]
        );
        $repeater = new Repeater();
        $repeater->add_control( 'link',
            [
                'label' => esc_html__( 'Link', 'crisop' ),
                'type' => Controls_Manager::URL,
                'label_block' => true,
                'show_external' => true
            ]
        );
        $repeater->add_control( 'menu_item_title',
            [
                'label' => esc_html__( 'Title', 'crisop' ),
                'type' => Controls_Manager::TEXT,
                'label_block' => true
            ]
        );
        $repeater->add_control( 'icon',
            [
                'label' => esc_html__( 'Menu Item Icon', 'crisop' ),
                'type' => Controls_Manager::ICONS
            ]
        );
        $repeater->add_control( 'submenu_type',
            [
                'label' => esc_html__( 'Submenu Type', 'crisop' ),
                'type' => Controls_Manager::SELECT,
                'default' => 'none',
                'options' => [
                    'none' => esc_html__( 'None', 'crisop' ),
                    'wp-menu' => esc_html__( 'WP Menu', 'crisop' ),
                    'template' => esc_html__( 'Elementor Template', 'crisop' )
                ]
            ]
        );
        $repeater->add_control( 'submenu',
            [
                'label' => esc_html__( 'Select Menu', 'crisop' ),
                'type' => Controls_Manager::SELECT2,
                'multiple' => false,
                'label_block' => true,
                'options' => $this->registered_nav_menus(),
                'condition' => ['submenu_type' => 'wp-menu']
            ]
        );
        $repeater->add_control( 'content_template',
            [
                'label' => esc_html__( 'Content Template', 'crisop' ),
                'type' => Controls_Manager::SELECT2,
                'default' => '',
                'multiple' => false,
                'options' => $this->ninetheme_get_elementor_templates('section'),
                'condition' => ['submenu_type' => 'template']
            ]
        );
        $this->add_control( 'icon_size',
            [
                'label' => esc_html__( 'Content Template Min Width', 'crisop' ),
                'type' => Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'max' => 1000
                    ]
                ],
                'selectors' => ['{{WRAPPER}} .ninetheme-header-menu-widget.display-type-dropdown .submenu .submenu.mega-menu-content' => 'min-width: {{SIZE}}px;'],
                 'condition' => ['submenu_type' => 'template']
            ]
        );
        $this->add_control( 'menu_items',
            [
                'label' => esc_html__( 'Items', 'crisop' ),
                'type' => Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'title_field' => '{{menu_item_title}}',
                'default' => []
            ]
        );
        $this->end_controls_section();
        /*****   END CONTROLS SECTION   ******/

        /*****   START CONTROLS SECTION   ******/
        $this->start_controls_section( 'dropdown_menu_button_section',
            [
                'label'=> esc_html__( 'MENU BUTTON STYLE', 'crisop' ),
                'tab' => Controls_Manager::TAB_CONTENT,
                'condition' => ['display_type' => 'dropdown']
            ]
        );
        $this->add_responsive_control( 'header_btn_minheight',
            [
                'label' => esc_html__( 'Min Height', 'crisop' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => [ 'px' ],
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 300,
                        'step' => 1
                    ]
                ],
                'selectors' => [
                    '{{WRAPPER}} .ninetheme-header-menu-widget.display-type-dropdown .ninetheme-dropdown-menu-trigger' => 'padding-top:0;padding-bottom:0;height:auto;min-height:{{SIZE}}{{UNIT}};'
                ]
            ]
        );
        $this->add_responsive_control( 'header_btn_minwidth',
            [
                'label' => esc_html__( 'Min Width', 'crisop' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => [ 'px' ],
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 300,
                        'step' => 1
                    ]
                ],
                'selectors' => [
                    '{{WRAPPER}} .ninetheme-header-menu-widget.display-type-dropdown .ninetheme-dropdown-menu-trigger' => 'padding-left:0;padding-right:0;width:auto;min-width:{{SIZE}}{{UNIT}};'
                ]
            ]
        );
        $this->add_responsive_control( 'alignment',
            [
                'label' => esc_html__( 'Alignment', 'crisop' ),
                'type' => Controls_Manager::CHOOSE,
                'selectors' => ['{{WRAPPER}} .ninetheme-dropdown-menu-trigger' => 'justify-content: {{VALUE}};'],
                'options' => [
                    'flex-start' => [
                        'title' => esc_html__( 'Left', 'crisop' ),
                        'icon' => 'eicon-h-align-left'
                    ],
                    'center' => [
                        'title' => esc_html__( 'Center', 'crisop' ),
                        'icon' => 'eicon-h-align-center'
                    ],
                    'flex-end' => [
                        'title' => esc_html__( 'Right', 'crisop' ),
                        'icon' => 'eicon-h-align-right'
                    ]
                ],
                'toggle' => true,
                'default' => ''
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'header_btn_typo',
                'label' => esc_html__( 'Typography', 'crisop' ),
                'selector' => '{{WRAPPER}} .ninetheme-header-menu-widget.display-type-dropdown .ninetheme-dropdown-menu-trigger .btn-text'
            ]
        );
        $this->add_control( 'bg_type',
            [
                'label' => esc_html__( 'Background Type', 'crisop' ),
                'type' => Controls_Manager::SELECT,
                'default' => 'ninetheme-btn-solid',
                'options' => [
                    'ninetheme-btn-border' => esc_html__( 'Bordered', 'crisop' ),
                    'ninetheme-btn-solid' => esc_html__( 'Solid', 'crisop' ),
                    'ninetheme-btn-text' => esc_html__( 'Simple Text', 'crisop' )
                ]
            ]
        );
        $this->add_control( 'color_type',
            [
                'label' => esc_html__( 'Color Type', 'crisop' ),
                'type' => Controls_Manager::SELECT,
                'default' => 'ninetheme-btn-blue',
                'options' => [
                    'ninetheme-btn-primary' => esc_html__( 'Primary', 'crisop' ),
                    'ninetheme-btn-dark' => esc_html__( 'Black', 'crisop' ),
                    'ninetheme-btn-brown' => esc_html__( 'Brown', 'crisop' ),
                    'ninetheme-btn-red' => esc_html__( 'Red', 'crisop' ),
                    'ninetheme-btn-gray' => esc_html__( 'Gray', 'crisop' ),
                    'ninetheme-btn-gray-soft' => esc_html__( 'Gray Soft', 'crisop' ),
                    'ninetheme-btn-green' => esc_html__( 'Green', 'crisop' ),
                    'ninetheme-btn-green-soft' => esc_html__( 'Green Soft', 'crisop' ),
                    'ninetheme-btn-blue' => esc_html__( 'Blue', 'crisop' ),
                    'ninetheme-btn-blue-dark' => esc_html__( 'Blue Dark', 'crisop' ),
                    'ninetheme-btn-blue-soft' => esc_html__( 'Blue Soft', 'crisop' ),
                    'ninetheme-btn-purple' => esc_html__( 'Purple', 'crisop' ),
                    'ninetheme-btn-purple-soft' => esc_html__( 'Purple Soft', 'crisop' ),
                    'ninetheme-btn-yellow' => esc_html__( 'Yellow', 'crisop' ),
                    'ninetheme-btn-yellow-soft' => esc_html__( 'Yellow Soft', 'crisop' ),
                    'ninetheme-btn-custom-color' => esc_html__( 'Custom', 'crisop' ),
                ]
            ]
        );
        $this->add_control( 'radius_type',
            [
                'label' => esc_html__( 'Radius Type', 'crisop' ),
                'type' => Controls_Manager::SELECT,
                'default' => 'ninetheme-btn-square',
                'options' => [
                    'ninetheme-btn-radius' => esc_html__( 'Radius', 'crisop' ),
                    'ninetheme-btn-square' => esc_html__( 'Square', 'crisop' ),
                ],
                'condition' => ['bg_type!' => 'ninetheme-btn-text']
            ]
        );
        $this->add_control( 'size',
            [
                'label' => esc_html__( 'Size', 'crisop' ),
                'type' => Controls_Manager::SELECT,
                'default' => 'ninetheme-btn-medium',
                'options' => [
                    'ninetheme-btn-large' => esc_html__( 'Large', 'crisop' ),
                    'ninetheme-btn-medium' => esc_html__( 'Medium', 'crisop' ),
                    'ninetheme-btn-small' => esc_html__( 'Small', 'crisop' )
                ],
                'condition' => ['bg_type!' => 'ninetheme-btn-text']
            ]
        );
        $this->start_controls_tabs('btn_tabs');
        $this->start_controls_tab( 'btn_normal_tab',
            [
                'label' => esc_html__( 'Normal', 'crisop' ),
                'condition' => ['color_type' => 'ninetheme-btn-custom-color']
            ]
        );
        $this->add_control( 'btn_color',
            [
                'label' => esc_html__( 'Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => ['{{WRAPPER}} .ninetheme-btn.ninetheme-btn-custom-color' => 'color: {{VALUE}};']
            ]
        );
        $this->add_control( 'btn_bgcolor',
            [
                'label' => esc_html__( 'Background Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => ['{{WRAPPER}} .ninetheme-btn.ninetheme-btn-custom-color' => 'background-color: {{VALUE}};'],
            ]
        );
        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name' => 'btn_border',
                'label' => esc_html__( 'Border', 'crisop' ),
                'selector' => '{{WRAPPER}} .ninetheme-btn.ninetheme-btn-custom-color'
            ]
        );
        $this->end_controls_tab();
        $this->start_controls_tab('btn_hover_tab',
            [
                'label' => esc_html__( 'Hover', 'crisop' ),
                'condition' => ['color_type' => 'ninetheme-btn-custom-color']
            ]
        );
        $this->add_control( 'btn_hvrcolor',
            [
                'label' => esc_html__( 'Color ( Hover )', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => ['{{WRAPPER}} .ninetheme-btn.ninetheme-btn-custom-color:hover' => 'color: {{VALUE}};']
            ]
        );
        $this->add_control( 'btn_hvrbgcolor',
            [
                'label' => esc_html__( 'Background Color ( Hover )', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => ['{{WRAPPER}} .ninetheme-btn.ninetheme-btn-custom-color:hover' => 'background-color: {{VALUE}};']
            ]
        );
        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name' => 'btn_hvr_border',
                'label' => esc_html__( 'Border', 'crisop' ),
                'selector' => '{{WRAPPER}} .ninetheme-btn.ninetheme-btn-custom-color:hover'
            ]
        );
        $this->end_controls_tab();
        $this->end_controls_tabs();
        $this->add_responsive_control( 'btn_border_radius',
            [
                'label' => esc_html__( 'Border Radius', 'crisop' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px' ],
                'selectors' => ['{{WRAPPER}} .ninetheme-btn.ninetheme-btn-custom-color' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};']
            ]
        );
        $this->add_responsive_control( 'menu_btn_padding',
            [
                'label' => esc_html__( 'Padding', 'crisop' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px' ],
                'selectors' => ['{{WRAPPER}} .ninetheme-header-menu-widget.display-type-dropdown .ninetheme-dropdown-menu-trigger' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};']
            ]
        );
        $this->add_control( 'icon',
            [
                'label' => esc_html__( 'Button Icon Before', 'crisop' ),
                'type' => Controls_Manager::ICONS,
                'default' => [
                    'value' => '',
                    'library' => 'solid'
                ],
                'separator' => 'before'
            ]
        );
        $this->add_control( 'icon_color',
            [
                'label' => esc_html__( 'Button Icon Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => ['{{WRAPPER}} .ninetheme-dropdown-menu-trigger .btn-icon.btn-icon-left' => 'color: {{VALUE}};']
            ]
        );
        $this->add_control( 'icon_hvrcolor',
            [
                'label' => esc_html__( 'Button Icon Color ( Hover )', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => ['{{WRAPPER}} .ninetheme-dropdown-menu-trigger:hover .btn-icon.btn-icon-left' => 'color: {{VALUE}};']
            ]
        );
        $rtl = is_rtl() ? 'left' : 'right';
        $this->add_control( 'icon_spacing',
            [
                'label' => esc_html__( 'Icon Spacing', 'crisop' ),
                'type' => Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'max' => 300
                    ]
                ],
                'default' => [
                    'unit' => 'px',
                    'size' => 15
                ],
                'selectors' => [ '{{WRAPPER}} .ninetheme-dropdown-menu-trigger .btn-icon.btn-icon-left' => 'margin-'.$rtl.': {{SIZE}}px;' ]
            ]
        );
        $this->add_control( 'btn_icon_size',
            [
                'label' => esc_html__( 'Icon Size', 'crisop' ),
                'type' => Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'max' => 300
                    ]
                ],
                'selectors' => ['{{WRAPPER}} .ninetheme-dropdown-menu-trigger .btn-icon.btn-icon-left' => 'font-size: {{SIZE}}px;']
            ]
        );
        $this->add_control( 'icon2',
            [
                'label' => esc_html__( 'Button Icon After', 'crisop' ),
                'type' => Controls_Manager::ICONS,
                'default' => [
                    'value' => '',
                    'library' => 'solid'
                ],
                'separator' => 'before'
            ]
        );
        $this->add_control( 'icon2_color',
            [
                'label' => esc_html__( 'Button Icon Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => ['{{WRAPPER}} .ninetheme-dropdown-menu-trigger .btn-icon.btn-icon-left' => 'color: {{VALUE}};']
            ]
        );
        $this->add_control( 'icon2_hvrcolor',
            [
                'label' => esc_html__( 'Button Icon Color ( Hover )', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => ['{{WRAPPER}} .ninetheme-dropdown-menu-trigger:hover .btn-icon.btn-icon-left' => 'color: {{VALUE}};']
            ]
        );
        $is_left = is_rtl() ? 'right' : 'left';
        $this->add_control( 'icon_spacing2',
            [
                'label' => esc_html__( 'Icon Spacing', 'crisop' ),
                'type' => Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'max' => 300
                    ]
                ],
                'default' => [
                    'unit' => 'px',
                    'size' => 15
                ],
                'selectors' => [ '{{WRAPPER}} .ninetheme-dropdown-menu-trigger .btn-icon.btn-icon-right' => 'margin-'.$is_left.': {{SIZE}}px;' ]
            ]
        );
        $this->add_control( 'btn_icon_size2',
            [
                'label' => esc_html__( 'Icon Size', 'crisop' ),
                'type' => Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'max' => 300
                    ]
                ],
                'selectors' => ['{{WRAPPER}} .ninetheme-dropdown-menu-trigger .btn-icon.btn-icon-right' => 'font-size: {{SIZE}}px;']
            ]
        );
        $this->end_controls_section();
        /*****   END CONTROLS SECTION   ******/

        /*****   START CONTROLS SECTION   ******/
        $this->start_controls_section( 'menu_item_style_section',
            [
                'label'=> esc_html__( 'PRIMARY MENU STYLE', 'crisop' ),
                'tab' => Controls_Manager::TAB_CONTENT,
                'condition' => ['display_type' => 'inline']
            ]
        );
        $this->add_control( 'menu_item_color',
            [
                'label' => esc_html__( 'Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .ninetheme-header-menu-widget .ninetheme-header-top-menu-area>ul>li.menu-item>a,
                    {{WRAPPER}} .ninetheme-header-menu-widget .ninetheme-header-top-menu-area ul li .submenu>li.menu-item>a,
                    {{WRAPPER}} .ninetheme-header-menu-widget .ninetheme-header-top-menu-area>ul>li.menu-item-mega-parent>.submenu>li.menu-item:hover>a,
                    {{WRAPPER}} .ninetheme-header-menu-widget .ninetheme-header-top-menu-area>ul>li.menu-item-mega-parent>.submenu>li.menu-item.active>a' => 'color:{{VALUE}};'
                ]
            ]
        );
        $this->add_control( 'menu_item_hvrcolor',
            [
                'label' => esc_html__( 'Color ( Hover/Active )', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .ninetheme-header-menu-widget .ninetheme-header-top-menu-area>ul>li.menu-item:hover>a,
                    {{WRAPPER}} .ninetheme-header-menu-widget .ninetheme-header-top-menu-area>ul>li.menu-item.active>a,
                    {{WRAPPER}} .ninetheme-header-menu-widget .ninetheme-header-top-menu-area ul li .submenu>li.menu-item:hover>a,
                    {{WRAPPER}} .ninetheme-header-menu-widget .ninetheme-header-top-menu-area ul li .submenu>li.menu-item.active>a,
                    {{WRAPPER}} .ninetheme-header-menu-widget .ninetheme-header-top-menu-area>ul>li.menu-item-mega-parent>.submenu>li.menu-item:hover>a,
                    {{WRAPPER}} .ninetheme-header-menu-widget .ninetheme-header-top-menu-area>ul>li.menu-item-mega-parent>.submenu>li.menu-item.active>a' => 'color:{{VALUE}};'
                ]
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'primary_menu_item_typo',
                'label' => esc_html__( 'Typography', 'crisop' ),
                'selector' => '{{WRAPPER}} .ninetheme-header-menu-widget .ninetheme-header-top-menu-area>ul>li.menu-item>a'
            ]
        );
        $this->add_responsive_control( 'menu_item_spacing',
            [
                'label' => esc_html__( 'Spacing Between Menu Items', 'crisop' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => [ 'px' ],
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 100,
                        'step' => 1
                    ]
                ],
                'selectors' => [ '{{WRAPPER}} .ninetheme-header-menu-widget .ninetheme-header-top-menu-area>ul>li.menu-item>a' => 'margin-right:{{SIZE}}{{UNIT}};' ]
            ]
        );
        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name' => 'menu_item_border',
                'label' => esc_html__( 'Border', 'crisop' ),
                'selector' => '{{WRAPPER}} .ninetheme-header-menu-widget .ninetheme-header-top-menu-area>ul>li.menu-item>a',
            ]
        );
        $this->add_responsive_control( 'menu_item_padding',
            [
                'label' => esc_html__( 'Padding', 'crisop' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px' ],
                'selectors' => ['{{WRAPPER}} .ninetheme-header-menu-widget .ninetheme-header-top-menu-area>ul>li.menu-item>a' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};'],
            ]
        );
        $this->end_controls_section();
        /*****   END CONTROLS SECTION   ******/

        /*****   START CONTROLS SECTION   ******/
        $this->start_controls_section( 'submenu_style_section',
            [
                'label'=> esc_html__( 'SUBMENU STYLE', 'crisop' ),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );
        $this->add_control( 'submenu_position',
            [
                'label' => esc_html__( 'Submenu Position', 'crisop' ),
                'type' => Controls_Manager::SELECT,
                'default' => 'left',
                'options' => [
                    'left' => esc_html__( 'Left', 'crisop' ),
                    'right' => esc_html__( 'Right', 'crisop' )
                ]
            ]
        );
        $this->add_control( 'submenu_boxshadow',
            [
                'label' => esc_html__( 'Box Shadow?', 'crisop' ),
                'type' => Controls_Manager::SWITCHER,
                'default' => 'no'
            ]
        );
        $this->add_control( 'submenu_bgcolor',
            [
                'label' => esc_html__( 'Background Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .ninetheme-header-menu-widget .ninetheme-header-top-menu-area>ul>li>.submenu,
                    {{WRAPPER}} .ninetheme-header-menu-widget.display-type-dropdown .ninetheme-header-top-menu-area .submenu,
                    {{WRAPPER}} .ninetheme-header-menu-widget .ninetheme-header-top-menu-area>ul>li>.item-shortcode-wrapper' => 'background-color:{{VALUE}};'
                ]
            ]
        );
        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name' => 'box_border',
                'label' => esc_html__( 'Border', 'crisop' ),
                'selector' => '{{WRAPPER}} .ninetheme-header-menu-widget .ninetheme-header-top-menu-area>ul>li>.submenu,
                    {{WRAPPER}} .ninetheme-header-menu-widget.display-type-dropdown .ninetheme-header-top-menu-area .submenu,
                    {{WRAPPER}} .ninetheme-header-menu-widget .ninetheme-header-top-menu-area>ul>li>.item-shortcode-wrapper'
            ]
        );
        $this->add_responsive_control( 'box_border_radius',
            [
                'label' => esc_html__( 'Border Radius', 'crisop' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px' ],
                'selectors' => [
                    '{{WRAPPER}} .ninetheme-header-menu-widget .ninetheme-header-top-menu-area>ul>li>.submenu,
                    {{WRAPPER}} .ninetheme-header-menu-widget.display-type-dropdown .ninetheme-header-top-menu-area .submenu,
                    {{WRAPPER}} .ninetheme-header-menu-widget .ninetheme-header-top-menu-area>ul>li>.item-shortcode-wrapper'  => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};'
                ]
            ]
        );
        $this->add_group_control(
            Group_Control_Box_Shadow::get_type(),
            [
                'name' => 'box_shadow',
                'label' => esc_html__( 'Box Shadow', 'crisop' ),
                'selector' =>'{{WRAPPER}} .ninetheme-header-menu-widget .ninetheme-header-top-menu-area>ul>li>.submenu,
                    {{WRAPPER}} .ninetheme-header-menu-widget.display-type-dropdown .ninetheme-header-top-menu-area .submenu,
                    {{WRAPPER}} .ninetheme-header-menu-widget .ninetheme-header-top-menu-area>ul>li>.item-shortcode-wrapper'
            ]
        );
        $this->add_control( 'submenu_bgcolor',
            [
                'label' => esc_html__( 'MENU ITEMS', 'crisop' ),
                'type' => Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'submenu_item_typo',
                'label' => esc_html__( 'Typography', 'crisop' ),
                'selector' =>
                    '{{WRAPPER}} .ninetheme-header-menu-widget .ninetheme-header-top-menu-area ul li .submenu>li.menu-item>a,
                    {{WRAPPER}} .ninetheme-header-menu-widget .ninetheme-header-top-menu-area>ul>li.menu-item-mega-parent>.submenu>li.menu-item>a,
                    {{WRAPPER}} .ninetheme-header-menu-widget.display-type-dropdown .submenu li > a'
            ]
        );
        $this->add_control( 'submenu_item_color',
            [
                'label' => esc_html__( 'Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .ninetheme-header-menu-widget .ninetheme-header-top-menu-area>ul>li.menu-item-mega-parent>.submenu>li.menu-item>a,
                    {{WRAPPER}} .ninetheme-header-menu-widget .ninetheme-header-top-menu-area ul li .submenu>li.menu-item>a,
                    {{WRAPPER}} .ninetheme-header-menu-widget.display-type-dropdown .submenu li a' => 'color:{{VALUE}};'
                ]
            ]
        );
        $this->add_control( 'submenu_item_hvrcolor',
            [
                'label' => esc_html__( 'Color ( Hover/Active )', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .ninetheme-header-menu-widget .ninetheme-header-top-menu-area ul li .submenu>li.menu-item:hover>a,
                    {{WRAPPER}} .ninetheme-header-menu-widget .ninetheme-header-top-menu-area ul li .submenu>li.menu-item.active>a,
                    {{WRAPPER}} .ninetheme-header-menu-widget .ninetheme-header-top-menu-area>ul>li.menu-item-mega-parent>.submenu>li.menu-item:hover>a,
                    {{WRAPPER}} .ninetheme-header-menu-widget .ninetheme-header-top-menu-area>ul>li.menu-item-mega-parent>.submenu>li.menu-item.active>a,
                    {{WRAPPER}} .ninetheme-header-menu-widget.display-type-dropdown .submenu li.active>a,
                    {{WRAPPER}} .ninetheme-header-menu-widget.display-type-dropdown .submenu li:hover>a' => 'color:{{VALUE}};'
                ]
            ]
        );
        $this->add_control( 'submenu_item_bgcolor',
            [
                'label' => esc_html__( 'Background Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .ninetheme-header-menu-widget .ninetheme-header-top-menu-area>ul>li.menu-item-mega-parent>.submenu>li.menu-item,
                    {{WRAPPER}} .ninetheme-header-menu-widget .ninetheme-header-top-menu-area ul li .submenu>li.menu-item,
                    {{WRAPPER}} .ninetheme-header-menu-widget.display-type-dropdown .submenu li' => 'background-color:{{VALUE}};'
                ]
            ]
        );
        $this->add_control( 'submenu_item_hvrcolor',
            [
                'label' => esc_html__( 'Background Color ( Hover/Active )', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .ninetheme-header-menu-widget .ninetheme-header-top-menu-area ul li .submenu>li.menu-item:hover,
                     {{WRAPPER}} .ninetheme-header-menu-widget .ninetheme-header-top-menu-area ul li .submenu>li.menu-item.active,
                    {{WRAPPER}} .ninetheme-header-menu-widget .ninetheme-header-top-menu-area>ul>li.menu-item-mega-parent>.submenu>li.menu-item:hover,
                    {{WRAPPER}} .ninetheme-header-menu-widget .ninetheme-header-top-menu-area>ul>li.menu-item-mega-parent>.submenu>li.menu-item.active,
                    {{WRAPPER}} .ninetheme-header-menu-widget.display-type-dropdown .submenu li.active,
                    {{WRAPPER}} .ninetheme-header-menu-widget.display-type-dropdown .submenu li:hover' => 'background-color:{{VALUE}};'
                ]
            ]
        );
        $this->add_control( 'submenu_separator',
            [
                'label' => esc_html__( 'Separator', 'crisop' ),
                'type' => Controls_Manager::SWITCHER,
                'default' => 'no'
            ]
        );
        $this->add_control( 'submenu_separator_color',
            [
                'label' => esc_html__( 'Separator Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [ '{{WRAPPER}} .ninetheme-header-menu-widget.has-separator ul li .submenu>li+li' => 'border-top-color:{{VALUE}};' ]
            ]
        );
        $this->add_responsive_control( 'submenu_item_padding',
            [
                'label' => esc_html__( 'Padding', 'crisop' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px' ],
                'selectors' => [
                    '{{WRAPPER}} .ninetheme-header-menu-widget .ninetheme-header-top-menu-area ul li .submenu>li.menu-item,
                    {{WRAPPER}} .ninetheme-header-menu-widget.display-type-dropdown .submenu >li' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};'
                ]
            ]
        );

        $this->end_controls_section();
        /*****   END CONTROLS SECTION   ******/

        /*****   START CONTROLS SECTION   ******/
        $this->start_controls_section( 'megamenu_style_section',
            [
                'label'=> esc_html__( 'MEGA MENU STYLE', 'crisop' ),
                'tab' => Controls_Manager::TAB_CONTENT,
                'condition' => ['display_type' => 'inline']
            ]
        );
        $this->add_control( 'mega_submenu_layout',
            [
                'label' => esc_html__( 'Mega Submenu Horizontal Alignment', 'crisop' ),
                'type' => Controls_Manager::SELECT,
                'default' => 'space-between',
                'options' => [
                    'center' => esc_html__( 'center', 'crisop' ),
                    'flex-start' => esc_html__( 'flex-start', 'crisop' ),
                    'space-around' => esc_html__( 'space-around', 'crisop' ),
                    'space-between' => esc_html__( 'space-between', 'crisop' ),
                    'space-evenly' => esc_html__( 'space-evenly', 'crisop' )
                ],
                'selectors' => [ '{{WRAPPER}} .ninetheme-header-menu-widget .ninetheme-header-top-menu-area>ul>li.menu-item-mega-parent>ul.submenu' => 'justify-content:{{VALUE}};']
            ]
        );
        $this->add_responsive_control( 'mega_submenu_col_padding',
            [
                'label' => esc_html__( 'Mega Submenu Column Spacing', 'crisop' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => [ 'px' ],
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 100,
                        'step' => 1
                    ]
                ],
                'selectors' => ['{{WRAPPER}} .ninetheme-header-menu-widget .ninetheme-header-top-menu-area>ul>li.menu-item-mega-parent>ul.submenu.depth_0>li.menu-item' => 'padding: 0 {{SIZE}}{{UNIT}};' ]
            ]
        );
        $this->add_control( 'mega_submenu_col_heading_color',
            [
                'label' => esc_html__( 'Column Heading Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .ninetheme-header-menu-widget .ninetheme-header-top-menu-area>ul>li.menu-item-mega-parent>.submenu>li.menu-item>a' => 'color:{{VALUE}};'
                ]
            ]
        );
        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name' => 'mega_submenu_col_heading_border',
                'label' => esc_html__( 'Column Heading Border', 'crisop' ),
                'selector' => '{{WRAPPER}} .ninetheme-header-menu-widget .ninetheme-header-top-menu-area ul li .submenu>li.menu-item>a',
            ]
        );
        $this->add_responsive_control( 'mega_submenu_col_heading_padding',
            [
                'label' => esc_html__( 'Column Heading Padding', 'crisop' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px' ],
                'selectors' => ['{{WRAPPER}} .ninetheme-header-menu-widget .ninetheme-header-top-menu-area ul li .submenu>li.menu-item>a' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};'],
            ]
        );
       $this->add_control( 'mega_submenu_item_color',
            [
                'label' => esc_html__( 'Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .ninetheme-header-menu-widget .ninetheme-header-top-menu-area>ul>li.menu-item-mega-parent>.submenu>li.menu-item.active>a' => 'color:{{VALUE}};'
                ]
            ]
        );
        $this->add_control( 'mega_submenu_item_hvrcolor',
            [
                'label' => esc_html__( 'Color ( Hover/Active )', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .ninetheme-header-menu-widget .ninetheme-header-top-menu-area>ul>li.menu-item-mega-parent>.submenu>li.menu-item:hover>a,
                    {{WRAPPER}} .ninetheme-header-menu-widget .ninetheme-header-top-menu-area>ul>li.menu-item-mega-parent>.submenu>li.menu-item.active>a' => 'color:{{VALUE}};'
                ]
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'mega_submenu_item_typo',
                'label' => esc_html__( 'Typography', 'crisop' ),
                'selector' => '{{WRAPPER}} .ninetheme-header-menu-widget .ninetheme-header-top-menu-area>ul>li.menu-item-mega-parent>.submenu>li.menu-item>a'
            ]
        );
        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name' => 'mega_submenu_item_border',
                'label' => esc_html__( 'Border', 'crisop' ),
                'selector' => '{{WRAPPER}} .ninetheme-header-menu-widget .ninetheme-header-top-menu-area>ul>li.menu-item-mega-parent>.submenu>li.menu-item>a',
            ]
        );
        $this->add_responsive_control( 'menu_item_padding',
            [
                'label' => esc_html__( 'Padding', 'crisop' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px' ],
                'selectors' => ['{{WRAPPER}} .ninetheme-header-menu-widget .ninetheme-header-top-menu-area>ul>li.menu-item-mega-parent>.submenu>li.menu-item>a' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};'],
            ]
        );
        $this->end_controls_section();
        /*****   END CONTROLS SECTION   ******/
    }

    public function header_dropdown_button()
    {
        $settings = $this->get_settings_for_display();
        $id = $this->get_id();
        if ( 'inline' == $settings['display_type'] ) {
            return;
        }

        $class  = ' '.$settings['color_type'];
        $class .= ' '.$settings['bg_type'];
        $class .= ' '.$settings['radius_type'];
        $class .= ' '.$settings['size'];

        echo '<div class="ninetheme-dropdown-menu-trigger ninetheme-btn'.$class.'">';
            if ( !empty( $settings['icon']['value'] ) ) {
                echo '<span class="btn-icon btn-icon-left">';
                Icons_Manager::render_icon( $settings['icon'], [ 'aria-hidden' => 'true' ] );
                echo '</span>';
            }
            echo $settings['btn_text'] ? '<span class="btn-text">'.$settings['btn_text'].'</span>' : '';

            if ( !empty( $settings['icon2']['value'] ) ) {
                echo '<span class="btn-icon btn-icon-right">';
                Icons_Manager::render_icon( $settings['icon2'], [ 'aria-hidden' => 'true' ] );
                echo '</span>';
            }

        echo '</div>';
    }

    protected function render()
    {
        $settings = $this->get_settings_for_display();
        $id = $this->get_id();
        $class  = '';
        $class .= \Elementor\Plugin::$instance->editor->is_edit_mode() && 'yes' == $settings['show_megasubmenu'] && 'wp-menu' == $settings['source'] ? ' open-megamenu' : '';
        $class .= \Elementor\Plugin::$instance->editor->is_edit_mode() && 'yes' == $settings['show_submenu'] && 'wp-menu' == $settings['source'] ? ' open-submenu' : '';
        $class .= ' display-type-'.$settings['display_type'];
        $class .= 'yes' == $settings['submenu_separator'] ? ' has-separator' : '';
        $class .= ' '.$settings['submenu_action'];
        $class .= ' submenu-boxshadow-'.$settings['submenu_boxshadow'];
        $primary_sub  = 'dropdown' == $settings['display_type'] ? ' primary-menu submenu' : ' primary-menu';
        $primary_sub .= ' submenu-position-'.$settings['submenu_position'];
        $primary_sub .= ' is-active-'.$settings['is_active'];
        $sub_arrow    = 'dropdown' == $settings['display_type'] ? 'right' : 'down';

        if ( 'wp-menu' == $settings['source'] ) {

            echo '<div class="ninetheme-header-menu-widget wp-menu-type'.$class.'">';
                echo 'inline' == $settings['display_type'] ? '<div class="ninetheme-header-top-menu-area">' : '';
                    $this->header_dropdown_button();
                    echo '<ul class="navigation'.$primary_sub.'">';
                        echo wp_nav_menu(
                            array(
                                'menu' => $settings['register_menus'],
                                'container' => '',
                                'container_class' => '',
                                'container_id' => '',
                                'menu_class' => '',
                                'menu_id' => '',
                                'items_wrap' => '%3$s',
                                'before' => '',
                                'after' => '',
                                'link_before' => '',
                                'link_after' => '',
                                'depth' => 4,
                                'echo' => true,
                                'fallback_cb' => 'Ninetheme_Wp_Bootstrap_Navwalker::fallback',
                                'walker' => new \Ninetheme_Wp_Bootstrap_Navwalker()
                            )
                        );
                    echo '</ul>';
                echo 'inline' == $settings['display_type'] ? '</div>' : '';
            echo '</div>';

        } elseif( 'custom' == $settings['source'] ) {

            echo '<div class="ninetheme-header-menu-widget wp-menu-custom'.$class.'">';
                echo 'inline' == $settings['display_type'] ? '<div class="ninetheme-header-top-menu-area">' : '';
                    $this->header_dropdown_button();
                    echo '<ul class="navigation'.$primary_sub.'">';
                    foreach ( $settings['menu_items'] as $item ) {
                        if ( $item['menu_item_title'] ) {
                            $target     = !empty( $item['link']['is_external'] ) ? ' target="_blank"' : '';
                            $nofollow   = !empty( $item['link']['nofollow'] ) ? ' rel="nofollow"' : '';
                            $href       = !empty( $item['link']['url'] ) ? $item['link']['url'] : '';
                            echo '<li class="menu-item custom-menu-item">';

                                if ( 'wp-menu' == $item['submenu_type'] && !empty( $item['submenu'] ) ) {
                                    echo '<a class="ninetheme-menu-link" href="'.$href.'"'.$target.$nofollow.'>';
                                        echo '<span class="btn-text">'.$item['menu_item_title'].'</span>';
                                        echo !empty( $item['submenu'] ) ? '<span class="dropdown-btn fas fa-angle-'.$sub_arrow.'"></span>' : '';
                                    echo '</a>';
                                    echo '<ul class="submenu depth_0">';
                                        echo wp_nav_menu(
                                            array(
                                                'menu' => $item['submenu'],
                                                'container' => '',
                                                'container_class' => '',
                                                'container_id' => '',
                                                'menu_class' => '',
                                                'menu_id' => '',
                                                'items_wrap' => '%3$s',
                                                'before' => '',
                                                'after' => '',
                                                'link_before' => '',
                                                'link_after' => '',
                                                'depth' => 4,
                                                'echo' => true,
                                                'fallback_cb' => 'Ninetheme_Wp_Bootstrap_Navwalker::fallback',
                                                'walker' => new \Ninetheme_Wp_Bootstrap_Navwalker()
                                            )
                                        );
                                    echo '</ul>';
                                }
                                if ( 'template' == $item['submenu_type'] && !empty( $item['content_template'] ) ) {
                                    echo '<a class="ninetheme-menu-link" href="'.$href.'"'.$target.$nofollow.'>';
                                        echo '<span class="btn-text">'.$item['menu_item_title'].'</span>';
                                        echo !empty( $item['content_template'] ) ? '<span class="dropdown-btn fas fa-angle-'.$sub_arrow.'"></span>' : '';
                                    echo '</a>';
                                    echo '<ul class="submenu mega-menu-content depth_0">';
                                        $style = \Elementor\Plugin::$instance->editor->is_edit_mode() ? true : false;
                                        $content_template = new Frontend;
                                        echo $content_template->get_builder_content_for_display($item['content_template'], $style );
                                    echo '</ul>';
                                }
                            echo '</li>';
                        }
                    }
                    echo '</ul>';
                echo 'inline' == $settings['display_type'] ? '</div>' : '';
            echo '</div>';

        } else {

            echo '<div class="ninetheme-header-menu-widget'.$class.'">';
                    $this->header_dropdown_button();
                    echo '<ul class="ninetheme-vertical-catmenu-primary'.$primary_sub.'">';
                        echo wp_list_categories(
                            array(
                                'echo'       => true,
                                'taxonomy'   => $settings['taxonomies'] ? $settings['taxonomies'] : 'product_cat',
                                'depth'      => 5,
                                'hide_empty' => 0,
                                'title_li'   => '',
                                'exclude'    => !empty( $settings['exclude'] ) ? $settings['exclude'] : '',
                                'walker'     => new \Ninetheme_WooCommerce_Categories_Walker()
                            )
                        );
                echo '</ul>';
            echo '</div>';
        }

        if ( \Elementor\Plugin::$instance->editor->is_edit_mode() ) { ?>
            <script>
            jQuery( document ).ready( function($) {

                <?php if ( 'wp-menu' == $settings['source'] && 'inline' == $settings['display_type'] ) { ?>

                    $('.ninetheme-header-menu-widget.open-megamenu .primary-menu li.menu-item-mega-parent:first-child').addClass('show');

                    $('.ninetheme-header-menu-widget.open-submenu .primary-menu > li.has-dropdown:not(.menu-item-mega-parent)').each( function(i,e) {
                        $(e).addClass('z-index-'+i);
                    });
                    $('.elementor-top-section .ninetheme-header-top-menu-area li.menu-item-mega-parent > ul.submenu').each( function() {
                        var cont     = $( this ),
                            wrap     = cont.closest( '.navigation' ),
                            wrapoff  = wrap.offset(),
                            wrapleft = wrapoff.left,
                            parentw  = cont.closest( '.elementor-top-section' ).outerWidth();

                        if ( $(window).outerWidth() > 1024 ) {
                            cont.css({
                                'left':'-'+ ( wrapleft ) +'px'
                            });
                        } else {
                            cont.removeAttr('style');
                        }
                    });

                <?php } ?>

                <?php if ( 'dropdown' == $settings['display_type'] ) { ?>

                    $(".ninetheme-header-menu-widget.display-type-dropdown.open-submenu-on-click .ninetheme-dropdown-menu-trigger").off('click').on('click',function(){
                        $(this).toggleClass('active').parent().toggleClass('active');
                        $(this).next().find('.active').removeClass('active');
                    });
                    $(".ninetheme-header-menu-widget.display-type-dropdown.open-submenu-on-click .dropdown-btn").off('click').on('click',function(){
                        $(this).toggleClass('active').parent().toggleClass('active');
                        $(this).parent().siblings().removeClass('active');
                    });

                <?php } ?>

            });
            </script>
            <?php
        }

    }
}
