<?php

namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) exit; // If this file is called directly, abort.

class Ninetheme_Header_Slide_Menu extends Widget_Base {
    use Ninetheme_Helper;
    public function get_name() {
        return 'ninetheme-slide-menu';
    }
    public function get_title() {
        return 'Slide Menu (N)';
    }
    public function get_icon() {
        return 'eicon-nav-menu';
    }
    public function get_categories() {
        return [ 'ninetheme-header' ];
    }
    public function get_keywords() {
        return [ 'header', 'menu', 'mini', 'slide' ];
    }
    // Registering Controls
    protected function register_controls() {
        /*****   START CONTROLS SECTION   ******/
        $this->start_controls_section('menu_general_settings',
            [
                'label' => esc_html__( 'General', 'crisop' ),
                'tab' => Controls_Manager::TAB_CONTENT
            ]
        );
        $this->add_control( 'register_menus',
            [
                'label' => esc_html__( 'Select Menu', 'crisop' ),
                'type' => Controls_Manager::SELECT2,
                'multiple' => false,
                'label_block' => true,
                'options' => $this->registered_nav_menus(),
            ]
        );
        $this->end_controls_section();
        /*****   END CONTROLS SECTION   ******/

        /*****   START CONTROLS SECTION   ******/
        $this->start_controls_section( 'menu_item_style_section',
            [
                'label'=> esc_html__( 'MENU STYLE', 'crisop' ),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );
        $this->add_responsive_control( 'menu_max_width',
            [
                'label' => esc_html__( 'Max Width', 'crisop' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => [ 'px','%' ],
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 2000,
                        'step' => 1
                    ],
                    '%' => [
                        'min' => 0,
                        'max' => 100,
                        'step' => 1
                    ]
                ],
                'selectors' => [ '{{WRAPPER}} .ninetheme-header-widget-slide-menu' => 'max-width:{{SIZE}}{{UNIT}};' ]
            ]
        );
        $this->add_control( 'menu_item_color',
            [
                'label' => esc_html__( 'Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [ 
                    '{{WRAPPER}} .sliding-menu li .sliding-menu__nav,
                    {{WRAPPER}} .sliding-menu li.menu-item>a,
                    {{WRAPPER}} .sliding-menu .sliding-menu-inner li a' => 'color:{{VALUE}};'
                ]
            ]
        );
        $this->add_control( 'menu_item_hvrcolor',
            [
                'label' => esc_html__( 'Color ( Hover )', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [ 
                    '{{WRAPPER}} .sliding-menu li:hover> .sliding-menu__nav,
                    {{WRAPPER}} .sliding-menu .sliding-menu-inner li a,
                    {{WRAPPER}} .sliding-menu li.menu-item:hover>a' => 'color:{{VALUE}};'
                ]
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'menu_item_typo',
                'label' => esc_html__( 'Typography', 'crisop' ),
                'selector' => '{{WRAPPER}} .sliding-menu .sliding-menu-inner li .sliding-menu__nav,{{WRAPPER}} .sliding-menu li.menu-item>a,{{WRAPPER}} .sliding-menu .sliding-menu-inner li a'
            ]
        );
        $this->add_responsive_control( 'menu_item_spacing',
            [
                'label' => esc_html__( 'Spacing Between Menu Items', 'crisop' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => [ 'px' ],
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 100,
                        'step' => 1
                    ]
                ],
                'selectors' => [ '{{WRAPPER}} .sliding-menu .sliding-menu-inner li + li' => 'margin-top:{{SIZE}}{{UNIT}};' ]
            ]
        );
        $this->add_control( 'menu_item_arrow_color',
            [
                'label' => esc_html__( 'Arrow Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [ '{{WRAPPER}} .sliding-menu .sliding-menu__nav:before' => 'color:{{VALUE}};' ]
            ]
        );
        $this->add_responsive_control( 'menu_item_arrow_spacing',
            [
                'label' => esc_html__( 'Arrow Size', 'crisop' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => [ 'px' ],
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 100,
                        'step' => 1
                    ]
                ],
                'selectors' => [ '{{WRAPPER}} .sliding-menu .sliding-menu__nav:before' => 'font-size:{{SIZE}}{{UNIT}};' ]
            ]
        );
        $this->add_control( 'menu_item_back_heading',
            [
                'label' => esc_html__( 'SUBMENU BACK HEADING', 'crisop' ),
                'type' => Controls_Manager::HEADING,
                'separator' => 'before'
            ]
        );
        $this->add_control( 'menu_item_back_color',
            [
                'label' => esc_html__( 'Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [ '{{WRAPPER}} .sliding-menu li .sliding-menu__back' => 'color:{{VALUE}};' ]
            ]
        );
        $this->add_control( 'menu_item_back_hvrcolor',
            [
                'label' => esc_html__( 'Color ( Hover )', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [ '{{WRAPPER}} .sliding-menu li:hover> .sliding-menu__back' => 'color:{{VALUE}};' ]
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'menu_item_back_typo',
                'label' => esc_html__( 'Typography', 'crisop' ),
                'selector' => '{{WRAPPER}} .sliding-menu li .sliding-menu__nav.sliding-menu__back'
            ]
        );
        $this->add_responsive_control( 'menu_item_back_spacing',
            [
                'label' => esc_html__( 'Bottom Spacing', 'crisop' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => [ 'px' ],
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 100,
                        'step' => 1
                    ]
                ],
                'selectors' => [ '{{WRAPPER}} .sliding-menu li .sliding-menu__nav.sliding-menu__back' => 'margin-bottom:{{SIZE}}{{UNIT}};' ]
            ]
        );
        $this->add_control( 'menu_item_back_brd_color',
            [
                'label' => esc_html__( 'Border Bottom Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [ '{{WRAPPER}} .sliding-menu li .sliding-menu__nav.sliding-menu__back:after' => 'opacity:1;border-bottom-color:{{VALUE}};' ]
            ]
        );
        $this->add_control( 'menu_item_back_arrow_color',
            [
                'label' => esc_html__( 'Arrow Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [ '{{WRAPPER}} .sliding-menu li .sliding-menu__nav.sliding-menu__back:before' => 'color:{{VALUE}};' ]
            ]
        );
        $this->add_responsive_control( 'menu_item_back_arrow_spacing',
            [
                'label' => esc_html__( 'Arrow Size', 'crisop' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => [ 'px' ],
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 100,
                        'step' => 1
                    ]
                ],
                'selectors' => [ '{{WRAPPER}} .sliding-menu li .sliding-menu__nav.sliding-menu__back:before' => 'font-size:{{SIZE}}{{UNIT}};' ]
            ]
        );
        $this->end_controls_section();
        /*****   END CONTROLS SECTION   ******/
    }

    protected function render()
    {
        $settings = $this->get_settings_for_display();
        $id = $this->get_id();
        $rtl = is_rtl() ? ' has-rtl' : '';
        if ( !empty( $settings['register_menus'] ) ) {
            
            echo '<div class="ninetheme-header-widget-slide-menu ninetheme-slide-menu'.$rtl.'">';
                echo '<ul class="navigation primary">';
                    echo wp_nav_menu(
                        array(
                            'menu' => $settings['register_menus'],
                            'container' => '',
                            'container_class' => '',
                            'container_id' => '',
                            'menu_class' => '',
                            'menu_id' => '',
                            'items_wrap' => '%3$s',
                            'before' => '',
                            'after' => '',
                            'link_before' => '',
                            'link_after' => '',
                            'depth' => 4,
                            'echo' => true,
                            'fallback_cb' => 'Ninetheme_Sliding_Navwalker::fallback',
                            'walker' => new \Ninetheme_Sliding_Navwalker()
                        )
                    );
                echo '</ul>';
            echo '</div>';
        }
        if ( \Elementor\Plugin::$instance->editor->is_edit_mode() ) { ?>
            <script>
            jQuery( document ).ready( function($) {
                $('.ninetheme-slide-menu').slidingMenu({
                    className : "ninetheme-slide-menu",
                    transitionDuration : 250,
                    dataJSON : false,
                    initHref : false,
                    backLabel: 'Back'
                });
                $('.sliding-menu .menu-item-has-children>.sliding-menu__nav').each( function() {
                    var $this = $( this ),
                        id = $this.data( 'id' ),
                        parentTitle = $this.text(),
                        parents = $this.parents( '.sliding-menu' ),
                        subBack = parents.find( '.sliding-menu__panel[data-id="'+id+'"] .sliding-menu__back' );
                    subBack.text(parentTitle);
                });
            });
            </script>
            <?php
        }
    }
}
