<?php

namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) exit; // If this file is called directly, abort.

class Ninetheme_Label extends Widget_Base {
    use Ninetheme_Helper;
    public function get_name() {
        return 'ninetheme-widget-label';
    }
    public function get_title() {
        return 'Label (N)';
    }
    public function get_icon() {
        return 'eicon-animated-headline';
    }
    public function get_categories() {
        return [ 'crisop' ];
    }
    // Registering Controls
    protected function register_controls() {

        /*****   label Options   ******/
        $this->start_controls_section('label_settings',
            [
                'label' => esc_html__( 'Label', 'crisop' ),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );
        $this->add_control( 'text',
            [
                'label' => esc_html__( 'Text', 'crisop' ),
                'type' => Controls_Manager::TEXT,
                'label_block' => true,
                'default' => esc_html__( 'This is label', 'crisop' )
            ]
        );
        $this->add_control( 'bg_type',
            [
                'label' => esc_html__( 'Type', 'crisop' ),
                'type' => Controls_Manager::SELECT,
                'default' => 'external',
                'options' => [
                    'label-border' => esc_html__( 'Bordered', 'crisop' ),
                    'label-solid' => esc_html__( 'Solid', 'crisop' ),
                ]
            ]
        );
        $this->add_control( 'color_type',
            [
                'label' => esc_html__( 'Color Type', 'crisop' ),
                'type' => Controls_Manager::SELECT,
                'default' => 'ninetheme-primary',
                'options' => [
                    'ninetheme-label-primary' => esc_html__( 'Primary', 'crisop' ),
                    'ninetheme-label-secondary' => esc_html__( 'Secondary', 'crisop' ),
                    'ninetheme-label-success' => esc_html__( 'Success', 'crisop' ),
                    'ninetheme-label-dark' => esc_html__( 'Black', 'crisop' ),
                    'ninetheme-label-dark-soft' => esc_html__( 'Black Soft', 'crisop' ),
                    'ninetheme-label-light' => esc_html__( 'White', 'crisop' ),
                    'ninetheme-label-light-soft' => esc_html__( 'White Soft', 'crisop' ),
                    'ninetheme-label-brown' => esc_html__( 'Brown', 'crisop' ),
                    'ninetheme-label-cream' => esc_html__( 'Cream', 'crisop' ),
                    'ninetheme-label-red' => esc_html__( 'Red', 'crisop' ),
                    'ninetheme-label-red-dark' => esc_html__( 'Red Dark', 'crisop' ),
                    'ninetheme-label-red-soft' => esc_html__( 'Red Soft', 'crisop' ),
                    'ninetheme-label-gray' => esc_html__( 'Gray', 'crisop' ),
                    'ninetheme-label-gray-soft' => esc_html__( 'Gray Soft', 'crisop' ),
                    'ninetheme-label-gray-dark' => esc_html__( 'Gray Dark', 'crisop' ),
                    'ninetheme-label-green' => esc_html__( 'Green', 'crisop' ),
                    'ninetheme-label-green-soft' => esc_html__( 'Green Soft', 'crisop' ),
                    'ninetheme-label-green-bg' => esc_html__( 'Green BG', 'crisop' ),
                    'ninetheme-label-blue' => esc_html__( 'Blue', 'crisop' ),
                    'ninetheme-label-blue-dark' => esc_html__( 'Blue Dark', 'crisop' ),
                    'ninetheme-label-blue-soft' => esc_html__( 'Blue Soft', 'crisop' ),
                    'ninetheme-label-blue-bg' => esc_html__( 'Blue BG', 'crisop' ),
                    'ninetheme-label-purple' => esc_html__( 'Purple', 'crisop' ),
                    'ninetheme-label-purple-soft' => esc_html__( 'Purple Soft', 'crisop' ),
                    'ninetheme-label-purple-bg' => esc_html__( 'Purple BG', 'crisop' ),
                    'ninetheme-label-yellow' => esc_html__( 'Yellow', 'crisop' ),
                    'ninetheme-label-yellow-soft' => esc_html__( 'Yellow Soft', 'crisop' ),
                    'ninetheme-label-yellow-bg' => esc_html__( 'Yellow BG', 'crisop' ),
                ]
            ]
        );
        $this->add_control( 'radius_type',
            [
                'label' => esc_html__( 'Radius Type', 'crisop' ),
                'type' => Controls_Manager::SELECT,
                'default' => 'label-radius-soft',
                'options' => [
                    'label-radius' => esc_html__( 'Radius', 'crisop' ),
                    'label-radius-soft' => esc_html__( 'Radius Soft', 'crisop' ),
                    'label-square' => esc_html__( 'Square', 'crisop' ),
                ]
            ]
        );
        $this->add_control( 'size',
            [
                'label' => esc_html__( 'Size', 'crisop' ),
                'type' => Controls_Manager::SELECT,
                'default' => 'label-medium',
                'options' => [
                    'label-large' => esc_html__( 'Large', 'crisop' ),
                    'label-medium' => esc_html__( 'Medium', 'crisop' ),
                    'label-small' => esc_html__( 'Small', 'crisop' )
                ]
            ]
        );
        $this->add_responsive_control( 'alignment',
            [
                'label' => esc_html__( 'Alignment', 'crisop' ),
                'type' => Controls_Manager::CHOOSE,
                'selectors' => ['{{WRAPPER}}' => 'text-align: {{VALUE}};'],
                'options' => [
                    'left' => [
                        'title' => esc_html__( 'Left', 'crisop' ),
                        'icon' => 'eicon-h-align-left'
                    ],
                    'center' => [
                        'title' => esc_html__( 'Center', 'crisop' ),
                        'icon' => 'eicon-h-align-center'
                    ],
                    'right' => [
                        'title' => esc_html__( 'Right', 'crisop' ),
                        'icon' => 'eicon-h-align-right'
                    ]
                ],
                'toggle' => true,
                'default' => ''
            ]
        );
        $this->end_controls_section();
        /*****   End label Options   ******/

        /***** label Style ******/
        $this->start_controls_section('label_styling',
            [
                'label' => esc_html__( 'STYLE', 'crisop' ),
            ]
        );
        $this->add_control( 'label_color',
            [
                'label' => esc_html__( 'Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => ['{{WRAPPER}} .ninetheme-widget-label' => 'color: {{VALUE}};']
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'label_typo',
                'label' => esc_html__( 'Typography', 'crisop' ),
                'selector' => '{{WRAPPER}} .ninetheme-widget-label'
            ]
        );
        $this->add_responsive_control( 'label_padding',
            [
                'label' => esc_html__( 'Padding', 'crisop' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px' ],
                'selectors' => ['{{WRAPPER}} .ninetheme-widget-label' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};'],
                'default' => [
                    'top' => '',
                    'right' => '',
                    'bottom' => '',
                    'left' => '',
                ],
                'separator' => 'before'
            ]
        );
        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name' => 'label_border',
                'label' => esc_html__( 'Border', 'crisop' ),
                'selector' => '{{WRAPPER}} .ninetheme-widget-label',
                'separator' => 'before'
            ]
        );
        $this->add_responsive_control( 'label_border_radius',
            [
                'label' => esc_html__( 'Border Radius', 'crisop' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px' ],
                'selectors' => ['{{WRAPPER}} .ninetheme-widget-label' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};'],
                'default' => [
                    'top' => '',
                    'right' => '',
                    'bottom' => '',
                    'left' => '',
                ],
                'separator' => 'before'
            ]
        );
        $this->add_group_control(
            Group_Control_Background::get_type(),
            [
                'name' => 'label_background',
                'label' => esc_html__( 'Background', 'crisop' ),
                'types' => [ 'classic', 'gradient' ],
                'selector' => '{{WRAPPER}} .ninetheme-widget-label',
                'separator' => 'before'
            ]
        );
        $this->end_controls_section();
        /***** End label Styling *****/
    }

    protected function render() {
        $settings   = $this->get_settings_for_display();
        $settingsid = $this->get_id();

        echo '<span class="ninetheme-widget-label '.$settings['bg_type'].' '.$settings['radius_type'].' '.$settings['size'].' '.$settings['color_type'].'">'.$settings['text'].'</span>';

    }
}
