<?php

namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) exit; // If this file is called directly, abort.

class Ninetheme_Page_Title extends Widget_Base {

    public function get_name() {
        return 'ninetheme-page-title';
    }
    public function get_title() {
        return 'Page Title (N)';
    }
    public function get_icon() {
        return 'eicon-heading';
    }
    public function get_categories() {
        return [ 'crisop' ];
    }
	public function get_keywords() {
		return [ 'page','post','woocommerce', 'woo','title','heading','wc', 'shop', 'store', 'text', 'description', 'product', 'archive' ];
	}
    // Registering Controls
    protected function register_controls() {

        /*****   label Options   ******/
        $this->start_controls_section('title_settings',
            [
                'label' => esc_html__( 'Label', 'crisop' ),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );
        $this->add_control( 'tag',
            [
                'label' => esc_html__( 'Tag', 'crisop' ),
                'type' => Controls_Manager::SELECT,
                'default' => 'h2',
                'options' => [
                    'h1' => esc_html__( 'h1', 'crisop' ),
                    'h2' => esc_html__( 'h2', 'crisop' ),
                    'h3' => esc_html__( 'h3', 'crisop' ),
                    'h4' => esc_html__( 'h4', 'crisop' ),
                    'h5' => esc_html__( 'h5', 'crisop' ),
                    'h6' => esc_html__( 'h6', 'crisop' ),
                    'div' => esc_html__( 'div', 'crisop' ),
                    'p' => esc_html__( 'p', 'crisop' )
                ]
            ]
        );
        $this->add_responsive_control( 'alignment',
            [
                'label' => esc_html__( 'Alignment', 'crisop' ),
                'type' => Controls_Manager::CHOOSE,
                'selectors' => ['{{WRAPPER}}' => 'text-align: {{VALUE}};'],
                'options' => [
                    'left' => [
                        'title' => esc_html__( 'Left', 'crisop' ),
                        'icon' => 'eicon-h-align-left'
                    ],
                    'center' => [
                        'title' => esc_html__( 'Center', 'crisop' ),
                        'icon' => 'eicon-h-align-center'
                    ],
                    'right' => [
                        'title' => esc_html__( 'Right', 'crisop' ),
                        'icon' => 'eicon-h-align-right'
                    ]
                ],
                'toggle' => true,
                'default' => ''
            ]
        );

        $this->add_control( 'color',
            [
                'label' => esc_html__( 'Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => ['{{WRAPPER}} .ninetheme-page-title' => 'color: {{VALUE}};']
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'typo',
                'label' => esc_html__( 'Typography', 'crisop' ),
                'selector' => '{{WRAPPER}} .ninetheme-page-title'
            ]
        );
        $this->add_responsive_control( 'padding',
            [
                'label' => esc_html__( 'Padding', 'crisop' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px' ],
                'selectors' => ['{{WRAPPER}} .ninetheme-page-title' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};'],
                'default' => [
                    'top' => '',
                    'right' => '',
                    'bottom' => '',
                    'left' => '',
                ],
                'separator' => 'before'
            ]
        );
        $this->add_responsive_control( 'margin',
            [
                'label' => esc_html__( 'Margin', 'crisop' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px' ],
                'selectors' => ['{{WRAPPER}} .ninetheme-page-title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};'],
                'default' => [
                    'top' => '',
                    'right' => '',
                    'bottom' => '',
                    'left' => '',
                ],
                'separator' => 'before'
            ]
        );
        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name' => 'border',
                'label' => esc_html__( 'Border', 'crisop' ),
                'selector' => '{{WRAPPER}} .ninetheme-page-title',
                'separator' => 'before'
            ]
        );
        $this->add_responsive_control( 'border_radius',
            [
                'label' => esc_html__( 'Border Radius', 'crisop' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px' ],
                'selectors' => ['{{WRAPPER}} .ninetheme-page-title' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};'],
                'default' => [
                    'top' => '',
                    'right' => '',
                    'bottom' => '',
                    'left' => '',
                ],
                'separator' => 'before'
            ]
        );
        $this->add_group_control(
            Group_Control_Background::get_type(),
            [
                'name' => 'background',
                'label' => esc_html__( 'Background', 'crisop' ),
                'types' => [ 'classic', 'gradient' ],
                'selector' => '{{WRAPPER}} .ninetheme-page-title',
                'separator' => 'before'
            ]
        );
        $this->end_controls_section();
        /***** End label Styling *****/
    }

    protected function render() {
        $settings   = $this->get_settings_for_display();
        $settingsid = $this->get_id();
        $title = get_the_title();
        
        if ( is_404() ) {

            $title = esc_html__( 'Page Not Found', 'crisop' );

        } elseif ( is_archive() ) {

            $title = get_the_archive_title();

        } elseif ( is_search() ) {

            $title = esc_html__( 'Search results for: ', 'crisop' ).get_search_query();

        } elseif ( is_home() || is_front_page() ) {

            $title = esc_html__( 'Blog', 'crisop' );

        } elseif ( is_single() || is_page() ) {

            $title = get_the_title();

        }
        
        echo '<'.$settings['tag'].' class="ninetheme-page-title">'.$title.'</'.$settings['tag'].'>';

    }
}
