<?php

namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) exit; // If this file is called directly, abort.

class Ninetheme_Tooltip_Pointer extends Widget_Base {
    use Ninetheme_Helper;
    public function get_name() {
        return 'ninetheme-pointer';
    }
    public function get_title() {
        return 'Popup Points (N)';
    }
    public function get_icon() {
        return 'eicon-alert';
    }
    public function get_categories() {
        return [ 'crisop' ];
    }
    public function get_style_depends() {
        return [ 'tooltipster' ];
    }
    public function get_script_depends() {
        return [ 'tooltipster' ];
    }
    // Registering Controls
    protected function register_controls() {

        /*****   Button Options   ******/
        $this->start_controls_section('pointer_background_settings',
            [
                'label' => esc_html__( 'Background Image', 'crisop' ),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );
        $this->add_group_control(
            Group_Control_Background::get_type(),
            [
                'name' => 'pointer_background',
                'label' => esc_html__( 'Background', 'crisop' ),
                'types' => [ 'classic', 'gradient' ],
                'selector' => '{{WRAPPER}} .ninetheme-pointer-wrapper',
            ]
        );
        $this->add_responsive_control( 'btn_minh',
            [
                'label' => esc_html__( 'Min Height ( px )', 'crisop' ),
                'type' => Controls_Manager::SLIDER,
                'range' => [
                    'px' => ['max' => 1500]
                ],
				'default' => [
					'unit' => 'px',
					'size' => 500,
				],
                'selectors' => [
                    '{{WRAPPER}} .ninetheme-pointer-wrapper' => 'min-height: {{SIZE}}px;',
                ]
            ]
        );
        $this->end_controls_section();
        /*****   End Button Options   ******/
        
        /*****   Button Options   ******/
        $this->start_controls_section('pointer_repeater_settings',
            [
                'label' => esc_html__( 'Points', 'crisop' ),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );
        $repeater = new Repeater();
        $repeater->add_control( 'icon',
            [
                'label' => esc_html__( 'Pointer Icon', 'crisop' ),
                'type' => Controls_Manager::ICONS,
                'default' => [
                    'value' => '',
                    'library' => 'solid'
                ]
            ]
        );
        $repeater->add_control( 'content_type',
            [
                'label' => esc_html__( 'Content Type', 'crisop' ),
                'type' => Controls_Manager::SELECT,
                'default' => 'link',
                'options' => [
                    'image' => esc_html__( 'Image', 'crisop' ),
                    'product' => esc_html__( 'Product', 'crisop' ),
                    'custom' => esc_html__( 'Custom HTML or Shortcode', 'crisop' ),
                ]
            ]
        );
        $repeater->add_control( 'image',
            [
                'label' => esc_html__( 'Image', 'crisop' ),
                'type' => Controls_Manager::MEDIA,
                'condition' => [ 'content_type' => 'image' ]
            ]
        );
        $repeater->add_group_control(
            Group_Control_Image_Size::get_type(),
            [
                'name' => 'thumbnail',
                'condition' => [ 
                    'content_type' => 'image'
                ]
            ]
        );
        $repeater->add_control( 'post_filter',
            [
                'label' => esc_html__( 'Select Procuct', 'crisop' ),
                'type' => Controls_Manager::SELECT2,
                'multiple' => false,
                'options' => $this->get_all_posts_by_type('product'),
                'description' => 'Select Specific Post',
                'condition' => [ 'content_type' => 'product' ]
            ]
        );
        $repeater->add_control( 'tooltiptext',
            [
                'label' => esc_html__( 'Content', 'crisop' ),
                'type' => Controls_Manager::WYSIWYG,
                'label_block' => true,
                'default' => '<h3>Modal</h3><p>Lorem ipsum dolor sit amet, consectetur adipiscing elit. Nulla rhoncus pharetra dui, nec tempus tellus maximus et. Sed sed elementum ligula, id cursus leo. Duis imperdiet tortor id condimentum hendrerit.</p>',
                'pleaceholder' => esc_html__( 'Add html content here', 'crisop' ),
                'condition' => [ 'content_type' => 'custom' ]
            ]
        );
        $repeater->add_control( 'tooltip_pos_heading',
            [
                'label' => esc_html__( 'POSITION', 'crisop' ),
                'type' => Controls_Manager::HEADING,
                'separator' => 'before'
            ]
        );
        $repeater->add_control( 'align_x',
            [
                'label' => esc_html__( 'Horizontal Alignment', 'crisop' ),
                'type' => Controls_Manager::CHOOSE,
                'options' => [
                    'align-left' => [
                        'title' => esc_html__( 'Left', 'crisop' ),
                        'icon' => 'eicon-h-align-left'
                    ],
                    'align-right' => [
                        'title' => esc_html__( 'Right', 'crisop' ),
                        'icon' => 'eicon-h-align-right'
                    ]
                ],
                'toggle' => false,
                'default' => 'align-left'
            ]
        );
        $repeater->add_responsive_control( 'position_x',
            [
                'label' => esc_html__( 'Point Horizontal Position', 'crisop' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => ['px','%'],
                'range' => [
                    'px' => [
                        'max' => 2000,
                        'min' => 0
                    ],
                    '%' => [
                        'max' => 100,
                        'min' => 0
                    ]
                ],
                'selectors' => [
                    '{{WRAPPER}} {{CURRENT_ITEM}}.align-left' => 'left: {{SIZE}}{{UNIT}};',
                    '{{WRAPPER}} {{CURRENT_ITEM}}.align-right' => 'left:auto;right: {{SIZE}}{{UNIT}};',
                ]
            ]
        );
        $repeater->add_control( 'align_y',
            [
                'label' => esc_html__( 'Vertical Alignment', 'crisop' ),
                'type' => Controls_Manager::CHOOSE,
                'options' => [
                    'align-top' => [
                        'title' => esc_html__( 'Top', 'crisop' ),
                        'icon' => 'eicon-v-align-top'
                    ],
                    'align-bottom' => [
                        'title' => esc_html__( 'Bottom', 'crisop' ),
                        'icon' => 'eicon-v-align-bottom'
                    ]
                ],
                'toggle' => false,
                'default' => 'align-top'
            ]
        );
        $repeater->add_responsive_control( 'position_y',
            [
                'label' => esc_html__( 'Point Vertical Position', 'crisop' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => ['px','%'],
                'range' => [
                    'px' => [
                        'max' => 2000,
                        'min' => 0
                    ],
                    '%' => [
                        'max' => 100,
                        'min' => 0
                    ]
                ],
                'selectors' => [
                    '{{WRAPPER}} {{CURRENT_ITEM}}.align-top' => 'top: {{SIZE}}{{UNIT}};',
                    '{{WRAPPER}} {{CURRENT_ITEM}}.align-bottom' => 'top:auto;bottom: {{SIZE}}{{UNIT}};'
                ]
            ]
        );
        $repeater->add_control( 'tooltip_style_heading',
            [
                'label' => esc_html__( 'TOOLTIP STYLE', 'crisop' ),
                'type' => Controls_Manager::HEADING,
                'separator' => 'before'
            ]
        );
        $repeater->add_control( 'tooltip_pos',
            [
                'label' => esc_html__( 'Position', 'crisop' ),
                'type' => Controls_Manager::SELECT,
                'default' => 'top',
                'options' => [
                    'top' => esc_html__( 'Top', 'crisop' ),
                    'right' => esc_html__( 'Right', 'crisop' ),
                    'bottom' => esc_html__( 'Bottom', 'crisop' ),
                    'left' => esc_html__( 'Left', 'crisop' )
                ]
            ]
        );
        $repeater->add_control( 'tooltip_maxWidth',
            [
                'label' => esc_html__( 'Max Width', 'crisop' ),
                'type' => Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 3000
                    ]
                ]
            ]
        );
        $repeater->add_control( 'tooltip_bgcolor',
            [
                'label' => esc_html__( 'Background Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
            ]
        );
        $repeater->add_control( 'tooltip_brdcolor',
            [
                'label' => esc_html__( 'Border Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
            ]
        );
        $this->add_control( 'items',
            [
                'label' => esc_html__( 'Items', 'crisop' ),
                'type' => Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'title_field' => 'Content:{{content_type}}/Tooltip:{{tooltip_pos}}',
                'default' => []
            ]
        );
        $this->end_controls_section();
        /*****   End Button Options   ******/
        
        /***** Tooltips Style ******/
        $this->start_controls_section('points_styling',
            [
                'label' => esc_html__( 'Point Style', 'crisop' )
            ]
        );
        $this->add_responsive_control( 'pointer_minw',
            [
                'label' => esc_html__( 'Min Width ( px )', 'crisop' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => ['px','%'],
                'range' => [
                    'px' => [
                        'max' => 2000,
                        'min' => 0
                    ],
                    '%' => [
                        'max' => 100,
                        'min' => 0
                    ]
                ],
                'selectors' => [
                    '{{WRAPPER}} .ninetheme-pointer-wrapper .ninetheme-pointer' => 'width: {{SIZE}}px;',
                    '{{WRAPPER}} .ninetheme-pointer-wrapper .ninetheme-pointer.has-pulse:before' => 'width: calc( {{SIZE}}px + 16px );top:-8px;left:-8px;',
                ]
            ]
        );
        $this->add_responsive_control( 'pointer_minh',
            [
                'label' => esc_html__( 'Min Height ( px )', 'crisop' ),
                'type' => Controls_Manager::SLIDER,
                'range' => [
                    'px' => ['max' => 1500]
                ],
                'selectors' => [
                    '{{WRAPPER}} .ninetheme-pointer-wrapper .ninetheme-pointer' => 'height: {{SIZE}}px;',
                    '{{WRAPPER}} .ninetheme-pointer-wrapper .ninetheme-pointer.has-pulse:before' => 'height: calc( {{SIZE}}px + 16px );top:-8px;left:-8px;',
                ]
            ]
        );
        $this->add_control( 'pointer_pulse',
            [
                'label' => esc_html__( 'Pulse Effect', 'crisop' ),
                'type' => Controls_Manager::SWITCHER,
                'default' => 'yes',
            ]
        );
        $this->add_responsive_control( 'pointer_radius',
            [
                'label' => esc_html__( 'Border Radius ( px )', 'crisop' ),
                'type' => Controls_Manager::SLIDER,
                'range' => [
                    'px' => ['max' => 2000]
                ],
                'selectors' => [
                    '{{WRAPPER}} .ninetheme-pointer-wrapper .ninetheme-pointer' => 'border-radius: {{SIZE}}px;',
                    '{{WRAPPER}} .ninetheme-pointer-wrapper .ninetheme-pointer.has-pulse:before' => 'border-radius:{{SIZE}}px;',
                ]
            ]
        );
        $this->add_control( 'pointer_icon_size',
            [
                'label' => esc_html__( 'Icon Size', 'crisop' ),
                'type' => Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'max' => 300
                    ]
                ],
                'selectors' => ['{{WRAPPER}} .ninetheme-pointer-wrapper .ninetheme-pointer' => 'font-size: {{SIZE}}px;'],
            ]
        );
        $this->add_control( 'pointer_icon_color',
            [
                'label' => esc_html__( 'Icon Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .ninetheme-pointer-wrapper .ninetheme-pointer' => 'color: {{VALUE}};',
                ]
            ]
        );
        $this->add_control( 'pointer_bgcolor',
            [
                'label' => esc_html__( 'Background Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .ninetheme-pointer-wrapper .ninetheme-pointer' => 'background-color: {{VALUE}};',
                    '{{WRAPPER}} .ninetheme-pointer-wrapper .ninetheme-pointer.has-pulse:before' => 'border-color: {{VALUE}};',
                ]
            ]
        );
        $this->end_controls_section();
        /*****   End Button Options   ******/
        
        /***** Tooltips Style ******/
        $this->start_controls_section('tooltips_styling',
            [
                'label' => esc_html__( 'Tooltips', 'crisop' )
            ]
        );
        $this->add_control( 'tooltip_trigger',
            [
                'label' => esc_html__( 'Action', 'crisop' ),
                'type' => Controls_Manager::SELECT,
                'default' => 'click',
                'options' => [
                    'hover' => esc_html__( 'Hover', 'crisop' ),
                    'click' => esc_html__( 'Click', 'crisop' )
                ]
            ]
        );
        $this->add_control( 'tooltip_animation',
            [
                'label' => esc_html__( 'Animation', 'crisop' ),
                'type' => Controls_Manager::SELECT,
                'default' => 'fade',
                'options' => [
                    'fade' => esc_html__( 'fade', 'crisop' ),
                    'grow' => esc_html__( 'grow', 'crisop' ),
                    'swing' => esc_html__( 'swing', 'crisop' ),
                    'slide' => esc_html__( 'slide', 'crisop' ),
                    'fall' => esc_html__( 'fall', 'crisop' )
                ]
            ]
        );
        $this->add_control( 'tooltip_theme',
            [
                'label' => esc_html__( 'Theme', 'crisop' ),
                'type' => Controls_Manager::SELECT,
                'default' => 'default',
                'options' => [
                    'default' => esc_html__( 'default', 'crisop' ),
                    'light' => esc_html__( 'light', 'crisop' ),
                    'punk' => esc_html__( 'punk', 'crisop' ),
                    'noir' => esc_html__( 'noir', 'crisop' ),
                    'shadow' => esc_html__( 'shadow', 'crisop' )
                ]
            ]
        );
        $this->add_control( 'tooltip_arrow',
            [
                'label' => esc_html__( 'Arrow', 'crisop' ),
                'type' => Controls_Manager::SWITCHER,
                'default' => 'yes'
            ]
        );
        $this->add_control( 'tooltip_allbgcolor',
            [
                'label' => esc_html__( 'Background Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
            ]
        );
        $this->add_control( 'tooltip_allbrdcolor',
            [
                'label' => esc_html__( 'Border Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
            ]
        );
        $this->add_control( 'tooltip_offsetx',
            [
                'label' => esc_html__( 'Offset X', 'crisop' ),
                'type' => Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 300
                    ]
                ]
            ]
        );
        $this->add_control( 'tooltip_offsety',
            [
                'label' => esc_html__( 'Offset Y', 'crisop' ),
                'type' => Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 300
                    ]
                ]
            ]
        );
        $this->end_controls_section();
        /*****   End Button Options   ******/
    }

    public function get_content_product($id) {
        $settings = $this->get_settings_for_display();
        
        $args = array(
            'post_type' => 'product',
            'posts_per_page' => 1,
            'post__in' => array($id)
        );
        
        $html = '';
        
        $the_query = new \WP_Query( $args );
        if ( $the_query->have_posts() ) {

            $html .='<div class="product-item woocommerce">';
                while ( $the_query->have_posts() ) {
                    $the_query->the_post();
                    ob_start();
                    wc_get_template_part( 'content', 'product' );
                }
            $html .= ob_get_clean().'</div>';
        }
         wp_reset_postdata();
        return $html;
    }

    protected function render() {
        $settings   = $this->get_settings_for_display();
        $settingsid = $this->get_id();
        $edit       = \Elementor\Plugin::$instance->editor->is_edit_mode() ? '-edit' : '';
        $pulse      = 'yes' == $settings['pointer_pulse'] ? ' has-pulse' : '';

        $tooltipsdata = array(
            'arrow'     => 'yes' == $settings['tooltip_arrow'] ? true : false,
            'trigger'   => $settings['tooltip_trigger'],
            'theme'     => 'tooltipster-'.$settings['tooltip_theme'],
            'animation' => $settings['tooltip_animation'],
            'offsetx'   => $settings['tooltip_offsetx']['size'],
            'offsety'   => $settings['tooltip_offsety']['size']
        );
        add_filter( 'ninetheme_loop_product_images', '__return_false' );
        echo '<div class="ninetheme-pointer-wrapper">';
            foreach( $settings['items'] as $point ) {
                
                $tooltipsdata['position'] = $point['tooltip_pos'];
                $tooltipsdata['maxwidth'] = 0 == $point['tooltip_maxWidth']['size'] ? 'auto' : $point['tooltip_maxWidth']['size'];
                $tooltipsdata['bgcolor']  = !empty( $point['tooltip_bgcolor'] ) ? $point['tooltip_bgcolor'] : $settings['tooltip_allbgcolor'];
                $tooltipsdata['brdcolor'] = !empty( $point['tooltip_brdcolor'] ) ? $point['tooltip_brdcolor'] :$settings['tooltip_allbrdcolor'];
                
                if ( 'image' == $point['content_type'] && !empty( $point['image']['url'] ) ) {
                    $size = !empty( $point['thumbnail_size'] ) ? $point['thumbnail_size'] : [100,100];
                    if ( 'custom' == $size ) {
                        $sizew = $point['thumbnail_custom_dimension']['width'];
                        $sizeh = $point['thumbnail_custom_dimension']['height'];
                        $size  = [ $sizew, $sizeh ];
                    }
                    $tooltipsdata['content'] = !empty( $point['image']['url'] ) ? wp_get_attachment_image( $point['image']['id'], $size, false, ['class'=>'pointer-img'] ) : esc_html__('Empty Content', 'crisop');
                }
                
                if ( 'product' == $point['content_type'] && !empty( $point['post_filter'] ) ) {
                    $tooltipsdata['content'] = $this->get_content_product($point['post_filter']);
                }
                
                if ( 'custom' == $point['content_type'] && !empty( $point['tooltiptext'] ) ) {
                    $tooltipsdata['content'] = do_shortcode($point['tooltiptext']);
                }
                
                $class = ' elementor-repeater-item-'.$point['_id'].' '.$point['align_x'].' '.$point['align_y'].$pulse;
                echo '<span data-id="btn-'.$point['_id'].'" class="ninetheme-pointer'.$class.'" data-ninetheme-tooltip'.$edit.'=\''.json_encode($tooltipsdata).'\'>';
                    if ( !empty( $point['icon']['value'] ) ) { 
                        Icons_Manager::render_icon( $point['icon'], [ 'aria-hidden' => 'true' ] ); 
                    } else {
                        echo '<i aria-hidden="true" class="ninetheme-icons flaticon-plus"></i>';
                    }
                echo '</span>';
            }
        echo '</div>';
        remove_filter( 'ninetheme_loop_product_images', '__return_false' );
        
        // in edit mode
        if ( \Elementor\Plugin::$instance->editor->is_edit_mode() ) {
            ?>
            <script>
            jQuery(document).ready(function($){
                var myTooltips = $('[data-ninetheme-tooltip-edit]');
                myTooltips.each(function(i, el) {
                    var myTooltip = $(el).data('ninetheme-tooltip-edit');
                    $(el).tooltipster({
                        position      : myTooltip.position,
                        content       : myTooltip.content,
                        animation     : myTooltip.animation,
                        theme         : myTooltip.theme,
                        trigger       : myTooltip.trigger,
                        distance      : [ myTooltip.offsetx,myTooltip.offsety ],
                        arrow         : myTooltip.arrow,
                        maxWidth      : myTooltip.maxwidth,
                        contentAsHTML : true,
                        hideOnClick   : true,
                        interactive   : true,
                        touchDevices  : true,
                        functionReady : function(){
                            var id  = this.__namespace,
                                bg  = myTooltip.bgcolor != '' ? myTooltip.bgcolor : '',
                                brd = myTooltip.brdcolor != '' ? myTooltip.brdcolor : '',
                                pos = myTooltip.position;

                            $('#'+id+' .tooltipster-box').css({
                                'background-color' : bg,
                                'border-color' : brd
                            });

                            if ( myTooltip.arrow ) {
                                $('#'+id+' .tooltipster-arrow-background').css('border-'+pos+'-color', bg);
                                $('#'+id+' .tooltipster-arrow-border').css('border-'+pos+'-color', brd);
                            }
                        }
                    });
                });
            });
            </script>
            <?php
        }
    }
}
