<?php

namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) exit; // If this file is called directly, abort.

class Ninetheme_Team extends Widget_Base {

    public function get_name() {
        return 'ninetheme-team';
    }
    public function get_title() {
        return 'Team (N)';
    }
    public function get_icon() {
        return 'eicon-person';
    }
    public function get_categories() {
        return [ 'ninetheme' ];
    }
    public function get_keywords() {
        return [ 'team', 'member'];
    }
    // Registering Controls
    protected function register_controls() {
        /*****   START CONTROLS SECTION   ******/
        $this->start_controls_section( 'loop_settings',
            [
                'label' => esc_html__('Team/Members Items', 'crisop'),
            ]
        );
        $repeater = new Repeater();
        $repeater->add_control( 'image',
            [
                'label' => esc_html__( 'Image', 'crisop' ),
                'type' => Controls_Manager::MEDIA
            ]
        );
        $repeater->add_control( 'subtitle',
            [
                'label' => esc_html__( 'Subtitle', 'crisop' ),
                'type' => Controls_Manager::TEXT
            ]
        );
        $repeater->add_control( 'title',
            [
                'label' => esc_html__( 'Title', 'crisop' ),
                'type' => Controls_Manager::TEXT
            ]
        );
        $repeater->add_control( 'desc',
            [
                'label' => esc_html__( 'Description', 'crisop' ),
                'type' => Controls_Manager::TEXTAREA
            ]
        );
        $repeater->add_control( 'btn_title',
            [
                'label' => esc_html__( 'Button Title', 'crisop' ),
                'type' => Controls_Manager::TEXT
            ]
        );
        $repeater->add_control( 'link',
            [
                'label' => esc_html__( 'Link', 'crisop' ),
                'type' => Controls_Manager::URL,
                'label_block' => true,
                'default' => [
                    'url' => '',
                    'is_external' => ''
                ],
                'show_external' => true,
            ]
        );
        $this->add_control( 'items',
            [
                'label' => esc_html__( 'Items', 'crisop' ),
                'type' => Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'title_field' => '{{title}}',
                'default' => [
                    [
                    'subtitle' => 'Director',
                    'title' => 'Adam Falan',
                    'btn_title' => 'See More',
                    'link' => '#0'
                    ],
                    [
                    'subtitle' => 'Director',
                    'title' => 'Adam Falan',
                    'btn_title' => 'See More',
                    'link' => '#0'
                    ],
                    [
                    'subtitle' => 'Director',
                    'title' => 'Adam Falan',
                    'btn_title' => 'See More',
                    'link' => '#0'
                    ]
                ]
            ]
        );
        $this->add_group_control(
            Group_Control_Image_Size::get_type(),
            [
                'name' => 'thumbnail',
                'default' => 'medium_large'
            ]
        );
        $this->end_controls_section();
        /*****   END CONTROLS SECTION   ******/
        /*****   START CONTROLS SECTION   ******/
        $this->start_controls_section( 'general_settings',
            [
                'label' => esc_html__('General Settings', 'crisop'),
            ]
        );
        $this->add_control( 'type',
            [
                'label' => esc_html__( 'Type', 'crisop' ),
                'type' => Controls_Manager::SELECT,
                'default' => 'grid',
                'options' => [
                    'grid' => esc_html__( 'Grid', 'crisop' ),
                    'slider' => esc_html__( 'Slider', 'crisop' )
                ]
            ]
        );
        $this->add_control( 'box_type',
            [
                'label' => esc_html__( 'Box Type', 'crisop' ),
                'type' => Controls_Manager::SELECT,
                'default' => 'box-type-classic',
                'options' => [
                    'box-type-classic' => esc_html__( 'Classic', 'crisop' ),
                    'box-type-card' => esc_html__( 'Card', 'crisop' )
                ]
            ]
        );
        $this->add_responsive_control( 'card_min_height',
            [
                'label' => esc_html__( 'Item Min Height', 'crisop' ),
                'type' => Controls_Manager::SLIDER,
                'range' => [
                    'px' => ['max' => 300]
                ],
				'default' => [
					'size' => 100
				],
                'selectors' => [
                    '{{WRAPPER}} .ninetheme-team-item-inner' => 'padding-top: {{SIZE}}%;'
                ],
                'condition' => [ 'box_type' => 'box-type-card' ]
            ]
        );
        $this->add_control( 'card_min_overlay_color',
            [
                'label' => esc_html__( 'Overlay Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => ['{{WRAPPER}} .ninetheme-team-item-inner:before' => 'background-color:{{VALUE}};' ],
                'condition' => [ 'box_type' => 'box-type-card' ]
            ]
        );
        $this->add_control( 'content_type',
            [
                'label' => esc_html__( 'Content Display Type', 'crisop' ),
                'type' => Controls_Manager::SELECT,
                'default' => 'content-show-hover',
                'options' => [
                    'content-show-always' => esc_html__( 'Show Always', 'crisop' ),
                    'content-show-hover' => esc_html__( 'Show on Hover', 'crisop' )
                ]
            ]
        );
        $this->add_responsive_control( 'column',
            [
                'label' => esc_html__( 'Column Width', 'crisop' ),
                'type' => Controls_Manager::NUMBER,
                'min' => 1,
                'max' => 12,
                'step' => 1,
                'default' => 3,
                'selectors' => [ '{{WRAPPER}} .ninetheme-team-item' => '-ms-flex: 0 0 calc(100% / {{VALUE}} );flex: 0 0 calc(100% / {{VALUE}} );max-width: calc(100% / {{VALUE}} );' ],
                'condition' => ['type' => 'grid']
            ]
        );
        $this->add_responsive_control( 'item_space',
            [
                'label' => esc_html__( 'Space Between Column', 'crisop' ),
                'type' => Controls_Manager::SLIDER,
                'range' => [
                    'px' => ['max' => 100]
                ],
				'default' => [
					'unit' => 'px',
					'size' => 30
				],
                'selectors' => [
                    '{{WRAPPER}} .ninetheme-team-grid .ninetheme-team-item' => 'padding-left: calc({{SIZE}}px / 2 ); padding-right: calc({{SIZE}}px / 2 ); margin-bottom: {{SIZE}}px',
                    '{{WRAPPER}} .ninetheme-team-grid.row' => 'margin: 0 calc(-{{SIZE}}px / 2 ) -{{SIZE}}px calc(-{{SIZE}}px / 2 );',
                ],
                'condition' => ['type' => 'grid']
            ]
        );
        $this->add_control( 'slider_title',
            [
                'label' => esc_html__( 'Section Title', 'crisop' ),
                'type' => Controls_Manager::TEXTAREA,
                'separator' => 'before'
            ]
        );
        $this->add_control( 'title_tag',
            [
                'label' => esc_html__( 'Title Tag', 'crisop' ),
                'type' => Controls_Manager::SELECT,
                'default' => 'h3',
                'options' => [
                    'h1' => esc_html__( 'H1', 'crisop' ),
                    'h2' => esc_html__( 'H2', 'crisop' ),
                    'h3' => esc_html__( 'H3', 'crisop' ),
                    'h4' => esc_html__( 'H4', 'crisop' ),
                    'h5' => esc_html__( 'H5', 'crisop' ),
                    'h6' => esc_html__( 'H6', 'crisop' ),
                    'div' => esc_html__( 'div', 'crisop' ),
                    'p' => esc_html__( 'p', 'crisop' )
                ],
                'condition' => [ 'slider_title!' => '' ]
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'slider_title_typo',
                'label' => esc_html__( 'Typography', 'crisop' ),
                'selector' => '{{WRAPPER}} .ninetheme-slider-nav-title',
                'condition' => [ 'slider_title!' => '' ]
            ]
        );
        $this->add_control( 'slider_title_color',
            [
                'label' => esc_html__( 'Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [ '{{WRAPPER}} .ninetheme-slider-nav-title' => 'color:{{VALUE}};' ],
                'condition' => [ 'slider_title!' => '' ]
            ]
        );
        $this->add_responsive_control( 'title_spacing',
            [
                'label' => esc_html__( 'Title Spacing ( px )', 'crisop' ),
                'type' => Controls_Manager::SLIDER,
                'range' => [
                    'px' => ['max' => 300]
                ],
				'default' => [
					'unit' => 'px',
					'size' => 30
				],
                'selectors' => [
                    '{{WRAPPER}} .ninetheme-swiper-theme-style .ninetheme-slider-title-wrapper.nav-top' => 'margin-bottom: {{SIZE}}px;'
                ],
                'condition' => [ 'slider_title!' => '' ]
            ]
        );
        $this->end_controls_section();
        /*****   END CONTROLS SECTION   ******/
        /*****   START CONTROLS SECTION   ******/
        $this->start_controls_section( 'style_section',
            [
                'label'=> esc_html__( 'STYLE', 'crisop' ),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );
        $this->add_control( 'image_sdivider',
            [
                'label' => esc_html__( 'ITEM BOX', 'crisop' ),
                'type' => Controls_Manager::HEADING,
            ]
        );
        $this->add_responsive_control( 'alignment',
            [
                'label' => esc_html__( 'Content Alignment', 'crisop' ),
                'type' => Controls_Manager::CHOOSE,
                'options' => [
                    'left' => [
                        'title' => esc_html__( 'Left', 'crisop' ),
                        'icon' => 'eicon-text-align-left'
                    ],
                    'center' => [
                        'title' => esc_html__( 'Center', 'crisop' ),
                        'icon' => 'eicon-text-align-center'
                    ],
                    'right' => [
                        'title' => esc_html__( 'Right', 'crisop' ),
                        'icon' => 'eicon-text-align-right'
                    ]
                ],
                'toggle' => true,
                'default' => '',
                'selectors' => ['{{WRAPPER}} .ninetheme-team-item-inner' => 'text-align: {{VALUE}};']
            ]
        );
        $this->add_control( 'box_content_bgcolor',
            [
                'label' => esc_html__( 'Background Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => ['{{WRAPPER}} .ninetheme-team-item-inner' => 'background-color:{{VALUE}};' ]
            ]
        );
        $this->add_responsive_control( 'box_item_padding',
            [
                'label' => esc_html__( 'Padding', 'crisop' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px' ],
                'selectors' => ['{{WRAPPER}} .ninetheme-team-item-inner' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};']
            ]
        );
        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name' => 'box_item_border',
                'label' => esc_html__( 'Border', 'crisop' ),
                'selector' => '{{WRAPPER}} .ninetheme-team-item-inner'
            ]
        );
        $this->add_responsive_control( 'box_item_border_radius',
            [
                'label' => esc_html__( 'Border Radius', 'crisop' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px' ],
                'selectors' => ['{{WRAPPER}} .ninetheme-team-item-inner' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};']
            ]
        );
        $this->add_group_control(
            Group_Control_Box_Shadow::get_type(),
            [
                'name' => 'box_item_box_shadow',
                'label' => esc_html__( 'Box Shadow', 'crisop' ),
                'selector' => '{{WRAPPER}} .ninetheme-team-item-inner'
            ]
        );
        $this->add_control( 'text_content_sdivider',
            [
                'label' => esc_html__( 'TEXT CONTENT', 'crisop' ),
                'type' => Controls_Manager::HEADING,
                'separator' => 'before'
            ]
        );
        $this->add_control( 'text_content_bgcolor',
            [
                'label' => esc_html__( 'Background Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => ['{{WRAPPER}} .ninetheme-team-details' => 'background-color:{{VALUE}};' ]
            ]
        );
        $this->add_responsive_control( 'text_content_padding',
            [
                'label' => esc_html__( 'Padding', 'crisop' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px' ],
                'selectors' => ['{{WRAPPER}} .ninetheme-team-details' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};']
            ]
        );
        $this->add_control( 'subtitle_sdivider',
            [
                'label' => esc_html__( 'SUBTITLE', 'crisop' ),
                'type' => Controls_Manager::HEADING,
                'separator' => 'before'
            ]
        );
        $this->add_control( 'subtitle_color',
            [
                'label' => esc_html__( 'Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => ['{{WRAPPER}} .ninetheme-team-subtitle' => 'color:{{VALUE}};' ]
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'subtitle_typo',
                'label' => esc_html__( 'Typography', 'crisop' ),
                'selector' => '{{WRAPPER}} .ninetheme-team-subtitle'
            ]
        );
        $this->add_responsive_control( 'subtitle_margin',
            [
                'label' => esc_html__( 'Margin', 'crisop' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px' ],
                'selectors' => ['{{WRAPPER}} .ninetheme-team-item-inner .ninetheme-team-subtitle' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};']
            ]
        );
        $this->add_control( 'title_sdivider',
            [
                'label' => esc_html__( 'TITLE', 'crisop' ),
                'type' => Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );
        $this->add_control( 'tag',
            [
                'label' => esc_html__( 'Title Tag', 'crisop' ),
                'type' => Controls_Manager::SELECT,
                'default' => 'h4',
                'options' => [
                    'h1' => esc_html__( 'H1', 'crisop' ),
                    'h2' => esc_html__( 'H2', 'crisop' ),
                    'h3' => esc_html__( 'H3', 'crisop' ),
                    'h4' => esc_html__( 'H4', 'crisop' ),
                    'h5' => esc_html__( 'H5', 'crisop' ),
                    'h6' => esc_html__( 'H6', 'crisop' ),
                    'div' => esc_html__( 'div', 'crisop' ),
                    'p' => esc_html__( 'p', 'crisop' )
                ]
            ]
        );
        $this->add_control( 'title_color',
            [
                'label' => esc_html__( 'Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => ['{{WRAPPER}} .ninetheme-team-title' => 'color:{{VALUE}};' ]
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'title_typo',
                'label' => esc_html__( 'Typography', 'crisop' ),
                'selector' => '{{WRAPPER}} .ninetheme-team-title'
            ]
        );
        $this->add_responsive_control( 'title_margin',
            [
                'label' => esc_html__( 'Margin', 'crisop' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px' ],
                'selectors' => ['{{WRAPPER}} .ninetheme-team-item-inner .ninetheme-team-title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};']
            ]
        );
        $this->add_control( 'text_sdivider',
            [
                'label' => esc_html__( 'DESCRIPTION', 'crisop' ),
                'type' => Controls_Manager::HEADING,
                'separator' => 'before'
            ]
        );
        $this->add_control( 'text_color',
            [
                'label' => esc_html__( 'Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => ['{{WRAPPER}} .ninetheme-team-description' => 'color:{{VALUE}};' ]
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'text_typo',
                'label' => esc_html__( 'Typography', 'crisop' ),
                'selector' => '{{WRAPPER}} .ninetheme-team-description'
            ]
        );
        $this->add_responsive_control( 'text_margin',
            [
                'label' => esc_html__( 'Margin', 'crisop' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px' ],
                'selectors' => ['{{WRAPPER}} .ninetheme-team-item-inner .ninetheme-team-description' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};']
            ]
        );
        $this->add_control( 'btn_sdivider',
            [
                'label' => esc_html__( 'BUTTON', 'crisop' ),
                'type' => Controls_Manager::HEADING,
                'separator' => 'before'
            ]
        );
        $this->add_control( 'btn_bg_type',
            [
                'label' => esc_html__( 'Background Type', 'crisop' ),
                'type' => Controls_Manager::SELECT,
                'default' => 'ninetheme-btn-text',
                'options' => [
                    'ninetheme-btn-border' => esc_html__( 'Bordered', 'crisop' ),
                    'ninetheme-btn-solid' => esc_html__( 'Solid', 'crisop' ),
                    'ninetheme-btn-text' => esc_html__( 'Simple Text', 'crisop' )
                ]
            ]
        );
        $this->add_control( 'btn_color_type',
            [
                'label' => esc_html__( 'Color Type', 'crisop' ),
                'type' => Controls_Manager::SELECT,
                'default' => 'ninetheme-btn-dark',
                'options' => [
                    'ninetheme-btn-primary' => esc_html__( 'Primary', 'crisop' ),
                    'ninetheme-btn-dark' => esc_html__( 'Black', 'crisop' ),
                    'ninetheme-btn-brown' => esc_html__( 'Brown', 'crisop' ),
                    'ninetheme-btn-red' => esc_html__( 'Red', 'crisop' ),
                    'ninetheme-btn-gray' => esc_html__( 'Gray', 'crisop' ),
                    'ninetheme-btn-gray-soft' => esc_html__( 'Gray Soft', 'crisop' ),
                    'ninetheme-btn-green' => esc_html__( 'Green', 'crisop' ),
                    'ninetheme-btn-green-soft' => esc_html__( 'Green Soft', 'crisop' ),
                    'ninetheme-btn-blue' => esc_html__( 'Blue', 'crisop' ),
                    'ninetheme-btn-blue-dark' => esc_html__( 'Blue Dark', 'crisop' ),
                    'ninetheme-btn-blue-soft' => esc_html__( 'Blue Soft', 'crisop' ),
                    'ninetheme-btn-purple' => esc_html__( 'Purple', 'crisop' ),
                    'ninetheme-btn-purple-soft' => esc_html__( 'Purple Soft', 'crisop' ),
                    'ninetheme-btn-yellow' => esc_html__( 'Yellow', 'crisop' ),
                    'ninetheme-btn-yellow-soft' => esc_html__( 'Yellow Soft', 'crisop' )
                ]
            ]
        );
        $this->add_control( 'btn_radius_type',
            [
                'label' => esc_html__( 'Radius Type', 'crisop' ),
                'type' => Controls_Manager::SELECT,
                'default' => 'ninetheme-btn-square',
                'options' => [
                    'ninetheme-btn-radius' => esc_html__( 'Radius', 'crisop' ),
                    'ninetheme-btn-square' => esc_html__( 'Square', 'crisop' )
                ],
                'condition' => ['btn_bg_type!' => 'ninetheme-btn-text']
            ]
        );
        $this->add_control( 'btn_size',
            [
                'label' => esc_html__( 'Size', 'crisop' ),
                'type' => Controls_Manager::SELECT,
                'default' => 'ninetheme-btn-medium',
                'options' => [
                    'ninetheme-btn-large' => esc_html__( 'Large', 'crisop' ),
                    'ninetheme-btn-medium' => esc_html__( 'Medium', 'crisop' ),
                    'ninetheme-btn-small' => esc_html__( 'Small', 'crisop' )
                ],
                'condition' => ['btn_bg_type!' => 'ninetheme-btn-text']
            ]
        );
        $this->add_control( 'btn_radius',
            [
                'label' => esc_html__( 'Border Radius ( px )', 'crisop' ),
                'type' => Controls_Manager::SLIDER,
                'range' => [
                    'px' => ['max' => 2000]
                ],
                'selectors' => ['{{WRAPPER}} .ninetheme-btn' => 'border-radius: {{SIZE}}px;'],
                'condition' => ['btn_bg_type!' => 'ninetheme-btn-text']
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'btn_typo',
                'label' => esc_html__( 'Typography', 'crisop' ),
                'selector' => '{{WRAPPER}} .ninetheme-team-link'
            ]
        );
        $this->add_control( 'btn_custom_sdivider',
            [
                'label' => esc_html__( 'BUTTON', 'crisop' ),
                'type' => Controls_Manager::HEADING,
                'separator' => 'before'
            ]
        );
        $this->start_controls_tabs('btn_tabs');
        $this->start_controls_tab( 'btn_normal_tab',
            [ 'label' => esc_html__( 'Normal', 'crisop' ) ]
        );
        $this->add_control( 'btn_color',
            [
                'label' => esc_html__( 'Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => ['{{WRAPPER}} .ninetheme-btn' => 'color: {{VALUE}};']
            ]
        );
        $this->add_responsive_control( 'btn_padding',
            [
                'label' => esc_html__( 'Padding', 'crisop' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px' ],
                'selectors' => ['{{WRAPPER}} .ninetheme-btn' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};'],
                'default' => [
                    'top' => '',
                    'right' => '',
                    'bottom' => '',
                    'left' => '',
                ],
                'separator' => 'before'
            ]
        );
        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name' => 'btn_border',
                'label' => esc_html__( 'Border', 'crisop' ),
                'selector' => '{{WRAPPER}} .ninetheme-btn',
                'separator' => 'before'
            ]
        );
        $this->add_responsive_control( 'btn_border_radius',
            [
                'label' => esc_html__( 'Border Radius', 'crisop' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px' ],
                'selectors' => ['{{WRAPPER}} .ninetheme-btn' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};'],
                'default' => [
                    'top' => '',
                    'right' => '',
                    'bottom' => '',
                    'left' => '',
                ],
                'separator' => 'before'
            ]
        );
        $this->add_group_control(
            Group_Control_Background::get_type(),
            [
                'name' => 'btn_background',
                'label' => esc_html__( 'Background', 'crisop' ),
                'types' => [ 'classic', 'gradient' ],
                'selector' => '{{WRAPPER}} .ninetheme-btn',
                'separator' => 'before'
            ]
        );
        $this->end_controls_tab();

        $this->start_controls_tab('btn_hover_tab',
            [ 'label' => esc_html__( 'Hover', 'crisop' ) ]
        );
         $this->add_control( 'btn_hvr_color',
            [
                'label' => esc_html__( 'Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => ['{{WRAPPER}} .ninetheme-btn:hover' => 'color: {{VALUE}};']
            ]
        );
        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name' => 'btn_hvr_border',
                'label' => esc_html__( 'Border', 'crisop' ),
                'selector' => '{{WRAPPER}} .ninetheme-btn:hover',
                'separator' => 'before'
            ]
        );
        $this->add_group_control(
            Group_Control_Background::get_type(),
            [
                'name' => 'btn_hvr_background',
                'label' => esc_html__( 'Background', 'crisop' ),
                'types' => [ 'classic', 'gradient' ],
                'selector' => '{{WRAPPER}} .ninetheme-btn:hover',
                'separator' => 'before'
            ]
        );
        $this->end_controls_tab();
        $this->end_controls_tabs();
        $this->end_controls_section();
        /*****   END CONTROLS SECTION   ******/

       /*****   START CONTROLS SECTION   ******/
        $this->start_controls_section('slider_options_section',
            [
                'label'=> esc_html__( 'SLIDER OPTIONS', 'crisop' ),
                'tab' => Controls_Manager::TAB_CONTENT,
                'condition' => ['type' => 'slider']
            ]
        );
        $this->add_control( 'loop',
            [
                'label' => esc_html__( 'Infinite', 'crisop' ),
                'type' => Controls_Manager::SWITCHER,
                'default' => 'no'
            ]
        );
        $this->add_control( 'autoplay',
            [
                'label' => esc_html__( 'Autoplay', 'crisop' ),
                'type' => Controls_Manager::SWITCHER,
                'default' => 'yes'
            ]
        );
        $this->add_control( 'nav',
            [
                'label' => esc_html__( 'Navigation', 'crisop' ),
                'type' => Controls_Manager::SWITCHER,
                'default' => 'yes'
            ]
        );
        $this->add_control( 'dots',
            [
                'label' => esc_html__( 'Dots', 'crisop' ),
                'type' => Controls_Manager::SWITCHER,
                'default' => 'yes'
            ]
        );
        $this->add_control( 'space',
            [
                'label' => esc_html__( 'Space Between Items', 'crisop' ),
                'type' => Controls_Manager::NUMBER,
                'min' => 0,
                'max' => 100,
                'step' => 1,
                'default' => 30
            ]
        );
        $this->add_control( 'speed',
            [
                'label' => esc_html__( 'Speed', 'crisop' ),
                'type' => Controls_Manager::NUMBER,
                'min' => 100,
                'max' => 10000,
                'step' => 100,
                'default' => 1000
            ]
        );
        $this->add_control( 'mditems',
            [
                'label' => esc_html__( 'Items', 'crisop' ),
                'type' => Controls_Manager::NUMBER,
                'min' => 1,
                'max' => 20,
                'step' => 1,
                'default' => 5
            ]
        );
        $this->add_control( 'mditems2',
            [
                'label' => esc_html__( 'Items Laptop', 'crisop' ),
                'type' => Controls_Manager::NUMBER,
                'min' => 1,
                'max' => 20,
                'step' => 1,
                'default' => 4
            ]
        );
        $this->add_control( 'smitems',
            [
                'label' => esc_html__( 'Items Tablet', 'crisop' ),
                'type' => Controls_Manager::NUMBER,
                'min' => 1,
                'max' => 20,
                'step' => 1,
                'default' => 3
            ]
        );
        $this->add_control( 'xsitems',
            [
                'label' => esc_html__( 'Items Phone', 'crisop' ),
                'type' => Controls_Manager::NUMBER,
                'min' => 1,
                'max' => 20,
                'step' => 1,
                'default' => 2
            ]
        );
        $this->add_control( 'navs_type',
            [
                'label' => esc_html__( 'Navs Type', 'crisop' ),
                'type' => Controls_Manager::SELECT,
                'default' => 'both',
                'options' => [
                    'both' => esc_html__( 'Both Nav and Dots', 'crisop' ),
                    'default' => esc_html__( 'Nav Center + Dots Bottom', 'crisop' )
                ]
            ]
        );
        $this->add_responsive_control( 'navs_horizontal_pos',
            [
                'label' => esc_html__( 'Nav Horizontal Alignment', 'crisop' ),
                'type' => Controls_Manager::CHOOSE,
                'options' => [
                    'flex-start' => [
                        'title' => esc_html__( 'Left', 'crisop' ),
                        'icon' => 'eicon-h-align-left'
                    ],
                    'center' => [
                        'title' => esc_html__( 'Center', 'crisop' ),
                        'icon' => 'eicon-h-align-center'
                    ],
                    'flex-end' => [
                        'title' => esc_html__( 'Right', 'crisop' ),
                        'icon' => 'eicon-h-align-right'
                    ]
                ],
                'toggle' => true,
                'default' => '',
                'selectors' => [ '{{WRAPPER}} .ninetheme-swiper-theme-style .ninetheme-slider-nav' => 'justify-content:{{VALUE}};' ],
                'condition' => [ 'slider_title' => '' ]
            ]
        );
        $this->add_responsive_control( 'navs_vertical_pos',
            [
                'label' => esc_html__( 'Nav Vertical Position', 'crisop' ),
                'type' => Controls_Manager::CHOOSE,
                'options' => [
                    'top' => [
                        'title' => esc_html__( 'Top', 'crisop' ),
                        'icon' => 'eicon-v-align-top'
                    ],
                    'bottom' => [
                        'title' => esc_html__( 'Bottom', 'crisop' ),
                        'icon' => 'eicon-v-align-bottom'
                    ]
                ],
                'toggle' => true,
                'default' => 'top',
                'condition' => [
                    'navs_type' => 'both'
                ]
            ]
        );
        $this->add_responsive_control( 'navs_horizontal_pos2',
            [
                'label' => esc_html__( 'Nav Horizontal Alignment', 'crisop' ),
                'type' => Controls_Manager::CHOOSE,
                'options' => [
                    'flex-start' => [
                        'title' => esc_html__( 'Left', 'crisop' ),
                        'icon' => 'eicon-h-align-left'
                    ],
                    'center' => [
                        'title' => esc_html__( 'Center', 'crisop' ),
                        'icon' => 'eicon-h-align-center'
                    ],
                    'flex-end' => [
                        'title' => esc_html__( 'Right', 'crisop' ),
                        'icon' => 'eicon-h-align-right'
                    ]
                ],
                'toggle' => true,
                'default' => '',
                'selectors' => [ '{{WRAPPER}} .ninetheme-swiper-theme-style .ninetheme-slider-nav.nav-bottom' => 'justify-content:{{VALUE}};' ],
                'condition' => [
                    'slider_title!' => '',
                    'navs_type' => 'both',
                    'navs_vertical_pos' => 'bottom'
                ]
            ]
        );
        $this->add_responsive_control( 'navs_spacing',
            [
                'label' => esc_html__( 'Nav Spacing ( px )', 'crisop' ),
                'type' => Controls_Manager::SLIDER,
                'range' => [
                    'px' => ['max' => 300]
                ],
				'default' => [
					'unit' => 'px',
					'size' => 30,
				],
                'selectors' => [
                    '{{WRAPPER}} .ninetheme-swiper-theme-style.nav-type-both .ninetheme-slider-nav.nav-bottom' => 'margin-top: {{SIZE}}px;',
                    '{{WRAPPER}} .ninetheme-swiper-theme-style.nav-type-both .ninetheme-slider-nav.nav-top' => 'margin-bottom: {{SIZE}}px;',
                ],
                'condition' => [
                    'navs_type' => 'both'
                ]
            ]
        );
        $this->end_controls_section();
        /*****   END CONTROLS SECTION   ******/

        /*****   START CONTROLS SECTION   ******/
        $this->start_controls_section('navs_style_section',
            [
                'label'=> esc_html__( 'SLIDER NAV STYLE', 'crisop' ),
                'tab' => Controls_Manager::TAB_CONTENT,
                'condition' => ['type' => 'slider']
            ]
        );
        $this->add_control( 'navs_size',
            [
                'label' => esc_html__( 'Size', 'crisop' ),
                'type' => Controls_Manager::NUMBER,
                'min' => 0,
                'max' => 100,
                'step' => 1,
                'default' => '',
                'selectors' => [ '{{WRAPPER}} .ninetheme-swiper-theme-style .swiper-button-prev:after,{{WRAPPER}} .ninetheme-swiper-theme-style .swiper-button-next:after' => 'font-size:{{SIZE}}px;' ]
            ]
        );
        $this->add_control( 'navs_color',
            [
                'label' => esc_html__( 'Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => ['{{WRAPPER}} .ninetheme-swiper-theme-style .swiper-button-prev:after,{{WRAPPER}} .ninetheme-swiper-theme-style .swiper-button-next:after' => 'color:{{VALUE}};' ]
            ]
        );
        $this->add_control( 'navs_hvrcolor',
            [
                'label' => esc_html__( 'Hover Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => ['{{WRAPPER}} .ninetheme-swiper-theme-style .swiper-button-prev:hover:after,{{WRAPPER}} .ninetheme-swiper-theme-style .swiper-button-next:hover:after' => 'color:{{VALUE}};' ]
            ]
        );
        $this->add_control( 'navs_bgcolor',
            [
                'label' => esc_html__( 'Background olor', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => ['{{WRAPPER}} .ninetheme-swiper-theme-style .swiper-button-prev,{{WRAPPER}} .ninetheme-swiper-theme-style .swiper-button-next' => 'background-color:{{VALUE}};' ]
            ]
        );
        $this->add_control( 'navs_bghvrcolor',
            [
                'label' => esc_html__( 'Hover Background Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => ['{{WRAPPER}} .ninetheme-swiper-theme-style .swiper-button-prev:hover,{{WRAPPER}} .ninetheme-swiper-theme-style .swiper-button-next:hover' => 'background-color:{{VALUE}};' ]
            ]
        );
        $this->add_control( 'navs_brdcolor',
            [
                'label' => esc_html__( 'Border olor', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => ['{{WRAPPER}} .ninetheme-swiper-theme-style .swiper-button-prev,{{WRAPPER}} .ninetheme-swiper-theme-style .swiper-button-next' => 'border-color:{{VALUE}};' ]
            ]
        );
        $this->add_control( 'navs_brdhvrcolor',
            [
                'label' => esc_html__( 'Hover Border Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => ['{{WRAPPER}} .ninetheme-swiper-theme-style .swiper-button-prev:hover,{{WRAPPER}} .ninetheme-swiper-theme-style .swiper-button-next:hover' => 'border-color:{{VALUE}};' ]
            ]
        );

        $this->end_controls_section();
        /*****   END CONTROLS SECTION   ******/
        /*****   START CONTROLS SECTION   ******/
        $this->start_controls_section('dots_style_section',
            [
                'label'=> esc_html__( 'SLIDER DOTS STYLE', 'crisop' ),
                'tab' => Controls_Manager::TAB_CONTENT,
                'condition' => ['type' => 'slider']
            ]
        );
        $this->add_responsive_control( 'dots_spacing',
            [
                'label' => esc_html__( 'Top Offset ( px )', 'crisop' ),
                'type' => Controls_Manager::SLIDER,
                'range' => [
                    'px' => ['max' => 300]
                ],
				'default' => [
					'unit' => 'px',
					'size' => 30
				],
                'selectors' => [
                    '{{WRAPPER}} .ninetheme-swiper-theme-style.nav-type-default .swiper-pagination' => 'margin-top: {{SIZE}}px;',
                ],
                'condition' => [
                    'navs_type' => 'default'
                ]
            ]
        );
        $this->add_responsive_control( 'dots_horizontal_pos',
            [
                'label' => esc_html__( 'Horizontal Alignment', 'crisop' ),
                'type' => Controls_Manager::CHOOSE,
                'options' => [
                    'left' => [
                        'title' => esc_html__( 'Left', 'crisop' ),
                        'icon' => 'eicon-h-align-left'
                    ],
                    'center' => [
                        'title' => esc_html__( 'Center', 'crisop' ),
                        'icon' => 'eicon-h-align-center'
                    ],
                    'right' => [
                        'title' => esc_html__( 'Right', 'crisop' ),
                        'icon' => 'eicon-h-align-right'
                    ]
                ],
                'toggle' => true,
                'default' => '',
                'selectors' => [ '{{WRAPPER}} .ninetheme-swiper-theme-style .swiper-pagination' => 'text-align:{{VALUE}};' ],
                'condition' => [
                    'navs_type' => 'default'
                ]
            ]
        );
        $this->add_control( 'dots_size',
            [
                'label' => esc_html__( 'Size', 'crisop' ),
                'type' => Controls_Manager::NUMBER,
                'min' => 0,
                'max' => 100,
                'step' => 1,
                'default' => '',
                'selectors' => [ '{{WRAPPER}} .swiper-pagination-bullets .swiper-pagination-bullet:before' => 'width:{{SIZE}}px;height:{{SIZE}}px;' ]
            ]
        );
        $this->add_control( 'dots_space',
            [
                'label' => esc_html__( 'Space', 'crisop' ),
                'type' => Controls_Manager::NUMBER,
                'min' => 0,
                'max' => 100,
                'step' => 1,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .swiper-horizontal > .swiper-pagination-bullets .swiper-pagination-bullet + .swiper-pagination-bullet' => 'margin: 0;margin-left: {{SIZE}}px;',
                    '{{WRAPPER}} .swiper-pagination-horizontal.swiper-pagination-bullets .swiper-pagination-bullet + .swiper-pagination-bullet' => 'margin: 0;margin-left: {{SIZE}}px;',
                ]
            ]
        );
        $this->start_controls_tabs( 'dots_nav_tabs');
        $this->start_controls_tab( 'dots_normal_tab',
            [ 'label' => esc_html__( 'Normal', 'crisop' ) ]
        );
        $this->add_control( 'dots_bgcolor',
            [
                'label' => esc_html__( 'Background', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => ['{{WRAPPER}} .swiper-pagination-bullets .swiper-pagination-bullet:before' => 'background-color:{{VALUE}};' ]
            ]
        );
        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name' => 'dots_border',
                'label' => esc_html__( 'Border', 'crisop' ),
                'selector' => '{{WRAPPER}} .swiper-pagination-bullets .swiper-pagination-bullet',
            ]
        );
        $this->add_responsive_control( 'dots_border_radius',
            [
                'label' => esc_html__( 'Border Radius', 'crisop' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px' ],
                'selectors' => [
                    '{{WRAPPER}} .swiper-pagination-bullets .swiper-pagination-bullet:before,
                    {{WRAPPER}} .swiper-pagination-bullets .swiper-pagination-bullet' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};'
                ]
            ]
        );
        $this->end_controls_tab();
        $this->start_controls_tab( 'dots_hover_tab',
            [ 'label' => esc_html__( 'Active', 'crisop' ) ]
        );
        $this->add_control( 'dots_hvrbgcolor',
            [
                'label' => esc_html__( 'Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [ '{{WRAPPER}} .swiper-pagination-bullet.swiper-pagination-bullet-active:before' => 'background-color:{{VALUE}};' ]
            ]
        );
        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name' => 'dots_hvrborder',
                'label' => esc_html__( 'Border', 'crisop' ),
                'selector' => '{{WRAPPER}} .swiper-pagination-bullet.swiper-pagination-bullet-active'
            ]
        );
        $this->add_responsive_control( 'dots_hvrborder_radius',
            [
                'label' => esc_html__( 'Border Radius', 'crisop' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px' ],
                'selectors' => [
                    '{{WRAPPER}} .swiper-pagination-bullets .swiper-pagination-bullet.swiper-pagination-bullet-active:before,
                    {{WRAPPER}} .swiper-pagination-bullets .swiper-pagination-bullet.swiper-pagination-bullet-active' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};'
                ]
            ]
        );
        $this->end_controls_tab();
        $this->end_controls_tabs();
        $this->end_controls_section();
        /*****   END CONTROLS SECTION   ******/
    }

    protected function render() {
        if ( ! class_exists('WooCommerce') ) {
            return;
        }
        $settings = $this->get_settings_for_display();
        $id       = $this->get_id();

        $size = $settings['thumbnail_size'] ? $settings['thumbnail_size'] : 'full';
        if ( 'custom' == $size ) {
            $sizew = $settings['thumbnail_custom_dimension']['width'];
            $sizeh = $settings['thumbnail_custom_dimension']['height'];
            $size  = [ $sizew, $sizeh ];
        }

        if ( 'slider' == $settings['type'] ) {
            $editmode   = \Elementor\Plugin::$instance->editor->is_edit_mode() ? '-'.$id: '';

            $slider_options = json_encode( array(
                    "slidesPerView" => 1,
                    "touchRatio"    => 2,
                    "loop"          => 'yes' == $settings['loop'] ? true : false,
                    "autoHeight"    => false,
                    "autoplay"      => 'yes' == $settings['autoplay'] ? [ "pauseOnMouseEnter" => true,"disableOnInteraction" => false ] : false,
                    "speed"         => $settings['speed'],
                    "spaceBetween"  => $settings['space'] ? $settings['space'] : 30,
                    "direction"     => "horizontal",
                    "navigation" => [
                        "nextEl" => ".ninetheme-team-slider .slide-next-$id",
                        "prevEl" => ".ninetheme-team-slider .slide-prev-$id"
                    ],
                    "pagination" => [
                        "el" => ".ninetheme-team-slider .ninetheme-pagination-$id",
                        "type" => "bullets",
                        "clickable" => true
                    ],
                    "breakpoints" => [
                        "0" => [
                            "slidesPerView" => $settings['xsitems']
                        ],
                        "768" => [
                            "slidesPerView" => $settings['smitems']
                        ],
                        "992" => [
                            "slidesPerView" => $settings['mditems2']
                        ],
                        "1280" => [
                            "slidesPerView" => $settings['mditems']
                        ]
                    ]
                )
            );
            $next = is_rtl() ? 'next' : 'prev';
            $prev = is_rtl() ? 'prev' : 'next';
            echo '<div class="ninetheme-team-slider ninetheme-swiper-theme-style nav-type-'.$settings['navs_type'].' swiper-container ninetheme-swiper-slider'.$editmode.'" data-swiper-options=\''.$slider_options.'\'>';
                if ( $settings['slider_title'] ) {
                    echo '<div class="ninetheme-slider-title-wrapper nav-top">';
                        echo '<'.$settings['title_tag'].' class="ninetheme-slider-nav-title">'.$settings['slider_title'].'</'.$settings['title_tag'].'>';
                }
                        if ( 'both' == $settings['navs_type'] ) {
                            if ( 'bottom' != $settings['navs_vertical_pos'] && ( 'yes' == $settings['dots'] || 'yes' == $settings['nav'] ) ) {
                                $top = '' == $settings['slider_title'] ? ' nav-top' : '';
                                echo '<div class="ninetheme-slider-nav'.$top.'">';
                                    if ( 'yes' == $settings['nav'] ) {
                                        echo '<div class="theme-swiper-btn swiper-button-prev slide-prev-'.$id.'"></div>';
                                    }
                                    if ( 'yes' == $settings['dots'] ) {
                                        echo '<div class="swiper-pagination ninetheme-pagination-'.$id.'"></div>';
                                    }
                                    if ( 'yes' == $settings['nav'] ) {
                                        echo '<div class="theme-swiper-btn swiper-button-next slide-next-'.$id.'"></div>';
                                    }
                                echo '</div>';
                            }
                        }
                if ( $settings['slider_title'] ) {
                    echo '</div>';
                }
                echo '<div class="swiper-wrapper">';
                    foreach ( $settings['items'] as $item ) {
                        echo '<div class="ninetheme-team-item swiper-slide '.$settings['box_type'].' '.$settings['content_type'].'">';
                            if ( !empty( $item['image']['id'] ) ) {
                                $target     = !empty( $item['link']['is_external'] ) ? ' target="_blank"' : '';
                                $nofollow   = !empty( $item['link']['nofollow'] ) ? ' rel="nofollow"' : '';
                                $href       = !empty( $item['link']['url'] ) ? $item['link']['url'] : '';

                                echo '<div class="ninetheme-team-item-inner">';
                                    echo 'box-type-classic' == $settings['box_type'] ? '<div class="ninetheme-team-image-wraper">' : '';
                                    echo wp_get_attachment_image( $item['image']['id'], $size );
                                    echo 'box-type-classic' == $settings['box_type'] ? '</div>' : '';
                                    echo '<div class="ninetheme-team-details">';
                                        echo !empty( $item['subtitle'] ) ? '<span class="ninetheme-team-subtitle">'.$item['subtitle'].'</span>' : '';
                                        echo !empty( $item['title'] ) ? '<'.$settings['tag'].' class="ninetheme-team-title">'.$item['title'].'</'.$settings['tag'].'>' : '';
                                        echo !empty( $item['desc'] ) ? '<p class="ninetheme-team-description">'.$item['desc'].'</p>' : '';
                                        echo !empty( $item['btn_title'] ) ? '<a class="ninetheme-team-link ninetheme-btn '.$settings['btn_color_type'].' '.$settings['btn_bg_type'].' '.$settings['btn_radius_type'].' '.$settings['btn_size'].'" href="'.$href.'"'.$target.$nofollow.'>'.$item['btn_title'].'</a>' : '';
                                    echo '</div>';
                                echo '</div>';
                            }
                        echo '</div>';
                    }
                echo '</div>';
                if ( 'both' == $settings['navs_type'] ) {
                    if ( 'bottom' == $settings['navs_vertical_pos'] && ( 'yes' == $settings['dots'] || 'yes' == $settings['nav'] ) ) {
                        echo '<div class="ninetheme-slider-nav nav-bottom">';
                            if ( 'yes' == $settings['nav'] ) {
                                echo '<div class="theme-swiper-btn swiper-button-prev slide-prev-'.$id.'"></div>';
                            }
                            if ( 'yes' == $settings['dots'] ) {
                                echo '<div class="swiper-pagination ninetheme-pagination-'.$id.'"></div>';
                            }
                            if ( 'yes' == $settings['nav'] ) {
                                echo '<div class="theme-swiper-btn swiper-button-next slide-next-'.$id.'"></div>';
                            }
                        echo '</div>';
                    }
                }
                if ( 'default' == $settings['navs_type'] ) {
                    if ( 'yes' == $settings['dots'] ) {
                        echo '<div class="swiper-pagination ninetheme-pagination-'.$id.'"></div>';
                    }
                    if ( 'yes' == $settings['nav'] ) {
                        echo '<div class="theme-swiper-btn swiper-button-prev slide-prev-'.$id.'"></div>';
                        echo '<div class="theme-swiper-btn swiper-button-next slide-next-'.$id.'"></div>';
                    }
                }
            echo '</div>';

            if ( \Elementor\Plugin::$instance->editor->is_edit_mode() ) { ?>
                <script>
                jQuery( document ).ready( function($) {
                    $('.ninetheme-swiper-slider-<?php echo $id ?>').each(function (i, el) {
                        var options = $(el).data('swiper-options')
                        const mySlider = new NTSwiper(el, options);
                    });
                });
                </script>
                <?php
            }
        } else {

            echo '<div class="ninetheme-team-grid row">';
                if ( $settings['slider_title'] ) {
                    echo '<div class="ninetheme-slider-title-wrapper nav-top">';
                        echo '<'.$settings['title_tag'].' class="ninetheme-slider-nav-title">'.$settings['slider_title'].'</'.$settings['title_tag'].'>';
                    echo '</div>';
                }
                foreach ( $settings['items'] as $item ) {
                    echo '<div class="ninetheme-team-item col-12 col-sm-2 col-md-3 '.$settings['box_type'].' '.$settings['content_type'].'">';
                        if ( !empty( $item['image']['id'] ) ) {
                            $target     = !empty( $item['link']['is_external'] ) ? ' target="_blank"' : '';
                            $nofollow   = !empty( $item['link']['nofollow'] ) ? ' rel="nofollow"' : '';
                            $href       = !empty( $item['link']['url'] ) ? $item['link']['url'] : '';

                            echo '<div class="ninetheme-team-item-inner">';
                                echo 'box-type-classic' == $settings['box_type'] ? '<div class="ninetheme-team-image-wraper">' : '';
                                echo wp_get_attachment_image( $item['image']['id'], $size );
                                echo 'box-type-classic' == $settings['box_type'] ? '</div>' : '';
                                echo '<div class="ninetheme-team-details">';
                                    echo !empty( $item['subtitle'] ) ? '<span class="ninetheme-team-subtitle">'.$item['subtitle'].'</span>' : '';
                                    echo !empty( $item['title'] ) ? '<'.$settings['tag'].' class="ninetheme-team-title">'.$item['title'].'</'.$settings['tag'].'>' : '';
                                    echo !empty( $item['desc'] ) ? '<p class="ninetheme-team-description">'.$item['desc'].'</p>' : '';
                                    echo !empty( $item['btn_title'] ) ? '<a class="ninetheme-team-link ninetheme-btn '.$settings['btn_color_type'].' '.$settings['btn_bg_type'].' '.$settings['btn_radius_type'].' '.$settings['btn_size'].'" href="'.$href.'"'.$target.$nofollow.'>'.$item['btn_title'].'</a>' : '';
                                echo '</div>';
                            echo '</div>';
                        }
                    echo '</div>';
                }
            echo '</div>';
        }
    }
}
