<?php

namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) exit; // If this file is called directly, abort.

class Ninetheme_Timer extends Widget_Base {
    use Ninetheme_Helper;
    public function get_name() {
        return 'ninetheme-countdown';
    }
    public function get_title() {
        return 'Countdown (N)';
    }
    public function get_icon() {
        return 'eicon-countdown';
    }
    public function get_categories() {
        return [ 'crisop' ];
    }
    public function get_keywords() {
		return [ 'time', 'timer', 'count', 'counter', 'countdown', 'date' ];
	}
    // Registering Controls
    protected function register_controls() {
        /*****   START CONTROLS SECTION   ******/
        $this->start_controls_section('countdown_settings',
            [
                'label' => esc_html__( 'Countdown Settings', 'crisop' ),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );
        $this->add_control( 'date',
            [
                'label' => esc_html__( 'Time', 'crisop' ),
                'type' => Controls_Manager::TEXT,
                'placeholder' => esc_html__( 'Usage : 2030/01/01', 'crisop' ),
                'default' => '2030/01/01'
            ]
        );
        $this->add_control( 'expired',
            [
                'label' => esc_html__( 'Expired Text', 'crisop' ),
                'type' => Controls_Manager::TEXT,
                'default' => ''
            ]
        );
        $this->add_control( 'hide_sep',
            [
                'label' => esc_html__( 'Separator', 'crisop' ),
                'type' => Controls_Manager::SWITCHER,
                'default' => 'no'
            ]
        );
        $this->add_control( 'time_sep',
            [
                'label' => esc_html__( 'Seperator', 'crisop' ),
                'type' => Controls_Manager::TEXT,
                'default' => ':',
                'condition' => ['hide_sep' => 'yes']
            ]
        );
        $this->end_controls_section();
        /*****   END CONTROLS SECTION   ******/
        /*****   START CONTROLS SECTION   ******/
        $this->start_controls_section( 'style_section',
            [
                'label'=> esc_html__( 'STYLE', 'crisop' ),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );
        $this->add_responsive_control('alignment',
            [
                'label' => esc_html__( 'Alignment', 'crisop' ),
                'type' => Controls_Manager::CHOOSE,
                'toggle' => true,
                'default' => 'left',
                'options' => [
                    'flex-start' => [
                        'title' => esc_html__( 'Left', 'crisop' ),
                        'icon' => 'eicon-h-align-left'
                    ],
                    'center' => [
                        'title' => esc_html__( 'Center', 'crisop' ),
                        'icon' => 'eicon-h-align-center'
                    ],
                    'flex-end' => [
                        'title' => esc_html__( 'Right', 'crisop' ),
                        'icon' => 'eicon-h-align-right'
                    ]
                ],
                'selectors' => [ '{{WRAPPER}} .ninetheme-coming-time' => 'justify-content: {{VALUE}};' ]
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'time_typo',
                'label' => esc_html__( 'Typography', 'crisop' ),
                'selector' => '{{WRAPPER}} .ninetheme-coming-time .time-count'
            ]
        );
        $this->add_responsive_control( 'time_color',
            [
                'label' => esc_html__( 'Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => ['{{WRAPPER}} .ninetheme-coming-time .time-count' => 'color:{{VALUE}};' ],
            ]
        );
        $this->add_responsive_control( 'time_sep_color',
            [
                'label' => esc_html__( 'Seperator Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => ['{{WRAPPER}} .ninetheme-coming-time .separator' => 'color:{{VALUE}};' ],
                'condition' => ['hide_sep' => 'no']
            ]
        );
        $this->add_responsive_control( 'time_sep_size',
            [
                'label' => esc_html__( 'Seperator Size', 'crisop' ),
                'type' => Controls_Manager::NUMBER,
                'min' => 0,
                'max' => 100,
                'step' => 1,
                'default' => 15,
                'selectors' => ['{{WRAPPER}} .ninetheme-coming-time .separator' => 'font-size:{{SIZE}}px;' ],
                'condition' => ['hide_sep' => 'no']
            ]
        );
        $this->add_responsive_control( 'time_min_width',
            [
                'label' => esc_html__( 'Item Min Width', 'crisop' ),
                'type' => Controls_Manager::NUMBER,
                'min' => 0,
                'max' => 1000,
                'step' => 1,
                'default' => '',
                'selectors' => ['{{WRAPPER}} .ninetheme-coming-time .time-count' => 'min-width:{{SIZE}}px;' ],
            ]
        );
        $this->add_responsive_control( 'time_min_height',
            [
                'label' => esc_html__( 'Item Min height', 'crisop' ),
                'type' => Controls_Manager::NUMBER,
                'min' => 0,
                'max' => 1000,
                'step' => 1,
                'default' => '',
                'selectors' => ['{{WRAPPER}} .ninetheme-coming-time .time-count' => 'min-height:{{SIZE}}px;' ],
            ]
        );
        $this->add_responsive_control( 'time_sep_space',
            [
                'label' => esc_html__( 'Space Between Items', 'crisop' ),
                'type' => Controls_Manager::NUMBER,
                'min' => 0,
                'max' => 100,
                'step' => 1,
                'default' => 15,
                'selectors' => ['{{WRAPPER}} .ninetheme-coming-time .separator' => 'margin:0 {{SIZE}}px;'],
            ]
        );
        $this->add_responsive_control( 'time_padding',
            [
                'label' => esc_html__( 'Item Padding', 'crisop' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px' ],
                'selectors' => ['{{WRAPPER}} .ninetheme-coming-time .time-count' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};'],
                'default' => [
                    'top' => '',
                    'right' => '',
                    'bottom' => '',
                    'left' => '',
                ]
            ]
        );
        $this->add_responsive_control( 'time_bgcolor',
            [
                'label' => esc_html__( 'Item Background', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => ['{{WRAPPER}} .ninetheme-coming-time .time-count' => 'background-color:{{VALUE}};' ]
            ]
        );
        $this->add_responsive_control( 'time_first_bgcolor',
            [
                'label' => esc_html__( 'First Item Background', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => ['{{WRAPPER}} .ninetheme-coming-time .time-count.first-item' => 'background-color:{{VALUE}};' ]
            ]
        );
        $this->add_responsive_control( 'time_first_color',
            [
                'label' => esc_html__( 'First Item Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => ['{{WRAPPER}} .ninetheme-coming-time .time-count.first-item' => 'color:{{VALUE}};' ],
            ]
        );
        $this->add_responsive_control( 'time_second_bgcolor',
            [
                'label' => esc_html__( 'Second Item Background', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => ['{{WRAPPER}} .ninetheme-coming-time .time-count.second-item' => 'background-color:{{VALUE}};' ]
            ]
        );
        $this->add_responsive_control( 'time_second_color',
            [
                'label' => esc_html__( 'Second Item Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => ['{{WRAPPER}} .ninetheme-coming-time .time-count.second-item' => 'color:{{VALUE}};' ],
            ]
        );
        $this->add_responsive_control( 'time_third_bgcolor',
            [
                'label' => esc_html__( 'Third Item Background', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => ['{{WRAPPER}} .ninetheme-coming-time .time-count.third-item' => 'background-color:{{VALUE}};' ]
            ]
        );
        $this->add_responsive_control( 'time_third_color',
            [
                'label' => esc_html__( 'Third Item Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => ['{{WRAPPER}} .ninetheme-coming-time .time-count.third-item' => 'color:{{VALUE}};' ],
            ]
        );
        $this->add_responsive_control( 'time_last_bgcolor',
            [
                'label' => esc_html__( 'Last Item Background', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => ['{{WRAPPER}} .ninetheme-coming-time .time-count.last-item' => 'background-color:{{VALUE}};' ]
            ]
        );
        $this->add_responsive_control( 'time_last_color',
            [
                'label' => esc_html__( 'Last Item Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => ['{{WRAPPER}} .ninetheme-coming-time .time-count.last-item' => 'color:{{VALUE}};' ],
            ]
        );
        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name' => 'time_border',
                'label' => esc_html__( 'Border', 'crisop' ),
                'selector' => '{{WRAPPER}} .ninetheme-coming-time .time-count',
            ]
        );
        $this->add_responsive_control( 'time_last_brdcolor',
            [
                'label' => esc_html__( 'Last Item Border Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => ['{{WRAPPER}} .ninetheme-coming-time .time-count.last' => 'border-color:{{VALUE}};' ]
            ]
        );
        $this->add_responsive_control( 'time_border_radius',
            [
                'label' => esc_html__( 'Border Radius', 'crisop' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px' ],
                'selectors' => [
                    '{{WRAPPER}} .ninetheme-coming-time .time-count' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};'
                ]
            ]
        );
        $this->end_controls_section();
        /*****   END CONTROLS SECTION   ******/
    }

    protected function render() {
        $s  = $this->get_settings_for_display();
        $id = $this->get_id();

        if ( $s['date'] ) {
            $sep = 'yes' == $s['hide_sep'] ? '' : $s['time_sep'];
            echo '<div class="ninetheme-widget ninetheme-coming-time ninetheme-coming-time-'.$id.'" data-countdown=\'{"date":"'.$s['date'].'","expired":"'.$s['expired'].'"}\'>';
                echo '<div class="time-count days first-item"></div>';
                echo '<span class="separator">'.$sep.'</span>';
                echo '<div class="time-count hours second-item"></div>';
                echo '<span class="separator">'.$sep.'</span>';
                echo '<div class="time-count minutes third-item"></div>';
                echo '<span class="separator">'.$sep.'</span>';
                echo '<div class="time-count second last-item"></div>';
            echo '</div>';
            
            if ( \Elementor\Plugin::$instance->editor->is_edit_mode() ) { ?>
                <script>
                jQuery( document ).ready( function($) {

                    var self      = $('.ninetheme-coming-time-<?php echo $id; ?>'),
                        data      = self.data('countdown'),
                        countDate = data.date,
                        expired   = data.expired;
                        
                    let countDownDate = new Date( countDate ).getTime();
                    
                    const d = self.find( '.days' );
                    const h = self.find( '.hours' );
                    const m = self.find( '.minutes' );
                    const s = self.find( '.second' );
                    
                    var x = setInterval(function() {
                        
                        var now = new Date().getTime();
                        
                        var distance = countDownDate - now;
                        
                        var days    = ('0' + Math.floor(distance / (1000 * 60 * 60 * 24))).slice(-2);
                        var hours   = ('0' + Math.floor((distance % (1000 * 60 * 60 * 24)) / (1000 * 60 * 60))).slice(-2);
                        var minutes = ('0' + Math.floor((distance % (1000 * 60 * 60)) / (1000 * 60))).slice(-2);
                        var seconds = ('0' + Math.floor((distance % (1000 * 60)) / 1000)).slice(-2);
                        
                        d.text( days );
                        h.text( hours );
                        m.text( minutes );
                        s.text( seconds );
                        
                        if (distance < 0) {
                            clearInterval(x);
                            console.log( expired );
                            self.html('<div class="expired">' + expired + '</div>');
                        }
                    }, 1000);
                });
                </script>
                <?php
            }
        }
    }
}
