<?php

namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) exit; // If this file is called directly, abort.

class Ninetheme_Toggle_Menu extends Widget_Base {
    use Ninetheme_Helper;
    public function get_name() {
        return 'ninetheme-toggle-menu';
    }
    public function get_title() {
        return 'Toggle Menu Button (N)';
    }
    public function get_icon() {
        return 'eicon-button';
    }
    public function get_categories() {
        return [ 'ninetheme-header' ];
    }
    // Registering Controls
    protected function register_controls() {

        /*****   Button Options   ******/
        $this->start_controls_section('btn_settings',
            [
                'label' => esc_html__( 'Button', 'crisop' ),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );
        $this->add_control( 'text',
            [
                'label' => esc_html__( 'Button Open Text', 'crisop' ),
                'type' => Controls_Manager::TEXT,
                'label_block' => true,
                'default' => esc_html__( 'Menu', 'crisop' )
            ]
        );
        $this->add_control( 'icon',
            [
                'label' => esc_html__( 'Button Icon', 'crisop' ),
                'type' => Controls_Manager::ICONS
            ]
        );
        $this->add_control( 'text_close',
            [
                'label' => esc_html__( 'Button Close Text', 'crisop' ),
                'type' => Controls_Manager::TEXT,
                'label_block' => true,
                'default' => esc_html__( 'Close', 'crisop' )
            ]
        );
        $this->add_control( 'icon_close',
            [
                'label' => esc_html__( 'Button Close Icon', 'crisop' ),
                'type' => Controls_Manager::ICONS
            ]
        );
        $this->add_control( 'icon_size',
            [
                'label' => esc_html__( 'Icon Size', 'crisop' ),
                'type' => Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'max' => 100
                    ]
                ],
                'selectors' => ['{{WRAPPER}} .ninetheme-menu-toggle i' => 'font-size: {{SIZE}}px;']
            ]
        );
        $this->add_responsive_control( 'alignment',
            [
                'label' => esc_html__( 'Alignment', 'crisop' ),
                'type' => Controls_Manager::CHOOSE,
                'selectors' => ['{{WRAPPER}} .ninetheme-menu-toggle-wrapper' => 'text-align: {{VALUE}};'],
                'options' => [
                    'left' => [
                        'title' => esc_html__( 'Left', 'crisop' ),
                        'icon' => 'eicon-h-align-left'
                    ],
                    'center' => [
                        'title' => esc_html__( 'Center', 'crisop' ),
                        'icon' => 'eicon-h-align-center'
                    ],
                    'right' => [
                        'title' => esc_html__( 'Right', 'crisop' ),
                        'icon' => 'eicon-h-align-right'
                    ]
                ],
                'toggle' => true,
                'default' => ''
            ]
        );
        $this->end_controls_section();
        /*****   End Button Options   ******/

        /***** Button Style ******/
        $this->start_controls_section('btn_styling',
            [
                'label' => esc_html__( 'STYLE', 'crisop' ),
                'tab' => Controls_Manager::TAB_CONTENT
            ]
        );
        $this->start_controls_tabs('btn_tabs');
        $this->start_controls_tab( 'btn_normal_tab',
            [ 'label' => esc_html__( 'Normal', 'crisop' ) ]
        );
        $this->add_control( 'btn_color',
            [
                'label' => esc_html__( 'Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => ['{{WRAPPER}} .ninetheme-menu-toggle-wrapper' => 'color: {{VALUE}};']
            ]
        );
        $this->add_control( 'btn_bgcolor',
            [
                'label' => esc_html__( 'Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => ['{{WRAPPER}} .ninetheme-menu-toggle-wrapper' => 'background-color: {{VALUE}};']
            ]
        );
        $this->add_responsive_control( 'btn_padding',
            [
                'label' => esc_html__( 'Padding', 'crisop' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px' ],
                'selectors' => ['{{WRAPPER}} .ninetheme-menu-toggle-wrapper' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};']
            ]
        );
        $this->add_responsive_control( 'btn_margin',
            [
                'label' => esc_html__( 'Padding', 'crisop' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px' ],
                'selectors' => ['{{WRAPPER}} .ninetheme-menu-toggle-wrapper' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};']
            ]
        );
        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name' => 'btn_border',
                'label' => esc_html__( 'Border', 'crisop' ),
                'selector' => '{{WRAPPER}} .ninetheme-menu-toggle-wrapper',
                'separator' => 'before'
            ]
        );
        $this->add_responsive_control( 'btn_border_radius',
            [
                'label' => esc_html__( 'Border Radius', 'crisop' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px' ],
                'selectors' => ['{{WRAPPER}} .ninetheme-menu-toggle-wrapper' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};']
            ]
        );
        $this->add_control( 'btn_text_color',
            [
                'label' => esc_html__( 'Text Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => ['{{WRAPPER}} .ninetheme-menu-toggle-wrapper .btn-text' => 'color: {{VALUE}};']
            ]
        );
        $this->end_controls_tab();

        $this->start_controls_tab('btn_hover_tab',
            [ 'label' => esc_html__( 'Hover', 'crisop' ) ]
        );
        $this->add_control( 'btn_hvr_color',
            [
                'label' => esc_html__( 'Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => ['{{WRAPPER}} .ninetheme-btn:hover' => 'color: {{VALUE}};']
            ]
        );
        $this->add_control( 'btn_hvr_bgcolor',
            [
                'label' => esc_html__( 'Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => ['{{WRAPPER}} .ninetheme-menu-toggle:hover' => 'background-color: {{VALUE}};']
            ]
        );
        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name' => 'btn_hvr_border',
                'label' => esc_html__( 'Border', 'crisop' ),
                'selector' => '{{WRAPPER}} .ninetheme-menu-toggle:hover',
                'separator' => 'before'
            ]
        );
        $this->add_control( 'btn_text_hvrcolor',
            [
                'label' => esc_html__( 'Text Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => ['{{WRAPPER}} .ninetheme-menu-toggle:hover .btn-text' => 'color: {{VALUE}};']
            ]
        );
        $this->end_controls_tab();
        $this->end_controls_tabs();
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'title_typo',
                'label' => esc_html__( 'Text Typography', 'crisop' ),
                'selector' => '{{WRAPPER}} .ninetheme-menu-toggle .btn-text'
            ]
        );
        $this->end_controls_section();
        /***** End Button Styling *****/
    }

    protected function render() {
        $settings   = $this->get_settings_for_display();
        $edit       = \Elementor\Plugin::$instance->editor->is_edit_mode() ? '-edit' : '';
        
        echo '<div class="ninetheme-menu-toggle-wrapper">';
            echo '<div class="ninetheme-menu-toggle mobile-menu-open'.$edit.'">';
                if ( !empty( $settings['icon']['value'] ) ) { 
                    Icons_Manager::render_icon( $settings['icon'], [ 'aria-hidden' => 'true' ] );
                    if ( $settings['text'] ) { 
                        echo '<span class="btn-text">'.$settings['text'].'</span>';
                    }
                } else {
                    echo '<span class="btn-text">'.$settings['text'].'</span>';
                }
            echo '</div>';
            echo '<div class="ninetheme-menu-toggle mobile-menu-close'.$edit.'">';
                if ( !empty( $settings['icon']['value'] ) ) { 
                    Icons_Manager::render_icon( $settings['icon_close'], [ 'aria-hidden' => 'true' ] );
                    if ( $settings['text'] ) { 
                        echo '<span class="btn-text">'.$settings['text_close'].'</span>';
                    }
                } else {
                    echo '<span class="btn-text">'.$settings['text_close'].'</span>';
                }
            echo '</div>';
        echo '</div>';
        
        // in edit mode
        if ( \Elementor\Plugin::$instance->editor->is_edit_mode() ) {
            ?>
            <script>
            jQuery(document).ready(function($){

                $('.elementor-section.ninetheme-elementor-header-mobile .mobile-menu-open-edit, .elementor-section .mobile-menu-close-edit').on('click', function(e) {
                    e.preventDefault();
                    var $this = $( this );
                    $this.parent().toggleClass('active');
                    $('.ninetheme-elementor-header-mobile-menu').toggleClass('active');
                    $('html,body').toggleClass('ninetheme-overlay-open');
                    $('body').toggleClass('mobile-menu-active');
                });
            });
            </script>
            <?php
        }
    }
}
