<?php
/**
* Main class
*
* @author Crisop
* @package Crisop WooCommerce Ajax Search
* @version 1.0.0
*/
if ( ! defined( 'ABSPATH' ) ) exit; // If this file is called directly, abort.
if ( ! class_exists( 'Ninetheme_Wc_As' ) ) {
    /**
    * Crisop WooCommerce Ajax Search
    *
    * @since 1.0.0
    */
    class Ninetheme_Wc_As {

        private static $instance = null;

        public static function get_instance() {
            if ( is_null( self::$instance ) ) {
                self::$instance = new self;
            }
            return self::$instance;
        }
        /**
        * Constructor
        *
        * @return Ninetheme_Wc_As
        * @since 1.0.0
        */
        public function __construct() {

            if ( ! isset( $_REQUEST['action'] ) || 'ninetheme_as_products' !== $_REQUEST['action']  ) {

                add_action( 'wp_enqueue_scripts', array( $this, 'enqueue_styles_scripts' ) );
            }

            add_action( 'wp_ajax_ninetheme_as_products', array( $this, 'ajax_search_products' ) );
            add_action( 'wp_ajax_nopriv_ninetheme_as_products', array( $this, 'ajax_search_products' ) );

            // register shortcode.
            add_shortcode( 'ninetheme_wc_ajax_search', array( $this, 'add_wc_ajax_search_shortcode' ) );

        }

        /**
        * Enqueue styles and scripts
        *
        * @access public
        * @return void
        * @since 1.0.0
        */
        public function enqueue_styles_scripts() {
            wp_enqueue_script( 'ninetheme-autocomplete', NINETHEME_PLUGIN_URL. 'widgets/woocommerce/ajax-search/css-js/autocomplete.min.js','', NINETHEME_PLUGIN_VERSION, true );
            wp_enqueue_script( 'ninetheme-ajax-search', NINETHEME_PLUGIN_URL . 'widgets/woocommerce/ajax-search/css-js/script.js', array( 'jquery' ), NINETHEME_PLUGIN_VERSION, true );
        }

        public function add_wc_ajax_search_shortcode() {
            wp_enqueue_script( 'ninetheme-autocomplete' );
            wp_enqueue_script( 'ninetheme-ajax-search' );
            $terms = get_terms( array( 'taxonomy' => 'product_cat', 'hide_empty' => false, 'parent' => 0 ) );
            ob_start();
            ?>
            <div class="ninetheme-asform-container">
                <form role="search" method="get" class="ninetheme-asform" action="<?php echo esc_url( home_url( '/' ) ); ?>">
                    <select class="ninetheme-ajax-form-select custom-select" name="product_cat">
                        <option value="0" selected="selected"><?php esc_html_e( 'All Category', 'crisop' ) ?></option>
                        <?php
                            echo wp_list_categories(array(
                                'echo'       => true,
                                'taxonomy'   => 'product_cat',
                                'depth'      => 5,
                                'hide_empty' => 1,
                                'title_li'   => '',
                                'walker'     => new Ninetheme_WooCommerce_Categories_Select_Walker()
                            ));
                        ?>
                    </select>
                    <input type="search"
                    value="<?php echo esc_attr( get_search_query() ); ?>"
                    name="s" class="ninetheme-as"
                    placeholder="<?php echo esc_attr( apply_filters( 'ninetheme_as_input_label', esc_html__( 'Search products...', 'crisop' ) ) ); ?>"
                    data-loader-icon="<?php echo esc_attr( str_replace( '"', '', apply_filters( 'ninetheme_as_ajax_search_icon', '' ) ) ); ?>"
                    data-min-chars="1" />
                    <input type="hidden" name="post_type" value="<?php echo esc_attr( apply_filters( 'ninetheme_as_search_type', 'product' ) ); ?>"/>
                    <div class="search-icon"><span class="ajax-loading"></span></div>
                    <?php do_action( 'wpml_add_language_form_field' ); ?>
                </form>
            </div>
            <?php
            return ob_get_clean();
        }

        /**
        * Get microtime.
        *
        * @return float
        */
        public function get_microtime() {
            list( $usec, $sec ) = explode( ' ', microtime() );

            return ( (float) $usec + (float) $sec );
        }

        /**
        * Perform ajax search products
        */
        public function ajax_search_products() {
            global $woocommerce;

            $time_start         = $this->get_microtime();
            $transient_enabled  = apply_filters( 'ninetheme_as_enable_transient', 'no' );
            $transient_duration = apply_filters( 'ninetheme_as_transient_duration', 12 );
            $search_keyword     = sanitize_text_field( wp_unslash( $_REQUEST['query'] ) );
            $ordering_args      = $woocommerce->query->get_catalog_ordering_args( 'title', 'asc' );
            $suggestions        = array();

            $transient_name = 'ninetheme_as_' . $search_keyword;
            $suggestions = get_transient( $transient_name );
            if ( 'no' === $transient_enabled || false === $suggestions ) {
                $args = array(
                    's'                   => apply_filters( 'ninetheme_as_search_query', $search_keyword ),
                    'post_type'           => 'product',
                    'post_status'         => 'publish',
                    'ignore_sticky_posts' => 1,
                    'orderby'             => $ordering_args['orderby'],
                    'order'               => $ordering_args['order'],
                    'posts_per_page'      => -1,
                    'suppress_filters'    => false
                );

                if ( isset( $_REQUEST['product_cat'] ) ) {
                    $args['tax_query'] = array(
                        'relation' => 'AND',
                        array(
                            'taxonomy' => 'product_cat',
                            'field'    => 'slug',
                            'terms'    => sanitize_text_field( wp_unslash( $_REQUEST['product_cat'] ) )
                        )
                    );
                }

                if ( version_compare( WC()->version, '2.7.0', '<' ) ) {
                    $args['meta_query'] = array(
                        array(
                            'key'     => '_visibility',
                            'value'   => array( 'search', 'visible' ),
                            'compare' => 'IN'
                        )
                    );
                } else {
                    $product_visibility_term_ids = wc_get_product_visibility_term_ids();
                    $args['tax_query'][] = array(
                        'taxonomy' => 'product_visibility',
                        'field'    => 'term_taxonomy_id',
                        'terms'    => $product_visibility_term_ids['exclude-from-search'],
                        'operator' => 'NOT IN'
                    );
                }

                $products = get_posts( $args );

                if ( ! empty( $products ) ) {
                    foreach ( $products as $post ) {
                        $product = wc_get_product( $post );

                        $suggestions[] = apply_filters( 'ninetheme_as_suggestion',
                            array(
                                'id'    => $product->get_id(),
                                'value' => wp_strip_all_tags( $product->get_title() ),
                                'url'   => $product->get_permalink(),
                                'img'   => get_the_post_thumbnail_url( $product->get_id(), array( 50, 50 ) ),
                                'prc'   => $product->get_price_html(),
                            ),
                            $product
                        );
                    }
                } else {
                    $suggestions[] = array(
                        'id'    => - 1,
                        'value' => __( 'No results', 'crisop' ),
                        'url'   => ''
                    );
                }
                wp_reset_postdata();

                if ( 'yes' === $transient_enabled ) {
                    set_transient( $transient_name, $suggestions, $transient_duration * HOUR_IN_SECONDS );
                }
            }

            $time_end    = $this->get_microtime();
            $time        = $time_end - $time_start;
            $suggestions = array(
                'suggestions' => $suggestions,
                'time' => $time
            );
            echo wp_json_encode( $suggestions );
            die();

        }
    }
    Ninetheme_Wc_As::get_instance();
}

if ( !class_exists('Ninetheme_WooCommerce_Categories_Select_Walker') ) {
    class Ninetheme_WooCommerce_Categories_Select_Walker extends Walker {
        /**
    	 * What the class handles.
    	 *
    	 * @var string
    	 */
    	public $tree_type = 'product_cat';

    	/**
    	 * DB fields to use.
    	 *
    	 * @var array
    	 */
    	public $db_fields = array(
    		'parent' => 'parent',
    		'id'     => 'term_id',
    		'slug'   => 'slug',
    	);

    	/**
    	 * Start the element output.
    	 *
    	 * @see Walker::start_el()
    	 * @since 2.1.0
    	 *
    	 * @param string  $output            Passed by reference. Used to append additional content.
    	 * @param object  $cat               Category.
    	 * @param int     $depth             Depth of category in reference to parents.
    	 * @param array   $args              Arguments.
    	 * @param integer $current_object_id Current object ID.
    	 */
    	public function start_el( &$output, $cat, $depth = 0, $args = array(), $current_object_id = 0 ) {
    		$cat_id = intval( $cat->term_id );
            $space  = $depth > 0 ? '&nbsp;&nbsp;&nbsp;' : '';

    		$output .= '<option class="cat-item cat-item-'.$cat_id.' cat-depth-'.$depth;

    		if ( $args['current_category'] === $cat_id ) {
    			$output .= ' current-cat';
    		}

    		if ( $args['has_children'] && $args['hierarchical'] && ( empty( $args['max_depth'] ) || $args['max_depth'] > $depth + 1 ) ) {
    			$output .= ' cat-parent';
    		}

    		if ( isset($args['current_category_ancestors']) && $args['current_category'] && in_array( $cat_id, $args['current_category_ancestors'], true ) ) {
    			$output .= ' current-cat-parent';
    		}

    		$output .= '" value="'.$cat->slug.'">';
            $output .= $space.$cat->name;
    	}

    	/**
    	 * Ends the element output, if needed.
    	 *
    	 * @see Walker::end_el()
    	 * @since 2.1.0
    	 *
    	 * @param string $output Passed by reference. Used to append additional content.
    	 * @param object $cat    Category.
    	 * @param int    $depth  Depth of category. Not used.
    	 * @param array  $args   Only uses 'list' for whether should append to output.
    	 */
    	public function end_el( &$output, $cat, $depth = 0, $args = array() ) {
    		$output .= "</option>\n";
    	}

    	/**
    	 * Traverse elements to create list from elements.
    	 *
    	 * Display one element if the element doesn't have any children otherwise,
    	 * display the element and its children. Will only traverse up to the max.
    	 * depth and no ignore elements under that depth. It is possible to set the.
    	 * max depth to include all depths, see walk() method.
    	 *
    	 * This method shouldn't be called directly, use the walk() method instead.
    	 *
    	 * @since 2.5.0
    	 *
    	 * @param object $element           Data object.
    	 * @param array  $children_elements List of elements to continue traversing.
    	 * @param int    $max_depth         Max depth to traverse.
    	 * @param int    $depth             Depth of current element.
    	 * @param array  $args              Arguments.
    	 * @param string $output            Passed by reference. Used to append additional content.
    	 * @return null Null on failure with no changes to parameters.
    	 */
    	public function display_element( $element, &$children_elements, $max_depth, $depth, $args, &$output ) {
    		if ( ! $element || ( 0 === $element->count && ! empty( $args[0]['hide_empty'] ) ) ) {
    			return;
    		}
    		parent::display_element( $element, $children_elements, $max_depth, $depth, $args, $output );
    	}
    }
}
