<?php
/**
* Taxonomy: Crisop Brands.
*/
if ( ! defined( 'ABSPATH' ) ) exit; // If this file is called directly, abort.
if ( ! class_exists( 'Ninetheme_Product_Brand' ) ) {
    class Ninetheme_Product_Brand {
        private static $instance = null;
        public static function get_instance() {
            if ( is_null( self::$instance ) ) {
                self::$instance = new self;
            }
            return self::$instance;
        }
        public function __construct() {
            add_action( 'init', array( $this, 'register_taxes' ) );
            // Set Brand taxonomy term when you duplicate the product
            add_action( 'woocommerce_product_duplicate', array( $this, 'product_duplicate' ), 10, 2 );

            add_action('ninetheme_product_brands_add_form_fields', array( $this, 'add_new_meta_field' ) );
            add_action('ninetheme_product_brands_edit_form_fields', array( $this, 'edit_meta_field' ), 10 );
            add_action('created_term', array( $this, 'save_category_fields2'), 10, 3 );
            add_action('edit_term', array( $this, 'save_category_fields2'), 10, 3 );
        }
        public function register_taxes() {
            $labels = [
                "name"                       => __( "Brands", "crisop" ),
                "singular_name"              => __( "Brand", "crisop" ),
                "menu_name"                  => __( "Brands", "crisop" ),
                "all_items"                  => __( "All Brands", "crisop" ),
                "edit_item"                  => __( "Edit Brand", "crisop" ),
                "view_item"                  => __( "View Brand", "crisop" ),
                "update_item"                => __( "Update Brand name", "crisop" ),
                "add_new_item"               => __( "Add new Brand", "crisop" ),
                "new_item_name"              => __( "New brand name", "crisop" ),
                "parent_item"                => __( "Parent Brand", "crisop" ),
                "parent_item_colon"          => __( "Parent Brand:", "crisop" ),
                "search_items"               => __( "Search Brands", "crisop" ),
                "popular_items"              => __( "Popular Brands", "crisop" ),
                "separate_items_with_commas" => __( "Separate brand with commas", "crisop" ),
                "add_or_remove_items"        => __( "Add or remove brand", "crisop" ),
                "choose_from_most_used"      => __( "Choose from the most used brand", "crisop" ),
                "not_found"                  => __( "No brand found", "crisop" ),
                "no_terms"                   => __( "No brand", "crisop" ),
                "items_list_navigation"      => __( "Brands list navigation", "crisop" ),
                "items_list"                 => __( "Brands list", "crisop" )
            ];
            $args = [
                "label"              => __( "Crisop Brands", "crisop" ),
                "labels"             => $labels,
                "public"             => true,
                "publicly_queryable" => true,
                "hierarchical"       => true,
                "show_ui"            => true,
                "show_in_menu"       => true,
                "show_in_nav_menus"  => true,
                "query_var"          => true,
                "has_archive"        => true,
                "rewrite"            => array(
                    'slug'         => apply_filters('ninetheme_product_brands_slug', 'product-brands' ),
                    'with_front'   => true,
                    'hierarchical' => false
                ),
                "show_admin_column"  => true,
                "show_in_quick_edit" => true,
                'capabilities'       => array(
                    'manage_terms' => 'manage_product_terms',
                    'edit_terms'   => 'edit_product_terms',
                    'delete_terms' => 'delete_product_terms',
                    'assign_terms' => 'assign_product_terms',
                ),
                'update_count_callback' => '_wc_term_recount'
            ];
            register_taxonomy( "ninetheme_product_brands", "product", $args );
            register_taxonomy_for_object_type( "ninetheme_product_brands", "product" );
        }
        /**
        * Set brands for duplicated product
        *
        * @param $duplicate
        * @param $product
        */
        public function product_duplicate( $duplicate, $product ) {
            $brands     = wp_get_object_terms( $product->get_id(), "ninetheme_product_brands" );
            $brands_ids = array();
            if ( count( $brands ) > 0 ) {
                foreach ( $brands as $brand ) {
                    $brands_ids[] = $brand->term_id;
                }
                wp_set_object_terms( $duplicate->get_id(), $brands_ids, "ninetheme_product_brands" );
            }
        }

        //Product Cat Create page
        public function add_new_meta_field() {
            wp_enqueue_media();
            ?>
            <div class="form-field ninetheme_term-brand_image-wrap">
                <label><?php esc_html_e( 'Brand Image', 'crisop' ); ?></label>
                <div id="ninetheme_product_brand_image" style="float: left; margin-right: 10px;"><img src="<?php echo esc_url( wc_placeholder_img_src() ); ?>" width="60px" height="60px" /></div>
                <div style="line-height: 60px;">
                    <input type="hidden" id="brand_thumbnail_id" name="brand_thumbnail_id" />
                    <button type="button" class="ninetheme_upload_image_button button"><?php esc_html_e( 'Upload/Add image', 'crisop' ); ?></button>
                    <button type="button" class="ninetheme_remove_image_button button"><?php esc_html_e( 'Remove image', 'crisop' ); ?></button>
                </div>
                <div class="clear"></div>
                <span class="description"><?php esc_html_e( 'Upload product brand image from here.', 'crisop'); ?></span>
                <script type="text/javascript">

                // Only show the "remove image" button when needed
                if ( ! jQuery( '#brand_thumbnail_id' ).val() ) {
                    jQuery( '.ninetheme_term-brand_image-wrap .ninetheme_remove_image_button' ).hide();
                }

                // Uploading files
                var ninetheme_brand_image_file_frame;

                jQuery( document ).on( 'click', '.ninetheme_term-brand_image-wrap .ninetheme_upload_image_button', function( event ) {

                    event.preventDefault();

                    // If the media frame already exists, reopen it.
                    if ( ninetheme_brand_image_file_frame ) {
                        ninetheme_brand_image_file_frame.open();
                        return;
                    }

                    // Create the media frame.
                    ninetheme_brand_image_file_frame = wp.media.frames.downloadable_file = wp.media({
                        title: '<?php esc_html_e( 'Choose an image', 'crisop' ); ?>',
                        button: {
                            text: '<?php esc_html_e( 'Use image', 'crisop' ); ?>'
                        },
                        multiple: false
                    });

                    // When an image is selected, run a callback.
                    ninetheme_brand_image_file_frame.on( 'select', function() {
                        var attachment           = ninetheme_brand_image_file_frame.state().get( 'selection' ).first().toJSON();
                        var attachment_thumbnail = attachment.sizes.thumbnail || attachment.sizes.full;

                        jQuery( '#brand_thumbnail_id' ).val( attachment.id );
                        jQuery( '#ninetheme_product_brand_image' ).find( 'img' ).attr( 'src', attachment_thumbnail.url );
                        jQuery( '.ninetheme_term-brand_image-wrap .ninetheme_remove_image_button' ).show();
                    });

                    // Finally, open the modal.
                    ninetheme_brand_image_file_frame.open();
                });

                jQuery( document ).on( 'click', '.ninetheme_term-brand_image-wrap .ninetheme_remove_image_button', function() {
                    jQuery( '#ninetheme_product_brand_image' ).find( 'img' ).attr( 'src', '<?php echo esc_js( wc_placeholder_img_src() ); ?>' );
                    jQuery( '#brand_thumbnail_id' ).val( '' );
                    jQuery( '.ninetheme_term-brand_image-wrap .ninetheme_remove_image_button' ).hide();
                    return false;
                });

                jQuery( document ).ajaxComplete( function( event, request, options ) {
                    if ( request && 4 === request.readyState && 200 === request.status
                        && options.data && 0 <= options.data.indexOf( 'action=add-tag' ) ) {

                            var res = wpAjax.parseAjaxResponse( request.responseXML, 'ajax-response' );
                            if ( ! res || res.errors ) {
                                return;
                            }
                            // Clear Thumbnail fields on submit
                            jQuery( '#ninetheme_product_brand_image' ).find( 'img' ).attr( 'src', '<?php echo esc_js( wc_placeholder_img_src() ); ?>' );
                            jQuery( '#brand_thumbnail_id' ).val( '' );
                            jQuery( '.ninetheme_term-brand_image-wrap .ninetheme_remove_image_button' ).hide();
                            return;
                        }
                    } );

                </script>
            </div>
            <div class="clear"></div>
            <?php
        }

        //Product Cat Edit page
        public function edit_meta_field( $term ) {

            $thumb_id = absint( get_term_meta( $term->term_id, 'thumbnail_id', true ) );
            $image    = $thumb_id ? wp_get_attachment_thumb_url( $thumb_id ) : wc_placeholder_img_src();

            wp_enqueue_media();
            ?>
            <tr class="form-field ninetheme_term-brand_image-wrap">
                <th scope="row" valign="top"><label><?php esc_html_e( 'Brand Image', 'crisop' ); ?></label></th>
                <td>
                    <div id="ninetheme_product_brand_image" style="float: left; margin-right: 10px;"><img src="<?php echo esc_url( $image ); ?>" width="60px" height="60px" /></div>
                    <div style="line-height: 60px;">
                        <input type="hidden" id="brand_thumbnail_id" name="brand_thumbnail_id" value="<?php echo esc_attr( $thumb_id ); ?>" />
                        <button type="button" class="ninetheme_upload_image_button button"><?php esc_html_e( 'Upload/Add image', 'crisop' ); ?></button>
                        <button type="button" class="ninetheme_remove_image_button button"><?php esc_html_e( 'Remove image', 'crisop' ); ?></button>
                    </div>
                    <div class="clear"></div>
                    <span class="description"><?php esc_html_e( 'Upload product brand image from here.', 'crisop'); ?></span>
                    <script type="text/javascript">

                        // Only show the "remove image" button when needed
                        if ( '0' === jQuery( '#brand_thumbnail_id' ).val() ) {
                            jQuery( '.ninetheme_term-brand_image-wrap .ninetheme_remove_image_button' ).hide();
                        }

                        // Uploading files
                        var ninetheme_brand_image_file_frame;

                        jQuery( document ).on( 'click', '.ninetheme_term-brand_image-wrap .ninetheme_upload_image_button', function( event ) {

                            event.preventDefault();

                            // If the media frame already exists, reopen it.
                            if ( ninetheme_brand_image_file_frame ) {
                                ninetheme_brand_image_file_frame.open();
                                return;
                            }

                            // Create the media frame.
                            ninetheme_brand_image_file_frame = wp.media.frames.downloadable_file = wp.media({
                                title: '<?php esc_html_e( 'Choose an image', 'crisop' ); ?>',
                                button: {
                                    text: '<?php esc_html_e( 'Use image', 'crisop' ); ?>'
                                },
                                multiple: false
                            });

                            // When an image is selected, run a callback.
                            ninetheme_brand_image_file_frame.on( 'select', function() {
                                var attachment           = ninetheme_brand_image_file_frame.state().get( 'selection' ).first().toJSON();
                                var attachment_thumbnail = attachment.sizes.thumbnail || attachment.sizes.full;

                                jQuery( '#brand_thumbnail_id' ).val( attachment.id );
                                jQuery( '#ninetheme_product_brand_image' ).find( 'img' ).attr( 'src', attachment_thumbnail.url );
                                jQuery( '.ninetheme_term-brand_image-wrap .ninetheme_remove_image_button' ).show();
                            });

                            // Finally, open the modal.
                            ninetheme_brand_image_file_frame.open();
                        });

                        jQuery( document ).on( 'click', '.ninetheme_term-brand_image-wrap .ninetheme_remove_image_button', function() {
                            jQuery( '#ninetheme_product_brand_image' ).find( 'img' ).attr( 'src', '<?php echo esc_js( wc_placeholder_img_src() ); ?>' );
                            jQuery( '#brand_thumbnail_id' ).val( '' );
                            jQuery( '.ninetheme_term-brand_image-wrap .ninetheme_remove_image_button' ).hide();
                            return false;
                        });

                    </script>
                    <div class="clear"></div>
                </td>
            </tr>
            <?php
        }

        public function save_category_fields2( $term_id, $tt_id = '', $taxonomy = '' ) {

            if ( isset( $_POST['brand_thumbnail_id'] ) && 'ninetheme_product_brands' === $taxonomy ) {
                update_term_meta( $term_id, 'thumbnail_id', absint( $_POST['brand_thumbnail_id'] ) );
            }
        }
    }
    Ninetheme_Product_Brand::get_instance();

    class Ninetheme_Widget_Product_Brands extends WP_Widget {

        // Widget Settings
        function __construct() {
            $widget_ops  = array('description' => esc_html__('For Main Shop Page.','crisop') );
            $control_ops = array( 'width' => 300, 'height' => 350, 'id_base' => 'ninetheme_product_brands' );
            parent::__construct( 'ninetheme_product_brands', esc_html__('Crisop Product Brands','crisop'), $widget_ops, $control_ops );
        }

        // Widget Output
        function widget( $args, $instance )
        {
            if ( is_shop() && !is_tax( 'ninetheme_product_brands' ) )
            {
                extract( $args );
                $title      = apply_filters( 'widget_title', empty($instance['title'] ) ? '' : $instance['title'], $instance );
                $exclude    = $instance['brand_exclude'];
                $hide_empty = $instance['hide_empty'];

                echo $before_widget;

                if ( $title ) {
                    echo $before_title . $title . $after_title;
                }

                echo '<div class="ninetheme-widget-product-brands widget-body site-checkbox-lists">';
                echo '<div class="site-scroll">';
                echo '<ul>';

                    echo wp_list_categories(array(
                        'echo'       => true,
                        'taxonomy'   => 'ninetheme_product_brands',
                        'tax_type'   => 'brand',
                        'count'      => true,
                        'depth'      => 1,
                        'hide_empty' => $hide_empty ? true : false,
                        'title_li'   => '',
                        'exclude'    => !empty( $exclude ) ? $exclude : '',
                        'walker'     => new Ninetheme_Widget_Product_Categories_Walker()
                    ));

                echo '</ul>';;
                echo '</div>';
                echo '</div>';

                echo $after_widget;
            }
        }

        // Update
        function update( $new_instance, $old_instance )
        {
            $instance = $old_instance;

            $instance['title']         = strip_tags($new_instance['title']);
            $instance['hide_empty']    = !empty( $new_instance['hide_empty'] ) ? $new_instance['hide_empty'] : '';
            $instance['brand_exclude'] = $new_instance['brand_exclude'];

            return $instance;
        }

        // Backend Form
        function form( $instance )
        {
            $defaults   = array('title' => 'Product Brands', 'brand_exclude' => array(), 'hide_empty' => 0 );
            $instance   = wp_parse_args(( array ) $instance, $defaults );
            $select     = is_array( $instance['brand_exclude'] ) ? $instance['brand_exclude'] : array();
            $hide_empty = $instance['hide_empty'] ? true : false;

            $terms = get_terms( array(
                'taxonomy'   => 'ninetheme_product_brands',
                'hide_empty' => $hide_empty,
                'parent'     => 0
            ));

            wp_enqueue_style( 'select2-full' );
            wp_enqueue_script( 'select2-full' );
            ?>

            <p>
                <label for="<?php echo $this->get_field_id('title'); ?>"><?php esc_html_e('Title:','crisop'); ?></label>
                <input class="widefat" id="<?php echo $this->get_field_id('title'); ?>" name="<?php echo $this->get_field_name('title'); ?>" value="<?php echo $instance['title']; ?>" />
            </p>
            <p>
                <label for="<?php echo $this->get_field_id('hide_empty'); ?>"><?php esc_html_e( 'Hide if empty:','crisop' ); ?></label>
                <input type="checkbox" class="widefat" id="<?php echo $this->get_field_id('hide_empty'); ?>" name="<?php echo $this->get_field_name('hide_empty'); ?>" value="1" <?php checked( $instance['hide_empty'], 1 ); ?> />
            </p>
            <p>
                <label for="<?php echo $this->get_field_id('brand_exclude'); ?>"><?php esc_html_e( 'Exclude Brand(s):','crisop' ); ?></label>
                <select class="ninetheme-select2" id="<?php echo $this->get_field_id('brand_exclude'); ?>" name="<?php echo $this->get_field_name('brand_exclude'); ?>[]" multiple="multiple">
                    <?php foreach ( $terms as $term ) {
                        $selected = in_array( $term->term_id, $select) ? 'selected="selected"' : '';
                        ?>
                        <option value="<?php echo $term->term_id; ?>" <?php echo $selected; ?>><?php echo $term->name; ?></option>
                    <?php } ?>
                </select>
            </p>

            <?php
        }
    }

    // Add Widget
    function ninetheme_widget_product_brands_init() {
        register_widget('Ninetheme_Widget_Product_Brands');
    }
    add_action('widgets_init', 'ninetheme_widget_product_brands_init');
}
