<?php
/**
* Taxonomy: Crisop Campaigns.
*/
if ( ! defined( 'ABSPATH' ) ) exit; // If this file is called directly, abort.
if ( ! class_exists( 'Ninetheme_Product_Campaigns' ) ) {
    class Ninetheme_Product_Campaigns {
        private static $instance = null;
        public static function get_instance() {
            if ( is_null( self::$instance ) ) {
                self::$instance = new self;
            }
            return self::$instance;
        }
        public function __construct() {
            add_action( 'init', array( $this, 'register_taxes' ) );
            // Set Campaign taxonomy term when you duplicate the product
            add_action( 'woocommerce_product_duplicate', array( $this, 'woocommerce_product_duplicate' ), 10, 2 );

            add_action('ninetheme_product_campaigns_add_form_fields', array( $this, 'add_new_meta_field' ));
            add_action('ninetheme_product_campaigns_edit_form_fields', array( $this, 'edit_meta_field' ), 10, 2);
            add_action('edited_ninetheme_product_campaigns', array( $this, 'save_taxonomy_custom_meta'));
            add_action('create_ninetheme_product_campaigns', array( $this, 'save_taxonomy_custom_meta'));
        }
        public function register_taxes() {
            $labels = [
                "name"                       => __( "Campaigns", "crisop" ),
                "singular_name"              => __( "Campaign", "crisop" ),
                "menu_name"                  => __( "Campaigns", "crisop" ),
                "all_items"                  => __( "All Campaigns", "crisop" ),
                "edit_item"                  => __( "Edit Campaign", "crisop" ),
                "view_item"                  => __( "View Campaign", "crisop" ),
                "update_item"                => __( "Update Campaign name", "crisop" ),
                "add_new_item"               => __( "Add new Campaign", "crisop" ),
                "new_item_name"              => __( "New brand name", "crisop" ),
                "parent_item"                => __( "Parent Campaign", "crisop" ),
                "parent_item_colon"          => __( "Parent Campaign:", "crisop" ),
                "search_items"               => __( "Search Campaigns", "crisop" ),
                "popular_items"              => __( "Popular Campaigns", "crisop" ),
                "separate_items_with_commas" => __( "Separate brand with commas", "crisop" ),
                "add_or_remove_items"        => __( "Add or remove brand", "crisop" ),
                "choose_from_most_used"      => __( "Choose from the most used brand", "crisop" ),
                "not_found"                  => __( "No brand found", "crisop" ),
                "no_terms"                   => __( "No brand", "crisop" ),
                "items_list_navigation"      => __( "Campaigns list navigation", "crisop" ),
                "items_list"                 => __( "Campaigns List", "crisop" )
            ];
            $args = [
                "label"              => __( "Crisop Campaigns", "crisop" ),
                "labels"             => $labels,
                "public"             => true,
                "publicly_queryable" => true,
                "hierarchical"       => true,
                "show_ui"            => true,
                "show_in_menu"       => true,
                "show_in_nav_menus"  => true,
                "query_var"          => true,
                "has_archive"        => true,
                "rewrite"            => array(
                    'slug' => 'product-campaign',
                    'with_front'   => true,
                    'hierarchical' => true
                ),
                "show_admin_column"  => true,
                "show_in_quick_edit" => true,
                'capabilities'       => array(
                    'manage_terms' => 'manage_product_terms',
                    'edit_terms'   => 'edit_product_terms',
                    'delete_terms' => 'delete_product_terms',
                    'assign_terms' => 'assign_product_terms',
                ),
                'update_count_callback' => '_wc_term_recount'
            ];
            register_taxonomy( "ninetheme_product_campaigns", "product", $args );
            register_taxonomy_for_object_type( "ninetheme_product_campaigns", "product" );
        }
        /**
        * Set campaign for duplicated product
        *
        * @param $duplicate
        * @param $product
        */
        public function woocommerce_product_duplicate( $duplicate, $product ) {
            $campaigns     = wp_get_object_terms( $product->get_id(), "ninetheme_product_campaigns" );
            $campaigns_ids = array();
            if ( count( $campaigns ) > 0 ) {
                foreach ( $campaigns as $campaign ) {
                    $campaigns_ids[] = $campaign->term_id;
                }
                wp_set_object_terms( $duplicate->get_id(), $campaigns_ids, "ninetheme_product_campaigns" );
            }
        }

        //Product Cat Create page
        public function add_new_meta_field($taxonomy) {
            ?>
            <p class="form-field ninetheme_wc_campaign_banner_field">
            <label for="ninetheme_wc_campaign_banner"><?php esc_html_e( 'Crisop Campaign Banner', 'crisop' ); ?></label>
            <textarea name="ninetheme_wc_campaign_banner" id="ninetheme_wc_campaign_banner" rows="4"></textarea>
            <span class="description"><?php esc_html_e( 'If you want to show a different banner on the archive taxonomy page for this campaign, use this field.Iframe,shortcode,HTML content allowed.', 'crisop' ); ?></span>
            </p>
            <div class="clear"></div>
            <?php
        }

        //Product Cat Edit page
        public function edit_meta_field($term, $taxonomy) {

            $t_id = $term->term_id;
            $value = wp_unslash(get_option( "taxonomy_$t_id" ));
            ?>
            <tr class="form-field term-ninetheme-banner-wrap">
                <th scope="row" valign="top"><label for="ninetheme_wc_campaign_banner"><?php esc_html_e('Crisop Campaign Banner', 'crisop'); ?></label></th>
                <td>
                    <textarea name="ninetheme_wc_campaign_banner" id="ninetheme_wc_campaign_banner" rows="5" cols="50" class="large-text"><?php echo esc_html( $value ) ? $value : ''; ?></textarea>
                    <p class="description"><?php esc_html_e('If you want to show a different banner on the archive taxonomy page for this campaign, use this field.Iframe,shortcode,HTML content allowed.', 'crisop'); ?></p>
                </td>
            </tr>
            <?php
        }

        // Save extra taxonomy fields callback function.
        public function save_taxonomy_custom_meta( $term_id ) {
            if ( isset( $_POST['ninetheme_wc_campaign_banner'] ) ) {
                $termid = $term_id;
                $meta = get_option( "taxonomy_$termid");
                if ( $meta !== false ) {
                    update_option( "taxonomy_$termid",wp_unslash($_POST['ninetheme_wc_campaign_banner']) );
                }else{
                     add_option( "taxonomy_$termid",$_POST['ninetheme_wc_campaign_banner'] , '', 'yes' );
                }
            }
        }
    }
    Ninetheme_Product_Campaigns::get_instance();

    class Ninetheme_Widget_Product_Campaigns extends WP_Widget {

        // Widget Settings
        function __construct() {
            $widget_ops  = array('description' => esc_html__('For Main Shop Page.','crisop') );
            $control_ops = array( 'width' => 300, 'height' => 350, 'id_base' => 'ninetheme_product_campaigns' );
            parent::__construct( 'ninetheme_product_campaigns', esc_html__('Crisop Product Campaigns','crisop'), $widget_ops, $control_ops );
        }

        // Widget Output
        function widget( $args, $instance )
        {
            if ( is_shop() && !is_tax('product-brands') )
            {
                extract( $args );
                $title      = apply_filters( 'widget_title', empty($instance['title'] ) ? '' : $instance['title'], $instance );
                $exclude    = $instance['campaigns_exclude'];
                $hide_empty = $instance['hide_empty'];

                echo $before_widget;

                if ( $title ) {
                    echo $before_title . $title . $after_title;
                }

                echo '<div class="ninetheme-widget-product-brands widget-body site-checkbox-lists">';
                echo '<div class="site-scroll">';
                echo '<ul>';

                    echo wp_list_categories(array(
                        'echo'       => true,
                        'taxonomy'   => 'ninetheme_product_campaigns',
                        'tax_type'   => 'campaign',
                        'count'      => true,
                        'depth'      => 1,
                        'hide_empty' => $hide_empty ? true : false,
                        'title_li'   => '',
                        'exclude'    => !empty( $exclude ) ? $exclude : '',
                        'walker'     => new Ninetheme_Widget_Product_Categories_Walker()
                    ));

                echo '</ul>';;
                echo '</div>';
                echo '</div>';

                echo $after_widget;
            }
        }

        // Update
        function update( $new_instance, $old_instance )
        {
            $instance = $old_instance;

            $instance['title']         = strip_tags($new_instance['title']);
            $instance['hide_empty']    = !empty( $new_instance['hide_empty'] ) ? $new_instance['hide_empty'] : '';
            $instance['campaigns_exclude'] = $new_instance['campaigns_exclude'];

            return $instance;
        }

        // Backend Form
        function form( $instance )
        {
            $defaults   = array('title' => 'Product Campaigns', 'campaigns_exclude' => array(), 'hide_empty' => 0 );
            $instance   = wp_parse_args(( array ) $instance, $defaults );
            $select     = is_array( $instance['campaigns_exclude'] ) ? $instance['campaigns_exclude'] : array();
            $hide_empty = $instance['hide_empty'] ? true : false;

            $terms = get_terms( array(
                'taxonomy'   => 'ninetheme_product_campaigns',
                'hide_empty' => $hide_empty,
                'parent'     => 0
            ));

            wp_enqueue_style( 'select2-full' );
            wp_enqueue_script( 'select2-full' );
            ?>

            <p>
                <label for="<?php echo $this->get_field_id('title'); ?>"><?php esc_html_e('Title:','crisop'); ?></label>
                <input class="widefat" id="<?php echo $this->get_field_id('title'); ?>" name="<?php echo $this->get_field_name('title'); ?>" value="<?php echo $instance['title']; ?>" />
            </p>
            <p>
                <label for="<?php echo $this->get_field_id('hide_empty'); ?>"><?php esc_html_e( 'Hide if empty:','crisop' ); ?></label>
                <input type="checkbox" class="widefat" id="<?php echo $this->get_field_id('hide_empty'); ?>" name="<?php echo $this->get_field_name('hide_empty'); ?>" value="1" <?php checked( $instance['hide_empty'], 1 ); ?> />
            </p>
            <p>
                <label for="<?php echo $this->get_field_id('campaigns_exclude'); ?>"><?php esc_html_e( 'Exclude Brand(s):','crisop' ); ?></label>
                <select class="ninetheme-select2" id="<?php echo $this->get_field_id('campaigns_exclude'); ?>" name="<?php echo $this->get_field_name('campaigns_exclude'); ?>[]" multiple="multiple">
                    <?php foreach ( $terms as $term ) {
                        $selected = in_array( $term->term_id, $select) ? 'selected="selected"' : '';
                        ?>
                        <option value="<?php echo $term->term_id; ?>" <?php echo $selected; ?>><?php echo $term->name; ?></option>
                    <?php } ?>
                </select>
            </p>
            <?php
        }
    }

    // Add Widget
    function ninetheme_widget_product_campaigns_init() {
        register_widget('Ninetheme_Widget_Product_Campaigns');
    }
    add_action('widgets_init', 'ninetheme_widget_product_campaigns_init');
}
