<?php

/**
* Taxonomy: Ninetheme Popup Builder
*/
if ( ! defined( 'ABSPATH' ) ) exit; // If this file is called directly, abort.
if ( ! class_exists( 'Ninetheme_Location_Taxonomy' ) ) {
    class Ninetheme_Location_Taxonomy {

        private static $instance = null;

        public static function get_instance()
        {
            if ( is_null( self::$instance ) ) {
                self::$instance = new self;
            }
            return self::$instance;
        }

        public function __construct()
        {
            add_action( 'init', array( $this, 'taxonomy_location' ) );
            // Set Campaign taxonomy term when you duplicate the product
            add_action( 'woocommerce_product_duplicate', array( $this, 'product_duplicate' ), 10, 2 );
            add_filter( 'query_vars', array( $this, 'query_vars' ) );
            add_action( 'pre_get_posts', array( $this, 'location_product_query' ) );
            add_shortcode( 'ninetheme_location', [ $this, 'location_shortcode' ] );
        }

        /*************************************************
        ## Register Location Taxonomy
        *************************************************/
        function taxonomy_location()
        {
            $labels = [
                "name"                       => esc_html__( "Locations", "decoraty" ),
                "singular_name"              => esc_html__( "Location", "decoraty" ),
                "menu_name"                  => esc_html__( "Locations", "decoraty" ),
                "all_items"                  => esc_html__( "All Locations", "decoraty" ),
                "edit_item"                  => esc_html__( "Edit Location", "decoraty" ),
                "view_item"                  => esc_html__( "View Location", "decoraty" ),
                "update_item"                => esc_html__( "Update Location name", "decoraty" ),
                "add_new_item"               => esc_html__( "Add new Location", "decoraty" ),
                "new_item_name"              => esc_html__( "New Location name", "decoraty" ),
                "parent_item"                => esc_html__( "Parent Location", "decoraty" ),
                "parent_item_colon"          => esc_html__( "Parent Location:", "decoraty" ),
                "search_items"               => esc_html__( "Search Locations", "decoraty" ),
                "popular_items"              => esc_html__( "Popular Locations", "decoraty" ),
                "separate_items_with_commas" => esc_html__( "Separate Locations with commas", "decoraty" ),
                "add_or_remove_items"        => esc_html__( "Add or remove Locations", "decoraty" ),
                "choose_from_most_used"      => esc_html__( "Choose from the most used locations", "decoraty" ),
                "not_found"                  => esc_html__( "No Locations found", "decoraty" ),
                "no_terms"                   => esc_html__( "No Locations", "decoraty" ),
                "items_list_navigation"      => esc_html__( "Locations list navigation", "decoraty" ),
                "items_list"                 => esc_html__( "Locations list", "decoraty" ),
                "back_to_items"              => esc_html__( "Back to Locations", "decoraty" )
            ];

            $args = [
                "label"                 => esc_html__( "Locations", "decoraty" ),
                "labels"                => $labels,
                "public"                => true,
                "publicly_queryable"    => true,
                "hierarchical"          => true,
                "show_ui"               => true,
                "show_in_menu"          => true,
                "show_in_nav_menus"     => true,
                "query_var"             => true,
                "rewrite"               => [
                    'slug'         => 'location',
                    'with_front'   => true,
                    'hierarchical' => false
                ],
                "show_admin_column"     => true,
                "show_in_rest"          => true,
                "show_tagcloud"         => true,
                "rest_base"             => "location",
                "rest_controller_class" => "WP_REST_Terms_Controller",
                "show_in_quick_edit"    => true,
                "sort"                  => true,
                'update_count_callback' => '_wc_term_recount'
            ];
            register_taxonomy( "location", [ "product", "shop_coupon" ], $args );
            register_taxonomy_for_object_type( 'location', [ "product", "shop_coupon" ] );
        }

        /**
        * Set campaign for duplicated product
        *
        * @param $duplicate
        * @param $product
        */
        public function product_duplicate( $duplicate, $product ) {
            $locations    = wp_get_object_terms( $product->get_id(), "location" );
            $location_ids = array();
            if ( count( $locations ) > 0 ) {
                foreach ( $locations as $location ) {
                    $location_ids[] = $location->term_id;
                }
                wp_set_object_terms( $duplicate->get_id(), $location_ids, "location" );
            }
        }

        /*************************************************
        ## Query Vars
        *************************************************/
        public function query_vars( $query_vars )
        {
            $query_vars[] = 'ninetheme_location_query';
            return $query_vars;
        }

        /*************************************************
        ## Product Query for Shortcodes
        *************************************************/
        public function location_product_query( $query )
        {
            if ( isset( $query->query_vars['ninetheme_location_query'] ) && $this->get_location() != 'all' ) {
                $tax_query[] = array(
                    'taxonomy' => 'location',
                    'field'    => 'slug',
                    'terms'    => $this->get_location()
                );

                $query->set( 'tax_query', $tax_query );
            }
        }

        public function product_query_tax_query( $tax_query, $instance ) {

            if ( taxonomy_exists( 'location' ) ) {
                if ( $this->get_location() != 'all' ) {
                    $tax_query[] = array(
                        'taxonomy' => 'location',
                        'field'    => 'slug',
                        'terms'    => $this->get_location()
                    );
                }
            }

            if ( isset( $_GET['filter_cat'] ) ) {
                if ( !empty( $_GET['filter_cat'] ) ) {
                    $tax_query[] = array(
                        'taxonomy' => 'product_cat',
                        'field'    => 'id',
                        'terms'    => explode( ',',$_GET['filter_cat'] )
                    );
                }
            }

            return $tax_query;
        }


        /*************************************************
        ## Location Cokkie
        *************************************************/
        public function get_location()
        {
            $location = isset( $_COOKIE['location'] ) ? $_COOKIE['location'] : 'all';
            if ( $location ) {
                return $location;
            }
        }

        public function location_shortcode( $attr = '' )
        {
            $args = shortcode_atts(array(
                'class'            => '',
                'subtitle'         => '',
                'hide_subtitle'    => '',
                'subtitle_position'=> '',
                'title'            => '',
                'hide_inner_title' => '',
                'inner_title'      => '',
                'hide_inner_desc'  => '',
                'inner_desc'       => '',
                'placeholder'      => '',
                'select_text'      => '',
                'clear_text'       => ''
            ), $attr );

            $terms = get_terms( array(
                'taxonomy'   => 'location',
                'hide_empty' => false,
                'parent'     => 0
            ));

            $class = $args['class'] != '' ? ' '.$args['class'] : '';

            $subtitle    = $args['subtitle'] ? $args['subtitle'] : esc_html__( 'Your Location', 'crisop' );
            $title       = $args['title'] ? $args['title'] : esc_html__( 'Select a Location', 'crisop' );
            $inner_title = $args['inner_title'] ? $args['inner_title'] : esc_html__( 'Choose your Delivery Location', 'crisop' );
            $inner_desc  = $args['inner_desc'] ? $args['inner_desc'] : esc_html__( 'Enter your address and we will specify the offer for your area.', 'crisop' );
            $placeholder = $args['placeholder'] ? $args['placeholder'] : esc_html__( 'Search your area', 'crisop' );
            $select_text = $args['select_text'] ? $args['select_text'] : esc_html__( 'Select a Location', 'crisop' );
            $clear_text  = $args['clear_text'] ? $args['clear_text'] : esc_html__( 'Clear All', 'crisop' );

            wp_enqueue_script( 'jquery-cookie');
            wp_enqueue_style( 'select2-full');
            wp_enqueue_script( 'select2-full');

            ob_start();
            ?>
            <div class="ninetheme-header-location <?php echo esc_attr( $class ); ?>">
                <div class="ninetheme-header-location-trigger">
                    <?php if ( 'yes' != $args['hide_subtitle'] && 'bottom' != $args['subtitle_position'] ) { ?>
                        <span class="ninetheme-header-location-description"><?php echo esc_html( $subtitle ); ?></span>
                    <?php } ?>
                    <?php if ( $this->get_location() && 'all' != $this->get_location() ) { ?>
                        <div class="ninetheme-header-current-location active"><?php esc_html_e( $this->get_location() ); ?></div>
                    <?php } else { ?>
                        <div class="ninetheme-header-current-location"><?php echo esc_html( $title ); ?></div>
                    <?php } ?>
                    <?php if ( 'yes' != $args['hide_subtitle'] && 'bottom' == $args['subtitle_position'] ) { ?>
                        <span class="ninetheme-header-location-description"><?php echo esc_html( $subtitle ); ?></span>
                    <?php } ?>
                </div>

                <div class="ninetheme-select-location">
                    <div class="ninetheme-select-location-wrapper">
                        <?php if ( 'yes' != $args['hide_inner_title'] ) { ?>
                            <h6 class="ninetheme-location-title"><?php echo esc_html( $inner_title ); ?></h6>
                        <?php } ?>
                        <?php if ( 'yes' != $args['hide_inner_desc'] ) { ?>
                            <div class="ninetheme-location-description"><?php echo esc_html( $inner_desc ); ?></div>
                        <?php } ?>
                        <div class="ninetheme-search-location">
                            <select size="8" name="ninetheme-location-area" class="ninetheme-location-area" data-placeholder="<?php echo esc_attr( $placeholder ); ?>">
                                <option value="all" data-min="<?php echo esc_attr( $clear_text ); ?>"><?php echo esc_html( $select_text ); ?></option>
                                <?php
                                foreach ( $terms as $term ) {
                                    $select = $term->slug == $this->get_location() ? ' selected' : '';
                                    ?>
                                    <option value="<?php echo esc_attr( $term->slug ); ?>" data-min="<?php echo esc_attr( $term->description ); ?>"<?php echo esc_attr( $select ); ?>><?php echo esc_html( $term->name ); ?></option>
                                    <?php
                                }
                                ?>
                            </select>
                        </div>
                    </div>
                </div>
            </div>
            <?php
            return ob_get_clean();
        }
    }
    Ninetheme_Location_Taxonomy::get_instance();
}
