<?php
/**
* Ninetheme_Wishlist
*/
if ( ! defined( 'ABSPATH' ) ) exit; // If this file is called directly, abort.
if ( ! class_exists( 'Ninetheme_Wishlist' ) ) {
    class Ninetheme_Wishlist {
        private static $instance = null;
        public static function get_instance() {
            if ( is_null( self::$instance ) ) {
                self::$instance = new self;
            }
            return self::$instance;
        }

        function __construct()
        {
            if ( ! class_exists('WooCommerce') ) {
                return;
            }
            // frontend scripts
            add_action( 'wp_enqueue_scripts', array( $this, 'wp_enqueue_scripts' ) );
            // print template
            add_action( 'ninetheme_side_panel_header_after_cart', array( $this, 'template_header' ), 10 );
            add_action( 'ninetheme_side_panel_content_after_cart', array( $this, 'template_content' ) );
            add_action( 'ninetheme_mobile_panel_content_after_cart', array( $this, 'template_mobile_header_content' ) );
            // add wishlist
            add_action( 'wp_ajax_ninetheme_wishlist_add', array( $this, 'wishlist_add' ) );
            add_action( 'wp_ajax_nopriv_ninetheme_wishlist_add', array( $this, 'wishlist_add' ) );
            // remove wishlist
            add_action( 'wp_ajax_ninetheme_wishlist_remove', array( $this, 'wishlist_remove' ) );
            add_action( 'wp_ajax_nopriv_ninetheme_wishlist_remove', array( $this, 'wishlist_remove' ) );

            // user login & logout
            add_action( 'wp_login', array( $this, 'wishlist_wp_login' ), 10, 2 );
            add_action( 'wp_logout', array( $this, 'wishlist_wp_logout' ), 10, 1 );
        }

        function wp_enqueue_scripts()
        {
            // localize
            wp_enqueue_script( 'ninetheme-wishlist', NINETHEME_PLUGIN_URL . 'widgets/woocommerce/wishlist/css-js/wishlist.js', array( 'jquery' ), NINETHEME_PLUGIN_VERSION, true );
            wp_localize_script( 'ninetheme-wishlist', 'wishlist_vars', array(
                    'ajax_url' => admin_url( 'admin-ajax.php' ),
                    'count' => $this->get_count(),
                    'products' => $this->get_products(),
                    'nonce'    => wp_create_nonce( 'ninetheme-wishlist-nonce' ),
                    'user_id'  => md5( 'ninetheme_wishlist_' . get_current_user_id() ),
                )
            );
        }

        function template_header()
        {
            ?>
            <div class="panel-header-wishlist panel-header-btn" data-name="wishlist">
                <span class="ninetheme-wishlist-count ninetheme-wc-count"><?php echo esc_html( $this->get_count() ); ?></span>
                <?php echo ninetheme_svg_lists( 'love', 'ninetheme-svg-icon' ); ?>
            </div>
            <?php
        }

        function template_mobile_header_content()
        {
            $url = !is_shop() ? apply_filters( 'woocommerce_return_to_shop_redirect', wc_get_page_permalink( 'shop' ) ) : '#0';
            $btn_class = is_shop() ? ' ninetheme-panel-close' : '';
            $key = self::get_key();
            $products = get_option( 'ninetheme_wishlist_' . $key );
            $count = is_array( $products ) && ( count( $products ) > 0 ) ? count( $products ) : '0';
            ?>
            <div class="wishlist-area action-content" data-target-name="wishlist" data-wishlist-count="<?php echo esc_attr( $count ); ?>">
                <div class="wishlist-content">
                    <?php if ( function_exists('ninetheme_settings') && '' != ninetheme_settings('sidebar_panel_wishlist_custom_title') ) { ?>
                        <span class="panel-top-title"><?php echo esc_html( ninetheme_settings('sidebar_panel_wishlist_custom_title') ); ?></span>
                    <?php } else { ?>
                        <span class="panel-top-title"><?php esc_html_e( 'Your Wishlist', 'crisop' ); ?></span>
                    <?php } ?>
                    <div class="ninetheme-panel-content-items ninetheme-wishlist-content-items ninetheme-scrollbar">
                        <?php $this->print_wishlist(); ?>
                    </div>
                    <div class="ninetheme-panel-content-notice ninetheme-wishlist-content-notice ninetheme-empty-content">
                        <?php if ( !$this->get_count() ) { ?>
                            <?php echo ninetheme_svg_lists( 'love', 'ninetheme-big-svg-icon' ); ?>
                            <div class="ninetheme-small-title"><?php esc_html_e( 'There are no products on the wishlist!', 'crisop' ); ?></div>
                            <a class="ninetheme-btn-small mt-10<?php echo esc_attr( $btn_class ); ?>" href="<?php echo esc_url( $url ); ?>"><?php esc_html_e( 'Start Shopping', 'crisop' ); ?></a>
                        <?php } ?>
                    </div>
                </div>
            </div>
            <?php
        }

        function template_content()
        {
            $url = !is_shop() ? apply_filters( 'woocommerce_return_to_shop_redirect', wc_get_page_permalink( 'shop' ) ) : '#0';
            $btn_class = is_shop() ? ' ninetheme-panel-close' : '';
            $key = self::get_key();
            $products = get_option( 'ninetheme_wishlist_' . $key );
            $count = is_array( $products ) && ( count( $products ) > 0 ) ? count( $products ) : '0';
            ?>
            <div class="wishlist-area panel-content-item" data-name="wishlist" data-wishlist-count="<?php echo esc_attr( $count ); ?>">
                <div class="wishlist-content">
                    <?php if ( function_exists('ninetheme_settings') && '' != ninetheme_settings('sidebar_panel_wishlist_custom_title') ) { ?>
                        <span class="panel-top-title"><?php echo esc_html( ninetheme_settings('sidebar_panel_wishlist_custom_title') ); ?></span>
                    <?php } else { ?>
                        <span class="panel-top-title"><?php esc_html_e( 'Your Wishlist', 'crisop' ); ?></span>
                    <?php } ?>
                    <div class="ninetheme-panel-content-items ninetheme-wishlist-content-items ninetheme-scrollbar">
                        <?php $this->print_wishlist(); ?>
                    </div>
                    <div class="ninetheme-panel-content-notice ninetheme-wishlist-content-notice ninetheme-empty-content">
                        <?php if ( !$this->get_count() ) { ?>
                            <?php echo ninetheme_svg_lists( 'love', 'ninetheme-big-svg-icon' ); ?>
                            <div class="ninetheme-small-title"><?php esc_html_e( 'There are no products on the wishlist!', 'crisop' ); ?></div>
                            <a class="ninetheme-btn-small mt-10<?php echo esc_attr( $btn_class ); ?>" href="<?php echo esc_url( $url ); ?>"><?php esc_html_e( 'Start Shopping', 'crisop' ); ?></a>
                        <?php } ?>
                    </div>
                </div>
            </div>
            <?php
        }

        function print_wishlist()
        {
            $key = self::get_key();
            $products = get_option( 'ninetheme_wishlist_' . $key );

            if ( is_array( $products ) && ( count( $products ) > 0 ) ) {

                foreach ( $products as $product_id => $product_data ) {
                    $product = wc_get_product( $product_id );

                    if ( ! $product ) {
                        continue;
                    }
                    $stock_status = $product->is_in_stock() ? esc_html__( 'In stock', 'crisop' ) : esc_html__( 'Out of stock', 'crisop' );
                    ?>
                    <div class="ninetheme-content-item ninetheme-wishlist-item" data-id="<?php echo esc_attr( $product_id ); ?>" data-key="<?php echo esc_attr( $key ); ?>">
                        <div class="ninetheme-content-item-inner">
                            <?php
                            $imgurl = get_the_post_thumbnail_url($product->get_id(),'ninetheme-panel');
                            $imgsrc = $imgurl ? $imgurl : wc_placeholder_img_src();
                            $img    = '<img width="60" height="90" src="'.$imgsrc.'" alt="'.$product->get_name().'"/>';
                            echo sprintf( '<a href="%s">%s</a>',
                                esc_url( $product->get_permalink() ),
                                $img
                            );
                            ?>
                            <div class="ninetheme-content-info">
                                <div class="ninetheme-small-title">
                                    <a class="ninetheme-content-link" data-id="<?php echo esc_attr( $product_id ); ?>" href="<?php echo esc_url( $product->get_permalink() ); ?>">
                                        <span class="product-stock ninetheme-stock"> <?php echo esc_html( $stock_status ); ?></span>
                                        <span class="product-name"><?php echo esc_html( $product->get_name() ); ?></span>
                                        <?php if ( $product->get_price_html() ) { ?>
                                            <span class="product-price ninetheme-price"><?php printf('%s', $product->get_price_html() ); ?></span>
                                        <?php } ?>
                                    </a>
                                </div>
                                <?php echo do_shortcode('[add_to_cart style="" show_price="false" id="'.$product_id.'"]'); ?>
                            </div>
                            <div class="ninetheme-content-del-icon ninetheme-wishlist-del-icon"><?php echo ninetheme_svg_lists( 'trash', 'ninetheme-svg-icon mini-icon' ); ?></div>
                        </div>
                    </div>
                    <?php
                }
            }
        }

        function get_items( $key )
        {
            $key = self::get_key();
            $products = get_option( 'ninetheme_wishlist_' . $key );

            ob_start();

            if ( is_array( $products ) && ( count( $products ) > 0 ) ) {

                foreach ( $products as $product_id => $product_data ) {
                    $product = wc_get_product( $product_id );

                    if ( ! $product ) {
                        continue;
                    }
                    $stock_status = $product->is_in_stock() ? esc_html__( 'In stock', 'crisop' ) : esc_html__( 'Out of stock', 'crisop' );
                    ?>
                    <div class="ninetheme-content-item ninetheme-wishlist-item" data-id="<?php echo esc_attr( $product_id ); ?>" data-key="<?php echo esc_attr( $key ); ?>">
                        <div class="ninetheme-content-item-inner">
                            <?php
                            $imgurl = get_the_post_thumbnail_url($product->get_id(),'ninetheme-panel');
                            $imgsrc = $imgurl ? $imgurl : wc_placeholder_img_src();
                            $img    = '<img width="80" height="80" src="'.$imgsrc.'" alt="'.$product->get_name().'"/>';
                            echo sprintf( '<a href="%s">%s</a>',
                                esc_url( $product->get_permalink() ),
                                $img
                            );
                            ?>
                            <div class="ninetheme-content-info">
                                <div class="ninetheme-small-title">
                                    <a class="ninetheme-content-link" data-id="<?php echo esc_attr( $product_id ); ?>" href="<?php echo esc_url( $product->get_permalink() ); ?>">
                                        <span class="product-stock ninetheme-stock"> <?php echo esc_html( $stock_status ); ?></span>
                                        <span class="product-name"><?php echo esc_html( $product->get_name() ); ?></span>
                                        <?php if ( $product->get_price_html() ) { ?>
                                            <span class="product-price ninetheme-price"><?php printf('%s', $product->get_price_html() ); ?></span> /
                                        <?php } ?>
                                    </a>
                                </div>
                                <?php echo do_shortcode('[add_to_cart style="" class="ninetheme-quick-shop-btn" show_price="false" id="'.$product_id.'"]'); ?>
                            </div>
                            <div class="ninetheme-content-del-icon ninetheme-wishlist-del-icon"><?php echo ninetheme_svg_lists( 'trash', 'ninetheme-svg-icon mini-icon' ); ?></div>
                        </div>
                    </div>
                    <?php
                }
            }
            $html = ob_get_clean();

            return $html;
        }

        function wishlist_add()
        {
            $return = array( 'status' => 0 );
            $product_id = absint( $_POST['product_id'] );
            if ( $product_id > 0 ) {
                $key = self::get_key();

                if ( $key === '#' ) {
                    $return['status'] = 0;
                    $return['notice'] = esc_html__( 'Please log in to use the wishlist!', 'crisop' );
                    $return['value']  = esc_html__( 'There are no products on the wishlist!', 'crisop' );
                } else {
                    $products = get_option( 'ninetheme_wishlist_' . $key ) ? get_option( 'ninetheme_wishlist_' . $key ) : array();
                    $product  = wc_get_product( $product_id );
                    if ( ! array_key_exists( $product_id, $products ) ) {
                        $products = array(
                            $product_id => array('time' => time() )
                        ) + $products;
                        update_option( 'ninetheme_wishlist_' . $key, $products );
                        $this->update_meta( $product_id, 'ninetheme_wishlist_add' );
                        $return['notice'] = sprintf('<p class="ninetheme-small-title message"><span class="product-name">"%s"</span> <span>%s</span></p>',
                            esc_html( $product->get_name() ),
                            esc_html__( 'Added to the wishlist!', 'crisop' )
                        );
                    } else {
                        $return['notice'] = sprintf('<p class="ninetheme-small-title message"><span class="product-name">"%s"</span> <span>%s</span></p>',
                            esc_html( $product->get_name() ),
                            esc_html__( 'Already in the wishlist!', 'crisop' )
                        );
                    }

                    $return['status'] = 1;
                    $return['count']  = count( $products );
                    $return['value'] = $this->get_items( $key );
                    $return['products'] = $products;
                }
            } else {
                $product_id       = 0;
                $return['status'] = 0;
                $return['notice'] = esc_html__( 'Have an error, please try again!', 'crisop' );
            }

            echo json_encode( $return );
            die();
        }

        function wishlist_remove()
        {
            $return     = array( 'status' => 0 );
            $product_id = absint( $_POST['product_id'] );
            $icon       = ninetheme_svg_lists( 'love', 'ninetheme-big-svg-icon' );
            $url        = !is_shop() ? apply_filters( 'woocommerce_return_to_shop_redirect', wc_get_page_permalink( 'shop' ) ) : '#0';
            $btn_class  = is_shop() ? ' ninetheme-panel-close' : '';

            if ( $product_id > 0 ) {
                $key = self::get_key();

                if ( $key === '#' ) {
                    $return['notice'] = esc_html__( 'Please log in to use the wishlist!', 'crisop' );
                } else {

                    $products  = get_option( 'ninetheme_wishlist_' . $key ) ? get_option( 'ninetheme_wishlist_' . $key ) : array();
                    $product   = wc_get_product( $product_id );
                    $name      = '<span class="product-name">'.esc_html( $product->get_name() ).'</span>';

                    if ( array_key_exists( $product_id, $products ) ) {
                        unset( $products[ $product_id ] );
                        update_option( 'ninetheme_wishlist_' . $key, $products );
                        $this->update_meta( $product_id, 'ninetheme_wishlist_remove' );
                        $return['count']  = count( $products );
                        $return['status'] = 1;

                        if ( count( $products ) > 0 ) {
                            $return['notice'] = sprintf('<div class="ninetheme-small-title"><span class="product-name">"%s"</span> <span>%s</span></div>',
                                esc_html( $product->get_name() ),
                                esc_html__( 'Removed from wishlist!', 'crisop' )
                            );
                        } else {

                            $return['notice_type'] = 'empty';
                            $return['notice'] = sprintf('%s<div class="ninetheme-small-title">%s</div><a class="ninetheme-btn-small mt-10%s" href="%s">%s</a>',
                                $icon,
                                esc_html__( 'There are no products on the wishlist!', 'crisop' ),
                                $btn_class,
                                esc_url( $url ),
                                esc_html__( 'Start Shopping', 'crisop' )
                            );
                        }
                    } else {
                        $return['notice'] = sprintf('%s<div class="ninetheme-small-title">%s</div><a class="ninetheme-btn-small mt-10%s" href="%s">%s</a>',
                            $icon,
                            esc_html__( 'The product does not exist on the wishlist!', 'crisop' ),
                            $btn_class,
                            esc_url( $url ),
                            esc_html__( 'Start Shopping', 'crisop' )
                        );
                    }
                }
            } else {
                $product_id = 0;
                $return['notice'] = esc_html__( 'Have an error, please try again!', 'crisop' );
            }

            echo json_encode( $return );
            die();
        }

        function update_meta( $product_id, $action = 'ninetheme_wishlist_add' )
        {
            $meta_count = 'ninetheme_wishlist_count';
            $count      = get_post_meta( $product_id, $meta_count, true );
            $new_count  = 0;

            if ( $action === 'ninetheme_wishlist_add' ) {
                if ( $count ) {
                    $new_count = absint( $count ) + 1;
                } else {
                    $new_count = 1;
                }
            } elseif ( $action === 'ninetheme_wishlist_remove' ) {
                if ( $count && ( absint( $count ) > 1 ) ) {
                    $new_count = absint( $count ) - 1;
                } else {
                    $new_count = 0;
                }
            }

            update_post_meta( $product_id, $meta_count, $new_count );
            update_post_meta( $product_id, $action, time() );
        }

		public function wishlist_wp_login( $user_login, $user ) {
			if ( isset( $user->data->ID ) ) {
				$user_key = get_user_meta( $user->data->ID, 'ninetheme_wishlist_key', true );

				if ( empty( $user_key ) ) {
					$user_key = self::generate_key();

					while ( self::exists_key( $user_key ) ) {
						$user_key = self::generate_key();
					}

					// set a new key
					update_user_meta( $user->data->ID, 'ninetheme_wishlist_key', $user_key );
				}

				$secure   = apply_filters( 'ninetheme_wishlist_cookie_secure', wc_site_is_https() && is_ssl() );
				$httponly = apply_filters( 'ninetheme_wishlist_cookie_httponly', true );

				if ( isset( $_COOKIE['ninetheme_wishlist_key'] ) && ! empty( $_COOKIE['ninetheme_wishlist_key'] ) ) {
					wc_setcookie( 'ninetheme_wishlist_key_ori', $_COOKIE['ninetheme_wishlist_key'], time() + 604800, $secure, $httponly );
				}

				wc_setcookie( 'ninetheme_wishlist_key', $user_key, time() + 604800, $secure, $httponly );
			}
		}

		public function wishlist_wp_logout( $user_id ) {
			if ( isset( $_COOKIE['ninetheme_wishlist_key_ori'] ) && ! empty( $_COOKIE['ninetheme_wishlist_key_ori'] ) ) {
				$secure   = apply_filters( 'ninetheme_wishlist_cookie_secure', wc_site_is_https() && is_ssl() );
				$httponly = apply_filters( 'ninetheme_wishlist_cookie_httponly', true );

				wc_setcookie( 'ninetheme_wishlist_key', $_COOKIE['ninetheme_wishlist_key_ori'], time() + 604800, $secure, $httponly );
			} else {
				unset( $_COOKIE['ninetheme_wishlist_key_ori'] );
				unset( $_COOKIE['ninetheme_wishlist_key'] );
			}
		}

        public static function generate_key()
        {
            $key         = '';
            $key_str     = 'ABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789';
            $key_str_len = strlen( $key_str );

            for ( $i = 0; $i < 6; $i ++ ) {
                $key .= $key_str[ random_int( 0, $key_str_len - 1 ) ];
            }

            return $key;
        }

        public static function get_key()
        {
            if ( ! is_user_logged_in() ) {
                //return '#';
            }

            if ( is_user_logged_in() && ( ( $user_id = get_current_user_id() ) > 0 ) ) {
                $user_key = get_user_meta( $user_id, 'ninetheme_wishlist_key', true );

                if ( empty( $user_key ) ) {
                    $user_key = self::generate_key();

                    while ( self::exists_key( $user_key ) ) {
                        $user_key = self::generate_key();
                    }

                    // set a new key
                    update_user_meta( $user_id, 'ninetheme_wishlist_key', $user_key );
                }

                return $user_key;
            }

            if ( isset( $_COOKIE['ninetheme_wishlist_key'] ) ) {
                return esc_attr( $_COOKIE['ninetheme_wishlist_key'] );
            }

            return 'CRISOPWL';
        }

        public static function exists_key( $key )
        {
            return get_option( 'ninetheme_list_' . $key ) ? true : false;
        }

        public static function get_count( $key = null )
        {
            if ( ! $key ) {
                $key = self::get_key();
            }
            $products = get_option( 'ninetheme_wishlist_' . $key );

            if ( ( $key != '' ) && $products && is_array( $products ) ) {
                $count = count( $products );
            } else {
                $count = 0;
            }

            return $count;
        }

        public static function get_products( $key = null )
        {
            if ( ! $key ) {
                $key = self::get_key();
            }
            $products = get_option( 'ninetheme_wishlist_' . $key );
            $ids = array();
            if ( ( $key != '' ) && $products && is_array( $products ) ) {
                foreach ( $products as $key => $id ) {
                    $ids[] = $key;
                }
                return $ids;
            }
        }
    }
    Ninetheme_Wishlist::get_instance();
}
