<?php

namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) exit; // If this file is called directly, abort.

class Ninetheme_Woo_Ajax_Search extends Widget_Base {
    use Ninetheme_Helper;
    public function get_name() {
        return 'ninetheme-woo-ajax-search';
    }
    public function get_title() {
        return 'WC Ajax Search (N)';
    }
    public function get_icon() {
        return 'eicon-site-search';
    }
    public function get_categories() {
        return [ 'ninetheme-header' ];
    }
    public function get_keywords() {
        return [ 'woocommerce', 'shop', 'store', 'cat', 'wc', 'woo', 'product', 'search'  ];
    }
    // Registering Controls
    protected function register_controls() {

        /* HEADER MINICART SETTINGS */
        $this->start_controls_section( 'general_section',
            [
                'label' => esc_html__( 'Style', 'crisop' ),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );
        $this->add_control( 'form_style',
            [
                'label' => esc_html__( 'Form Style', 'crisop' ),
                'type' => Controls_Manager::SELECT,
                'default' => 'style-inline',
                'options' => [
                    'style-inline' => esc_html__( 'Inline', 'crisop' ),
                    'style-block' => esc_html__( 'Block', 'crisop' )
                ]
            ]
        );
        $this->add_responsive_control( 'form_max_width',
            [
                'label' => esc_html__( 'Max Width ( px )', 'crisop' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => [ 'px' ],
                'range' => [
                    'px' => [
                    'min' => 0,
                        'max' => 2000,
                        'step' => 1
                    ]
                ],
                'selectors' => ['{{WRAPPER}} .ninetheme-ajax-product-search.width-auto form' => 'width: {{SIZE}}px;max-width: {{SIZE}}px;'],
                'condition' => [ 'form_style' => 'style-inline']
            ]
        );
        $this->add_control( 'form_border_style',
            [
                'label' => esc_html__( 'Border Style', 'crisop' ),
                'type' => Controls_Manager::SELECT,
                'default' => 'style-border-none',
                'options' => [
                    'style-border' => esc_html__( 'Border', 'crisop' ),
                    'style-border-none' => esc_html__( 'Borderless', 'crisop' )
                ]
            ]
        );
        $this->add_control( 'form_radius_style',
            [
                'label' => esc_html__( 'Radius Style', 'crisop' ),
                'type' => Controls_Manager::SELECT,
                'default' => 'style-circle',
                'options' => [
                    'style-circle' => esc_html__( 'Circle', 'crisop' ),
                    'style-square' => esc_html__( 'Square', 'crisop' )
                ]
            ]
        );
        $this->add_control( 'form_select_style',
            [
                'label' => esc_html__( 'Category Style', 'crisop' ),
                'type' => Controls_Manager::SELECT,
                'default' => 'style-select-show',
                'options' => [
                    'style-select-bars' => esc_html__( 'Hidden', 'crisop' ),
                    'style-select-show' => esc_html__( 'Visible', 'crisop' )
                ]
            ]
        );
        $this->add_control( 'select_text',
            [
                'label' => esc_html__( 'Select Text', 'crisop' ),
                'type' => Controls_Manager::TEXT,
                'default' => 'Select an option',
                'separator' => 'before'
            ]
        );
        $this->add_control( 'search_text',
            [
                'label' => esc_html__( 'Search Text', 'crisop' ),
                'type' => Controls_Manager::TEXT,
                'default' => 'Search for product...',
            ]
        );
        $this->end_controls_section();
        /*****   END CONTROLS SECTION   ******/
        /*****   START CONTROLS SECTION   ******/
        $this->start_controls_section('style_section',
            [
                'label'=> esc_html__( 'STYLE', 'crisop' ),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );
        $this->add_responsive_control( 'form_padding',
            [
                'label' => esc_html__( 'Form Padding', 'crisop' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px' ],
                'selectors' => ['{{WRAPPER}} .ninetheme-ajax-product-search.width-auto form' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};']
            ]
        );
        $this->add_responsive_control( 'form_border_radius',
            [
                'label' => esc_html__( 'Border Radius', 'crisop' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px' ],
                'selectors' => ['{{WRAPPER}} .ninetheme-ajax-product-search.width-auto form' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};']
            ]
        );
        $this->add_responsive_control( 'form_padding',
            [
                'label' => esc_html__( 'Input Padding', 'crisop' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px' ],
                'selectors' => ['{{WRAPPER}} .ninetheme-ajax-product-search.width-auto form input.ninetheme-ajax-search-input' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};']
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'search_typo',
                'label' => esc_html__( 'Search Typography', 'crisop' ),
                'selector' => '{{WRAPPER}} .ninetheme-ajax-product-search.width-auto form input.ninetheme-ajax-search-input,
                {{WRAPPER}} .ninetheme-ajax-product-search.style-inline .ninetheme-ajax-category.nice-select,
                {{WRAPPER}} .ninetheme-ajax-product-search.style-inline select'
            ]
        );
        $this->start_controls_tabs( 'slider_nav_tabs');
        $this->start_controls_tab( 'slider_nav_normal_tab',
            [ 'label' => esc_html__( 'Normal', 'crisop' ) ]
        );
        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name' => 'form_border',
                'label' => esc_html__( 'Border', 'crisop' ),
                'selector' => '{{WRAPPER}} .ninetheme-ajax-product-search.width-auto form',
            ]
        );
        $this->add_control( 'form_bgclr',
           [
               'label' => esc_html__( 'Background Color', 'crisop' ),
               'type' => Controls_Manager::COLOR,
               'default' => '',
               'selectors' => ['{{WRAPPER}} .ninetheme-ajax-product-search.width-auto form' => 'background-color: {{VALUE}};']
           ]
        );
        $this->add_control( 'form_search_clr',
           [
               'label' => esc_html__( 'Search Input Color', 'crisop' ),
               'type' => Controls_Manager::COLOR,
               'default' => '',
               'selectors' => [
                   '{{WRAPPER}} .ninetheme-ajax-product-search.width-auto form input.ninetheme-ajax-search-input::-webkit-input-placeholder,
                   {{WRAPPER}} .ninetheme-ajax-product-search.width-auto form input.ninetheme-ajax-search-input::placeholder' => 'color: {{VALUE}};'
                ]
           ]
        );
        $this->end_controls_tab();
        $this->start_controls_tab( 'form_hover_tab',
            [ 'label' => esc_html__( 'Hover', 'crisop' ) ]
        );
        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name' => 'form_hvrborder',
                'label' => esc_html__( 'Border', 'crisop' ),
                'selector' => '{{WRAPPER}} .ninetheme-ajax-product-search.width-auto form:hover,{{WRAPPER}} .ninetheme-ajax-product-search.width-auto form:focus',
            ]
        );
        $this->add_control( 'form_hvrbgclr',
           [
               'label' => esc_html__( 'Background Color', 'crisop' ),
               'type' => Controls_Manager::COLOR,
               'default' => '',
               'selectors' => [
                   '{{WRAPPER}} .ninetheme-ajax-product-search.width-auto form:hover input.ninetheme-ajax-search-input,
                   {{WRAPPER}} .ninetheme-ajax-product-search.width-auto form:focus input.ninetheme-ajax-search-input' => 'background-color: {{VALUE}};'
                ]
           ]
        );
        $this->add_control( 'form_hvrclr',
           [
               'label' => esc_html__( 'Color', 'crisop' ),
               'type' => Controls_Manager::COLOR,
               'default' => '',
               'selectors' => [
                   '{{WRAPPER}} .ninetheme-ajax-product-search.width-auto form:hover input.ninetheme-ajax-search-input,
                   {{WRAPPER}} .ninetheme-ajax-product-search.width-auto form:focus input.ninetheme-ajax-search-input' => 'color: {{VALUE}};'
               ]
           ]
        );
        $this->end_controls_tab();
        $this->end_controls_tabs();
        $this->add_control( 'form_submit_heading',
           [
               'label' => esc_html__( 'SUBMIT BUTTON', 'crisop' ),
               'type' => Controls_Manager::HEADING,
               'separator' => 'before'
           ]
        );
        $this->add_control( 'submit_bgclr',
           [
               'label' => esc_html__( 'Submit Background Color', 'crisop' ),
               'type' => Controls_Manager::COLOR,
               'default' => '',
               'selectors' => [
                   '{{WRAPPER}} .ninetheme-ajax-search-wrapper button.ninetheme-ajax-search-submit,
                   {{WRAPPER}} .ninetheme-ajax-search-wrapper .ninetheme-ajax-close-search-results' => 'background-color: {{VALUE}};'
                ]
           ]
        );
        $this->add_control( 'submit_iconclr',
           [
               'label' => esc_html__( 'Submit Icon Color', 'crisop' ),
               'type' => Controls_Manager::COLOR,
               'default' => '',
               'selectors' => [ 
                   '{{WRAPPER}} .ninetheme-ajax-product-search .ninetheme-ajax-close-search-results:before,.ninetheme-ajax-close-search-results:after' => 'background-color: {{VALUE}};',
                   '{{WRAPPER}} .ninetheme-ajax-product-search .ninetheme-svg-icon' => 'fill: {{VALUE}};',
                ]
           ]
        );
        $this->add_responsive_control( 'form_submit_size',
            [
                'label' => esc_html__( 'Max Width ( px )', 'crisop' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => [ 'px' ],
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 200,
                        'step' => 1
                    ]
                ],
               'selectors' => [
                   '{{WRAPPER}} .ninetheme-ajax-search-wrapper button.ninetheme-ajax-search-submit,
                   {{WRAPPER}} .ninetheme-ajax-search-wrapper .ninetheme-ajax-close-search-results' => 'max-width: {{SIZE}}px;'
                ]
            ]
        );
        $this->add_control( 'form_cats_btn_heading',
           [
               'label' => esc_html__( 'CATEGORY SELECT BUTTON', 'crisop' ),
               'type' => Controls_Manager::HEADING,
               'separator' => 'before'
           ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'cat_typo',
                'label' => esc_html__( 'Category Typography', 'crisop' ),
                'selector' => '{{WRAPPER}} .ninetheme-ajax-product-search.style-inline .ninetheme-ajax-category.nice-select,{{WRAPPER}} .ninetheme-ajax-product-search.style-inline select'
            ]
        );
        $this->add_control( 'form_cats_btn_clr',
           [
               'label' => esc_html__( 'Current Category Color', 'crisop' ),
               'type' => Controls_Manager::COLOR,
               'default' => '',
               'selectors' => [ '{{WRAPPER}} .ninetheme-ajax-product-search .nice-select span.current' => 'color: {{VALUE}};' ]
           ]
        );
        $this->add_responsive_control( 'form_cats_select_width',
            [
                'label' => esc_html__( 'Select Max Width ( % )', 'crisop' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => [ 'px' ],
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 100,
                        'step' => 1
                    ]
                ],
               'selectors' => [ '
               {{WRAPPER}} .ninetheme-ajax-product-search.style-inline .ninetheme-ajax-category.nice-select,
               {{WRAPPER}} .ninetheme-ajax-product-search.style-inline select' => 'width: {{SIZE}}%;'
               ],
               'condition' => [ 'form_style' => 'style-inline']
            ]
        );
        $this->add_control( 'form_cats_btn_clr',
           [
               'label' => esc_html__( 'Icon Color', 'crisop' ),
               'type' => Controls_Manager::COLOR,
               'default' => '',
               'selectors' => [ '{{WRAPPER}} .ninetheme-ajax-product-search .ninetheme-ajax-cats-search .ninetheme-svg-icon' => 'fill: {{VALUE}};' ]
           ]
        );
        $this->add_responsive_control( 'form_cats_btn_size',
            [
                'label' => esc_html__( 'Icon Size ( px )', 'crisop' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => [ 'px' ],
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 200,
                        'step' => 1
                    ]
                ],
               'selectors' => [ '{{WRAPPER}} .ninetheme-ajax-product-search .ninetheme-ajax-cats-search .ninetheme-svg-icon' => 'max-width: {{SIZE}}px;max-height: {{SIZE}}px;' ]
            ]
        );
        $this->add_control( 'form_cats_option_heading_separator',
           [
               'label' => esc_html__( 'Select Option', 'crisop' ),
               'type' => Controls_Manager::HEADING,
               'separator' => 'before'
           ]
        );
        $this->add_control( 'form_cats_option_clr',
           [
               'label' => esc_html__( 'Option Color', 'crisop' ),
               'type' => Controls_Manager::COLOR,
               'default' => '',
               'selectors' => [ '{{WRAPPER}} .ninetheme-ajax-product-search .nice-select .option' => 'color: {{VALUE}};' ]
           ]
        );
        $this->add_control( 'form_cats_option_hvrclr',
           [
               'label' => esc_html__( 'Option Color ( Hover )', 'crisop' ),
               'type' => Controls_Manager::COLOR,
               'default' => '',
               'selectors' => [ '{{WRAPPER}} .ninetheme-ajax-product-search .nice-select .option:hover, {{WRAPPER}} .ninetheme-ajax-product-search .nice-select .option.focus' => 'color: {{VALUE}};' ]
           ]
        );
        $this->add_control( 'form_cats_option_bgclr',
           [
               'label' => esc_html__( 'Option Background', 'crisop' ),
               'type' => Controls_Manager::COLOR,
               'default' => '',
               'selectors' => [ '{{WRAPPER}} .ninetheme-ajax-product-search .nice-select .option, {{WRAPPER}} .ninetheme-ajax-product-search .nice-select .option' => 'background-color: {{VALUE}};' ]
           ]
        );
        $this->add_control( 'form_cats_option_hvrbgclr',
           [
               'label' => esc_html__( 'Option Background ( Hover )', 'crisop' ),
               'type' => Controls_Manager::COLOR,
               'default' => '',
               'selectors' => [ '{{WRAPPER}} .ninetheme-ajax-product-search .nice-select .option:hover, {{WRAPPER}} .ninetheme-ajax-product-search .nice-select .option.focus' => 'background-color: {{VALUE}};' ]
           ]
        );
        $this->end_controls_section();
    }

    protected function render() {
        if ( ! class_exists('WooCommerce') ) {
            return;
        }
        $settings = $this->get_settings_for_display();
        $class  = $settings['form_style'];
        $class .= ' '.$settings['form_border_style'];
        $class .= ' '.$settings['form_radius_style'];
        $class .= ' '.$settings['form_select_style'];
        $text = $settings['select_text'] ? ' select_text="'.esc_html( $settings['select_text'] ).'"' : ' select_text=""';
        $text .= $settings['search_text'] ? ' search_text="'.esc_html( $settings['search_text'] ).'"' : ' search_text=""';

        if ( shortcode_exists( 'ninetheme_wc_ajax_product_search' ) ) {
            echo do_shortcode('[ninetheme_wc_ajax_product_search class="'.$class.' width-auto" cats="hide"'.$text.']');
        }
        if ( \Elementor\Plugin::$instance->editor->is_edit_mode() ) { ?>
            <script>
            jQuery( document ).ready( function($) {
                if ( $('.ninetheme-ajax-product-search select').length ) {
                    $('.ninetheme-ajax-product-search select').niceSelect();
                    $('.nice-select .list').addClass('ninetheme-scrollbar');
                }
            });
            </script>
            <?php
        }

    }
}
