<?php

namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) exit; // If this file is called directly, abort.

class Ninetheme_Woo_Banner extends Widget_Base {
    use Ninetheme_Helper;
    public function get_name() {
        return 'ninetheme-woo-banner';
    }
    public function get_title() {
        return 'Banner (N)';
    }
    public function get_icon() {
        return 'eicon-icon-box';
    }
    public function get_categories() {
        return [ 'ninetheme-woo' ];
    }
    // Registering Controls
    protected function register_controls() {
        /*****   START CONTROLS SECTION   ******/
        $this->start_controls_section( 'general_section',
            [
                'label'=> esc_html__( 'Banner', 'crisop' ),
                'tab'=> Controls_Manager::TAB_CONTENT,
            ]
        );
        $this->add_control( 'category',
            [
                'label' => esc_html__( 'Select Category', 'crisop' ),
                'type' => Controls_Manager::SELECT2,
                'multiple' => false,
                'options' => $this->ninetheme_cpt_taxonomies('product_cat')
            ]
        );
        $this->add_control( 'image',
            [
                'label' => esc_html__( 'Image', 'crisop' ),
                'type' => Controls_Manager::MEDIA,
                'default' => ['url' => '']
            ]
        );
        $this->add_responsive_control('img_bottom_position',
            [
                'label' => esc_html__( 'Image Custom Vertical Position', 'ninetheme' ),
                'type' => Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => -1000,
                        'max' => 1000
                    ]
                ],
                'selectors' => ['{{WRAPPER}} .ninetheme-woo-banner-wrapper .ninetheme-banner-image img' => 'bottom: {{SIZE}}px;top: auto;']
            ]
        );
        $this->add_responsive_control('img_left_position',
            [
                'label' => esc_html__( 'Image Custom Horizontal Position', 'ninetheme' ),
                'type' => Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => -1000,
                        'max' => 1000
                    ]
                ],
                'selectors' => ['{{WRAPPER}} .ninetheme-woo-banner-wrapper .ninetheme-banner-image img' => 'left: {{SIZE}}px;right: auto;']
            ]
        );
        $this->add_control( 'use_video',
            [
                'label' => esc_html__( 'Use Background Video', 'crisop' ),
                'type' => Controls_Manager::SWITCHER,
                'separator' => 'before'
            ]
        );
        $this->add_control( 'video_provider',
            [
                'label' => esc_html__( 'Video Source', 'crisop' ),
                'type' => Controls_Manager::SELECT,
                'default' => 'youtube',
                'options' => [
                    'youtube' => esc_html__( 'YouTube', 'crisop' ),
                    'vimeo' => esc_html__( 'Vimeo', 'crisop' ),
                    'local' => esc_html__( 'Local', 'crisop' ),
                    'iframe' => esc_html__( 'Custom Iframe Embed', 'crisop' ),
                ],
                'condition' => ['use_video' => 'yes']
            ]
        );
        $this->add_control( 'iframe_embed',
            [
                'label' => esc_html__( 'Custom Iframe Embed Code', 'crisop' ),
                'type' => Controls_Manager::TEXTAREA,
                'default' => '',
                'label_block' => true,
                'conditions' => [
                    'relation' => 'and',
                    'terms' => [
                        [ 'name' => 'use_video','operator' => '==','value' => 'yes' ],
                        [ 'name' => 'video_provider','operator' => '==','value' => 'iframe' ]
                    ]
                ]
            ]
        );
        $this->add_control( 'loacal_video_url',
            [
                'label' => esc_html__( 'Loacal Video URL', 'crisop' ),
                'type' => Controls_Manager::TEXTAREA,
                'default' => '',
                'label_block' => true,
                'conditions' => [
                    'relation' => 'and',
                    'terms' => [
                        [ 'name' => 'use_video','operator' => '==','value' => 'yes' ],
                        [ 'name' => 'video_provider','operator' => '==','value' => 'local' ]
                    ]
                ]
            ]
        );
        $this->add_control( 'video_id',
            [
                'label' => esc_html__( 'Video ID', 'crisop' ),
                'placeholder' => '',
                'description' => esc_html__( 'YouTube/Vimeo video ID.', 'crisop' ),
                'type' => Controls_Manager::TEXT,
                'conditions' => [
                    'relation' => 'and',
                    'terms' => [
                        [ 'name' => 'use_video','operator' => '==','value' => 'yes' ],
                        [ 'name' => 'video_provider','operator' => '!=','value' => 'iframe' ],
                        [ 'name' => 'video_provider','operator' => '!=','value' => 'local' ]
                    ]
                ]
            ]
        );
        $this->add_control( 'video_loop',
            [
                'label' => esc_html__( 'Loop', 'crisop' ),
                'type' => Controls_Manager::SWITCHER,
                'default' => 'yes',
                'conditions' => [
                    'relation' => 'and',
                    'terms' => [
                        [ 'name' => 'use_video','operator' => '==','value' => 'yes' ],
                        [ 'name' => 'video_provider','operator' => '!=','value' => 'iframe' ]
                    ]
                ]
            ]
        );
        $this->add_control( 'video_start',
            [
                'label' => esc_html__( 'Video Start', 'crisop' ),
                'type' => Controls_Manager::NUMBER,
                'min' => 0,
                'max' => 10000,
                'step' => 1,
                'default' => '',
                'conditions' => [
                    'relation' => 'and',
                    'terms' => [
                        [ 'name' => 'use_video','operator' => '==','value' => 'yes' ],
                        [ 'name' => 'video_provider','operator' => '!=','value' => 'iframe' ]
                    ]
                ]
            ]
        );
        $this->add_control( 'video_end',
            [
                'label' => esc_html__( 'Video Start', 'crisop' ),
                'type' => Controls_Manager::NUMBER,
                'min' => 0,
                'max' => 10000,
                'step' => 1,
                'default' => '',
                'conditions' => [
                    'relation' => 'and',
                    'terms' => [
                        [ 'name' => 'use_video','operator' => '==','value' => 'yes' ],
                        [ 'name' => 'video_provider','operator' => '!=','value' => 'iframe' ]
                    ]
                ]
            ]
        );
        $this->add_control( 'auto_calculate',
            [
                'label' => esc_html__( 'Auto Calculate Video Size', 'crisop' ),
                'type' => Controls_Manager::SWITCHER,
            ]
        );
        $this->add_control( 'aspect_ratio',
            [
                'label' => esc_html__( 'Aspect Ratio', 'crisop' ),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    '16:9' => esc_html__( '16:9 ( Standard Video )', 'crisop' ),
                    '9:16' => esc_html__( '9:16 ( for vertical video )', 'crisop' ),
                    '1:1' =>esc_html__( '1:1', 'crisop' ),
                    '4:3' => esc_html__( '4:3', 'crisop' ),
                    '3:2' => esc_html__( '3:2', 'crisop' ),
                    '21:9' => esc_html__( '21:9', 'crisop' ),
                ],
                'default' => '16:9',
                'conditions' => [
                    'relation' => 'and',
                    'terms' => [
                        [ 'name' => 'use_video','operator' => '==','value' => 'yes' ],
                        [ 'name' => 'auto_calculate','operator' => '==','value' => 'yes' ]
                    ]
                ]
            ]
        );
        $this->add_responsive_control( 'video_box_size',
            [
                'label' => esc_html__( 'Video Box Height', 'crisop' ),
                'type' => Controls_Manager::NUMBER,
                'min' => 0,
                'max' => 4000,
                'step' => 1,
                'default' => 100,
                'selectors' => [ '{{WRAPPER}} .ninetheme-woo-banner-wrapper' => 'height:{{SIZE}}px;' ],
                'condition' => ['use_video' => 'yes']
            ]
        );
        $this->add_responsive_control( 'video_width',
            [
                'label' => esc_html__( 'Custom Video Width', 'crisop' ),
                'type' => Controls_Manager::NUMBER,
                'min' => 0,
                'max' => 4000,
                'step' => 1,
                'default' => '',
                'selectors' => [ '{{WRAPPER}} .ninetheme-woo-banner-iframe-wrapper iframe' => 'width:{{SIZE}}px;max-width:none;' ],
                'conditions' => [
                    'relation' => 'and',
                    'terms' => [
                        [ 'name' => 'use_video','operator' => '==','value' => 'yes' ],
                        [ 'name' => 'auto_calculate','operator' => '!=','value' => 'yes' ]
                    ]
                ]
            ]
        );
        $this->add_responsive_control( 'video_height',
            [
                'label' => esc_html__( 'Custom Video Height', 'crisop' ),
                'type' => Controls_Manager::NUMBER,
                'min' => 0,
                'max' => 4000,
                'step' => 1,
                'default' => '',
                'selectors' => [ '{{WRAPPER}} .ninetheme-woo-banner-iframe-wrapper iframe' => 'height:{{SIZE}}px;max-width:none;' ],
                'conditions' => [
                    'relation' => 'and',
                    'terms' => [
                        [ 'name' => 'use_video','operator' => '==','value' => 'yes' ],
                        [ 'name' => 'auto_calculate','operator' => '!=','value' => 'yes' ]
                    ]
                ]
            ]
        );
        $this->add_control( 'full_height',
            [
                'label' => esc_html__( 'Full Height', 'crisop' ),
                'type' => Controls_Manager::SWITCHER,
                'prefix_class' => 'full-height-',
                'condition' => ['use_video!' => 'yes']
            ]
        );
        $this->add_responsive_control( 'fit_size',
            [
                'label' => esc_html__( 'Box Min Height', 'crisop' ),
                'type' => Controls_Manager::NUMBER,
                'min' => 0,
                'max' => 500,
                'step' => 1,
                'default' => 75,
                'selectors' => [ 
                    '{{WRAPPER}} .ninetheme-woo-banner-wrapper:not(.full-height) .ninetheme-banner-image' => 'padding-top:{{SIZE}}%;',
                    '{{WRAPPER}} .ninetheme-woo-banner-wrapper.full-height .ninetheme-banner-image' => 'min-height:{{SIZE}}px;padding-top:0;'
                ],
                'condition' => ['use_video!' => 'yes']
            ]
        );
        $this->add_group_control(
            Group_Control_Image_Size::get_type(),
            [
                'name' => 'thumbnail',
                'default' => 'thumbnail',
                'condition' => ['use_video!' => 'yes']
            ]
        );
        $this->add_control( 'title',
            [
                'label' => esc_html__( 'Custom Title/Text', 'crisop' ),
                'type' => Controls_Manager::TEXTAREA,
                'default' => 'Free Shipping On Over $ 50',
                'label_block' => true,
                'separator' => 'before'
            ]
        );
        $this->add_control( 'tag',
            [
                'label' => esc_html__( 'Title Tag', 'crisop' ),
                'type' => Controls_Manager::SELECT,
                'default' => 'h6',
                'options' => [
                    'h1' => esc_html__( 'H1', 'crisop' ),
                    'h2' => esc_html__( 'H2', 'crisop' ),
                    'h3' => esc_html__( 'H3', 'crisop' ),
                    'h4' => esc_html__( 'H4', 'crisop' ),
                    'h5' => esc_html__( 'H5', 'crisop' ),
                    'h6' => esc_html__( 'H6', 'crisop' ),
                    'div' => esc_html__( 'div', 'crisop' ),
                    'p' => esc_html__( 'p', 'crisop' )
                ]
            ]
        );
        $this->add_control( 'desc',
            [
                'label' => esc_html__( 'Short Description', 'crisop' ),
                'type' => Controls_Manager::TEXTAREA,
                'default' => 'Agricultural mean crops livestock',
                'label_block' => true
            ]
        );
        $this->add_control( 'count_text',
            [
                'label' => esc_html__( 'After Count Text', 'crisop' ),
                'type' => Controls_Manager::TEXT,
                'default' => 'Products',
                'label_block' => true
            ]
        );
        $this->add_control( 'btn_title',
            [
                'label' => esc_html__( 'Button Title', 'crisop' ),
                'type' => Controls_Manager::TEXT,
                'default' => 'See More Products',
                'label_block' => true
            ]
        );
        $this->add_control( 'icon',
            [
                'label' => esc_html__( 'Button Icon', 'crisop' ),
                'type' => Controls_Manager::ICONS,
                'default' => [
                    'value' => '',
                    'library' => 'solid'
                ]
            ]
        );
        $this->add_control( 'icon_spacing',
            [
                'label' => esc_html__( 'Icon Spacing', 'crisop' ),
                'type' => Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'max' => 50
                    ]
                ],
                'selectors' => ['{{WRAPPER}} .ninetheme-banner-content .ninetheme-banner-button i' => 'margin-left: {{SIZE}}px;']
            ]
        );
        $this->add_control( 'link',
            [
                'label' => esc_html__( 'Custom Link', 'crisop' ),
                'type' => Controls_Manager::URL,
                'label_block' => true,
                'default' => [
                    'url' => '',
                    'is_external' => ''
                ],
                'show_external' => true
            ]
        );
        $this->end_controls_section();
        /*****   END CONTROLS SECTION   ******/
        /*****   START CONTROLS SECTION   ******/
        $this->start_controls_section( 'style_section',
            [
                'label' => esc_html__( 'STYLE', 'crisop' ),
                'tab' => Controls_Manager::TAB_CONTENT
            ]
        );
        $this->add_control( 'baner_style',
            [
                'label' => esc_html__( 'Banner Style', 'crisop' ),
                'type' => Controls_Manager::SELECT,
                'multiple' => false,
                'options' => [
                    'card'  => esc_html__( 'Card', 'crisop' ),
                    'card-hover'  => esc_html__( 'Card Hover', 'crisop' ),
                    'classic' => esc_html__( 'Classic', 'crisop' )
                ],
                'default' => 'card'
            ]
        );
        $repeater = new Repeater();
        $repeater->add_control( 'item_order',
            [
                'label' => esc_html__( 'Content Item order', 'crisop' ),
                'type' => Controls_Manager::SELECT,
                'multiple' => false,
                'options' => [
                    'cat'  => esc_html__( 'Category', 'crisop' ),
                    'title'  => esc_html__( 'Title', 'crisop' ),
                    'desc' => esc_html__( 'Description', 'crisop' ),
                    'count' => esc_html__( 'Count', 'crisop' ),
                    'button' => esc_html__( 'Button', 'crisop' ),
                ],
                'default' => 'cat',
            ]
        );
        $repeater->add_control( 'item_position',
            [
                'label' => esc_html__( 'Select Item Position', 'crisop' ),
                'type' => Controls_Manager::SELECT,
                'multiple' => false,
                'options' => [
                    'top'  => esc_html__( 'Top', 'crisop' ),
                    'center'  => esc_html__( 'Center', 'crisop' ),
                    'bottom' => esc_html__( 'Bottom', 'crisop' ),
                ],
                'default' => 'top',
            ]
        );
        $this->add_control('content_orders',
            [
                'label' => esc_html__( 'Content Items Order', 'crisop' ),
                'type' => Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'default' => [
                    [
                        'item_order' => 'cat',
                        'item_position' => 'top'
                    ],
                    [
                        'item_order' => 'title',
                        'item_position' => 'top'
                    ],
                ],
                'title_field' => '{{{item_order}}} - {{{item_position}}}',
            ]
        );
        $this->add_control( 'box_bgcolor',
            [
                'label' => esc_html__( 'Background Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [ '{{WRAPPER}} .ninetheme-woo-banner-wrapper' => 'background-color:{{VALUE}};' ]
            ]
        );
        $this->add_responsive_control( 'box_padding',
            [
                'label' => esc_html__( 'Box Content Padding', 'crisop' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', 'em', '%' ],
                'selectors' => ['{{WRAPPER}} .ninetheme-woo-banner-wrapper .ninetheme-banner-content' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};']
            ]
        );
        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name' => 'box_border',
                'selector' => '{{WRAPPER}} .ninetheme-woo-banner-wrapper'
            ]
        );
        $this->add_responsive_control( 'box_border_radius',
            [
                'label' => esc_html__( 'Box Border Radius', 'crisop' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%' ],
                'selectors' => ['{{WRAPPER}} .ninetheme-woo-banner-wrapper' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}}']
            ]
        );
        $this->add_responsive_control( 'overlay_color',
            [
                'label' => esc_html__( 'Overlay Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .ninetheme-woo-banner-wrapper:not(.banner-style-classic):before,
                    {{WRAPPER}} .ninetheme-woo-banner-wrapper.banner-style-classic .ninetheme-banner-image:before' => 'background-color:{{VALUE}};' ]
            ]
        );
        $this->add_responsive_control( 'overlay_hvrcolor',
            [
                'label' => esc_html__( 'Hover Overlay Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .ninetheme-woo-banner-wrapper:not(.banner-style-classic):hover::before,
                    {{WRAPPER}} .ninetheme-woo-banner-wrapper.banner-style-classic .ninetheme-banner-image:before' => 'background-color:{{VALUE}};' ]
            ]
        );
        $this->add_control( 'text_hvrcolor',
            [
                'label' => esc_html__( 'Hover Text Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [ '{{WRAPPER}} .ninetheme-woo-banner-wrapper:hover .ninetheme-banner-content .ninetheme-banner-title,{{WRAPPER}} .ninetheme-woo-banner-wrapper:hover .ninetheme-banner-content ' => 'color:{{VALUE}};' ]
            ]
        );
        $this->add_responsive_control( 'image_hvrscale',
            [
                'label' => esc_html__( 'Hover Image Scale', 'crisop' ),
                'type' => Controls_Manager::NUMBER,
                'min' => 1,
                'max' => 2,
                'step' => 0.1,
                'default' => 1.2,
                'selectors' => [ '{{WRAPPER}} .ninetheme-woo-banner-wrapper:hover .ninetheme-banner-image img' => 'transform: scale( {{SIZE}} );' ],
            ]
        );
        $this->add_responsive_control( 'alignment',
            [
                'label' => esc_html__( 'Text Alignment', 'crisop' ),
                'type' => Controls_Manager::CHOOSE,
                'selectors' => ['{{WRAPPER}} .ninetheme-woo-banner-wrapper .ninetheme-banner-content' => 'text-align: {{VALUE}};'],
                'options' => [
                    'left' => [
                        'title' => esc_html__( 'Left', 'crisop' ),
                        'icon' => 'eicon-h-align-left'
                    ],
                    'center' => [
                        'title' => esc_html__( 'Center', 'crisop' ),
                        'icon' => 'eicon-h-align-center'
                    ],
                    'right' => [
                        'title' => esc_html__( 'Right', 'crisop' ),
                        'icon' => 'eicon-h-align-right'
                    ]
                ],
                'toggle' => true,
                'default' => 'flex-start'
            ]
        );
        $this->add_control( 'cat_divider',
            [
                'label' => esc_html__( 'CATEGORY', 'crisop' ),
                'type' => Controls_Manager::HEADING,
                'separator' => 'before'
            ]
        );
        $this->add_control( 'cat_color',
            [
                'label' => esc_html__( 'Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [ '{{WRAPPER}} .ninetheme-banner-content .ninetheme-banner-catname' => 'color:{{VALUE}};' ]
            ]
        );
        $this->add_control( 'cat_bgcolor',
            [
                'label' => esc_html__( 'Background Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [ '{{WRAPPER}} .ninetheme-banner-content .ninetheme-banner-catname' => 'background-color:{{VALUE}};' ]
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'cat_typo',
                'label' => esc_html__( 'Typography', 'crisop' ),
                'selector' => '{{WRAPPER}} .ninetheme-banner-content .ninetheme-banner-catname'
            ]
        );
        $this->add_responsive_control( 'cat_padding',
            [
                'label' => esc_html__( 'Padding', 'crisop' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', 'em', '%' ],
                'selectors' => ['{{WRAPPER}} .ninetheme-banner-content .ninetheme-banner-catname' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};']
            ]
        );
        $this->add_responsive_control( 'cat_margin',
            [
                'label' => esc_html__( 'Margin', 'crisop' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', 'em', '%' ],
                'selectors' => ['{{WRAPPER}} .ninetheme-banner-content .ninetheme-banner-catname' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};']
            ]
        );
        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name' => 'cat_border',
                'selector' => '{{WRAPPER}} .ninetheme-banner-content .ninetheme-banner-catname'
            ]
        );
        $this->add_responsive_control( 'cat_border_radius',
            [
                'label' => esc_html__( 'Border Radius', 'crisop' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%' ],
                'selectors' => ['{{WRAPPER}} .ninetheme-banner-content .ninetheme-banner-catname' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}}']
            ]
        );
        $this->add_control( 'catcount_divider',
            [
                'label' => esc_html__( 'CATEGORY COUNT', 'crisop' ),
                'type' => Controls_Manager::HEADING,
                'separator' => 'before'
            ]
        );
        $this->add_control( 'catcount_color',
            [
                'label' => esc_html__( 'Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [ '{{WRAPPER}} .ninetheme-banner-content .ninetheme-banner-catcount' => 'color:{{VALUE}};' ]
            ]
        );
        $this->add_control( 'catcount_bgcolor',
            [
                'label' => esc_html__( 'Background Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [ '{{WRAPPER}} .ninetheme-banner-content .ninetheme-banner-catcount' => 'color:{{VALUE}};' ]
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'catcount_typo',
                'label' => esc_html__( 'Typography', 'crisop' ),
                'selector' => '{{WRAPPER}} .ninetheme-banner-content .ninetheme-banner-catcount'
            ]
        );
        $this->add_responsive_control( 'catcount_padding',
            [
                'label' => esc_html__( 'Padding', 'crisop' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', 'em', '%' ],
                'selectors' => ['{{WRAPPER}} .ninetheme-banner-content .ninetheme-banner-catcount' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};']
            ]
        );
        $this->add_responsive_control( 'catcount_margin',
            [
                'label' => esc_html__( 'Margin', 'crisop' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', 'em', '%' ],
                'selectors' => ['{{WRAPPER}} .ninetheme-banner-content .ninetheme-banner-catcount' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};']
            ]
        );
        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name' => 'catcount_border',
                'selector' => '{{WRAPPER}} .ninetheme-banner-content .ninetheme-banner-catcount'
            ]
        );
        $this->add_responsive_control( 'catcount_border_radius',
            [
                'label' => esc_html__( 'Border Radius', 'crisop' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%' ],
                'selectors' => ['{{WRAPPER}} .ninetheme-banner-content .ninetheme-banner-catcount' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}}']
            ]
        );
        $this->add_control( 'title_divider',
            [
                'label' => esc_html__( 'TITLE', 'crisop' ),
                'type' => Controls_Manager::HEADING,
                'separator' => 'before'
            ]
        );
        $this->add_control( 'title_color',
            [
                'label' => esc_html__( 'Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [ '{{WRAPPER}} .ninetheme-banner-content .ninetheme-banner-title' => 'color:{{VALUE}};' ]
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'title_typo',
                'label' => esc_html__( 'Typography', 'crisop' ),
                'selector' => '{{WRAPPER}} .ninetheme-banner-content .ninetheme-banner-title'
            ]
        );
        $this->add_responsive_control( 'title_padding',
            [
                'label' => esc_html__( 'Padding', 'crisop' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', 'em', '%' ],
                'selectors' => ['{{WRAPPER}} .ninetheme-banner-content .ninetheme-banner-title' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};']
            ]
        );
        $this->add_responsive_control( 'title_margin',
            [
                'label' => esc_html__( 'Margin', 'crisop' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', 'em', '%' ],
                'selectors' => ['{{WRAPPER}} .ninetheme-banner-content .ninetheme-banner-title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};']
            ]
        );
        $this->add_control( 'desc_divider',
            [
                'label' => esc_html__( 'DESCRIPTION', 'crisop' ),
                'type' => Controls_Manager::HEADING,
                'separator' => 'before'
            ]
        );
        $this->add_control( 'desc_color',
            [
                'label' => esc_html__( 'Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [ '{{WRAPPER}} .ninetheme-banner-content .ninetheme-banner-desc' => 'color:{{VALUE}};' ]
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'desc_typo',
                'label' => esc_html__( 'Typography', 'crisop' ),
                'selector' => '{{WRAPPER}} .ninetheme-banner-content .ninetheme-banner-desc'
            ]
        );
        $this->add_responsive_control( 'desc_padding',
            [
                'label' => esc_html__( 'Padding', 'crisop' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', 'em', '%' ],
                'selectors' => ['{{WRAPPER}} .ninetheme-banner-content .ninetheme-banner-desc' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};']
            ]
        );
        $this->add_responsive_control( 'desc_margin',
            [
                'label' => esc_html__( 'Margin', 'crisop' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', 'em', '%' ],
                'selectors' => ['{{WRAPPER}} .ninetheme-banner-content .ninetheme-banner-desc' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};']
            ]
        );
        $this->add_control( 'btn_divider',
            [
                'label' => esc_html__( 'BUTTON', 'crisop' ),
                'type' => Controls_Manager::HEADING,
                'separator' => 'before'
            ]
        );
        $this->add_control( 'btn_color',
            [
                'label' => esc_html__( 'Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [ '{{WRAPPER}} .ninetheme-banner-content .ninetheme-banner-button' => 'color:{{VALUE}};' ]
            ]
        );
        $this->add_control( 'btn_hvrcolor',
            [
                'label' => esc_html__( 'Hover Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [ '{{WRAPPER}} .ninetheme-woo-banner-wrapper:hover .ninetheme-banner-content .ninetheme-banner-button' => 'color:{{VALUE}};' ]
            ]
        );
        $this->add_control( 'btn_bgcolor',
            [
                'label' => esc_html__( 'Background Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [ '{{WRAPPER}} .ninetheme-banner-content .ninetheme-banner-button' => 'background-color:{{VALUE}};' ]
            ]
        );
        $this->add_control( 'btn_hvrbgcolor',
            [
                'label' => esc_html__( 'Hover Background Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [ '{{WRAPPER}} .ninetheme-woo-banner-wrapper:hover .ninetheme-banner-content .ninetheme-banner-button' => 'background-color:{{VALUE}};' ]
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'btn_typo',
                'label' => esc_html__( 'Typography', 'crisop' ),
                'selector' => '{{WRAPPER}} .ninetheme-banner-content .ninetheme-banner-button'
            ]
        );
        $this->add_responsive_control( 'btn_padding',
            [
                'label' => esc_html__( 'Padding', 'crisop' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', 'em', '%' ],
                'selectors' => ['{{WRAPPER}} .ninetheme-banner-content .ninetheme-banner-button' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};']
            ]
        );
        $this->add_responsive_control( 'btn_margin',
            [
                'label' => esc_html__( 'Margin', 'crisop' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', 'em', '%' ],
                'selectors' => ['{{WRAPPER}} .ninetheme-banner-content .ninetheme-banner-button' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};']
            ]
        );
        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name' => 'btn_border',
                'selector' => '{{WRAPPER}} .ninetheme-banner-content .ninetheme-banner-button'
            ]
        );
        $this->add_responsive_control( 'btn_border_radius',
            [
                'label' => esc_html__( 'Border Radius', 'crisop' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%' ],
                'selectors' => ['{{WRAPPER}} .ninetheme-banner-content .ninetheme-banner-button' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}}']
            ]
        );
        $this->end_controls_section();
        /*****   END CONTROLS SECTION   ******/
    }

    protected function render() {

        if ( ! class_exists('WooCommerce') ) {
            return;
        }
        
        $settings  = $this->get_settings_for_display();

        $term  = get_term( $settings['category'], 'product_cat' );
        $name  = !empty( $term ) ? $term->name : '';
        $count = !empty( $term ) ? $term->count : '';
        if ( !empty( $settings['link']['url'] ) ) {
            $target = !empty( $settings['link']['is_external'] ) ? ' target="_blank"' : '';
            $rel = !empty( $settings['link']['nofollow'] ) ? ' rel="nofollow"' : '';
            $link = $settings['link']['url'];
        } else {
            $link = get_category_link( $settings['category'] );
        }


        $size = $settings['thumbnail_size'] ? $settings['thumbnail_size'] : 'thumbnail';
        if ( 'custom' == $size ) {
            $sizew = $settings['thumbnail_custom_dimension']['width'];
            $sizeh = $settings['thumbnail_custom_dimension']['height'];
            $size = [ $sizew, $sizeh ];
        }
        
        $full_height = $settings['full_height'] ? ' full-height' : '';

        echo '<div class="ninetheme-woo-banner-wrapper banner-style-'.$settings['baner_style'].$full_height.'">';

            $count_text = $settings['count_text'] ? ' '.$settings['count_text'] : '';

            if ( !empty( $settings['link']['url'] ) ) {
                $target = !empty( $settings['link']['is_external'] ) ? ' target="_blank"' : '';
                $rel = !empty( $settings['link']['nofollow'] ) ? ' rel="nofollow"' : '';
                echo '<a class="ninetheme-banner-link" href="'.$settings['link']['url'].'"'.$target.$rel.'></a>';
            } else {
                echo '<a class="ninetheme-banner-link" href="'.get_category_link( $settings['category'] ).'"></a>';
            }
            if ( $settings['use_video'] == 'yes' ) {

                $vid      = $settings['video_id'];
                $as_ratio = $settings['aspect_ratio'] ? $settings['aspect_ratio'] : '16:9';
                $provider = $settings['video_provider'];
                $start    = $settings['video_start'] ? '&start='.$settings['video_start'] : '';
                $end      = $settings['video_end'] ? '&end='.$settings['video_end'] : '';
                $vstart   = $settings['video_start'] ? $settings['video_start'].',' : '';
                $vend     = $settings['video_end'] ? $settings['video_end'] : '';
                $vtime    = $vstart || $vend ? '#t='.$vstart.$vend : '';
                $playlist = $settings['video_loop'] ? 'playlist='.$vid : '';
                $loop     = $settings['video_loop'] ? 1 : 0;
                $autocalc = $settings['auto_calculate'] == 'yes' ? ' ninetheme-video-calculate' : '';

                echo '<div class="ninetheme-woo-banner-iframe-wrapper ninetheme-video-'.$provider.$autocalc.'" data-ninetheme-bg-video="'.$vid.'">';

                    if ( $provider == 'vimeo' && $vid ) {

                        echo '<iframe data-bg-aspect-ratio="'.$as_ratio.'" class="lazy" loading="lazy" src="https://player.vimeo.com/video/'.$vid.'?autoplay=1&loop='.$loop.'&title=0&byline=0&portrait=0&sidedock=0&controls=0&playsinline=1&muted=1" allow="autoplay; fullscreen; picture-in-picture" allowfullscreen></iframe>';

                    } elseif ( $provider == 'youtube' && $vid ) {

                        echo '<iframe data-bg-aspect-ratio="'.$as_ratio.'" class="lazy" loading="lazy" data-src="https://www.youtube.com/embed/'.$vid.'?'.$playlist.'&modestbranding=0&rel=0&controls=0&autoplay=1&enablejsapi=1&showinfo=0&mute=1&loop='.$loop.$start.$end.'" allow="autoplay; fullscreen; accelerometer; autoplay; clipboard-write; encrypted-media; gyroscope; picture-in-picture" allowfullscreen></iframe>';

                    } elseif ( $provider == 'iframe' && $settings['iframe_embed'] ) {

                        echo do_shortcode( $settings['iframe_embed'] );

                    } elseif ( $provider == 'local' && $settings['loacal_video_url'] ) {

                        echo '<video data-bg-aspect-ratio="'.$as_ratio.'" class="lazy" loading="lazy" controls="0" autoplay="true" loop="true" muted="true" playsinline="true" data-src="'.$settings['loacal_video_url'].$vtime.'"></video>';
                    }

                echo '</div>';

            } else {
                if ( !empty( $settings['image']['id'] ) ) {
                    echo '<div class="ninetheme-banner-image">';
                        echo wp_get_attachment_image( $settings['image']['id'], $size, false );
                    echo '</div>';
                }
            }

            echo '<div class="ninetheme-banner-content">';
                echo '<div class="ninetheme-banner-content-top">';
                    foreach (  $settings['content_orders'] as $item ) {
                        if ( $name && $item['item_order'] == 'cat' && $item['item_position'] == 'top' ) {
                            echo '<span class="ninetheme-banner-catname banner-content-item">'.$name.'</span>';
                        }
                        if ( $name && $item['item_order'] == 'count' && $item['item_position'] == 'top' ) {
                            echo '<span class="ninetheme-banner-catcount banner-content-item">'.$count.$count_text.'</span>';
                        }
                        if ( $settings['title'] && $item['item_order'] == 'title' && $item['item_position'] == 'top' ) {
                            echo '<'.$settings['tag'].' class="ninetheme-banner-title banner-content-item">'.$settings['title'].'</'.$settings['tag'].'>';
                        }
                        if ( $settings['desc'] && $item['item_order'] == 'desc' && $item['item_position'] == 'top' ) {
                            echo '<span class="ninetheme-banner-desc banner-content-item">'.$settings['desc'].'</span>';
                        }
                        if ( $settings['btn_title'] && $item['item_order'] == 'button' && $item['item_position'] == 'top' ) {
                            echo '<span class="ninetheme-banner-button banner-content-item">'.$settings['btn_title'].' ';if ( !empty( $settings['icon']['value'] ) ) { Icons_Manager::render_icon( $settings['icon'], [ 'aria-hidden' => 'true' ] ); }echo '</span>';
                        }
                    }
                echo '</div>';
                echo '<div class="ninetheme-banner-content-center">';
                    foreach (  $settings['content_orders'] as $item ) {
                        if ( $name && $item['item_order'] == 'cat' && $item['item_position'] == 'center' ) {
                            echo '<span class="ninetheme-banner-catname banner-content-item">'.$name.'</span>';
                        }
                        if ( $name && $item['item_order'] == 'count' && $item['item_position'] == 'center' ) {
                            echo '<span class="ninetheme-banner-catcount banner-content-item">'.$count.$count_text.'</span>';
                        }
                        if ( $settings['title'] && $item['item_order'] == 'title' && $item['item_position'] == 'center' ) {
                            echo '<'.$settings['tag'].' class="ninetheme-banner-title banner-content-item">'.$settings['title'].'</'.$settings['tag'].'>';
                        }
                        if ( $settings['desc'] && $item['item_order'] == 'desc' && $item['item_position'] == 'center' ) {
                            echo '<span class="ninetheme-banner-desc banner-content-item">'.$settings['desc'].'</span>';
                        }
                        if ( $settings['btn_title'] && $item['item_order'] == 'button' && $item['item_position'] == 'center' ) {
                            echo '<span class="ninetheme-banner-button banner-content-item">'.$settings['btn_title'].' ';if ( !empty( $settings['icon']['value'] ) ) { Icons_Manager::render_icon( $settings['icon'], [ 'aria-hidden' => 'true' ] ); }echo '</span>';
                        }
                    }
                echo '</div>';
                echo '<div class="ninetheme-banner-content-bottom">';
                    foreach (  $settings['content_orders'] as $item ) {
                        if ( $name && $item['item_order'] == 'cat' && $item['item_position'] == 'bottom' ) {
                            echo '<span class="ninetheme-banner-catname banner-content-item">'.$name.'</span>';
                        }
                        if ( $name && $item['item_order'] == 'count' && $item['item_position'] == 'bottom' ) {
                            echo '<span class="ninetheme-banner-catcount banner-content-item">'.$count.$count_text.'</span>';
                        }
                        if ( $settings['title'] && $item['item_order'] == 'title' && $item['item_position'] == 'bottom' ) {
                            echo '<'.$settings['tag'].' class="ninetheme-banner-title banner-content-item">'.$settings['title'].'</'.$settings['tag'].'>';
                        }
                        if ( $settings['desc'] && $item['item_order'] == 'desc' && $item['item_position'] == 'bottom' ) {
                            echo '<span class="ninetheme-banner-desc banner-content-item">'.$settings['desc'].'</span>';
                        }
                        if ( $settings['btn_title'] && $item['item_order'] == 'button' && $item['item_position'] == 'bottom' ) {
                            echo '<span class="ninetheme-banner-button banner-content-item">'.$settings['btn_title'].' ';if ( !empty( $settings['icon']['value'] ) ) { Icons_Manager::render_icon( $settings['icon'], [ 'aria-hidden' => 'true' ] ); }echo '</span>';
                        }
                    }
                echo '</div>';
            echo '</div>';
        echo '</div>';

    }
}
