<?php

namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) exit; // If this file is called directly, abort.

class Ninetheme_Woo_Campaigns_Tab extends Widget_Base {
    use Ninetheme_Helper;
    public function get_name() {
        return 'ninetheme-woo-campaigns-tab';
    }
    public function get_title() {
        return 'WC Campaigns Tab (N)';
    }
    public function get_icon() {
        return 'eicon-slider-push';
    }
    public function get_categories() {
        return [ 'ninetheme-woo' ];
    }
    public function get_keywords() {
        return [ 'woocommerce', 'shop', 'store', 'cat', 'wc', 'woo', 'product', 'campaign' ];
    }
    public function get_style_depends() {
        return [ 'ninetheme-swiper' ];
    }
    public function get_script_depends() {
        return [ 'ninetheme-swiper','widget-tab-slider' ];
    }

    // Registering Controls
    protected function register_controls() {

        /*****   START CONTROLS SECTION   ******/
        $this->start_controls_section( 'post_query_section',
            [
                'label' => esc_html__( 'Query', 'crisop' ),
                'tab' => Controls_Manager::TAB_CONTENT
            ]
        );
        $this->add_control( 'box_style',
            [
                'label' => esc_html__( 'Box Style', 'crisop' ),
                'type' => Controls_Manager::SELECT,
                'default' => 'style-1',
                'options' => [
                    'style-1' => esc_html__( 'Style 1', 'crisop' ),
                    'style-2' => esc_html__( 'Style 2', 'crisop' ),
                ]
            ]
        );
        $repeater = new Repeater();
        $repeater->add_control( 'title',
            [
                'label' => esc_html__( 'Tab Title', 'crisop' ),
                'type' => Controls_Manager::TEXT,
                'default' => 'Tab Title',
                'label_block' => true,
            ]
        );
        $repeater->add_control( 'icon',
            [
                'label' => esc_html__( 'Tab Icon', 'crisop' ),
                'type' => Controls_Manager::ICONS,
                'default' => [
                    'value' => '',
                    'library' => 'solid'
                ]
            ]
        );
        $repeater->add_control( 'campaign',
            [
                'label' => esc_html__( 'Campaign', 'crisop' ),
                'type' => Controls_Manager::SELECT2,
                'multiple' => false,
                'options' => $this->ninetheme_cpt_taxonomies('ninetheme_product_campaigns'),
                'description' => esc_html__( 'Select Campaign', 'crisop' )
            ]
        );
        $repeater->add_control( 'post_per_page',
            [
                'label' => esc_html__( 'Posts Per Page for This Tab', 'crisop' ),
                'type' => Controls_Manager::NUMBER,
                'min' => 1,
                'max' => 1000,
                'default' => 10,
                'separator' => 'before'
            ]
        );
        $repeater->add_control( 'order',
            [
                'label' => esc_html__( 'Select Order', 'crisop' ),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'ASC' => esc_html__( 'Ascending', 'crisop' ),
                    'DESC' => esc_html__( 'Descending', 'crisop' )
                ],
                'default' => 'DESC'
            ]
        );
        $repeater->add_control( 'orderby',
            [
                'label' => esc_html__( 'Order By', 'crisop' ),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'id' => esc_html__( 'Post ID', 'crisop' ),
                    'menu_order' => esc_html__( 'Menu Order', 'crisop' ),
                    'rand' => esc_html__( 'Random', 'crisop' ),
                    'date' => esc_html__( 'Date', 'crisop' ),
                    'title' => esc_html__( 'Title', 'crisop' ),
                ],
                'default' => 'id'
            ]
        );
        $this->add_control( 'tabs',
            [
                'label' => esc_html__( 'Tabs', 'crisop' ),
                'type' => Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'title_field' => '{{title}}'
            ]
        );
        $this->add_group_control(
            Group_Control_Image_Size::get_type(),
            [
                'name' => 'thumbnail',
                'default' => 'medium_large'
            ]
        );
        $this->add_control( 'slider_title',
            [
                'label' => esc_html__( 'Title', 'crisop' ),
                'type' => Controls_Manager::TEXT,
                'default' => ''
            ]
        );
        $this->add_control( 'text',
            [
                'label' => esc_html__( 'Button Text', 'crisop' ),
                'type' => Controls_Manager::TEXT,
                'label_block' => true,
                'default' => esc_html__( 'Button Text', 'crisop' )
            ]
        );
        $this->add_control( 'btn_id',
            [
                'label' => esc_html__( 'Button ID', 'crisop' ),
                'type' => Controls_Manager::TEXT,
                'label_block' => true,
                'default' => ''
            ]
        );
        $this->add_control( 'link',
            [
                'label' => esc_html__( 'Button Link', 'crisop' ),
                'type' => Controls_Manager::URL,
                'label_block' => true,
                'default' => [
                    'url' => '#',
                    'is_external' => ''
                ],
                'show_external' => true,
                'condition' => ['btn_action' => 'link']
            ]
        );
        $this->end_controls_section();
        /*****   END CONTROLS SECTION   ******/

        /*****   START CONTROLS SECTION   ******/
        $this->start_controls_section('tab_style_section',
            [
                'label'=> esc_html__( 'Tab Style', 'crisop' )
            ]
        );
        $this->add_responsive_control( 'alignment',
            [
                'label' => esc_html__( 'Alignment', 'crisop' ),
                'type' => Controls_Manager::CHOOSE,
                'selectors' => ['{{WRAPPER}} .ninetheme-tab-nav' => 'justify-content: {{VALUE}};'],
                'options' => [
                    'flex-start' => [
                        'title' => esc_html__( 'Left', 'crisop' ),
                        'icon' => 'eicon-h-align-left'
                    ],
                    'center' => [
                        'title' => esc_html__( 'Center', 'crisop' ),
                        'icon' => 'eicon-h-align-center'
                    ],
                    'flex-end' => [
                        'title' => esc_html__( 'Right', 'crisop' ),
                        'icon' => 'eicon-h-align-right'
                    ]
                ],
                'toggle' => true,
                'default' => ''
            ]
        );
        $this->add_responsive_control( 'tab_clr',
           [
               'label' => esc_html__( 'Color', 'crisop' ),
               'type' => Controls_Manager::COLOR,
               'default' => '',
               'selectors' => [
                   '{{WRAPPER}} .ninetheme-tab-nav-item' => 'color: {{VALUE}};',
               ]
            ]
        );
        $this->add_responsive_control( 'tab_hvrclr',
           [
               'label' => esc_html__( 'Hover/Active Color', 'crisop' ),
               'type' => Controls_Manager::COLOR,
               'default' => '',
               'selectors' => [
                   '{{WRAPPER}} .ninetheme-tab-nav-item:hover,{{WRAPPER}} .ninetheme-tab-nav-item.is-active' => 'color: {{VALUE}};',
                   '{{WRAPPER}} .ninetheme-tab-nav-item:after' => 'background-color: {{VALUE}};',
                ]
            ]
        );
        $this->add_responsive_control( 'tab_bottom_lineclr',
           [
               'label' => esc_html__( 'Bottom Line Color', 'crisop' ),
               'type' => Controls_Manager::COLOR,
               'default' => '',
               'selectors' => [
                   '{{WRAPPER}} .ninetheme-tab-nav-item:after' => 'background-color: {{VALUE}};'
                ]
            ]
        );
        $this->add_responsive_control( 'tab_spacing',
            [
                'label' => esc_html__( 'Space', 'crisop' ),
                'type' => Controls_Manager::NUMBER,
                'min' => 0,
                'max' => 200,
                'step' => 1,
                'default' => '',
                'selectors' => ['{{WRAPPER}} .ninetheme-tab-nav-item + .ninetheme-tab-nav-item' => 'margin-left: {{SIZE}}px;']
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'tab_typo',
                'label' => esc_html__( 'Typography', 'crisop' ),
                'selector' => '{{WRAPPER}} .ninetheme-tab-nav-item'
            ]
        );
        $this->add_control( 'icon_pos',
            [
                'label' => esc_html__( 'Icon Position', 'crisop' ),
                'type' => Controls_Manager::SELECT,
                'default' => 'icon-top',
                'options' => [
                    'icon-left' => esc_html__( 'Before', 'crisop' ),
                    'icon-right' => esc_html__( 'After', 'crisop' ),
                    'icon-top' => esc_html__( 'Top', 'crisop' ),
                    'icon-bottom' => esc_html__( 'Bottom', 'crisop' )
                ],
            ]
        );
        $this->add_control( 'icon_spacing',
            [
                'label' => esc_html__( 'Icon Spacing', 'crisop' ),
                'type' => Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'max' => 300
                    ]
                ],
                'selectors' => [
                    '{{WRAPPER}} .ninetheme-tab-nav-item.has-icon.icon-left .ninetheme-tab-icon' => 'margin-right: {{SIZE}}px;',
                    '{{WRAPPER}} .ninetheme-tab-nav-item.has-icon.icon-right .ninetheme-tab-icon' => 'margin-left: {{SIZE}}px;',
                    '{{WRAPPER}} .ninetheme-tab-nav-item.has-icon.icon-left,{{WRAPPER}} .ninetheme-tab-nav-item.has-icon.icon-right' => 'flex-direction:row;',
                    '{{WRAPPER}} .ninetheme-tab-nav-item.has-icon.icon-top .ninetheme-tab-icon' => 'margin-bottom: {{SIZE}}px;',
                    '{{WRAPPER}} .ninetheme-tab-nav-item.has-icon.icon-bottom .ninetheme-tab-icon' => 'margin-top: {{SIZE}}px;',
                ],
                'default' => [
                    'unit' => 'px',
                    'size' => ''
                ],
            ]
        );
        $this->add_control( 'icon_size',
            [
                'label' => esc_html__( 'Icon Size', 'crisop' ),
                'type' => Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'max' => 300
                    ]
                ],
                'selectors' => [
                    '{{WRAPPER}} .ninetheme-tab-nav-item.has-icon .ninetheme-tab-icon' => 'font-size: {{SIZE}}px;',
                    '{{WRAPPER}} .ninetheme-tab-nav-item.has-icon svg' => 'max-width: {{SIZE}}px;max-height: {{SIZE}}px;'
                ],
            ]
        );
        $this->add_responsive_control( 'icon_clr',
           [
               'label' => esc_html__( 'Color', 'crisop' ),
               'type' => Controls_Manager::COLOR,
               'default' => '',
               'selectors' => [
                   '{{WRAPPER}} .ninetheme-tab-nav-item.has-icon i' => 'color: {{VALUE}};',
                   '{{WRAPPER}} .ninetheme-tab-nav-item.has-icon svg' => 'fill: {{VALUE}};'
               ]
            ]
        );
        $this->add_responsive_control( 'icon_hvrclr',
           [
               'label' => esc_html__( 'Hover/Active Color', 'crisop' ),
               'type' => Controls_Manager::COLOR,
               'default' => '',
               'selectors' => [
                   '{{WRAPPER}} .ninetheme-tab-nav-item.has-icon:hover i,{{WRAPPER}} .ninetheme-tab-nav-item.has-icon.is-active i' => 'color: {{VALUE}};',
                   '{{WRAPPER}} .ninetheme-tab-nav-item.has-icon:hover svg,{{WRAPPER}} .ninetheme-tab-nav-item.has-icon.is-active svg' => 'fill: {{VALUE}};'
                ]
            ]
        );
        $this->end_controls_section();
        /*****   END CONTROLS SECTION   ******/
        /*****   START CONTROLS SECTION   ******/
        $this->start_controls_section('post_style_section',
            [
                'label' => esc_html__( 'Post Style', 'crisop' )
            ]
        );
        $this->add_responsive_control( 'post_padding',
            [
                'label' => esc_html__( 'Padding', 'crisop' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px' ],
                'selectors' => ['{{WRAPPER}} .woocommerce .ninetheme-type-product .ninetheme-loop-product' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};']
            ]
        );
        $this->add_control( 'post_bgcolor',
            [
                'label' => esc_html__( 'Background Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [ '{{WRAPPER}} .woocommerce .ninetheme-type-product .ninetheme-loop-product' => 'background-color: {{VALUE}};' ]
            ]
        );
        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name' => 'post_border',
                'label' => esc_html__( 'Border', 'crisop' ),
                'selector' => '{{WRAPPER}} .woocommerce .ninetheme-type-product .ninetheme-loop-product'
            ]
        );
        $this->add_group_control(
            Group_Control_Box_Shadow::get_type(),
            [
                'name' => 'post_item_box_shadow',
                'label' => esc_html__( 'Box Shadow', 'crisop' ),
                'selector' => '{{WRAPPER}} .woocommerce .ninetheme-type-product .ninetheme-loop-product, {{WRAPPER}} .woocommerce .ninetheme-type-product .ninetheme-loop-product:before'
            ]
        );
        $this->add_control( 'stock_heading',
            [
                'label' => esc_html__( 'STOCK STATUS', 'crisop' ),
                'type' => Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );
        $this->add_control( 'instock_color',
            [
                'label' => esc_html__( 'In Stock Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => ['{{WRAPPER}} .ninetheme-loop-product .ninetheme-stock-status.ninetheme-instock' => 'color: {{VALUE}};']
            ]
        );
        $this->add_control( 'outofstock_color',
            [
                'label' => esc_html__( 'Out of Stock Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => ['{{WRAPPER}} .ninetheme-loop-product .ninetheme-stock-status.ninetheme-outofstock' => 'color: {{VALUE}};']
            ]
        );
        $this->add_control( 'labels_heading',
            [
                'label' => esc_html__( 'LABELS', 'crisop' ),
                'type' => Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );
        $this->add_control( 'deflabel_color',
            [
                'label' => esc_html__( 'Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => ['{{WRAPPER}} .ninetheme-label,{{WRAPPER}} .ninetheme-label.ninetheme-bg-default' => 'color: {{VALUE}};']
            ]
        );
        $this->add_control( 'deflabel_bgcolor',
            [
                'label' => esc_html__( 'Background Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => ['{{WRAPPER}} .ninetheme-label,{{WRAPPER}} .ninetheme-label.ninetheme-bg-default' => 'background-color: {{VALUE}};']
            ]
        );
        $this->add_control( 'discount_color',
            [
                'label' => esc_html__( 'Discount Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => ['{{WRAPPER}} .ninetheme-loop-product .ninetheme-label.ninetheme-discount' => 'color: {{VALUE}};']
            ]
        );
        $this->add_control( 'discount_bgcolor',
            [
                'label' => esc_html__( 'Discount Background Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => ['{{WRAPPER}} .ninetheme-loop-product .ninetheme-label.ninetheme-discount' => 'background-color: {{VALUE}};']
            ]
        );
        $this->add_control( 'addtocart_heading',
            [
                'label' => esc_html__( 'ADD TO CART', 'crisop' ),
                'type' => Controls_Manager::HEADING,
                'separator' => 'before'
            ]
        );
        $this->add_control( 'addtocarticon_color',
            [
                'label' => esc_html__( 'Add To Cart Color ( Type Icon )', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => ['{{WRAPPER}} .ninetheme-loop-product .ninetheme-product-button.btn-type-icon .ninetheme-svg-icon' => 'fill: {{VALUE}};']
            ]
        );
        $this->add_control( 'addtocarticon_bgcolor',
            [
                'label' => esc_html__( 'Add To Cart Background Color ( Type Icon )', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => ['{{WRAPPER}} .ninetheme-loop-product .ninetheme-product-button.btn-type-icon' => 'background-color: {{VALUE}};']
            ]
        );
        $this->add_control( 'title_heading',
            [
                'label' => esc_html__( 'TITLE', 'crisop' ),
                'type' => Controls_Manager::HEADING,
                'separator' => 'before'
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'title_typo',
                'label' => esc_html__( 'Typography', 'crisop' ),
                'selector' => '{{WRAPPER}} .woocommerce .ninetheme-type-product .ninetheme-loop-product-name'
            ]
        );
        $this->add_control( 'title_color',
            [
                'label' => esc_html__( 'Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => ['{{WRAPPER}} .woocommerce .ninetheme-type-product .ninetheme-loop-product-name' => 'color: {{VALUE}};']
            ]
        );
        $this->add_control( 'price_heading',
            [
                'label' => esc_html__( 'PRICE', 'crisop' ),
                'type' => Controls_Manager::HEADING,
                'separator' => 'before'
            ]
        );
        $this->add_control( 'price_color',
            [
                'label' => esc_html__( 'Price Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => ['{{WRAPPER}} .woocommerce .ninetheme-type-product span.del > span' => 'color: {{VALUE}};']
            ]
        );
        $this->add_control( 'price_color2',
            [
                'label' => esc_html__( 'Price Color 2', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => ['{{WRAPPER}}  .woocommerce .ninetheme-type-product .ninetheme-price' => 'color: {{VALUE}};']
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'price_typo',
                'label' => esc_html__( 'Typography', 'crisop' ),
                'selector' => '{{WRAPPER}} .woocommerce .ninetheme-type-product .ninetheme-price'
            ]
        );
        $this->end_controls_section();
        /*****   END CONTROLS SECTION   ******/
       /*****   START CONTROLS SECTION   ******/
        $this->start_controls_section('slider_options_section',
            [
                'label'=> esc_html__( 'SLIDER OPTIONS', 'crisop' ),
                'tab' => Controls_Manager::TAB_CONTENT
            ]
        );
        $this->add_control( 'autoplay',
            [
                'label' => esc_html__( 'Autoplay', 'crisop' ),
                'type' => Controls_Manager::SWITCHER,
                'default' => 'yes'
            ]
        );
        $this->add_control( 'nav',
            [
                'label' => esc_html__( 'Navigation', 'crisop' ),
                'type' => Controls_Manager::SWITCHER,
                'default' => 'yes'
            ]
        );
        $this->add_control( 'dots',
            [
                'label' => esc_html__( 'Dots', 'crisop' ),
                'type' => Controls_Manager::SWITCHER,
                'default' => 'yes'
            ]
        );
        $this->add_control( 'space',
            [
                'label' => esc_html__( 'Space Between Items', 'crisop' ),
                'type' => Controls_Manager::NUMBER,
                'min' => 0,
                'max' => 100,
                'step' => 1,
                'default' => 30
            ]
        );
        $this->add_control( 'speed',
            [
                'label' => esc_html__( 'Speed', 'crisop' ),
                'type' => Controls_Manager::NUMBER,
                'min' => 100,
                'max' => 10000,
                'step' => 100,
                'default' => 1000
            ]
        );
        $this->add_control( 'mditems',
            [
                'label' => esc_html__( 'Items', 'crisop' ),
                'type' => Controls_Manager::NUMBER,
                'min' => 1,
                'max' => 20,
                'step' => 1,
                'default' => 5
            ]
        );
        $this->add_control( 'mditems2',
            [
                'label' => esc_html__( 'Items Laptop', 'crisop' ),
                'type' => Controls_Manager::NUMBER,
                'min' => 1,
                'max' => 20,
                'step' => 1,
                'default' => 4
            ]
        );
        $this->add_control( 'smitems',
            [
                'label' => esc_html__( 'Items Tablet', 'crisop' ),
                'type' => Controls_Manager::NUMBER,
                'min' => 1,
                'max' => 20,
                'step' => 1,
                'default' => 3
            ]
        );
        $this->add_control( 'xsitems',
            [
                'label' => esc_html__( 'Items Phone', 'crisop' ),
                'type' => Controls_Manager::NUMBER,
                'min' => 1,
                'max' => 20,
                'step' => 1,
                'default' => 2
            ]
        );
        $this->add_control( 'navs_type',
            [
                'label' => esc_html__( 'Navs Type', 'crisop' ),
                'type' => Controls_Manager::SELECT,
                'default' => 'both',
                'options' => [
                    'both' => esc_html__( 'Both Nav and Dots', 'crisop' ),
                    'default' => esc_html__( 'Nav Center + Dots Bottom', 'crisop' )
                ]
            ]
        );
        $this->add_responsive_control( 'navs_horizontal_pos',
            [
                'label' => esc_html__( 'Nav Horizontal Alignment', 'crisop' ),
                'type' => Controls_Manager::CHOOSE,
                'options' => [
                    'flex-start' => [
                        'title' => esc_html__( 'Left', 'crisop' ),
                        'icon' => 'eicon-h-align-left'
                    ],
                    'center' => [
                        'title' => esc_html__( 'Center', 'crisop' ),
                        'icon' => 'eicon-h-align-center'
                    ],
                    'flex-end' => [
                        'title' => esc_html__( 'Right', 'crisop' ),
                        'icon' => 'eicon-h-align-right'
                    ]
                ],
                'toggle' => true,
                'default' => '',
                'selectors' => [ '{{WRAPPER}} .ninetheme-swiper-theme-style .ninetheme-slider-nav' => 'justify-content:{{VALUE}};' ],
                'condition' => [ 'slider_title' => '' ]
            ]
        );
        $this->add_responsive_control( 'navs_vertical_pos',
            [
                'label' => esc_html__( 'Nav Vertical Position', 'crisop' ),
                'type' => Controls_Manager::CHOOSE,
                'options' => [
                    'top' => [
                        'title' => esc_html__( 'Top', 'crisop' ),
                        'icon' => 'eicon-v-align-top'
                    ],
                    'bottom' => [
                        'title' => esc_html__( 'Bottom', 'crisop' ),
                        'icon' => 'eicon-v-align-bottom'
                    ]
                ],
                'toggle' => true,
                'default' => 'top',
                'condition' => [
                    'navs_type' => 'both'
                ]
            ]
        );
        $this->add_responsive_control( 'navs_horizontal_pos2',
            [
                'label' => esc_html__( 'Nav Horizontal Alignment', 'crisop' ),
                'type' => Controls_Manager::CHOOSE,
                'options' => [
                    'flex-start' => [
                        'title' => esc_html__( 'Left', 'crisop' ),
                        'icon' => 'eicon-h-align-left'
                    ],
                    'center' => [
                        'title' => esc_html__( 'Center', 'crisop' ),
                        'icon' => 'eicon-h-align-center'
                    ],
                    'flex-end' => [
                        'title' => esc_html__( 'Right', 'crisop' ),
                        'icon' => 'eicon-h-align-right'
                    ]
                ],
                'toggle' => true,
                'default' => '',
                'selectors' => [ '{{WRAPPER}} .ninetheme-swiper-theme-style .ninetheme-slider-nav.nav-bottom' => 'justify-content:{{VALUE}};' ],
                'condition' => [
                    'slider_title!' => '',
                    'navs_type' => 'both',
                    'navs_vertical_pos' => 'bottom'
                ]
            ]
        );
        $this->add_responsive_control( 'navs_spacing',
            [
                'label' => esc_html__( 'Nav Spacing ( px )', 'crisop' ),
                'type' => Controls_Manager::SLIDER,
                'range' => [
                    'px' => ['max' => 300]
                ],
				'default' => [
					'unit' => 'px',
					'size' => 30,
				],
                'selectors' => [
                    '{{WRAPPER}} .ninetheme-swiper-theme-style.nav-type-both .ninetheme-slider-nav.nav-bottom' => 'margin-top: {{SIZE}}px;',
                    '{{WRAPPER}} .ninetheme-swiper-theme-style.nav-type-both .ninetheme-tab-nav-inner.nav-top' => 'margin-bottom: {{SIZE}}px;',
                ],
                'condition' => [
                    'navs_type' => 'both'
                ]
            ]
        );
        $this->end_controls_section();
        /*****   END CONTROLS SECTION   ******/

        /*****   START CONTROLS SECTION   ******/
        $this->start_controls_section('navs_style_section',
            [
                'label'=> esc_html__( 'SLIDER NAV STYLE', 'crisop' ),
                'tab' => Controls_Manager::TAB_CONTENT,
                'condition' => [ 'nav' => 'yes' ]
            ]
        );
        $this->add_control( 'navs_size',
            [
                'label' => esc_html__( 'Size', 'crisop' ),
                'type' => Controls_Manager::NUMBER,
                'min' => 0,
                'max' => 100,
                'step' => 1,
                'default' => '',
                'selectors' => [ '{{WRAPPER}} .ninetheme-swiper-theme-style .swiper-button-prev:after,{{WRAPPER}} .ninetheme-swiper-theme-style .swiper-button-next:after' => 'font-size:{{SIZE}}px;' ]
            ]
        );
        $this->add_control( 'navs_color',
            [
                'label' => esc_html__( 'Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => ['{{WRAPPER}} .ninetheme-swiper-theme-style .swiper-button-prev:after,{{WRAPPER}} .ninetheme-swiper-theme-style .swiper-button-next:after' => 'color:{{VALUE}};' ]
            ]
        );
        $this->add_control( 'navs_hvrcolor',
            [
                'label' => esc_html__( 'Hover Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => ['{{WRAPPER}} .ninetheme-swiper-theme-style .swiper-button-prev:hover:after,{{WRAPPER}} .ninetheme-swiper-theme-style .swiper-button-next:hover:after' => 'color:{{VALUE}};' ]
            ]
        );
        $this->add_control( 'navs_bgcolor',
            [
                'label' => esc_html__( 'Background olor', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => ['{{WRAPPER}} .ninetheme-swiper-theme-style .swiper-button-prev,{{WRAPPER}} .ninetheme-swiper-theme-style .swiper-button-next' => 'background-color:{{VALUE}};' ]
            ]
        );
        $this->add_control( 'navs_bghvrcolor',
            [
                'label' => esc_html__( 'Hover Background Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => ['{{WRAPPER}} .ninetheme-swiper-theme-style .swiper-button-prev:hover,{{WRAPPER}} .ninetheme-swiper-theme-style .swiper-button-next:hover' => 'background-color:{{VALUE}};' ]
            ]
        );
        $this->add_control( 'navs_brdcolor',
            [
                'label' => esc_html__( 'Border olor', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => ['{{WRAPPER}} .ninetheme-swiper-theme-style .swiper-button-prev,{{WRAPPER}} .ninetheme-swiper-theme-style .swiper-button-next' => 'border-color:{{VALUE}};' ]
            ]
        );
        $this->add_control( 'navs_brdhvrcolor',
            [
                'label' => esc_html__( 'Hover Border Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => ['{{WRAPPER}} .ninetheme-swiper-theme-style .swiper-button-prev:hover,{{WRAPPER}} .ninetheme-swiper-theme-style .swiper-button-next:hover' => 'border-color:{{VALUE}};' ]
            ]
        );

        $this->end_controls_section();
        /*****   END CONTROLS SECTION   ******/
        /*****   START CONTROLS SECTION   ******/
        $this->start_controls_section('dots_style_section',
            [
                'label'=> esc_html__( 'SLIDER DOTS STYLE', 'crisop' ),
                'tab' => Controls_Manager::TAB_CONTENT,
                'condition' => [ 'dots' => 'yes' ]
            ]
        );
        $this->add_responsive_control( 'dots_spacing',
            [
                'label' => esc_html__( 'Top Offset ( px )', 'crisop' ),
                'type' => Controls_Manager::SLIDER,
                'range' => [
                    'px' => ['max' => 300]
                ],
				'default' => [
					'unit' => 'px',
					'size' => 30
				],
                'selectors' => [
                    '{{WRAPPER}} .ninetheme-swiper-theme-style.nav-type-default .swiper-pagination' => 'margin-top: {{SIZE}}px;',
                ],
                'condition' => [
                    'navs_type' => 'default'
                ]
            ]
        );
        $this->add_responsive_control( 'dots_horizontal_pos',
            [
                'label' => esc_html__( 'Horizontal Alignment', 'crisop' ),
                'type' => Controls_Manager::CHOOSE,
                'options' => [
                    'left' => [
                        'title' => esc_html__( 'Left', 'crisop' ),
                        'icon' => 'eicon-h-align-left'
                    ],
                    'center' => [
                        'title' => esc_html__( 'Center', 'crisop' ),
                        'icon' => 'eicon-h-align-center'
                    ],
                    'right' => [
                        'title' => esc_html__( 'Right', 'crisop' ),
                        'icon' => 'eicon-h-align-right'
                    ]
                ],
                'toggle' => true,
                'default' => '',
                'selectors' => [ '{{WRAPPER}} .ninetheme-swiper-theme-style .swiper-pagination' => 'text-align:{{VALUE}};' ],
                'condition' => [
                    'navs_type' => 'default'
                ]
            ]
        );
        $this->add_control( 'dots_size',
            [
                'label' => esc_html__( 'Size', 'crisop' ),
                'type' => Controls_Manager::NUMBER,
                'min' => 0,
                'max' => 100,
                'step' => 1,
                'default' => '',
                'selectors' => [ '{{WRAPPER}} .swiper-pagination-bullets .swiper-pagination-bullet:before' => 'width:{{SIZE}}px;height:{{SIZE}}px;' ]
            ]
        );
        $this->add_control( 'dots_space',
            [
                'label' => esc_html__( 'Space', 'crisop' ),
                'type' => Controls_Manager::NUMBER,
                'min' => 0,
                'max' => 100,
                'step' => 1,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .swiper-horizontal > .swiper-pagination-bullets .swiper-pagination-bullet + .swiper-pagination-bullet' => 'margin: 0;margin-left: {{SIZE}}px;',
                    '{{WRAPPER}} .swiper-pagination-horizontal.swiper-pagination-bullets .swiper-pagination-bullet + .swiper-pagination-bullet' => 'margin: 0;margin-left: {{SIZE}}px;',
                ]
            ]
        );
        $this->start_controls_tabs( 'dots_nav_tabs');
        $this->start_controls_tab( 'dots_normal_tab',
            [ 'label' => esc_html__( 'Normal', 'crisop' ) ]
        );
        $this->add_control( 'dots_bgcolor',
            [
                'label' => esc_html__( 'Background', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => ['{{WRAPPER}} .swiper-pagination-bullets .swiper-pagination-bullet:before' => 'background-color:{{VALUE}};' ]
            ]
        );
        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name' => 'dots_border',
                'label' => esc_html__( 'Border', 'crisop' ),
                'selector' => '{{WRAPPER}} .swiper-pagination-bullets .swiper-pagination-bullet',
            ]
        );
        $this->add_responsive_control( 'dots_border_radius',
            [
                'label' => esc_html__( 'Border Radius', 'crisop' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px' ],
                'selectors' => [
                    '{{WRAPPER}} .swiper-pagination-bullets .swiper-pagination-bullet:before,{{WRAPPER}} .swiper-pagination-bullets .swiper-pagination-bullet' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};'
                ]
            ]
        );
        $this->end_controls_tab();
        $this->start_controls_tab( 'dots_hover_tab',
            [ 'label' => esc_html__( 'Active', 'crisop' ) ]
        );
        $this->add_control( 'dots_hvrbgcolor',
            [
                'label' => esc_html__( 'Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [ '{{WRAPPER}} .swiper-pagination-bullet.swiper-pagination-bullet-active:before' => 'background-color:{{VALUE}};' ]
            ]
        );
        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name' => 'dots_hvrborder',
                'label' => esc_html__( 'Border', 'crisop' ),
                'selector' => '{{WRAPPER}} .swiper-pagination-bullet.swiper-pagination-bullet-active'
            ]
        );
        $this->add_responsive_control( 'dots_hvrborder_radius',
            [
                'label' => esc_html__( 'Border Radius', 'crisop' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px' ],
                'selectors' => [
                    '{{WRAPPER}} .swiper-pagination-bullets .swiper-pagination-bullet.swiper-pagination-bullet-active:before,{{WRAPPER}} .swiper-pagination-bullets .swiper-pagination-bullet.swiper-pagination-bullet-active' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};'
                ]
            ]
        );
        $this->end_controls_tab();
        $this->end_controls_tabs();
        $this->end_controls_section();
        /*****   END CONTROLS SECTION   ******/
    }
    
    public function image_custom_size() {
        $settings = $this->get_settings_for_display();
        $size = $settings['thumbnail_size'] ? $settings['thumbnail_size'] : ninetheme_settings('product_imgsize','ninetheme-mini');
        if ( 'custom' == $size ) {
            $sizew = $settings['thumbnail_custom_dimension']['width'];
            $sizeh = $settings['thumbnail_custom_dimension']['height'];
            $size = [ $sizew, $sizeh ];
        }
        return $size;
    }
    
    public function set_shop_box_type() {
        return ninetheme_settings( 'shop_product_type', 4 );
    }
    
    protected function render() {
        if ( ! class_exists('WooCommerce') ) {
            return;
        }
        $settings  = $this->get_settings_for_display();
        $elementid = $this->get_id();

        $id         = \Elementor\Plugin::$instance->editor->is_edit_mode() ? '-edit-mode' : '';
        $count      = 1;
        $counttwo   = 1;
        $countthree = 1;
        $box_style  = $settings['box_style'];
        $space      = $settings['space'] ? $settings['space'] : 30;
        $space_item = 'style-2' == $box_style ? 0 : $space;
        $slider_options = array(
            "slidesPerView" => 1,
            "loop"          => false,
            "autoHeight"    => false,
            "observer"      => true,
            "observeParents" => true,
            "rewind"         => true,
            "observeSlideChildren" => true,
            "autoplay"      => 'yes' == $settings['autoplay'] ? [ "pauseOnMouseEnter" => true,"disableOnInteraction" => false ] : false,
            "speed"         => $settings['speed'],
            "spaceBetween"  => $space_item,
            "watchSlidesProgress" => true,
            "breakpoints"   => [
                "0" => [
                    "slidesPerView" => $settings['xsitems']
                ],
                "768" => [
                    "slidesPerView" => $settings['smitems']
                ],
                "992" => [
                    "slidesPerView" => $settings['mditems2']
                ],
                "1280" => [
                    "slidesPerView" => $settings['mditems']
                ]
            ]
        );

        add_filter( 'single_product_archive_thumbnail_size', [$this, 'image_custom_size' ] );

        $dots_none = 'yes' != $settings['dots'] ? ' dots-none': '';
        
        echo '<div class="ninetheme-elementor-widget ninetheme-wc-tab-slider'.$id.' ninetheme-swiper-slider-wrapper '.$box_style.' nav-type-'.$settings['navs_type'].$dots_none.'">';
            echo '<div class="ninetheme-tabs-wrapper">';
                if ( $settings['tabs'] ) {

                    echo '<div class="ninetheme-tab-nav-inner nav-top">';
                        echo '<div class="ninetheme-tab-nav">';
                            foreach ( $settings['tabs'] as $tab ) {
                                $is_active = 1 == $count ? ' is-active loaded' : '';
                                $terms = json_encode(
                                    array(
                                        'ajaxurl'  => admin_url( 'admin-ajax.php' ),
                                        'id'       => $tab['campaign'],
                                        'per_page' => $tab['post_per_page'],
                                        'order'    => $tab['order'],
                                        'orderby'  => $tab['orderby'],
                                        'scenario' => $tab['scenario'],
                                        'imgsize'  => $this->image_custom_size()
                                    )
                                );

                                $is_active = 1 == $count ? ' is-active loaded' : '';
                                if ( $tab['title'] ) {
                                    if ( !empty( $tab['icon']['value'] ) ) {
                                        echo '<span class="ninetheme-tab-nav-item has-icon '.$settings['icon_pos'].$is_active.'" data-tab-id="'.$tab['campaign'].$count.'" data-tab-terms=\''.$terms.'\'>';
                                            echo '<span class="ninetheme-tab-icon">';
                                                Icons_Manager::render_icon( $tab['icon'], [ 'aria-hidden' => 'true' ] );
                                            echo '</span>';
                                            echo '<span class="ninetheme-tab-nav-title">'.$tab['title'].'</span>';
                                        echo '</span>';
                                    } else {
                                        echo '<span class="ninetheme-tab-nav-item'.$is_active.'" data-tab-id="'.$tab['campaign'].$count.'" data-tab-terms=\''.$terms.'\'>'.$tab['title'].'</span>';
                                    }
                                }
                                $count++;
                            }
                        echo '</div>';

                        foreach ( $settings['tabs'] as $nav ) {
                            $isactive = 1 == $countthree ? ' is-active' : '';
                            $navcat = $nav['campaign'];
                            if ( 'both' == $settings['navs_type'] ) {
                                if ( 'bottom' != $settings['navs_vertical_pos'] && ( 'yes' == $settings['dots'] || 'yes' == $settings['nav'] ) ) {
                                    echo '<div class="ninetheme-slider-nav'.$isactive.'" data-nav-id="'.$navcat.$countthree.'">';
                                        if ( 'yes' == $settings['nav'] ) {
                                            echo '<div class="theme-swiper-btn swiper-button-prev slide-prev-'.$navcat.$countthree.'"></div>';
                                        }
                                        if ( 'yes' == $settings['dots'] ) {
                                            echo '<div class="swiper-pagination ninetheme-pagination-'.$navcat.$countthree.'"></div>';
                                        }
                                        if ( 'yes' == $settings['nav'] ) {
                                            echo '<div class="theme-swiper-btn swiper-button-next slide-next-'.$navcat.$countthree.'"></div>';
                                        }
                                    echo '</div>';
                                }
                            }
                            $countthree++;
                        }

                    echo '</div>';
                }

                foreach ( $settings['tabs'] as $tab ) {
                    $is_active = 1 == $counttwo ? ' is-active loaded' : '';
                    $isactive = 1 == $counttwo ? ' is-active' : '';
                    $tabcat = $tab['campaign'].$counttwo;
                    $slider_options["navigation"] = [
                        "nextEl" => ".slide-next-$tabcat",
                        "prevEl" => ".slide-prev-$tabcat"
                    ];
                    $slider_options["pagination"] = [
                        "el" => ".ninetheme-pagination-$tabcat",
                        "type" => "bullets",
                        "clickable" => true
                    ];

                    echo '<div class="ninetheme-tab-slider ninetheme-tab-page'.$is_active.'" data-cat-id="'.$tab['campaign'].$counttwo.'">';
                        echo '<div class="thm-tab-slider ninetheme-swiper-slider swiper-container ninetheme-swiper-theme-style" data-swiper-options=\''.json_encode($slider_options).'\'>';

                            echo '<div class="swiper-wrapper">';
                                $args = array(
                                    'post_type'      => 'product',
                                    'posts_per_page' => $tab['post_per_page'],
                                    'order'          => $tab['order'],
                                    'orderby'        => $tab['orderby']
                                );
                    
                                $args['tax_query'] = array(
                                    array(
                                        'taxonomy' => 'ninetheme_product_campaigns',
                                        'field'    => 'id',
                                        'terms'    => $tab['campaign'],
                                        'operator' => 'IN'
                                    )
                                );

                                $type = ninetheme_settings( 'shop_product_type', '4' );
                                $the_query = new \WP_Query( $args );
                                if ( $the_query->have_posts() && 1 == $counttwo ) {
                                    while ( $the_query->have_posts() ) {
                                        $the_query->the_post();
                                        if ( $visibility != 'hidden' ) {
                                            echo '<div class="swiper-slide product_item">';
                                                ninetheme_loop_product_widget_content( $box_style );
                                            echo '</div>';
                                        }
                                    }
                                }
                                wp_reset_postdata();
                            echo '</div>';
                        echo '</div>';
                        echo '<div class="loading-wrapper"><span class="ajax-loading"></span></div>';
                    echo '</div>';
                    $counttwo++;
                }
                $countfour = 1;
                foreach ( $settings['tabs'] as $nav ) {
                    $isactive = 1 == $countfour ? ' is-active' : '';
                    $navcat = $nav['campaign'].$countfour;
                    if ( 'both' == $settings['navs_type'] ) {
                        if ( 'bottom' == $settings['navs_vertical_pos'] && ( 'yes' == $settings['dots'] || 'yes' == $settings['nav'] ) ) {
                            echo '<div class="ninetheme-slider-nav nav-bottom'.$isactive.'" data-nav-id="'.$navcat.'">';
                                if ( 'yes' == $settings['nav'] ) {
                                    echo '<div class="theme-swiper-btn swiper-button-prev slide-prev-'.$navcat.'"></div>';
                                }
                                if ( 'yes' == $settings['dots'] ) {
                                    echo '<div class="swiper-pagination ninetheme-pagination-'.$navcat.'"></div>';
                                }
                                if ( 'yes' == $settings['nav'] ) {
                                    echo '<div class="theme-swiper-btn swiper-button-next slide-next-'.$navcat.'"></div>';
                                }
                            echo '</div>';
                        }
                    }
                    if ( 'default' == $settings['navs_type'] ) {
                        echo '<div class="ninetheme-slider-nav nav-default'.$isactive.'" data-nav-id="'.$navcat.'">';
                            if ( 'yes' == $settings['dots'] ) {
                                echo '<div class="swiper-pagination theme-style ninetheme-pagination-'.$navcat.'"></div>';
                            }
                            if ( 'yes' == $settings['nav'] ) {
                                echo '<div class="theme-swiper-btn theme-style nav-small swiper-button-prev slide-prev-'.$navcat.'"></div>';
                                echo '<div class="theme-swiper-btn theme-style nav-small swiper-button-next slide-next-'.$navcat.'"></div>';
                            }
                        echo '</div>';
                    }
                    $countfour++;
                }
            echo '</div>';
        echo '</div>';

        remove_filter( 'single_product_archive_thumbnail_size', [$this, 'image_custom_size' ] );
    }
}
