<?php

namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) exit; // If this file is called directly, abort.

class Ninetheme_Woo_Campaigns extends Widget_Base {
    use Ninetheme_Helper;
    public function get_name() {
        return 'ninetheme-woo-campaigns';
    }
    public function get_title() {
        return 'WC Campaigns (N)';
    }
    public function get_icon() {
        return 'eicon-gallery-grid';
    }
    public function get_categories() {
        return [ 'ninetheme-woo' ];
    }
    public function get_keywords() {
        return [ 'woocommerce', 'shop', 'store', 'cat', 'wc', 'woo', 'product', 'campaign' ];
    }
    public function get_style_depends() {
        return [ 'ninetheme-swiper' ];
    }
    public function get_script_depends() {
        return [ 'ninetheme-swiper', 'jquery-countdown' ];
    }
    // Registering Controls
    protected function register_controls() {
        /*****   START CONTROLS SECTION   ******/
        $this->start_controls_section( 'general_settings',
            [
                'label' => esc_html__('Product Campaigns', 'crisop'),
            ]
        );
        $this->add_control( 'type',
            [
                'label' => esc_html__( 'Type', 'crisop' ),
                'type' => Controls_Manager::SELECT,
                'default' => 'grid',
                'options' => [
                    'grid' => esc_html__( 'Grid', 'crisop' ),
                    'slider' => esc_html__( 'Slider', 'crisop' )
                ]
            ]
        );
        $this->add_control( 'box_style',
            [
                'label' => esc_html__( 'Box Style', 'crisop' ),
                'type' => Controls_Manager::SELECT,
                'default' => 'style-1',
                'options' => [
                    'style-1' => esc_html__( 'Style 1', 'crisop' ),
                    'style-2' => esc_html__( 'Style 2', 'crisop' ),
                ]
            ]
        );
		$campaigns = get_terms( 'ninetheme_product_campaigns' );

		$def = [];
		foreach ( $campaigns as $campaign ) {
			$def[] .= $campaign->term_id;
		}
        $this->add_control( 'campaigns_include',
            [
                'label' => esc_html__( 'Include Campaigns', 'crisop' ),
                'type' => Controls_Manager::SELECT2,
                'multiple' => true,
                'default' => $def,
                'options' => $this->ninetheme_cpt_taxonomies('ninetheme_product_campaigns'),
                'description' => 'Select campaigns(s) to Include'
            ]
        );
        $this->add_control( 'post_per_page',
            [
                'label' => esc_html__( 'Per Page', 'crisop' ),
                'type' => Controls_Manager::NUMBER,
                'min' => 1,
                'max' => 1000,
                'default' => 10,
            ]
        );
        $this->add_control( 'order',
            [
                'label' => esc_html__( 'Select Order', 'crisop' ),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'ASC' => esc_html__( 'Ascending', 'crisop' ),
                    'DESC' => esc_html__( 'Descending', 'crisop' )
                ],
                'default' => 'DESC'
            ]
        );
        $this->add_control( 'orderby',
            [
                'label' => esc_html__( 'Order By', 'crisop' ),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'id' => esc_html__( 'Post ID', 'crisop' ),
                    'menu_order' => esc_html__( 'Menu Order', 'crisop' ),
                    'rand' => esc_html__( 'Random', 'crisop' ),
                    'date' => esc_html__( 'Date', 'crisop' ),
                    'title' => esc_html__( 'Title', 'crisop' ),
                ],
                'default' => 'id',
            ]
        );
        $this->add_responsive_control( 'column',
            [
                'label' => esc_html__( 'Column Width', 'crisop' ),
                'type' => Controls_Manager::NUMBER,
                'min' => 1,
                'max' => 12,
                'step' => 1,
                'default' => 3,
                'selectors' => [ '{{WRAPPER}} .ninetheme-type-product' => '-ms-flex: 0 0 calc(100% / {{VALUE}} );flex: 0 0 calc(100% / {{VALUE}} );max-width: calc(100% / {{VALUE}} );' ],
                'condition' => ['type' => 'grid']
            ]
        );
        $this->add_responsive_control( 'item_space',
            [
                'label' => esc_html__( 'Space Between Column', 'crisop' ),
                'type' => Controls_Manager::NUMBER,
                'min' => 0,
                'max' => 100,
                'step' => 1,
                'default' => 30,
                'selectors' => [
                    '{{WRAPPER}} .style-1 .ninetheme-type-product' => 'padding-left: calc({{VALUE}}px / 2 ); padding-right: calc({{VALUE}}px / 2 ); margin-bottom: {{VALUE}}px',
                    '{{WRAPPER}} .style-1' => 'margin: 0 calc(-{{VALUE}}px / 2 ) -{{VALUE}}px calc(-{{VALUE}}px / 2 );',
                ],
                'condition' => ['type' => 'grid','box_style' => 'style-1']
            ]
        );
        $this->add_group_control(
            Group_Control_Image_Size::get_type(),
            [
                'name' => 'thumbnail',
                'default' => 'thumbnail'
            ]
        );
        $this->add_control( 'slider_title',
            [
                'label' => esc_html__( 'Title', 'crisop' ),
                'type' => Controls_Manager::TEXTAREA,
                'separator' => 'before'
            ]
        );
        $this->add_control( 'title_tag',
            [
                'label' => esc_html__( 'Title Tag', 'crisop' ),
                'type' => Controls_Manager::SELECT,
                'default' => 'h3',
                'options' => [
                    'h1' => esc_html__( 'H1', 'crisop' ),
                    'h2' => esc_html__( 'H2', 'crisop' ),
                    'h3' => esc_html__( 'H3', 'crisop' ),
                    'h4' => esc_html__( 'H4', 'crisop' ),
                    'h5' => esc_html__( 'H5', 'crisop' ),
                    'h6' => esc_html__( 'H6', 'crisop' ),
                    'div' => esc_html__( 'div', 'crisop' ),
                    'p' => esc_html__( 'p', 'crisop' )
                ],
                'condition' => [ 'slider_title!' => '' ]
            ]
        );
        $this->add_control( 'link_text',
            [
                'label' => esc_html__( 'Link Text', 'crisop' ),
                'type' => Controls_Manager::TEXT,
                'label_block' => true
            ]
        );
        $this->add_control( 'link',
            [
                'label' => esc_html__( 'Link', 'crisop' ),
                'type' => Controls_Manager::URL,
                'label_block' => true,
                'default' => [
                    'url' => '#',
                    'is_external' => ''
                ],
                'show_external' => true
            ]
        );
        $this->add_control( 'link_icon',
            [
                'label' => esc_html__( 'Link Icon', 'crisop' ),
                'type' => Controls_Manager::ICONS,
                'default' => [
                    'value' => '',
                    'library' => 'solid'
                ]
            ]
        );
        $this->add_control( 'short_desc',
            [
                'label' => esc_html__( 'Short Description', 'crisop' ),
                'type' => Controls_Manager::TEXTAREA,
                'label_block' => true
            ]
        );
        $this->end_controls_section();
        /*****   END CONTROLS SECTION   ******/
        /*****   START CONTROLS SECTION   ******/
        $this->start_controls_section( 'style_section',
            [
                'label'=> esc_html__( 'STYLE', 'crisop' ),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );
        $this->add_responsive_control( 'title_spacing',
            [
                'label' => esc_html__( 'Text Content Bottom Spacing ( px )', 'crisop' ),
                'type' => Controls_Manager::SLIDER,
                'range' => [
                    'px' => ['max' => 300]
                ],
				'default' => [
					'unit' => 'px',
					'size' => 30
				],
                'selectors' => ['{{WRAPPER}} .ninetheme-campaigns-title-wrapper .ninetheme-campaigns-title' => 'margin-bottom: {{SIZE}}px;']
            ]
        );
        $this->add_control( 'title_sdivider',
            [
                'label' => esc_html__( 'TITLE', 'crisop' ),
                'type' => Controls_Manager::HEADING,
                'separator' => 'before'
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'slider_title_typo',
                'label' => esc_html__( 'Title Typography', 'crisop' ),
                'selector' => '{{WRAPPER}} .ninetheme-campaigns-title',
            ]
        );
        $this->add_control( 'slider_title_color',
            [
                'label' => esc_html__( 'Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [ '{{WRAPPER}} .ninetheme-campaigns-title' => 'color:{{VALUE}};' ],
            ]
        );
        $this->add_control( 'link_text_sdivider',
            [
                'label' => esc_html__( 'LINK TEXT', 'crisop' ),
                'type' => Controls_Manager::HEADING,
                'separator' => 'before'
            ]
        );
        $this->add_control( 'link_color',
            [
                'label' => esc_html__( 'Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => ['{{WRAPPER}} .campaigns-link span' => 'color:{{VALUE}};' ],
            ]
        );
        $this->add_control( 'link_hover_color',
            [
                'label' => esc_html__( 'Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => ['{{WRAPPER}} .campaigns-link:hover span' => 'color:{{VALUE}};' ],
            ]
        );
        $this->add_control( 'bg_color',
            [
                'label' => esc_html__( 'Background Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => ['{{WRAPPER}} .campaigns-link' => 'background-color:{{VALUE}};' ],
            ]
        );
         $this->add_control( 'bg_hover_color',
            [
                'label' => esc_html__( 'Background Hover Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => ['{{WRAPPER}} .campaigns-link:hover' => 'background-color:{{VALUE}};' ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'link_typo',
                'label' => esc_html__( 'Typography', 'crisop' ),
                'selector' => '{{WRAPPER}} .campaigns-link .link-text',
            ]
        );
        $this->add_control( 'text_sdivider',
            [
                'label' => esc_html__( 'SHORT DESCRIPTION', 'crisop' ),
                'type' => Controls_Manager::HEADING,
                'separator' => 'before'
            ]
        );
        $this->add_control( 'text_color',
            [
                'label' => esc_html__( 'Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => ['{{WRAPPER}} .ninetheme-campaigns-desc' => 'color:{{VALUE}};' ]
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'text_typo',
                'label' => esc_html__( 'Typography', 'crisop' ),
                'selector' => '{{WRAPPER}} .ninetheme-campaigns-desc'
            ]
        );
        $this->end_controls_section();
        /*****   END CONTROLS SECTION   ******/

       /*****   START CONTROLS SECTION   ******/
        $this->start_controls_section('slider_options_section',
            [
                'label'=> esc_html__( 'SLIDER OPTIONS', 'crisop' ),
                'tab' => Controls_Manager::TAB_CONTENT,
                'condition' => ['type' => 'slider']
            ]
        );
        $this->add_control( 'loop',
            [
                'label' => esc_html__( 'Infinite', 'crisop' ),
                'type' => Controls_Manager::SWITCHER,
                'default' => 'no'
            ]
        );
        $this->add_control( 'autoplay',
            [
                'label' => esc_html__( 'Autoplay', 'crisop' ),
                'type' => Controls_Manager::SWITCHER,
                'default' => 'yes'
            ]
        );
        $this->add_control( 'centermode',
            [
                'label' => esc_html__( 'Center Mode', 'crisop' ),
                'type' => Controls_Manager::SWITCHER,
                'default' => 'no'
            ]
        );
        $this->add_control( 'nav',
            [
                'label' => esc_html__( 'Navigation', 'crisop' ),
                'type' => Controls_Manager::SWITCHER,
                'default' => 'yes'
            ]
        );
        $this->add_control( 'dots',
            [
                'label' => esc_html__( 'Dots', 'crisop' ),
                'type' => Controls_Manager::SWITCHER,
                'default' => 'yes'
            ]
        );
        $this->add_control( 'space',
            [
                'label' => esc_html__( 'Space Between Items', 'crisop' ),
                'type' => Controls_Manager::NUMBER,
                'min' => 0,
                'max' => 100,
                'step' => 1,
                'default' => 30
            ]
        );
        $this->add_control( 'speed',
            [
                'label' => esc_html__( 'Speed', 'crisop' ),
                'type' => Controls_Manager::NUMBER,
                'min' => 100,
                'max' => 10000,
                'step' => 100,
                'default' => 1000
            ]
        );
        $this->add_control( 'mditems',
            [
                'label' => esc_html__( 'Items', 'crisop' ),
                'type' => Controls_Manager::NUMBER,
                'min' => 1,
                'max' => 20,
                'step' => 1,
                'default' => 5
            ]
        );
        $this->add_control( 'mditems2',
            [
                'label' => esc_html__( 'Items Laptop', 'crisop' ),
                'type' => Controls_Manager::NUMBER,
                'min' => 1,
                'max' => 20,
                'step' => 1,
                'default' => 4
            ]
        );
        $this->add_control( 'smitems',
            [
                'label' => esc_html__( 'Items Tablet', 'crisop' ),
                'type' => Controls_Manager::NUMBER,
                'min' => 1,
                'max' => 20,
                'step' => 1,
                'default' => 3
            ]
        );
        $this->add_control( 'xsitems',
            [
                'label' => esc_html__( 'Items Phone', 'crisop' ),
                'type' => Controls_Manager::NUMBER,
                'min' => 1,
                'max' => 20,
                'step' => 1,
                'default' => 2
            ]
        );
        $this->add_responsive_control( 'navs_horizontal_pos',
            [
                'label' => esc_html__( 'Nav Horizontal Alignment', 'crisop' ),
                'type' => Controls_Manager::CHOOSE,
                'options' => [
                    'flex-start' => [
                        'title' => esc_html__( 'Left', 'crisop' ),
                        'icon' => 'eicon-h-align-left'
                    ],
                    'center' => [
                        'title' => esc_html__( 'Center', 'crisop' ),
                        'icon' => 'eicon-h-align-center'
                    ],
                    'flex-end' => [
                        'title' => esc_html__( 'Right', 'crisop' ),
                        'icon' => 'eicon-h-align-right'
                    ]
                ],
                'toggle' => true,
                'default' => '',
                'selectors' => [ '{{WRAPPER}} .ninetheme-swiper-theme-style .ninetheme-slider-nav' => 'justify-content:{{VALUE}};' ],
                'condition' => [ 'nav' => 'yes','dots' => 'yes' ]
            ]
        );
        $this->add_responsive_control( 'navs_spacing',
            [
                'label' => esc_html__( 'Nav Spacing ( px )', 'crisop' ),
                'type' => Controls_Manager::SLIDER,
                'range' => [
                    'px' => ['max' => 300]
                ],
				'default' => [
					'unit' => 'px',
					'size' => 30,
				],
                'selectors' => [
                    '{{WRAPPER}} .ninetheme-swiper-theme-style.nav-type-both .ninetheme-slider-nav.nav-bottom' => 'margin-top: {{SIZE}}px;',
                ],
                'condition' => [ 'nav' => 'yes','dots' => 'yes' ]
            ]
        );
        $this->end_controls_section();
        /*****   END CONTROLS SECTION   ******/

        /*****   START CONTROLS SECTION   ******/
        $this->start_controls_section('navs_style_section',
            [
                'label'=> esc_html__( 'SLIDER NAV STYLE', 'crisop' ),
                'tab' => Controls_Manager::TAB_CONTENT,
                'condition' => [ 'nav' => 'yes' ]
            ]
        );
        $this->add_control( 'navs_size',
            [
                'label' => esc_html__( 'Size', 'crisop' ),
                'type' => Controls_Manager::NUMBER,
                'min' => 0,
                'max' => 100,
                'step' => 1,
                'default' => '',
                'selectors' => [ '{{WRAPPER}} .ninetheme-swiper-theme-style .swiper-button-prev:after,{{WRAPPER}} .ninetheme-swiper-theme-style .swiper-button-next:after' => 'font-size:{{SIZE}}px;' ]
            ]
        );
        $this->add_control( 'navs_color',
            [
                'label' => esc_html__( 'Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => ['{{WRAPPER}} .ninetheme-swiper-theme-style .swiper-button-prev:after,{{WRAPPER}} .ninetheme-swiper-theme-style .swiper-button-next:after' => 'color:{{VALUE}};' ]
            ]
        );
        $this->add_control( 'navs_hvrcolor',
            [
                'label' => esc_html__( 'Hover Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => ['{{WRAPPER}} .ninetheme-swiper-theme-style .swiper-button-prev:hover:after,{{WRAPPER}} .ninetheme-swiper-theme-style .swiper-button-next:hover:after' => 'color:{{VALUE}};' ]
            ]
        );
        $this->add_control( 'navs_bgcolor',
            [
                'label' => esc_html__( 'Background olor', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => ['{{WRAPPER}} .ninetheme-swiper-theme-style .swiper-button-prev,{{WRAPPER}} .ninetheme-swiper-theme-style .swiper-button-next' => 'background-color:{{VALUE}};' ]
            ]
        );
        $this->add_control( 'navs_bghvrcolor',
            [
                'label' => esc_html__( 'Hover Background Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => ['{{WRAPPER}} .ninetheme-swiper-theme-style .swiper-button-prev:hover,{{WRAPPER}} .ninetheme-swiper-theme-style .swiper-button-next:hover' => 'background-color:{{VALUE}};' ]
            ]
        );
        $this->add_control( 'navs_brdcolor',
            [
                'label' => esc_html__( 'Border olor', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => ['{{WRAPPER}} .ninetheme-swiper-theme-style .swiper-button-prev,{{WRAPPER}} .ninetheme-swiper-theme-style .swiper-button-next' => 'border-color:{{VALUE}};' ]
            ]
        );
        $this->add_control( 'navs_brdhvrcolor',
            [
                'label' => esc_html__( 'Hover Border Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => ['{{WRAPPER}} .ninetheme-swiper-theme-style .swiper-button-prev:hover,{{WRAPPER}} .ninetheme-swiper-theme-style .swiper-button-next:hover' => 'border-color:{{VALUE}};' ]
            ]
        );

        $this->end_controls_section();
        /*****   END CONTROLS SECTION   ******/
        /*****   START CONTROLS SECTION   ******/
        $this->start_controls_section('dots_style_section',
            [
                'label'=> esc_html__( 'SLIDER DOTS STYLE', 'crisop' ),
                'tab' => Controls_Manager::TAB_CONTENT,
                'condition' => [ 'dots' => 'yes' ]
            ]
        );
        $this->add_control( 'dots_size',
            [
                'label' => esc_html__( 'Size', 'crisop' ),
                'type' => Controls_Manager::NUMBER,
                'min' => 0,
                'max' => 100,
                'step' => 1,
                'default' => '',
                'selectors' => [ '{{WRAPPER}} .swiper-pagination-bullets .swiper-pagination-bullet:before' => 'width:{{SIZE}}px;height:{{SIZE}}px;' ]
            ]
        );
        $this->add_control( 'dots_space',
            [
                'label' => esc_html__( 'Space', 'crisop' ),
                'type' => Controls_Manager::NUMBER,
                'min' => 0,
                'max' => 100,
                'step' => 1,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .swiper-horizontal > .swiper-pagination-bullets .swiper-pagination-bullet + .swiper-pagination-bullet' => 'margin: 0;margin-left: {{SIZE}}px;',
                    '{{WRAPPER}} .swiper-pagination-horizontal.swiper-pagination-bullets .swiper-pagination-bullet + .swiper-pagination-bullet' => 'margin: 0;margin-left: {{SIZE}}px;',
                ]
            ]
        );
        $this->start_controls_tabs( 'dots_nav_tabs');
        $this->start_controls_tab( 'dots_normal_tab',
            [ 'label' => esc_html__( 'Normal', 'crisop' ) ]
        );
        $this->add_control( 'dots_bgcolor',
            [
                'label' => esc_html__( 'Background', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => ['{{WRAPPER}} .swiper-pagination-bullets .swiper-pagination-bullet:before' => 'background-color:{{VALUE}};' ]
            ]
        );
        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name' => 'dots_border',
                'label' => esc_html__( 'Border', 'crisop' ),
                'selector' => '{{WRAPPER}} .swiper-pagination-bullets .swiper-pagination-bullet',
            ]
        );
        $this->add_responsive_control( 'dots_border_radius',
            [
                'label' => esc_html__( 'Border Radius', 'crisop' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px' ],
                'selectors' => [
                    '{{WRAPPER}} .swiper-pagination-bullets .swiper-pagination-bullet:before,
                    {{WRAPPER}} .swiper-pagination-bullets .swiper-pagination-bullet' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};'
                ]
            ]
        );
        $this->end_controls_tab();
        $this->start_controls_tab( 'dots_hover_tab',
            [ 'label' => esc_html__( 'Active', 'crisop' ) ]
        );
        $this->add_control( 'dots_hvrbgcolor',
            [
                'label' => esc_html__( 'Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [ '{{WRAPPER}} .swiper-pagination-bullet.swiper-pagination-bullet-active:before' => 'background-color:{{VALUE}};' ]
            ]
        );
        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name' => 'dots_hvrborder',
                'label' => esc_html__( 'Border', 'crisop' ),
                'selector' => '{{WRAPPER}} .swiper-pagination-bullet.swiper-pagination-bullet-active'
            ]
        );
        $this->add_responsive_control( 'dots_hvrborder_radius',
            [
                'label' => esc_html__( 'Border Radius', 'crisop' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px' ],
                'selectors' => [
                    '{{WRAPPER}} .swiper-pagination-bullets .swiper-pagination-bullet.swiper-pagination-bullet-active:before,
                    {{WRAPPER}} .swiper-pagination-bullets .swiper-pagination-bullet.swiper-pagination-bullet-active' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};'
                ]
            ]
        );
        $this->end_controls_tab();
        $this->end_controls_tabs();
        $this->end_controls_section();
        /*****   END CONTROLS SECTION   ******/
    }
    public function image_custom_size() {
        $settings = $this->get_settings_for_display();
        $size = $settings['thumbnail_size'] ? $settings['thumbnail_size'] : ninetheme_settings('product_imgsize','ninetheme-mini');
        if ( 'custom' == $size ) {
            $sizew = $settings['thumbnail_custom_dimension']['width'];
            $sizeh = $settings['thumbnail_custom_dimension']['height'];
            $size = [ $sizew, $sizeh ];
        }
        return $size;
    }
    protected function render() {
        if ( ! class_exists('WooCommerce') ) {
            return;
        }
        $settings = $this->get_settings_for_display();
        $id       = $this->get_id();

        add_filter( 'single_product_archive_thumbnail_size', [$this, 'image_custom_size' ] );
        
        $box_style  = $settings['box_style'];
        $space      = $settings['space'] ? $settings['space'] : 30;
        $space_item = 'style-2' == $box_style ? 0 : $space;
        
        $args = array(
            'post_type'      => 'product',
            'posts_per_page' => $settings['post_per_page'],
            'order'          => $settings['order'],
            'orderby'        => $settings['orderby']
        );

        if ( $settings['campaigns_include'] ) {
            $args['tax_query'] = array(
                array(
                    'taxonomy' => 'ninetheme_product_campaigns',
                    'field'    => 'id',
                    'terms'    => $settings['campaigns_include'],
                    'operator' => 'IN'
                )
            );
        }

        $the_query = new \WP_Query( $args );
        if ( $the_query->have_posts() ) {

            if ( 'slider' == $settings['type'] ) {
                $editmode   = \Elementor\Plugin::$instance->editor->is_edit_mode() ? '-'.$id: '';

                $slider_options = json_encode( array(
                        "slidesPerView" => 1,
                        //"touchRatio"    => 2,
                        "loop"          => 'yes' == $settings['loop'] ? true : false,
                        "autoHeight"    => true,
                        "autoplay"      => 'yes' == $settings['autoplay'] ? [ "pauseOnMouseEnter" => true,"disableOnInteraction" => false ] : false,
                        "centeredSlides"=> 'yes' == $settings['centermode'] ? true : false,
                        "speed"         => $settings['speed'],
                        "spaceBetween"  => $space_item,
                        "direction"     => "horizontal",
                        "watchSlidesProgress" => true,
                        "navigation" => [
                            "nextEl" => ".ninetheme-product-campaigns-slider .slide-next-$id",
                            "prevEl" => ".ninetheme-product-campaigns-slider .slide-prev-$id"
                        ],
                        "pagination" => [
                            "el" => ".ninetheme-product-campaigns-slider .ninetheme-pagination-$id",
                            "type" => "bullets",
                            "clickable" => true
                        ],
                        "breakpoints" => [
                            "0" => [
                                "slidesPerView" => $settings['xsitems']
                            ],
                            "768" => [
                                "slidesPerView" => $settings['smitems']
                            ],
                            "992" => [
                                "slidesPerView" => $settings['mditems2']
                            ],
                            "1280" => [
                                "slidesPerView" => $settings['mditems']
                            ]
                        ]
                    )
                );

                echo '<div class="ninetheme-elementor-widget ninetheme-product-campaigns-slider ninetheme-swiper-theme-style nav-type-both '.$box_style.'">';
                    if ( $settings['slider_title'] ) {
                        echo '<div class="ninetheme-campaigns-heading-wrapper">';
                            echo '<div class="ninetheme-campaigns-title-wrapper">';
                                echo '<'.$settings['title_tag'].' class="ninetheme-campaigns-title">'.$settings['slider_title'].'</'.$settings['title_tag'].'>';
                                if ( $settings['short_desc'] ) {
                                    echo '<p class="ninetheme-campaigns-desc">'.$settings['short_desc'].'</p>';
                                }
                            echo '</div>';
                           if ( $settings['link_text'] ) {
                                $attr  = !empty( $settings['link']['url'] ) ? ' href="'.$settings['link']['url'].'"' : '';
                                $attr .= !empty( $settings['link']['is_external'] ) ? ' target="_blank"' : '';
                                $attr .= !empty( $settings['link']['nofollow'] ) ? ' rel="nofollow"' : '';
                                echo '<a class="campaigns-link"'.$attr.'><span class="link-text">'.$settings['link_text'].'</span>';
                                    if ( !empty( $settings['link_icon']['value'] ) ) {
                                        echo '<span class="link-icon">';
                                        Icons_Manager::render_icon( $settings['link_icon'], [ 'aria-hidden' => 'true' ] );
                                        echo '</span>';
                                    }
                                echo '</a>';
                            }
                        echo '</div>';
                    }
                    echo '<div class="swiper-container ninetheme-swiper-slider'.$editmode.' '.$box_style.'" data-swiper-options=\''.$slider_options.'\'>';
                        echo '<div class="swiper-wrapper">';
                            while ( $the_query->have_posts() ) {
                                $the_query->the_post();
                                $product = new \WC_Product(get_the_ID());
                                $visibility = $product->get_catalog_visibility();
    
                                if ( $visibility != 'hidden' ) {
                                    echo '<div class="swiper-slide product_item visibility-'.$visibility.'">';
                                        wc_get_template_part( 'content', 'product' );
                                    echo '</div>';
                                }
                            }
                        echo '</div>';

                        if (  'yes' == $settings['dots'] || 'yes' == $settings['nav']  ) {
                            echo '<div class="ninetheme-slider-nav nav-bottom">';
                            if ( 'yes' == $settings['nav'] ) {
                                echo '<div class="theme-swiper-btn swiper-button-prev slide-prev-'.$id.'"></div>';
                            }
                            if ( 'yes' == $settings['dots'] ) {
                                echo '<div class="swiper-pagination ninetheme-pagination-'.$id.'"></div>';
                            }
                            if ( 'yes' == $settings['nav'] ) {
                                echo '<div class="theme-swiper-btn swiper-button-next slide-next-'.$id.'"></div>';
                            }
                            echo '</div>';
                        }
                    echo '</div>';

                if ( \Elementor\Plugin::$instance->editor->is_edit_mode() ) { ?>
                    <script>
                    jQuery( document ).ready( function($) {
                        $('.ninetheme-swiper-slider-<?php echo $id ?>').each(function (i, el) {
                            var options = $(el).data('swiper-options')
                            const mySlider = new NTSwiper(el, options);
                        });
                    });
                    </script>
                    <?php
                }

            } else {

                echo '<div class="ninetheme-elementor-widget ninetheme-campaigns-grid">';
                
                    if ( $settings['slider_title'] ) {
                        echo '<div class="ninetheme-campaigns-heading-wrapper">';
                            echo '<div class="ninetheme-campaigns-title-wrapper">';
                                echo '<'.$settings['title_tag'].' class="ninetheme-campaigns-title">'.$settings['slider_title'].'</'.$settings['title_tag'].'>';
                                if ( $settings['short_desc'] ) {
                                    echo '<p class="ninetheme-campaigns-desc">'.$settings['short_desc'].'</p>';
                                }
                            echo '</div>';
                            if ( $settings['link_text'] ) {
                                $attr  = !empty( $settings['link']['url'] ) ? ' href="'.$settings['link']['url'].'"' : '';
                                $attr .= !empty( $settings['link']['is_external'] ) ? ' target="_blank"' : '';
                                $attr .= !empty( $settings['link']['nofollow'] ) ? ' rel="nofollow"' : '';
                                echo '<a class="campaigns-link ninetheme-btn ninetheme-btn-yellow ninetheme-btn-small"'.$attr.'><span class="link-text">'.$settings['link_text'].'</span>';
                                    if ( !empty( $settings['link_icon']['value'] ) ) {
                                        echo '<span class="link-icon">';
                                        Icons_Manager::render_icon( $settings['link_icon'], [ 'aria-hidden' => 'true' ] );
                                        echo '</span>';
                                    }
                                echo '</a>';
                            }
                        echo '</div>';
                    }
                    echo '<div class="row '.$box_style.' row-cols-2 row-cols-sm-2 row-cols-lg-3 row-cols-xl-3">';
                        while ( $the_query->have_posts() ) {
                            $the_query->the_post();
                            $product = new \WC_Product(get_the_ID());
                            $visibility = $product->get_catalog_visibility();
    
                            if ( $box_style == 'style-1' ) {
                                //echo '<div class="ninetheme-campaigns-item">';
                                    wc_get_template_part( 'content', 'product' );
                                //echo '</div>';
                            } else {
                                wc_get_template_part( 'content', 'product' );
                            }
                        }
                    echo '</div>';
                echo '</div>';
            }
        }
        wp_reset_postdata();

        remove_filter( 'single_product_archive_thumbnail_size', [$this, 'image_custom_size' ] );
    }
}
