<?php
namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) exit; // If this file is called directly, abort.

class Ninetheme_Woo_Category_List extends Widget_Base {

	public function get_name() {
		return 'ninetheme-wc-category-list';
	}

	public function get_title() {
		return __( 'Product Category List', 'crisop' );
	}

	public function get_icon() {
		return 'eicon-product-categories';
	}

    public function get_keywords() {
        return [ 'woocommerce', 'shop', 'store', 'cat', 'wc', 'woo', 'product'  ];
    }

    public function get_categories() {
		return [ 'ninetheme-woo' ];
	}

	protected function register_controls() {

		$this->start_controls_section(
			'section_filter',
			[
				'label' => __( 'Query', 'crisop' ),
				'tab' => Controls_Manager::TAB_CONTENT
			]
		);

		$this->add_control(
			'source',
			[
				'label' => __( 'Source', 'crisop' ),
				'type' => Controls_Manager::SELECT,
				'options' => [
					'' => __( 'Show All', 'crisop' ),
					'by_id' => __( 'Manual Selection', 'crisop' ),
					'by_parent' => __( 'By Parent', 'crisop' ),
					'current_subcategories' => __( 'Current Subcategories', 'crisop' )
				],
				'label_block' => true
			]
		);

		$categories = get_terms( 'product_cat' );

		$options = [];
		foreach ( $categories as $category ) {
			$options[ $category->term_id ] = $category->name;
		}

		$this->add_control( 'exclude',
			[
				'label' => __( 'Exclude Categories', 'crisop' ),
				'type' => Controls_Manager::SELECT2,
				'options' => $options,
				'default' => [],
				'label_block' => true,
				'multiple' => true,
			]
		);
		$this->add_control( 'hide_empty',
			[
				'label' => __( 'Hide Empty', 'crisop' ),
				'type' => Controls_Manager::SWITCHER,
				'default' => ''
			]
		);
		$this->add_control( 'subcats',
			[
				'label' => __( 'Sub-Categories', 'crisop' ),
				'type' => Controls_Manager::SWITCHER,
				'default' => ''
			]
		);
        $this->add_responsive_control( 'depth',
            [
                'label' => esc_html__( 'Depth', 'crisop' ),
                'type' => Controls_Manager::NUMBER,
                'min' => 0,
                'max' => 5,
                'step' => 1,
                'default' => 5,
                'condition' => ['subcats' => 'yes']
            ]
        );
		$this->add_control( 'orderby',
			[
				'label' => __( 'Order By', 'crisop' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'name',
				'options' => [
					'name' => __( 'Name', 'crisop' ),
					'slug' => __( 'Slug', 'crisop' ),
					'description' => __( 'Description', 'crisop' ),
					'count' => __( 'Count', 'crisop' )
				],
			]
		);
		$this->add_control( 'order',
			[
				'label' => __( 'Order', 'crisop' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'desc',
				'options' => [
					'asc' => __( 'ASC', 'crisop' ),
					'desc' => __( 'DESC', 'crisop' )
				]
			]
		);
		$this->add_control( 'cat_img',
			[
				'label' => __( 'Category Image', 'crisop' ),
				'type' => Controls_Manager::SWITCHER,
				'default' => 'yes'
			]
		);
		$this->add_control( 'more',
			[
				'label' => __( 'More Link', 'crisop' ),
				'type' => Controls_Manager::SWITCHER,
				'default' => 'yes',
				'separator' => 'before'
			]
		);
		$this->add_control( 'more_title',
			[
				'label' => __( 'More Link Title', 'crisop' ),
				'type' => Controls_Manager::TEXT,
				'default' => 'See More',
				'condition' => ['more' => 'yes']
			]
		);
        $this->add_control( 'more_link',
            [
                'label' => esc_html__( 'Button Link', 'crisop' ),
                'type' => Controls_Manager::URL,
                'label_block' => true,
                'default' => [
                    'url' => '#0',
                    'is_external' => ''
                ],
                'show_external' => true,
                'condition' => ['more' => 'yes']
            ]
        );
		$this->end_controls_section();

		$this->start_controls_section( 'section_style',
			[
				'label' => __( 'STYLE', 'crisop' )
			]
		);
        $this->add_responsive_control( 'min_height',
            [
                'label' => esc_html__( 'Container Min Height', 'crisop' ),
                'type' => Controls_Manager::SLIDER,
                'range' => [
                    'px' => ['max' => 1000]
                ],
				'default' => [],
                'selectors' => ['{{WRAPPER}} .ninetheme-header-wc-categories' => 'min-height:{{SIZE}}px;padding-top:0,padding-bottom:0;'],
            ]
        );
        $this->add_responsive_control( 'max_width',
            [
                'label' => esc_html__( 'Max Width ( px )', 'crisop' ),
                'type' => Controls_Manager::SLIDER,
                'range' => [
                    'px' => ['max' => 1000]
                ],
				'default' => [],
                'selectors' => ['{{WRAPPER}} .ninetheme-header-wc-categories .primary-cats' => 'max-width: {{SIZE}}px;']
            ]
        );
        $this->add_responsive_control( 'image_max_width',
            [
                'label' => esc_html__( 'Image Max Width ( px )', 'crisop' ),
                'type' => Controls_Manager::SLIDER,
                'range' => [
                    'px' => ['max' => 60]
                ],
				'default' => [],
                'selectors' => ['{{WRAPPER}} .ninetheme-header-wc-categories li.cat-item img' => 'max-width: {{SIZE}}px;height:auto;']
            ]
        );
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'typography',
				'selector' => '{{WRAPPER}} .ninetheme-header-wc-categories .primary-cats li:not(.more-cat) a'
			]
		);
		$this->add_control( 'color',
			[
				'label' => __( 'Color', 'crisop' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => ['{{WRAPPER}} .ninetheme-header-wc-categories .primary-cats li:not(.more-cat) a' => 'color: {{VALUE}}']
			]
		);
		$this->add_control( 'hvrcolor',
			[
				'label' => __( 'Color', 'crisop' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => ['
				{{WRAPPER}} .ninetheme-header-wc-categories .primary-cats li:not(.more-cat):hover .dropdown-btn,
				{{WRAPPER}} .ninetheme-header-wc-categories .primary-cats li:not(.more-cat):hover a' => 'color: {{VALUE}}'
				]
			]
		);
        $this->add_responsive_control( 'padding',
            [
                'label' => esc_html__( 'Padding', 'crisop' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px' ],
                'selectors' => ['{{WRAPPER}} .ninetheme-header-wc-categories .primary-cats li:not(.more-cat)' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};']
            ]
        );
        $this->add_responsive_control( 'item_spacing',
            [
                'label' => esc_html__( 'Spacing Between Items( px )', 'crisop' ),
                'type' => Controls_Manager::SLIDER,
                'range' => [
                    'px' => ['max' => 100]
                ],
				'default' => [],
                'selectors' => [
                    '{{WRAPPER}} .ninetheme-header-wc-categories .primary-cats li:not(.more-cat)+li' => 'margin-top: {{SIZE}}px;'
                ]
            ]
        );
        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name' => 'item_border',
                'label' => esc_html__( 'Border', 'crisop' ),
                'selector' => '{{WRAPPER}} .ninetheme-header-wc-categories .primary-cats li:not(.more-cat)+li',
            ]
        );
        $this->add_responsive_control( 'arrow_spacing',
            [
                'label' => esc_html__( 'Arrow Size ( px )', 'crisop' ),
                'type' => Controls_Manager::SLIDER,
                'range' => [
                    'px' => ['max' => 100]
                ],
				'default' => [],
                'selectors' => [ '{{WRAPPER}} .ninetheme-header-wc-categories .dropdown-btn' => 'font-size: {{SIZE}}px;']
            ]
        );
		$this->add_control(
			'submenu_style',
			[
				'label' => __( 'Sub-Categories Content', 'crisop' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before'
			]
		);
        $this->add_control( 'submneu_content_bgcolor',
            [
                'label' => esc_html__( 'Background Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => ['{{WRAPPER}} .ninetheme-header-wc-categories .submenu' => 'background-color:{{VALUE}};' ],
            ]
        );
        $this->add_responsive_control( 'submneu_padding',
            [
                'label' => esc_html__( 'Padding', 'crisop' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px' ],
                'selectors' => ['{{WRAPPER}} .ninetheme-header-wc-categories .primary-cats .submenu' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};']
            ]
        );
        $this->add_group_control(
            Group_Control_Box_Shadow::get_type(),
            [
                'name' => 'submneu_box_shadow',
                'label' => esc_html__( 'Box Shadow', 'crisop' ),
                'selector' => '{{WRAPPER}} .ninetheme-header-wc-categories .primary-cats .submenu'
            ]
        );
        $this->add_control( 'more_heading_separator',
            [
                'label' => esc_html__( 'MORE LINK', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'separator' => 'before',
                'condition' => ['more' => 'yes']
            ]
        );
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'more_typography',
				'selector' => '{{WRAPPER}} .ninetheme-header-wc-categories .primary-cats li.more-cat a',
				'condition' => ['more' => 'yes']
			]
		);
		$this->add_control( 'more_color',
			[
				'label' => __( 'Color', 'crisop' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => ['{{WRAPPER}} .ninetheme-header-wc-categories .primary-cats li.more-cat a' => 'color: {{VALUE}}'],
				'condition' => ['more' => 'yes']
			]
		);
		$this->add_control( 'more_hvrcolor',
			[
				'label' => __( 'Color', 'crisop' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => ['
				    {{WRAPPER}} .ninetheme-header-wc-categories .primary-cats li.more-cat:hover .dropdown-btn,
				    {{WRAPPER}} .ninetheme-header-wc-categories .primary-cats li.more-cat:hover a' => 'color: {{VALUE}}'
				],
				'condition' => ['more' => 'yes']
			]
		);
        $this->add_responsive_control( 'more_padding',
            [
                'label' => esc_html__( 'Padding', 'crisop' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px' ],
                'selectors' => ['{{WRAPPER}} .ninetheme-header-wc-categories .primary-cats li.more-cat' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};'],
                'condition' => ['more' => 'yes']
            ]
        );
        $this->add_responsive_control( 'more_top_spacing',
            [
                'label' => esc_html__( 'Spacing Top Spacing ( px )', 'crisop' ),
                'type' => Controls_Manager::SLIDER,
                'range' => [
                    'px' => ['max' => 100]
                ],
                'default' => [],
                'selectors' => [ '{{WRAPPER}} .ninetheme-header-wc-categories .primary-cats li.more-cat' => 'margin-top: {{SIZE}}px;' ],
                'condition' => ['more' => 'yes']
            ]
        );
        $this->end_controls_section();
    }

    public function render() {
        if ( ! class_exists('WooCommerce') ) {
            return;
        }
        $settings = $this->get_settings();

        $product_categories = get_terms( 'product_cat', array(
            'orderby'    => 'name',
            'order'      => 'asc',
            'hide_empty' => true
        ));

        if ( !empty( $product_categories ) ) {

            $args = array(
                'echo'       => true,
                'taxonomy'   => 'product_cat',
                'depth'      => 'yes' == $settings['subcats'] && $settings['depth'] ? $settings['depth'] : 1,
                'hide_empty' => 'yes' === $settings['hide_empty'] ? 1 : 0,
                'orderby'    => $settings['orderby'],
                'order'      => $settings['order'],
                'is_widget'  => 1,
                'cat_img'    => 'yes' == $settings['cat_img'] ? 1 : 0,
                'title_li'   => '',
                'walker'     => new \Ninetheme_WooCommerce_Categories_Walker()
            );
            if ( !empty( $settings['exclude'] ) ){
                $args['exclude'] = $settings['exclude'];
            }

            echo '<div class="ninetheme-header-wc-categories ninetheme-wc-vertical-menu ninetheme-elementor-widget">';
                echo '<ul class="ninetheme-vertical-catmenu-primary primary-cats">';
                    echo wp_list_categories( $args );
                    if ( 'yes' == $settings['more'] ) {
                        $rtl = is_rtl() ? 'left' : 'right';
                        $target     = !empty( $settings['more_link']['is_external'] ) ? ' target="_blank"' : '';
                        $nofollow   = !empty( $settings['more_link']['nofollow'] ) ? ' rel="nofollow"' : '';
                        $href       = !empty( $settings['more_link']['url'] ) ? $settings['more_link']['url'] : '';
                        echo '<li class="cat-item cat-more"><a class="product_cat" href="'.$href.'"'.$target.$nofollow.'>'.$settings['more_title'].'</a><span class="dropdown-btn fas fa-angle-'.$rtl.'"></span></li>';
                    }
                echo '</ul>';
            echo '</div>';
        }
    }
}
