<?php

namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) exit; // If this file is called directly, abort.

class Ninetheme_Woo_Deals_Single extends Widget_Base {
    use Ninetheme_Helper;
    public function get_name() {
        return 'ninetheme-woo-deals-single';
    }
    public function get_title() {
        return 'WC Deals Single Slider (N)';
    }
    public function get_icon() {
        return 'eicon-slider-push';
    }
    public function get_categories() {
        return [ 'ninetheme-woo' ];
    }
    public function get_keywords() {
        return [ 'woocommerce', 'shop', 'store', 'cat', 'wc', 'woo', 'product', 'deals'  ];
    }
    public function get_style_depends() {
        return [ 'ninetheme-swiper' ];
    }
    public function get_script_depends() {
        return [ 'ninetheme-swiper' ];
    }

    // Registering Controls
    protected function register_controls() {

        /*****   START CONTROLS SECTION   ******/
        $this->start_controls_section( 'post_query_section',
            [
                'label' => esc_html__( 'Query', 'crisop' ),
                'tab' => Controls_Manager::TAB_CONTENT
            ]
        );
        $this->add_control( 'only_deals',
            [
                'label' => esc_html__( 'Only Deals Products', 'crisop' ),
                'type' => Controls_Manager::SWITCHER,
                'default' => 'yes'
            ]
        );
        $this->add_control( 'scenario',
            [
                'label' => esc_html__( 'Select Scenario', 'crisop' ),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    '' => esc_html__( 'Newest', 'crisop' ),
                    'featured' => esc_html__( 'Featured', 'crisop' ),
                    'on-sale' => esc_html__( 'On Sale', 'crisop' ),
                    'best' => esc_html__( 'Best Selling', 'crisop' ),
                    'custom' => esc_html__( 'Specific Categories', 'crisop' ),
                ],
                'default' => ''
            ]
        );
        $this->add_control( 'post_per_page',
            [
                'label' => esc_html__( 'Posts Per Page', 'crisop' ),
                'type' => Controls_Manager::NUMBER,
                'min' => -1,
                'max' => 100,
                'default' => 3
            ]
        );
        $this->add_control( 'category_filter_heading',
            [
                'label' => esc_html__( 'Category Filter', 'crisop' ),
                'type' => Controls_Manager::HEADING
            ]
        );
        $this->add_control( 'category_include',
            [
                'label' => esc_html__( 'Category', 'crisop' ),
                'type' => Controls_Manager::SELECT2,
                'multiple' => true,
                'options' => $this->ninetheme_cpt_taxonomies('product_cat'),
                'description' => 'Select Category(s)',
                'condition' => [ 'scenario' => 'custom' ]
            ]
        );
        $this->add_control( 'category_exclude',
            [
                'label' => esc_html__( 'Exclude Category', 'crisop' ),
                'type' => Controls_Manager::SELECT2,
                'multiple' => true,
                'options' => $this->ninetheme_cpt_taxonomies('product_cat'),
                'description' => 'Select Category(s) to Exclude'
            ]
        );
        $this->add_control( 'post_filter_heading',
            [
                'label' => esc_html__( 'Post Filter', 'crisop' ),
                'type' => Controls_Manager::HEADING,
                'separator' => 'before'
            ]
        );
        $this->add_control( 'post_include',
            [
                'label' => esc_html__( 'Specific Post(s)', 'crisop' ),
                'type' => Controls_Manager::SELECT2,
                'multiple' => true,
                'options' => $this->get_all_posts_by_type('product'),
                'description' => 'Select Specific Post(s)',
                'condition' => [ 'scenario' => 'custom' ]
            ]
        );
        $this->add_control( 'post_exclude',
            [
                'label' => esc_html__( 'Exclude Post', 'crisop' ),
                'type' => Controls_Manager::SELECT2,
                'multiple' => true,
                'options' => $this->get_all_posts_by_type('product'),
                'description' => 'Select Post(s) to Exclude',
            ]
        );
        $this->add_control( 'post_other_heading',
            [
                'label' => esc_html__( 'Other Filter', 'crisop' ),
                'type' => Controls_Manager::HEADING,
                'separator' => 'before'
            ]
        );
        $this->add_control( 'order',
            [
                'label' => esc_html__( 'Select Order', 'crisop' ),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'ASC' => esc_html__( 'Ascending', 'crisop' ),
                    'DESC' => esc_html__( 'Descending', 'crisop' )
                ],
                'default' => 'DESC'
            ]
        );
        $this->add_control( 'orderby',
            [
                'label' => esc_html__( 'Order By', 'crisop' ),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'id' => esc_html__( 'Post ID', 'crisop' ),
                    'menu_order' => esc_html__( 'Menu Order', 'crisop' ),
                    'rand' => esc_html__( 'Random', 'crisop' ),
                    'date' => esc_html__( 'Date', 'crisop' ),
                    'title' => esc_html__( 'Title', 'crisop' ),
                ],
                'default' => 'id',
            ]
        );
        $this->add_group_control(
            Group_Control_Image_Size::get_type(),
            [
                'name' => 'thumbnail',
                'default' => 'woocommerce_single',
            ]
        );
        $this->add_control( 'slider_title',
            [
                'label' => esc_html__( 'Slider Title', 'crisop' ),
                'type' => Controls_Manager::TEXTAREA,
                'separator' => 'before'
            ]
        );
        $this->add_control( 'title_tag',
            [
                'label' => esc_html__( 'Title Tag', 'crisop' ),
                'type' => Controls_Manager::SELECT,
                'default' => 'h3',
                'options' => [
                    'h1' => esc_html__( 'H1', 'crisop' ),
                    'h2' => esc_html__( 'H2', 'crisop' ),
                    'h3' => esc_html__( 'H3', 'crisop' ),
                    'h4' => esc_html__( 'H4', 'crisop' ),
                    'h5' => esc_html__( 'H5', 'crisop' ),
                    'h6' => esc_html__( 'H6', 'crisop' ),
                    'div' => esc_html__( 'div', 'crisop' ),
                    'p' => esc_html__( 'p', 'crisop' )
                ],
                'condition' => [ 'slider_title!' => '' ]
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'slider_title_typo',
                'label' => esc_html__( 'Typography', 'crisop' ),
                'selector' => '{{WRAPPER}} .ninetheme-slider-nav-title',
                'condition' => [ 'slider_title!' => '' ]
            ]
        );
        $this->add_control( 'slider_title_color',
            [
                'label' => esc_html__( 'Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [ '{{WRAPPER}} .ninetheme-slider-nav-title' => 'color:{{VALUE}};' ],
                'condition' => [ 'slider_title!' => '' ]
            ]
        );
        $this->add_responsive_control( 'title_spacing',
            [
                'label' => esc_html__( 'Title Spacing ( px )', 'crisop' ),
                'type' => Controls_Manager::SLIDER,
                'range' => [
                    'px' => ['max' => 300]
                ],
				'default' => [
					'unit' => 'px',
					'size' => 30
				],
                'selectors' => [
                    '{{WRAPPER}} .ninetheme-swiper-theme-style .ninetheme-slider-title-wrapper.nav-top' => 'margin-bottom: {{SIZE}}px;'
                ],
                'condition' => [ 'slider_title!' => '' ]
            ]
        );
        $this->add_control( 'gallery_col',
            [
                'label' => esc_html__( 'Gallery Column Width', 'crisop' ),
                'type' => Controls_Manager::NUMBER,
                'min' => 0,
                'max' => 12,
                'step' => 1,
                'default' => 4,
                'separator' => 'before'
            ]
        );
        $this->add_control( 'labels',
            [
                'label' => esc_html__( 'Product Labels', 'crisop' ),
                'type' => Controls_Manager::SWITCHER,
                'default' => 'yes'
            ]
        );
        $this->add_control( 'title',
            [
                'label' => esc_html__( 'Product Title', 'crisop' ),
                'type' => Controls_Manager::SWITCHER,
                'default' => 'yes'
            ]
        );
        $this->add_control( 'rating',
            [
                'label' => esc_html__( 'Product Rating', 'crisop' ),
                'type' => Controls_Manager::SWITCHER,
                'default' => 'yes'
            ]
        );
        $this->add_control( 'price',
            [
                'label' => esc_html__( 'Product Price', 'crisop' ),
                'type' => Controls_Manager::SWITCHER,
                'default' => 'yes'
            ]
        );
        $this->add_control( 'progressbar',
            [
                'label' => esc_html__( 'Product Stock Progressbar', 'crisop' ),
                'type' => Controls_Manager::SWITCHER,
                'default' => 'yes'
            ]
        );
        $this->add_control( 'excerpt',
            [
                'label' => esc_html__( 'Product Excerpt', 'crisop' ),
                'type' => Controls_Manager::SWITCHER,
                'default' => 'yes'
            ]
        );
        $this->add_control( 'cart',
            [
                'label' => esc_html__( 'Product Cart', 'crisop' ),
                'type' => Controls_Manager::SWITCHER,
                'default' => 'yes'
            ]
        );
        $this->add_control( 'meta',
            [
                'label' => esc_html__( 'Product Meta', 'crisop' ),
                'type' => Controls_Manager::SWITCHER,
                'default' => 'yes'
            ]
        );
        $this->add_control( 'share',
            [
                'label' => esc_html__( 'Product Share Icons', 'crisop' ),
                'type' => Controls_Manager::SWITCHER,
                'default' => 'yes'
            ]
        );
        $this->end_controls_section();
        /*****   END CONTROLS SECTION   ******/
        /*****   START CONTROLS SECTION   ******/
        $this->start_controls_section('product_style_section',
            [
                'label'=> esc_html__( 'PRODUCT STYLE', 'crisop' ),
                'tab' => Controls_Manager::TAB_CONTENT
            ]
        );
        $this->add_control( 'box_heading',
            [
                'label' => esc_html__( 'BOX CONTAINER', 'crisop' ),
                'type' => Controls_Manager::HEADING,
                'separator' => 'before'
            ]
        );
        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name' => 'box_border',
                'label' => esc_html__( 'Border', 'crisop' ),
                'selector' => '{{WRAPPER}} .ninetheme-widget-deals-products-slider-wrapper'
            ]
        );
        $this->add_responsive_control( 'box_border_radius',
            [
                'label' => esc_html__( 'Border Radius', 'crisop' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px' ],
                'selectors' => ['{{WRAPPER}} .ninetheme-widget-deals-products-slider-wrapper' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};']
            ]
        );
        $this->add_responsive_control( 'box_padding',
            [
                'label' => esc_html__( 'Padding', 'crisop' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px' ],
                'selectors' => ['{{WRAPPER}} .ninetheme-widget-deals-products-slider-wrapper' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};']
            ]
        );
        $this->add_responsive_control( 'summary_padding',
            [
                'label' => esc_html__( 'Summary Padding', 'crisop' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px' ],
                'selectors' => ['{{WRAPPER}} .summary-col' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};']
            ]
        );
        $this->add_control( 'title_heading',
            [
                'label' => esc_html__( 'TITLE', 'crisop' ),
                'type' => Controls_Manager::HEADING,
                'separator' => 'before'
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'product_title_typo',
                'label' => esc_html__( 'Typography', 'crisop' ),
                'selector' => '{{WRAPPER}} .ninetheme-product-title',
            ]
        );
        $this->add_control( 'title_color',
            [
                'label' => esc_html__( 'Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [ '{{WRAPPER}} .ninetheme-product-title' => 'color:{{VALUE}};' ]
            ]
        );
        $this->add_responsive_control( 'title_margin',
            [
                'label' => esc_html__( 'Margin', 'crisop' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px' ],
                'selectors' => ['{{WRAPPER}} .ninetheme-btn' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};'],
            ]
        );
        $this->add_control( 'price_heading',
            [
                'label' => esc_html__( 'PRICE', 'crisop' ),
                'type' => Controls_Manager::HEADING,
                'separator' => 'before'
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'product_price_typo',
                'label' => esc_html__( 'Typography', 'crisop' ),
                'selector' => '{{WRAPPER}} .ninetheme-product-summary .ninetheme-summary-item.ninetheme-price.price',
            ]
        );
        $this->add_control( 'price_color',
            [
                'label' => esc_html__( 'Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [ '{{WRAPPER}} .ninetheme-product-summary .ninetheme-summary-item.ninetheme-price.price' => 'color:{{VALUE}};' ]
            ]
        );
        $this->add_control( 'price_color2',
            [
                'label' => esc_html__( 'Color 2', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [ '{{WRAPPER}} .ninetheme-widget-deals-products-slider-wrapper .ninetheme-primary-color.ins' => 'color:{{VALUE}};' ]
            ]
        );
        $this->add_responsive_control( 'price_margin',
            [
                'label' => esc_html__( 'Margin', 'crisop' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px' ],
                'selectors' => ['{{WRAPPER}} .ninetheme-product-summary .ninetheme-summary-item.ninetheme-price.price' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};'],
            ]
        );
        $this->add_control( 'excerpt_heading',
            [
                'label' => esc_html__( 'EXCERPT', 'crisop' ),
                'type' => Controls_Manager::HEADING,
                'separator' => 'before'
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'product_excerpt_typo',
                'label' => esc_html__( 'Typography', 'crisop' ),
                'selector' => '{{WRAPPER}} .ninetheme-product-summary .ninetheme-summary-item.woocommerce-product-details__short-description p',
            ]
        );
        $this->add_control( 'excerpt_color',
            [
                'label' => esc_html__( 'Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [ '{{WRAPPER}} .ninetheme-product-summary .ninetheme-summary-item.woocommerce-product-details__short-description p' => 'color:{{VALUE}};' ]
            ]
        );
        $this->add_responsive_control( 'excerpt_margin',
            [
                'label' => esc_html__( 'Margin', 'crisop' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px' ],
                'selectors' => ['{{WRAPPER}} .ninetheme-product-summary .ninetheme-summary-item.woocommerce-product-details__short-description p' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};'],
            ]
        );
        $this->add_control( 'meta_heading',
            [
                'label' => esc_html__( 'META', 'crisop' ),
                'type' => Controls_Manager::HEADING,
                'separator' => 'before'
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'product_meta_typo',
                'label' => esc_html__( 'Typography', 'crisop' ),
                'selector' => '{{WRAPPER}} .ninetheme-product-view span,
                {{WRAPPER}} .ninetheme-estimated-delivery span,
                {{WRAPPER}} a.ninetheme-open-popup,
                {{WRAPPER}} .ninetheme-product-summary .ninetheme-product-meta .ninetheme-brands,
                {{WRAPPER}} .ninetheme-product-summary .ninetheme-product-meta .posted_in,
                {{WRAPPER}} .ninetheme-product-summary .ninetheme-product-meta .tagged_as,
                {{WRAPPER}} .ninetheme-product-summary .ninetheme-product-meta .ninetheme-sku-wrapper',
            ]
        );
        $this->add_control( 'meta_color',
            [
                'label' => esc_html__( 'Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [ '{{WRAPPER}} .ninetheme-product-view span,
                {{WRAPPER}} .ninetheme-estimated-delivery span,
                {{WRAPPER}} a.ninetheme-open-popup,
                {{WRAPPER}} .ninetheme-product-summary .ninetheme-product-meta .ninetheme-brands,
                {{WRAPPER}} .ninetheme-product-summary .ninetheme-product-meta .posted_in,
                {{WRAPPER}} .ninetheme-product-summary .ninetheme-product-meta .tagged_as,
                {{WRAPPER}} .ninetheme-product-summary .ninetheme-product-meta .ninetheme-sku-wrapper' => 'color:{{VALUE}};' ]
            ]
        );
        $this->add_control( 'meta_color2',
            [
                'label' => esc_html__( 'Meta Value Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [ '{{WRAPPER}} .ninetheme-product-summary .ninetheme-product-meta .ninetheme-brands a,
                {{WRAPPER}} .ninetheme-product-summary .ninetheme-product-meta .posted_in a,
                {{WRAPPER}} .ninetheme-product-summary .ninetheme-product-meta span span,
                {{WRAPPER}} .ninetheme-product-summary .ninetheme-product-meta .tagged_as a' => 'color:{{VALUE}};' ]
            ]
        );
        $this->add_responsive_control( 'meta_margin',
            [
                'label' => esc_html__( 'Margin', 'crisop' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px' ],
                'selectors' => ['{{WRAPPER}} .ninetheme-summary-item.ninetheme-product-meta' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};']
            ]
        );
        $this->add_control( 'cart_heading',
            [
                'label' => esc_html__( 'CART', 'crisop' ),
                'type' => Controls_Manager::HEADING,
                'separator' => 'before'
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'product_cart_typo',
                'label' => esc_html__( 'Typography', 'crisop' ),
                'selector' => '{{WRAPPER}} .single_add_to_cart_button.ninetheme-btn',
            ]
        );
        $this->add_control( 'cart_color',
            [
                'label' => esc_html__( 'Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [ '{{WRAPPER}} button,{{WRAPPER}} .single_add_to_cart_button.ninetheme-btn' => 'color:{{VALUE}};' ]
            ]
        );
        $this->add_control( 'cart_color2',
            [
                'label' => esc_html__( 'Hover Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [ '{{WRAPPER}} button:hover,{{WRAPPER}} .single_add_to_cart_button.ninetheme-btn:hover' => 'color:{{VALUE}};' ]
            ]
        );
        $this->add_control( 'cart_bgcolor',
            [
                'label' => esc_html__( 'Background Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [ '{{WRAPPER}} button,{{WRAPPER}} .single_add_to_cart_button.ninetheme-btn' => 'background-color:{{VALUE}};' ]
            ]
        );
        $this->add_control( 'cart_bgcolor2',
            [
                'label' => esc_html__( 'Hover Background Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [ '{{WRAPPER}} button:hover,{{WRAPPER}} .single_add_to_cart_button.ninetheme-btn:hover' => 'background-color:{{VALUE}};' ]
            ]
        );
        $this->add_responsive_control( 'cart_margin',
            [
                'label' => esc_html__( 'Margin', 'crisop' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px' ],
                'selectors' => ['{{WRAPPER}} .ninetheme-summary-item.cart' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};']
            ]
        );
        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name' => 'cart_border',
                'label' => esc_html__( 'Border', 'crisop' ),
                'selector' => '{{WRAPPER}} button,{{WRAPPER}} .single_add_to_cart_button.ninetheme-btn'
            ]
        );
        $this->add_responsive_control( 'cart_border_radius',
            [
                'label' => esc_html__( 'Border Radius', 'crisop' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px' ],
                'selectors' => ['{{WRAPPER}} button,{{WRAPPER}} .single_add_to_cart_button.ninetheme-btn' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};']
            ]
        );
        $this->end_controls_section();
        /*****   END CONTROLS SECTION   ******/
       /*****   START CONTROLS SECTION   ******/
        $this->start_controls_section('slider_options_section',
            [
                'label'=> esc_html__( 'SLIDER OPTIONS', 'crisop' ),
                'tab' => Controls_Manager::TAB_CONTENT
            ]
        );
        $this->add_control( 'loop',
            [
                'label' => esc_html__( 'Infinite', 'crisop' ),
                'type' => Controls_Manager::SWITCHER,
                'default' => 'no'
            ]
        );
        $this->add_control( 'autoplay',
            [
                'label' => esc_html__( 'Autoplay', 'crisop' ),
                'type' => Controls_Manager::SWITCHER,
                'default' => 'yes'
            ]
        );
        $this->add_control( 'nav',
            [
                'label' => esc_html__( 'Navigation', 'crisop' ),
                'type' => Controls_Manager::SWITCHER,
                'default' => 'yes'
            ]
        );
        $this->add_control( 'dots',
            [
                'label' => esc_html__( 'Dots', 'crisop' ),
                'type' => Controls_Manager::SWITCHER,
                'default' => 'yes'
            ]
        );
        $this->add_control( 'speed',
            [
                'label' => esc_html__( 'Speed', 'crisop' ),
                'type' => Controls_Manager::NUMBER,
                'min' => 100,
                'max' => 10000,
                'step' => 100,
                'default' => 1000
            ]
        );
        $this->end_controls_section();
        /*****   END CONTROLS SECTION   ******/

        /*****   START CONTROLS SECTION   ******/
        $this->start_controls_section('navs_style_section',
            [
                'label'=> esc_html__( 'SLIDER NAV STYLE', 'crisop' ),
                'tab' => Controls_Manager::TAB_CONTENT,
                'condition' => [ 'nav' => 'yes' ]
            ]
        );
        $this->add_control( 'navs_size',
            [
                'label' => esc_html__( 'Size', 'crisop' ),
                'type' => Controls_Manager::NUMBER,
                'min' => 0,
                'max' => 100,
                'step' => 1,
                'default' => '',
                'selectors' => [ '{{WRAPPER}} .ninetheme-swiper-theme-style .swiper-button-prev:after,{{WRAPPER}} .ninetheme-swiper-theme-style .swiper-button-next:after' => 'font-size:{{SIZE}}px;' ]
            ]
        );
        $this->add_control( 'navs_color',
            [
                'label' => esc_html__( 'Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => ['{{WRAPPER}} .ninetheme-swiper-theme-style .swiper-button-prev:after,{{WRAPPER}} .ninetheme-swiper-theme-style .swiper-button-next:after' => 'color:{{VALUE}};' ]
            ]
        );
        $this->add_control( 'navs_hvrcolor',
            [
                'label' => esc_html__( 'Hover Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => ['{{WRAPPER}} .ninetheme-swiper-theme-style .swiper-button-prev:hover:after,{{WRAPPER}} .ninetheme-swiper-theme-style .swiper-button-next:hover:after' => 'color:{{VALUE}};' ]
            ]
        );
        $this->add_control( 'navs_bgcolor',
            [
                'label' => esc_html__( 'Background olor', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => ['{{WRAPPER}} .ninetheme-swiper-theme-style .swiper-button-prev,{{WRAPPER}} .ninetheme-swiper-theme-style .swiper-button-next' => 'background-color:{{VALUE}};' ]
            ]
        );
        $this->add_control( 'navs_bghvrcolor',
            [
                'label' => esc_html__( 'Hover Background Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => ['{{WRAPPER}} .ninetheme-swiper-theme-style .swiper-button-prev:hover,{{WRAPPER}} .ninetheme-swiper-theme-style .swiper-button-next:hover' => 'background-color:{{VALUE}};' ]
            ]
        );
        $this->add_control( 'navs_brdcolor',
            [
                'label' => esc_html__( 'Border olor', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => ['{{WRAPPER}} .ninetheme-swiper-theme-style .swiper-button-prev,{{WRAPPER}} .ninetheme-swiper-theme-style .swiper-button-next' => 'border-color:{{VALUE}};' ]
            ]
        );
        $this->add_control( 'navs_brdhvrcolor',
            [
                'label' => esc_html__( 'Hover Border Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => ['{{WRAPPER}} .ninetheme-swiper-theme-style .swiper-button-prev:hover,{{WRAPPER}} .ninetheme-swiper-theme-style .swiper-button-next:hover' => 'border-color:{{VALUE}};' ]
            ]
        );
        $this->end_controls_section();
        /*****   END CONTROLS SECTION   ******/
        /*****   START CONTROLS SECTION   ******/
        $this->start_controls_section('dots_style_section',
            [
                'label'=> esc_html__( 'SLIDER DOTS STYLE', 'crisop' ),
                'tab' => Controls_Manager::TAB_CONTENT,
                'condition' => [ 'dots' => 'yes' ]
            ]
        );
        $this->add_control( 'dots_size',
            [
                'label' => esc_html__( 'Size', 'crisop' ),
                'type' => Controls_Manager::NUMBER,
                'min' => 0,
                'max' => 100,
                'step' => 1,
                'default' => '',
                'selectors' => [ '{{WRAPPER}} .swiper-pagination-bullets .swiper-pagination-bullet:before' => 'width:{{SIZE}}px;height:{{SIZE}}px;' ]
            ]
        );
        $this->add_control( 'dots_space',
            [
                'label' => esc_html__( 'Space', 'crisop' ),
                'type' => Controls_Manager::NUMBER,
                'min' => 0,
                'max' => 100,
                'step' => 1,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .swiper-horizontal > .swiper-pagination-bullets .swiper-pagination-bullet + .swiper-pagination-bullet' => 'margin: 0;margin-left: {{SIZE}}px;',
                    '{{WRAPPER}} .swiper-pagination-horizontal.swiper-pagination-bullets .swiper-pagination-bullet + .swiper-pagination-bullet' => 'margin: 0;margin-left: {{SIZE}}px;',
                ]
            ]
        );
        $this->start_controls_tabs( 'dots_nav_tabs');
        $this->start_controls_tab( 'dots_normal_tab',
            [ 'label' => esc_html__( 'Normal', 'crisop' ) ]
        );
        $this->add_control( 'dots_bgcolor',
            [
                'label' => esc_html__( 'Background', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => ['{{WRAPPER}} .swiper-pagination-bullets .swiper-pagination-bullet:before' => 'background-color:{{VALUE}};' ]
            ]
        );
        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name' => 'dots_border',
                'label' => esc_html__( 'Border', 'crisop' ),
                'selector' => '{{WRAPPER}} .swiper-pagination-bullets .swiper-pagination-bullet',
            ]
        );
        $this->add_responsive_control( 'dots_border_radius',
            [
                'label' => esc_html__( 'Border Radius', 'crisop' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px' ],
                'selectors' => [
                    '{{WRAPPER}} .swiper-pagination-bullets .swiper-pagination-bullet:before,{{WRAPPER}} .swiper-pagination-bullets .swiper-pagination-bullet' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};'
                ]
            ]
        );
        $this->end_controls_tab();
        $this->start_controls_tab( 'dots_hover_tab',
            [ 'label' => esc_html__( 'Active', 'crisop' ) ]
        );
        $this->add_control( 'dots_hvrbgcolor',
            [
                'label' => esc_html__( 'Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [ '{{WRAPPER}} .swiper-pagination-bullet.swiper-pagination-bullet-active:before' => 'background-color:{{VALUE}};' ]
            ]
        );
        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name' => 'dots_hvrborder',
                'label' => esc_html__( 'Border', 'crisop' ),
                'selector' => '{{WRAPPER}} .swiper-pagination-bullet.swiper-pagination-bullet-active'
            ]
        );
        $this->add_responsive_control( 'dots_hvrborder_radius',
            [
                'label' => esc_html__( 'Border Radius', 'crisop' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px' ],
                'selectors' => [
                    '{{WRAPPER}} .swiper-pagination-bullets .swiper-pagination-bullet.swiper-pagination-bullet-active:before,{{WRAPPER}} .swiper-pagination-bullets .swiper-pagination-bullet.swiper-pagination-bullet-active' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};'
                ]
            ]
        );
        $this->end_controls_tab();
        $this->end_controls_tabs();
        $this->end_controls_section();
        /*****   END CONTROLS SECTION   ******/
    }
    public function image_custom_size() {
        $settings = $this->get_settings_for_display();
        $size = $settings['thumbnail_size'] ? $settings['thumbnail_size'] : ninetheme_settings('product_imgsize','ninetheme-mini');
        if ( 'custom' == $size ) {
            $sizew = $settings['thumbnail_custom_dimension']['width'];
            $sizeh = $settings['thumbnail_custom_dimension']['height'];
            $size = [ $sizew, $sizeh ];
        }
        return $size;
    }
    public function product_gallery($id)
    {
        global $product;
        $settings = $this->get_settings_for_display();
        $images = $product->get_gallery_image_ids();
        $id     = $product->get_id();

        $size = $settings['thumbnail_size'] ? $settings['thumbnail_size'] : 'woocommerce_single';
        if ( 'custom' == $size ) {
            $sizew = $settings['thumbnail_custom_dimension']['width'];
            $sizeh = $settings['thumbnail_custom_dimension']['height'];
            $size = [ $sizew, $sizeh ];
        }

        $options = json_encode(
            array(
                "loop"          => false,
                "speed"         => 800,
                "spaceBetween"  => 0,
                "slidesPerView" => 1,
                "slidesPerView" => 1,
                "freeMode"      => false,
                "direction"     => "horizontal",
                "autoHeight"    => true,
                "autoPlay"      => false,
                "rewind"        => true,
                "effect"        => 'slide',
                "navigation"    => [
                    "nextEl" => ".ninetheme-widget-product-gallery-main-slider .ninetheme-swiper-next-$id",
                    "prevEl" => ".ninetheme-widget-product-gallery-main-slider .ninetheme-swiper-prev-$id"
                ]
            )
        );

        ?>
        <div class="ninetheme-widget-product-gallery-main-slider swiper-container ninetheme-swiper-slider" data-swiper-options="<?php echo esc_attr( $options ); ?>">

            <?php
            if ( 'yes' == $settings['labels'] ) {
                ninetheme_single_product_labels();
            }
            ?>

            <div class="swiper-wrapper ninetheme-gallery-items">
                <?php
                echo '<div class="swiper-slide ninetheme-swiper-slide-first">'.get_the_post_thumbnail( $id, $size, [ 'class' => 'swiper-product-image' ] ).'</div>';
                foreach ( $images as $image ) {
                    $gimg = wp_get_attachment_image( $image, $size );
                    echo '<div class="swiper-slide">'.$gimg.'</div>';
                }
                ?>
            </div>
            <div class="swiper-button-prev ninetheme-swiper-prev ninetheme-swiper-prev-<?php echo $id; ?>"></div>
            <div class="swiper-button-next ninetheme-swiper-next ninetheme-swiper-next-<?php echo $id; ?>"></div>
        </div>
        <?php
    }
    protected function render() {
        if ( ! class_exists('WooCommerce') ) {
            return;
        }
        global $wp_query;
        $settings = $this->get_settings_for_display();
        $id = $this->get_id();

        $args = array(
            'post_type'      => 'product',
            'posts_per_page' => $settings['post_per_page'],
            'post__in'       => $settings['post_include'],
            'post__not_in'   => $settings['post_exclude'],
            'order'          => $settings['order']
        );

        if ( 'featured' == $settings['scenario'] ) {
           $args['tax_query'] = array(
                array(
                    'taxonomy' => 'product_visibility',
                    'field' => 'name',
                    'terms' => 'featured'
                )
            );

        } elseif('on-sale' == $settings['scenario']) {

            $args['meta_query'] = array(
                'relation' => 'OR',
                array( // Simple products type
                    'key' => '_sale_price',
                    'value' => 0,
                    'compare' => '>',
                    'type' => 'numeric'
                ),
                array( // Variable products type
                    'key' => '_min_variation_sale_price',
                    'value' => 0,
                    'compare' => '>',
                    'type' => 'numeric'
                )
            );

        } elseif('best' == $settings['scenario']) {

            $args['orderby'] = 'meta_value_num';
            $args['meta_key'] = 'total_sales';

        } else {

            $args['orderby'] = $settings['orderby'];

        }

        if ( $settings['category_include'] ) {
            $args['tax_query'] = array(
                array(
                    'taxonomy' => 'product_cat',
                    'field' => 'id',
                    'terms' => $settings['category_include'],
                    'operator' => 'IN'
                )
            );
        }
        if ( $settings['category_exclude'] ) {
            $args['tax_query'] = array(
                array(
                    'taxonomy' => 'product_cat',
                    'field' => 'id',
                    'terms' => $settings['category_exclude'],
                    'operator' => 'NOT IN'
                )
            );
        }
        if ( 'yes' == $settings['only_deals'] ) {
            $args['meta_query'] = array(
                array(
                    'key' => 'ninetheme_countdown_date'
                )
            );
        }
        $editmode   = \Elementor\Plugin::$instance->editor->is_edit_mode() ? '-'.$id: '';

        $slider_options = json_encode( array(
                "slidesPerView" => 1,
                "loop"          => false,
                "autoHeight"    => false,
                "autoplay"      => false,
                "autoHeight"    => true,
                "speed"         => $settings['speed'],
                "spaceBetween"  => 0,
                "direction"     => "horizontal",
                "watchSlidesProgress" => true,
                "navigation" => [
                    "nextEl" => ".ninetheme-widget-deals-products-slider-wrapper .slide-next-$id",
                    "prevEl" => ".ninetheme-widget-deals-products-slider-wrapper .slide-prev-$id"
                ],
                "pagination" => [
                    "el"        => ".ninetheme-widget-deals-products-slider-wrapper .ninetheme-pagination-$id",
                    "type"      => "bullets",
                    "clickable" => true
                ]
            )
        );

        $has_title = '' != $settings['slider_title'] ? ' has-title' : '';
        $dots_none = 'yes' != $settings['dots'] ? ' dots-none': '';
        $column    = '12' == $settings['gallery_col'] || $settings['gallery_col'] >= 9 ? 12 : ( 12 - $settings['gallery_col'] );

        remove_action( 'woocommerce_single_product_summary', 'woocommerce_template_single_title', 5 );

        if ( 'yes' != $settings['rating'] ) {
            remove_action( 'woocommerce_single_product_summary', 'woocommerce_template_single_rating', 10 );
        }
        if ( 'yes' != $settings['price'] ) {
            remove_action( 'woocommerce_single_product_summary', 'woocommerce_template_single_price', 10 );
        }
        if ( 'yes' != $settings['excerpt'] ) {
            remove_action( 'woocommerce_single_product_summary', 'woocommerce_template_single_excerpt', 20 );
        }
        if ( 'yes' != $settings['progressbar'] ) {
            remove_action( 'woocommerce_single_product_summary', 'ninetheme_product_stock_progress_bar', 26 );
        }
        if ( 'yes' != $settings['cart'] ) {
            remove_action( 'woocommerce_single_product_summary', 'woocommerce_template_single_add_to_cart', 30 );
        }
        if ( 'yes' != $settings['meta'] ) {
            remove_action( 'woocommerce_single_product_summary', 'woocommerce_template_single_meta', 40 );
        }

        $the_query = new \WP_Query( $args );
        if ( $the_query->have_posts() ) {
            echo '<div class="ninetheme-widget-deals-products-slider-wrapper">';
                echo '<div class="ninetheme-swiper-theme-style nav-type-both'.$dots_none.' swiper-container ninetheme-swiper-slider'.$editmode.'" data-swiper-options=\''.$slider_options.'\'>';
                    if ( $settings['slider_title'] ) {
                        echo '<div class="ninetheme-slider-title-wrapper nav-top'.$has_title.'">';
                            echo '<'.$settings['title_tag'].' class="ninetheme-slider-nav-title">'.$settings['slider_title'].'</'.$settings['title_tag'].'>';
                    }
                        if ( 'yes' == $settings['nav'] || 'yes' == $settings['dots'] ) {

                            echo '<div class="ninetheme-slider-nav">';
                                if ( 'yes' == $settings['nav'] ) {
                                    echo '<div class="swiper-button-prev slide-prev-'.$id.'"></div>';
                                }
                                if ( 'yes' == $settings['dots'] ) {
                                    echo '<div class="swiper-pagination ninetheme-pagination-'.$id.'"></div>';
                                }
                                if ( 'yes' == $settings['nav'] ) {
                                    echo '<div class="swiper-button-next slide-next-'.$id.'"></div>';
                                }
                            echo '</div>';
                        }

                    if ( $settings['slider_title'] ) {
                        echo '</div>';
                    }
                    echo '<div class="swiper-wrapper">';
                        while ( $the_query->have_posts() ) {
                            $the_query->the_post();
                            $product = new \WC_Product(get_the_ID());
                            if ( 'yes' != $settings['share'] ) {
                                add_filter( 'ninetheme_product_share_buttons', '__return_false' );
                            }
                            $time = 'yes' == $settings['only_deals'] ? get_post_meta( $product->get_id(), 'ninetheme_countdown_date', true) : true;
                            if ( $time ) {
                                ?>
                                <div class="swiper-slide woocommerce ninetheme-deals-product">
                                    <div id="product-<?php the_ID(); ?>" <?php wc_product_class( 'ninetheme-single-product-type-1 ninetheme-deals-product-inner', $product ); ?>>
                                        <div class="row ninetheme-row-summary">
                                            <div class="col-12 col-lg-<?php echo esc_attr( $settings['gallery_col'] ); ?> gallery-col">
                                                <?php $this->product_gallery($product->get_id()); ?>
                                            </div>

                                            <div class="col-12 col-lg-<?php echo esc_attr( $column ); ?> summary-col">
                                                <div class="ninetheme-product-summary">
                                                    <div class="ninetheme-product-summary-inner">

                                                    <?php if ( 'yes' == $settings['title'] ) { ?>
                                                        <h6 class="ninetheme-summary-item ninetheme-product-title"> <?php echo get_the_title(); ?></h6>
                                                    <?php } ?>

                                                    <?php do_action( 'woocommerce_single_product_summary' ); ?>

                                                    </div>
                                                </div>
                                            </div>
                                        </div>
                                    </div>
                                </div>
                                <?php
                            }
                        }
                    echo '</div>';
                echo '</div>';
            echo '</div>';
        }
        wp_reset_postdata();

        if ( \Elementor\Plugin::$instance->editor->is_edit_mode() ) { ?>
            <script>
            jQuery( document ).ready( function($) {
                $('.ninetheme-swiper-slider-<?php echo $id ?>').each(function (i, el) {
                    var options = $(el).data('swiper-options')
                    const mySlider = new NTSwiper(el, options);

                    $(this).hover(
                        function() {
                            if ( options.autoplay == true ) {
                                mySlider.autoplay.stop();
                            }
                        },
                        function() {
                            if ( options.autoplay == true ) {
                                mySlider.autoplay.start();
                            }
                        }
                    );
                });
            });
            </script>
            <?php
        }
    }
}
