<?php

namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) exit; // If this file is called directly, abort.

class Ninetheme_Woo_Grid extends Widget_Base {
    use Ninetheme_Helper;
    public function get_name() {
        return 'ninetheme-woo-grid';
    }
    public function get_title() {
        return 'WC Products Grid (N)';
    }
    public function get_icon() {
        return 'eicon-gallery-grid';
    }
    public function get_categories() {
        return [ 'ninetheme-woo' ];
    }
    public function get_keywords() {
        return [ 'woocommerce', 'shop', 'store', 'cat', 'product', 'wc' ];
    }
    // Registering Controls
    protected function register_controls() {
        /*****   START CONTROLS SECTION   ******/
        $this->start_controls_section( 'post_query_scenario_section',
            [
                'label' => esc_html__( 'Query', 'crisop' ),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );
        $this->add_control( 'box_style',
            [
                'label' => esc_html__( 'Style', 'crisop' ),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'style-1' => esc_html__( 'Style 1', 'crisop' ),
                    'style-2' => esc_html__( 'Style 2', 'crisop' )
                ],
                'default' => 'style-1'
            ]
        );
        $this->add_responsive_control( 'col',
            [
                'label' => esc_html__( 'Column', 'crisop' ),
                'type' => Controls_Manager::NUMBER,
                'min' => 1,
                'max' => 6,
                'default' => 4,
                'selectors' => ['{{WRAPPER}} .ninetheme-products:not(.is-ajax).row>div' => '-ms-flex:0 0 calc( 100% / {{VALUE}} );flex:0 0 calc( 100% / {{VALUE}} );max-width: calc( 100% / {{VALUE}} );']
            ]
        );
        $this->add_control('column_gap',
            [
                'label' => __( 'Columns Gap', 'crisop' ),
                'type' => Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 100
                    ]
                ],
				'default' => [
					'unit' => 'px',
					'size' => 15
				],
                'selectors' => [
                    '{{WRAPPER}} .style-1 .ninetheme-products.row>div' => 'padding: 0 {{SIZE}}px;margin-bottom: {{SIZE}}px!important;',
                    '{{WRAPPER}} .style-1 .ninetheme-products.row' => 'margin: 0 -{{SIZE}}px -{{SIZE}}px -{{SIZE}}px;'
                ],
                'condition' => ['box_style' => 'style-1']
            ]
        );
        $this->add_control( 'limit',
            [
                'label' => esc_html__( 'Posts Per Page', 'crisop' ),
                'type' => Controls_Manager::NUMBER,
                'min' => 1,
                'max' => count( get_posts( array('post_type' => 'product', 'post_status' => 'publish', 'fields' => 'ids', 'posts_per_page' => '-1') ) ),
                'default' => 12
            ]
        );
        $this->add_control( 'scenario',
            [
                'label' => esc_html__( 'Select Scenerio', 'crisop' ),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'newest' => esc_html__( 'Newest', 'crisop' ),
                    'featured' => esc_html__( 'Featured', 'crisop' ),
                    'popularity' => esc_html__( 'Popularity', 'crisop' ),
                    'best' => esc_html__( 'Best Selling', 'crisop' ),
                    'attr' => esc_html__( 'Attribute Display', 'crisop' ),
                    'custom_cat' => esc_html__( 'Specific Categories', 'crisop' ),
                ],
                'default' => 'newest'
            ]
        );
        $this->add_control( 'paginate',
            [
                'label' => esc_html__( 'Pagination', 'crisop' ),
                'type' => Controls_Manager::SWITCHER,
                'default' => 'no',
            ]
        );
        $this->add_control( 'hr0',
            [
                'type' => Controls_Manager::DIVIDER,
                'condition' => [ 'scenario' => 'attr' ]
            ]
        );
        $this->add_control( 'attribute',
            [
                'label' => esc_html__( 'Select Attribute', 'crisop' ),
                'type' => Controls_Manager::SELECT2,
                'multiple' => true,
                'options' => $this->ninetheme_woo_attributes(),
                'description' => 'Select Attribute(s)',
                'condition' => [ 'scenario' => 'attr' ]
            ]
        );
        $this->add_control( 'attr_terms',
            [
                'label' => esc_html__( 'Select Attribute Terms', 'crisop' ),
                'type' => Controls_Manager::SELECT2,
                'multiple' => true,
                'options' => $this->ninetheme_woo_attributes_taxonomies(),
                'description' => 'Select Attribute(s)',
                'condition' => [ 'scenario' => 'attr' ]
            ]
        );
        $this->add_control( 'hr1',['type' => Controls_Manager::DIVIDER]);

        $this->add_control( 'cat_filter',
            [
                'label' => esc_html__( 'Filter Category', 'crisop' ),
                'type' => Controls_Manager::SELECT2,
                'multiple' => true,
                'options' => $this->ninetheme_cpt_taxonomies('product_cat'),
                'description' => 'Select Category(s)',
            ]
        );
        $this->add_control( 'cat_operator',
            [
                'label' => esc_html__( 'Category Operator', 'crisop' ),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'AND' => esc_html__( 'display all of the chosen categories', 'crisop' ),
                    'IN' => esc_html__( 'display products within the chosen category', 'crisop' ),
                    'NOT IN' => esc_html__( 'display products that are not in the chosen category.', 'crisop' ),
                ],
                'default' => 'AND',
                'condition' => [ 'scenario' => 'custom_cat' ]
            ]
        );

        $this->add_control( 'hr2',['type' => Controls_Manager::DIVIDER]);

        $this->add_control( 'tag_filter',
            [
                'label' => esc_html__( 'Filter Tag(s)', 'crisop' ),
                'type' => Controls_Manager::SELECT2,
                'multiple' => true,
                'options' => $this->ninetheme_cpt_taxonomies('product_tag','name'),
                'description' => 'Select Tag(s)',
            ]
        );
        $this->add_control( 'tag_operator',
            [
                'label' => esc_html__( 'Tags Operator', 'crisop' ),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'AND' => esc_html__( 'display all of the chosen tags', 'crisop' ),
                    'IN' => esc_html__( 'display ninetheme-products within the chosen tags', 'crisop' ),
                    'NOT IN' => esc_html__( 'display ninetheme-products that are not in the chosen tags.', 'crisop' ),
                ],
                'default' => 'AND',
            ]
        );

        $this->add_control( 'hr3',['type' => Controls_Manager::DIVIDER]);

        $this->add_control( 'order',
            [
                'label' => esc_html__( 'Select Order', 'crisop' ),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'ASC' => esc_html__( 'Ascending', 'crisop' ),
                    'DESC' => esc_html__( 'Descending', 'crisop' )
                ],
                'default' => 'DESC'
            ]
        );
        $this->add_control( 'orderby',
            [
                'label' => esc_html__( 'Order By', 'crisop' ),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'id' => esc_html__( 'Post ID', 'crisop' ),
                    'menu_order' => esc_html__( 'Menu Order', 'crisop' ),
                    'popularity' => esc_html__( 'Popularity', 'crisop' ),
                    'rand' => esc_html__( 'Random', 'crisop' ),
                    'rating' => esc_html__( 'Rating', 'crisop' ),
                    'date' => esc_html__( 'Date', 'crisop' ),
                    'title' => esc_html__( 'Title', 'crisop' ),
                ],
                'default' => 'id',
                'condition' => [ 'scenario!' => 'custom_cat' ]
            ]
        );
        $this->add_control( 'cat_orderby',
            [
                'label' => esc_html__( 'Order By', 'crisop' ),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'id' => esc_html__( 'Post ID', 'crisop' ),
                    'menu_order' => esc_html__( 'Menu Order', 'crisop' ),
                    'name' => esc_html__( 'Name', 'crisop' ),
                    'slug' => esc_html__( 'Slug', 'crisop' ),
                ],
                'default' => 'id',
                'condition' => [ 'scenario' => 'custom_cat' ]
            ]
        );
        $this->add_control( 'show_cat_empty',
            [
                'label' => esc_html__( 'Show Empty Categories', 'crisop' ),
                'type' => Controls_Manager::SWITCHER,
                'label_on' => esc_html__( 'Yes', 'crisop' ),
                'label_off' => esc_html__( 'No', 'crisop' ),
                'return_value' => 'yes',
                'default' => 'no',
                'condition' => [ 'scenario' => 'custom_cat' ]
            ]
        );
        $this->end_controls_section();
        /*****   END CONTROLS SECTION   ******/
        /*****   START CONTROLS SECTION   ******/
        $this->start_controls_section('post_style_section',
            [
                'label' => esc_html__( 'STYLE', 'crisop' )
            ]
        );
        $this->add_responsive_control( 'post_padding',
            [
                'label' => esc_html__( 'Padding', 'crisop' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px' ],
                'selectors' => ['{{WRAPPER}} .woocommerce .ninetheme-type-product .ninetheme-loop-product' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};']
            ]
        );
        $this->add_control( 'post_bgcolor',
            [
                'label' => esc_html__( 'Background Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [ 
                    '{{WRAPPER}} .ninetheme-widget-products-grid:not(.type-container-bordered) .ninetheme-type-product .ninetheme-loop-product,
                    {{WRAPPER}} .ninetheme-widget-products-grid.type-container-bordered .ninetheme-type-product' => 'background-color: {{VALUE}};'
                ]
            ]
        );
        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name' => 'post_border',
                'label' => esc_html__( 'Border', 'crisop' ),
                'selector' => '{{WRAPPER}} .ninetheme-widget-products-grid:not(.type-container-bordered) .ninetheme-type-product .ninetheme-loop-product'
            ]
        );
        $this->add_group_control(
            Group_Control_Box_Shadow::get_type(),
            [
                'name' => 'post_item_box_shadow',
                'label' => esc_html__( 'Box Shadow', 'crisop' ),
                'selector' => '{{WRAPPER}} .ninetheme-widget-products-grid:not(.type-container-bordered) .ninetheme-type-product .ninetheme-loop-product,
                {{WRAPPER}} .ninetheme-widget-products-grid.type-container-bordered .ninetheme-type-product:before,
                {{WRAPPER}} .ninetheme-widget-products-grid:not(.type-container-bordered) .ninetheme-type-product .ninetheme-loop-product:before'
            ]
        );
        $this->add_control( 'stock_heading',
            [
                'label' => esc_html__( 'STOCK STATUS', 'crisop' ),
                'type' => Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );
        $this->add_control( 'instock_color',
            [
                'label' => esc_html__( 'In Stock Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => ['{{WRAPPER}} .ninetheme-loop-product .ninetheme-stock-status.ninetheme-instock' => 'color: {{VALUE}};']
            ]
        );
        $this->add_control( 'outofstock_color',
            [
                'label' => esc_html__( 'Out of Stock Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => ['{{WRAPPER}} .ninetheme-loop-product .ninetheme-stock-status.ninetheme-outofstock' => 'color: {{VALUE}};']
            ]
        );
        $this->add_control( 'labels_heading',
            [
                'label' => esc_html__( 'LABELS', 'crisop' ),
                'type' => Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );
        $this->add_control( 'deflabel_color',
            [
                'label' => esc_html__( 'Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => ['{{WRAPPER}} .ninetheme-label,{{WRAPPER}} .ninetheme-label.ninetheme-bg-default' => 'color: {{VALUE}};']
            ]
        );
        $this->add_control( 'deflabel_bgcolor',
            [
                'label' => esc_html__( 'Background Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => ['{{WRAPPER}} .ninetheme-label,{{WRAPPER}} .ninetheme-label.ninetheme-bg-default' => 'background-color: {{VALUE}};']
            ]
        );
        $this->add_control( 'discount_color',
            [
                'label' => esc_html__( 'Discount Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => ['{{WRAPPER}} .ninetheme-loop-product .ninetheme-label.ninetheme-discount' => 'color: {{VALUE}};']
            ]
        );
        $this->add_control( 'discount_bgcolor',
            [
                'label' => esc_html__( 'Discount Background Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => ['{{WRAPPER}} .ninetheme-loop-product .ninetheme-label.ninetheme-discount' => 'background-color: {{VALUE}};']
            ]
        );
        $this->add_control( 'addtocart_heading',
            [
                'label' => esc_html__( 'ADD TO CART', 'crisop' ),
                'type' => Controls_Manager::HEADING,
                'separator' => 'before'
            ]
        );
        $this->add_control( 'addtocarticon_color',
            [
                'label' => esc_html__( 'Add To Cart Color ( Type Icon )', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => ['{{WRAPPER}} .ninetheme-loop-product .ninetheme-product-button.btn-type-icon .ninetheme-svg-icon' => 'fill: {{VALUE}};']
            ]
        );
        $this->add_control( 'addtocarticon_bgcolor',
            [
                'label' => esc_html__( 'Add To Cart Background Color ( Type Icon )', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => ['{{WRAPPER}} .ninetheme-loop-product .ninetheme-product-button.btn-type-icon' => 'background-color: {{VALUE}};']
            ]
        );
        $this->add_control( 'title_heading',
            [
                'label' => esc_html__( 'TITLE', 'crisop' ),
                'type' => Controls_Manager::HEADING,
                'separator' => 'before'
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'title_typo',
                'label' => esc_html__( 'Typography', 'crisop' ),
                'selector' => '{{WRAPPER}} .woocommerce .ninetheme-type-product .ninetheme-loop-product-name'
            ]
        );
        $this->add_control( 'title_color',
            [
                'label' => esc_html__( 'Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => ['{{WRAPPER}} .woocommerce .ninetheme-type-product .ninetheme-loop-product-name' => 'color: {{VALUE}};']
            ]
        );
        $this->add_control( 'price_heading',
            [
                'label' => esc_html__( 'PRICE', 'crisop' ),
                'type' => Controls_Manager::HEADING,
                'separator' => 'before'
            ]
        );
        $this->add_control( 'price_color',
            [
                'label' => esc_html__( 'Price Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => ['{{WRAPPER}} .woocommerce .ninetheme-type-product span.del > span' => 'color: {{VALUE}};']
            ]
        );
        $this->add_control( 'price_color2',
            [
                'label' => esc_html__( 'Price Color 2', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => ['{{WRAPPER}}  .woocommerce .ninetheme-type-product .ninetheme-price' => 'color: {{VALUE}};']
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'price_typo',
                'label' => esc_html__( 'Typography', 'crisop' ),
                'selector' => '{{WRAPPER}} .woocommerce .ninetheme-type-product .ninetheme-price'
            ]
        );
        $this->end_controls_section();
        /*****   END CONTROLS SECTION   ******/
    }

    public function set_shop_column() {
        return isset( $_GET['column'] ) ? 'is-ajax row-cols-2 row-cols-md-2 row-cols-lg-'.$_GET['column'] : 4;
    }

    public function set_shop_style() {
        $settings  = $this->get_settings_for_display();
        return 'style-2' == $settings['box_style'] ? 'bordered' : '';
    }

    protected function render() {
        if ( ! class_exists('WooCommerce') ) {
            return;
        }
        $settings  = $this->get_settings_for_display();
        $elementid = $this->get_id();
        
        $perpage = isset( $_GET['per_page'] ) ? $_GET['per_page'] : $settings['limit'];
        
        add_filter( 'ninetheme_products_column', [$this, 'set_shop_column'] );
        add_filter( 'ninetheme_shop_layout_style', [$this, 'set_shop_style'] );

        $limit          = 'limit="'.$perpage.'"';
        $order          = ' order="'.$settings['order'].'"';
        $orderby        = ' orderby="'.$settings['orderby'].'"';
        $paginate       = 'yes'== $settings['paginate'] ? ' paginate="true"' : '';
        $hide_empty     = 'yes'== $settings['show_cat_empty'] ? ' hide_empty="0"' : '';
        $operator       = ' cat_operator="'.$settings['cat_operator'].'"';
        $tag_operator   = ' tag_operator="'.$settings['tag_operator'].'"';
        $cat_orderby    = ' orderby="'.$settings['cat_orderby'].'"';
        $cat_filter     = is_array($settings['cat_filter']) ? ' category="'.implode(', ',$settings['cat_filter']).'"' : '';
        $hide_empty_cat = 'yes'== $settings['show_cat_empty'] ? ' hide_empty="0"' : '';
        $tag_filter     = is_array($settings['tag_filter']) ? ' tag="'.implode(', ',$settings['tag_filter']).'"' : '';
        $attr_filter    = is_array($settings['attribute']) ? ' attribute="'.implode(', ',$settings['attribute']).'"' : '';
        $attr_terms     = is_array($settings['attr_terms']) ? ' terms="'.implode(', ',$settings['attr_terms']).'"' : '';
        
        echo '<div class="row ninetheme-choosen-filters-row">'.do_action( 'ninetheme_choosen_filters' ).'</div>';
        echo '<div class="ninetheme-elementor-widget ninetheme-widget-products-grid products-ajax-content">';
            echo '<div class="ninetheme-products-wrapper">';
                if ( 'newest' == $settings['scenario'] ) {
                    echo do_shortcode('[products '.$limit.$orderby.$order.$tag_filter.$paginate.' visibility="visible"]');
                } elseif ( 'featured' == $settings['scenario'] ) {
                    echo do_shortcode('[products '.$limit.$orderby.$order.$tag_filter.$paginate.' visibility="featured"]');
                } elseif ( 'popularity' == $settings['scenario'] ) {
                    echo do_shortcode('[products '.$limit.$order.$tag_filter.$paginate.' orderby="popularity" on_sale="true"]');
                } elseif ( 'best' == $settings['scenario'] ) {
                    echo do_shortcode('[products '.$limit.$orderby.$order.$cat_filter.$operator.$hide_empty_cat.$tag_filter.$paginate.' best_selling="true"]');
                } elseif ( 'custom_cat' == $settings['scenario'] ) {
                    echo do_shortcode('[products '.$limit.$cat_orderby.$order.$cat_filter.$operator.$hide_empty_cat.$tag_filter.$paginate.']');
                } elseif ( 'attr' == $settings['scenario'] ) {
                    echo do_shortcode('[products '.$limit.$attr_filter.$attr_terms.$limit.$orderby.$order.$paginate.']');
                } else {
                    echo do_shortcode('[products '.$limit.$orderby.$order.$tag_filter.$operator.$paginate.' visibility="visible"]');
                }
            echo '</div>';
        echo '</div>';
        remove_filter( 'ninetheme_shop_layout_style', [$this, 'set_shop_style'] );
    }
}
