<?php

namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) exit; // If this file is called directly, abort.

class Ninetheme_Woo_Header_Actions extends Widget_Base {
    use Ninetheme_Helper;
    public function get_name() {
        return 'ninetheme-woo-header-actions';
    }
    public function get_title() {
        return 'WC Header Actions (N)';
    }
    public function get_icon() {
        return 'eicon-product-breadcrumbs';
    }
    public function get_categories() {
        return [ 'ninetheme-header' ];
    }
    public function get_keywords() {
        return [ 'woocommerce', 'shop', 'store', 'breadcrumbs', 'internal','links', 'product' ];
    }
    // Registering Controls
    protected function register_controls() {

        /* HEADER MINICART SETTINGS */
        $this->start_controls_section( 'general_section',
            [
                'label' => esc_html__( 'Header Actions', 'crisop' ),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );
        $repeater = new Repeater();
        $repeater->add_control( 'trigger',
            [
                'label' => esc_html__( 'Action', 'crisop' ),
                'type' => Controls_Manager::SELECT,
                'default' => 'style-inline',
                'options' => [
                    'cart' => esc_html__( 'Cart Popup', 'crisop' ),
                    'cart-page' => esc_html__( 'Cart Page', 'crisop' ),
                    'wishlist' => esc_html__( 'Wishlist Popup', 'crisop' ),
                    'compare' => esc_html__( 'Compare Popup', 'crisop' ),
                    'account' => esc_html__( 'Myaccount Page', 'crisop' ),
                    'search-popup' => esc_html__( 'Search Popup', 'crisop' ),
                ]
            ]
        );
        $repeater->add_control( 'icon',
            [
                'label' => esc_html__( 'Icon', 'crisop' ),
                'type' => Controls_Manager::ICONS
            ]
        );
        $repeater->add_control( 'text',
            [
                'label' => esc_html__( 'Text Bottom', 'crisop' ),
                'type' => Controls_Manager::TEXT
            ]
        );
        $this->add_control( 'items',
            [
                'label' => esc_html__( 'Items', 'crisop' ),
                'type' => Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'title_field' => '{{trigger}}',
                'default' => [
                	['trigger' => 'cart','text' => 'Cart' ],
                	['trigger' => 'wishlist','text' => 'Wishlist' ],
                	['trigger' => 'compare','text' => 'Compare' ]
                ]
            ]
        );
        $this->end_controls_section();
        /*****   END CONTROLS SECTION   ******/
        /*****   START CONTROLS SECTION   ******/
        $this->start_controls_section('style_section',
            [
                'label'=> esc_html__( 'STYLE', 'crisop' ),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );
        $this->add_control( 'icon_divider',
            [
                'label' => esc_html__( 'ICON', 'crisop' ),
                'type' => Controls_Manager::HEADING
            ]
        );
        $is_first = is_rtl() ? 'last' : 'first';
        $this->add_responsive_control( 'icon_space',
            [
                'label' => esc_html__( 'Space Between Items', 'crisop' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'range' => [
                    'px' => [
                        'max' => 100,
                        'min' => 0
                    ],
                ],
                'selectors' => [ '{{WRAPPER}} .ninetheme-header-default-inner .header-top-buttons>.top-action-btn:not(:'.$is_first.'-child)' => 'margin-left:{{SIZE}}px;' ]
            ]
        );
        $this->add_responsive_control( 'icon_size',
            [
                'label' => esc_html__( 'Size', 'crisop' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'range' => [
                    'px' => [
                        'max' => 100,
                        'min' => 0
                    ],
                ],
                'selectors' => [
                	'{{WRAPPER}} .ninetheme-header-widget-woo-actions .top-action-btn .btn-icon' => 'font-size:{{SIZE}}px;',
                	'{{WRAPPER}} .ninetheme-header-widget-woo-actions .top-action-btn .ninetheme-svg-icon' => 'max-width:{{SIZE}}px;max-height:{{SIZE}}px;'
                ]
            ]
        );
        $this->add_control( 'icon_color',
           [
               'label' => esc_html__( 'Color', 'crisop' ),
               'type' => Controls_Manager::COLOR,
               'default' => '',
               'selectors' => [
               		'{{WRAPPER}} .header-top-buttons .top-action-btn .btn-icon' => 'color: {{VALUE}};',
               		'{{WRAPPER}} .header-top-buttons .top-action-btn .btn-icon .ninetheme-svg-icon' => 'fill: {{VALUE}};'
               	]
           ]
        );
        $this->add_control( 'icon_hvrcolor',
           [
               'label' => esc_html__( 'Color ( Hover )', 'crisop' ),
               'type' => Controls_Manager::COLOR,
               'default' => '',
               'selectors' => [
               		'{{WRAPPER}} .header-top-buttons .top-action-btn:hover .btn-icon' => 'color: {{VALUE}};',
               		'{{WRAPPER}} .header-top-buttons .top-action-btn:hover .btn-icon .ninetheme-svg-icon' => 'fill: {{VALUE}};',
               	]
           ]
        );
        $this->add_control( 'counter_divider',
            [
                'label' => esc_html__( 'COUNTER', 'crisop' ),
                'type' => Controls_Manager::HEADING,
                'separator' => 'before'
            ]
        );
        $this->add_control( 'counter_color_type',
            [
                'label' => esc_html__( 'Counter Color Type', 'crisop' ),
                'type' => Controls_Manager::SELECT,
                'default' => 'counter-brown',
                'options' => [
                    'counter-primary' => esc_html__( 'Primary', 'crisop' ),
                    'counter-dark' => esc_html__( 'Black', 'crisop' ),
                    'counter-brown' => esc_html__( 'Brown', 'crisop' ),
                    'counter-red' => esc_html__( 'Red', 'crisop' ),
                    'counter-gray' => esc_html__( 'Gray', 'crisop' ),
                    'counter-gray-soft' => esc_html__( 'Gray Soft', 'crisop' ),
                    'counter-green' => esc_html__( 'Green', 'crisop' ),
                    'counter-green-soft' => esc_html__( 'Green Soft', 'crisop' ),
                    'counter-blue' => esc_html__( 'Blue', 'crisop' ),
                    'counter-blue-dark' => esc_html__( 'Blue Dark', 'crisop' ),
                    'counter-blue-soft' => esc_html__( 'Blue Soft', 'crisop' ),
                    'counter-purple' => esc_html__( 'Purple', 'crisop' ),
                    'counter-purple-soft' => esc_html__( 'Purple Soft', 'crisop' ),
                    'counter-yellow' => esc_html__( 'Yellow', 'crisop' ),
                    'counter-yellow-soft' => esc_html__( 'Yellow Soft', 'crisop' ),
                    'counter-custom-color' => esc_html__( 'Custom', 'crisop' )
                ]
            ]
        );
        $this->add_control( 'counter_custom_bgcolor',
           [
               'label' => esc_html__( 'Counter Custom Background Color', 'crisop' ),
               'type' => Controls_Manager::COLOR,
               'default' => '',
               'selectors' => ['{{WRAPPER}} .header-top-buttons .top-action-btn .ninetheme-wc-count' => 'background-color: {{VALUE}};'],
               'condition' => ['counter_color_type' => 'counter-custom-color']
           ]
        );
        $this->add_control( 'counter_custom_color',
           [
               'label' => esc_html__( 'Counter Custom Color', 'crisop' ),
               'type' => Controls_Manager::COLOR,
               'default' => '',
               'selectors' => ['{{WRAPPER}} .header-top-buttons .top-action-btn .ninetheme-wc-count' => 'color: {{VALUE}};'],
               'condition' => ['counter_color_type' => 'counter-custom-color']
           ]
        );
        $this->add_control( 'counter_position',
            [
                'label' => esc_html__( 'Counter Position', 'crisop' ),
                'type' => Controls_Manager::SELECT,
                'default' => 'counter-right',
                'options' => [
                    'counter-left' => esc_html__( 'Left', 'crisop' ),
                    'counter-right' => esc_html__( 'Right', 'crisop' ),
                    'counter-custom-position' => esc_html__( 'Custom', 'crisop' ),
                ]
            ]
        );
        $this->add_responsive_control( 'counter_top_position',
            [
                'label' => esc_html__( 'Top', 'crisop' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'range' => [
                    'px' => [
                        'max' => 100,
                        'min' => -100
                    ],
                ],
                'selectors' => [ '{{WRAPPER}} .ninetheme-header-default-inner .header-top-buttons .top-action-btn .ninetheme-wc-count' => 'top:{{SIZE}}px;' ],
                'condition' => ['counter_position' => 'counter-custom-position']
            ]
        );
        $this->add_responsive_control( 'counter_left_position',
            [
                'label' => esc_html__( 'Left', 'crisop' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'range' => [
                    'px' => [
                        'max' => 100,
                        'min' => -100
                    ],
                ],
                'selectors' => [ '{{WRAPPER}} .ninetheme-header-default-inner .header-top-buttons .top-action-btn .ninetheme-wc-count' => 'right:auto;left:{{SIZE}}px;' ],
                'condition' => ['counter_position' => 'counter-custom-position']
            ]
        );
        $this->add_control( 'text_divider',
            [
                'label' => esc_html__( 'TEXT', 'crisop' ),
                'type' => Controls_Manager::HEADING,
                'separator' => 'before'
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'text_typo',
                'label' => esc_html__( 'Typography', 'crisop' ),
                'selector' => '{{WRAPPER}} .header-top-buttons .top-action-btn-text'
            ]
        );
        $this->add_control( 'text_color',
           [
               'label' => esc_html__( 'Text Color', 'crisop' ),
               'type' => Controls_Manager::COLOR,
               'default' => '',
               'selectors' => ['{{WRAPPER}} .header-top-buttons .top-action-btn-text' => 'color: {{VALUE}};']
           ]
        );
        $this->end_controls_section();
    }

    protected function render() {
        if ( ! class_exists('WooCommerce') ) {
            return;
        }
        $settings = $this->get_settings_for_display();

        $class  = ' '.$settings['counter_position'];
        $class .= ' '.$settings['counter_color_type'];

		echo '<div class="ninetheme-header-widget-woo-actions ninetheme-header-default">';
			echo '<div class="ninetheme-header-default-inner">';
				echo '<div class="header-top-buttons'.$class.' shape-default display-default">';
				foreach ( $settings['items'] as $item ) {
					$link = 'account' == $item['trigger'] ? wc_get_page_permalink( 'myaccount' ) : wc_get_page_permalink( 'cart' );
					$data = 'account' != $item['trigger'] && 'cart-page' != $item['trigger'] ? ' data-name="'.$item['trigger'].'"' : '';
					$icon = $item['trigger'];
					if ( 'account' == $item['trigger'] ) {
						$icon = 'user2';
					}
					if ( 'wishlist' == $item['trigger'] ) {
						$icon = 'love';
					}
					if ( 'cart' == $item['trigger'] || 'cart-page' == $item['trigger'] ) {
						$icon = 'bag';
					}
					echo '<div class="top-action-btn"'.$data.'>';
						echo 'account' == $item['trigger'] || 'cart-page' == $item['trigger'] ? '<a class="account-page-link" href="'.esc_url($link).'">' : '';
		                if ( !empty( $item['icon']['value'] ) ) {
		                	echo '<span class="btn-icon">';Icons_Manager::render_icon( $item['icon'], [ 'aria-hidden' => 'true' ] );echo '</span>';
		                } else {
		                	echo ninetheme_svg_lists( $icon, 'ninetheme-svg-icon' );
		                }
						if ( 'account' != $item['trigger'] && 'search-popup' != $item['trigger'] ) {
							echo '<span class="ninetheme-'.$item['trigger'].'-count ninetheme-wc-count"></span>';
						}
						echo 'account' == $item['trigger'] || 'cart-page' == $item['trigger'] ? '</a>' : '';

						if ( !empty( $item['text'] ) ) {
							echo '<span class="top-action-btn-text">'.$item['text'].'</span>';
						}
					echo '</div>';
				}
				echo '</div>';
			echo '</div>';
		echo '</div>';
    }
}
