<?php

namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) exit; // If this file is called directly, abort.

class Ninetheme_Woo_Header_Locations extends Widget_Base {
    use Ninetheme_Helper;
    public function get_name() {
        return 'ninetheme-woo-header-locations';
    }
    public function get_title() {
        return 'WC Locations (N)';
    }
    public function get_icon() {
        return 'eicon-site-search';
    }
    public function get_categories() {
        return [ 'ninetheme-header' ];
    }
    public function get_keywords() {
        return [ 'woocommerce', 'shop', 'store', 'cat', 'wc', 'woo', 'product', 'locations', 'menu'  ];
    }
    // Registering Controls
    protected function register_controls() {
        /* HEADER MINICART SETTINGS */
        $this->start_controls_section( 'general_section',
            [
                'label' => esc_html__( 'Location', 'crisop' ),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );
        $this->add_control( 'hide_mobile',
            [
                'label' => esc_html__( 'Hide On Mobile', 'crisop' ),
                'type' => Controls_Manager::SWITCHER,
                'default' => 'yes'
            ]
        );
        $this->add_control( 'btn_style',
            [
                'label' => esc_html__( 'Button Style', 'crisop' ),
                'type' => Controls_Manager::SELECT,
                'default' => 'style-border-none',
                'options' => [
                    'style-border' => esc_html__( 'Border', 'crisop' ),
                    'style-border-none' => esc_html__( 'Borderless', 'crisop' )
                ]
            ]
        );
        $this->add_control( 'btn_radius_style',
            [
                'label' => esc_html__( 'Radius Style', 'crisop' ),
                'type' => Controls_Manager::SELECT,
                'default' => 'style-square',
                'options' => [
                    'style-radius' => esc_html__( 'Circle', 'crisop' ),
                    'style-square' => esc_html__( 'Square', 'crisop' )
                ],
                'condition' => ['btn_style' => 'style-border']
            ]
        );
        $this->add_control( 'strings_heading_separator',
            [
                'label' => esc_html__( 'Strings Button', 'crisop' ),
                'type' => Controls_Manager::HEADING,
                'separator' => 'before'
            ]
        );
        $this->add_control( 'hide_subtitle',
            [
                'label' => esc_html__( 'Hide Subtitle', 'crisop' ),
                'type' => Controls_Manager::SWITCHER,
                'default' => 'no'
            ]
        );
        $this->add_control( 'subtitle',
            [
                'label' => esc_html__( 'Subtitle', 'crisop' ),
                'type' => Controls_Manager::TEXT,
                'label_block' => true,
                'default' => 'Your Loacation',
                'condition' => ['hide_subtitle!' => 'yes']
            ]
        );
        $this->add_control( 'subtitle_position',
            [
                'label' => esc_html__( 'Subtitle Position', 'crisop' ),
                'type' => Controls_Manager::SELECT,
                'default' => 'top',
                'options' => [
                    'top' => esc_html__( 'Top', 'crisop' ),
                    'bottom' => esc_html__( 'Bottom', 'crisop' )
                ],
                'condition' => ['hide_subtitle!' => 'yes']
            ]
        );
        $this->add_control( 'title',
            [
                'label' => esc_html__( 'Button Title', 'crisop' ),
                'type' => Controls_Manager::TEXT,
                'label_block' => true,
                'default' => 'Select a Location',
            ]
        );
        $this->add_control( 'strings_popup_heading_separator',
            [
                'label' => esc_html__( 'Strings Search Popup', 'crisop' ),
                'type' => Controls_Manager::HEADING,
                'separator' => 'before'
            ]
        );
        $this->add_control( 'hide_inner_title',
            [
                'label' => esc_html__( 'Hide Popup Title', 'crisop' ),
                'type' => Controls_Manager::SWITCHER,
                'default' => 'no'
            ]
        );
        $this->add_control( 'inner_title',
            [
                'label' => esc_html__( 'Popup Title', 'crisop' ),
                'type' => Controls_Manager::TEXT,
                'label_block' => true,
                'default' => 'Choose your Delivery Location',
                'condition' => ['hide_inner_title!' => 'yes']
            ]
        );
        $this->add_control( 'hide_inner_desc',
            [
                'label' => esc_html__( 'Hide Popup Description', 'crisop' ),
                'type' => Controls_Manager::SWITCHER,
                'default' => 'no'
            ]
        );
        $this->add_control( 'inner_desc',
            [
                'label' => esc_html__( 'Popup Description', 'crisop' ),
                'type' => Controls_Manager::TEXTAREA,
                'label_block' => true,
                'default' => 'Enter your address and we will specify the offer for your area.',
                'condition' => ['hide_inner_desc!' => 'yes']
            ]
        );
        $this->add_control( 'placeholder',
            [
                'label' => esc_html__( 'Popup Search Placeholder', 'crisop' ),
                'type' => Controls_Manager::TEXT,
                'label_block' => true,
                'default' => 'Search your area'
            ]
        );
        $this->add_control( 'select_text',
            [
                'label' => esc_html__( 'Popup Select Option Text', 'crisop' ),
                'type' => Controls_Manager::TEXT,
                'label_block' => true,
                'default' => 'Select a Location'
            ]
        );
        $this->add_control( 'clear_text',
            [
                'label' => esc_html__( 'Popup Clear Text', 'crisop' ),
                'type' => Controls_Manager::TEXT,
                'label_block' => true,
                'default' => 'Clear All'
            ]
        );
        $this->end_controls_section();
        /*****   END CONTROLS SECTION   ******/
        /*****   START CONTROLS SECTION   ******/
        $this->start_controls_section('btn_style_section',
            [
                'label'=> esc_html__( 'BUTTON STYLE', 'crisop' ),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );
        $this->add_responsive_control( 'btn_padding',
            [
                'label' => esc_html__( 'Button Padding', 'crisop' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', 'em', '%' ],
                'selectors' => ['{{WRAPPER}} .ninetheme-header-location .ninetheme-header-location-trigger' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};']
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'subtitle_typo',
                'label' => esc_html__( 'Subtitle Typography', 'crisop' ),
                'selector' => '{{WRAPPER}} .ninetheme-header-location .ninetheme-header-location-description',
                'condition' => ['hide_subtitle!' => 'yes']
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'title_typo',
                'label' => esc_html__( 'Title Typography', 'crisop' ),
                'selector' => '{{WRAPPER}} .ninetheme-header-location.ninetheme-widget-woo-location .ninetheme-header-current-location'
            ]
        );
        $this->start_controls_tabs( 'btn_tabs');
        $this->start_controls_tab( 'btn_normal_tab',
            [ 'label' => esc_html__( 'Normal', 'crisop' ) ]
        );
        $this->add_control( 'arrow_color',
           [
               'label' => esc_html__( 'Arrow Color', 'crisop' ),
               'type' => Controls_Manager::COLOR,
               'default' => '',
               'selectors' => ['{{WRAPPER}} .ninetheme-header-location .ninetheme-header-location-trigger:after' => 'color: {{VALUE}};']
           ]
        );
        $this->add_control( 'subtitle_color',
           [
               'label' => esc_html__( 'Subtitle Color', 'crisop' ),
               'type' => Controls_Manager::COLOR,
               'default' => '',
               'selectors' => ['{{WRAPPER}} .ninetheme-header-location .ninetheme-header-location-description' => 'color: {{VALUE}};'],
               'condition' => ['hide_subtitle!' => 'yes']
           ]
        );
        $this->add_control( 'title_color',
           [
               'label' => esc_html__( 'Title Color', 'crisop' ),
               'type' => Controls_Manager::COLOR,
               'default' => '',
               'selectors' => ['{{WRAPPER}} .ninetheme-header-location.ninetheme-widget-woo-location .ninetheme-header-current-location' => 'color: {{VALUE}};']
           ]
        );
        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name' => 'btn_border',
                'label' => esc_html__( 'Border', 'crisop' ),
                'selector' => '{{WRAPPER}} .ninetheme-header-location.ninetheme-widget-woo-location',
            ]
        );
        $this->add_responsive_control( 'btn_border_radius',
            [
                'label' => esc_html__( 'Border Radius', 'crisop' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px' ],
                'selectors' => ['{{WRAPPER}} .ninetheme-header-location.ninetheme-widget-woo-location' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};']
            ]
        );
        $this->add_group_control(
            Group_Control_Box_Shadow::get_type(),
            [
                'name' => 'btn_shadow',
                'label' => esc_html__( 'Box Shadow', 'crisop' ),
                'selector' =>'{{WRAPPER}} .ninetheme-header-location.ninetheme-widget-woo-location'
            ]
        );
        $this->end_controls_tab();
        $this->start_controls_tab( 'btn_hover_tab',
            [ 'label' => esc_html__( 'Hover', 'crisop' ) ]
        );
        $this->add_control( 'arrow_hvrcolor',
           [
               'label' => esc_html__( 'Arrow Color', 'crisop' ),
               'type' => Controls_Manager::COLOR,
               'default' => '',
               'selectors' => ['{{WRAPPER}} .ninetheme-header-location.ninetheme-widget-woo-location:hover .ninetheme-header-location-trigger:after' => 'color: {{VALUE}};']
           ]
        );
        $this->add_control( 'subtitle_hvrcolor',
           [
               'label' => esc_html__( 'Subtitle Color', 'crisop' ),
               'type' => Controls_Manager::COLOR,
               'default' => '',
               'selectors' => ['{{WRAPPER}} .ninetheme-header-location.ninetheme-widget-woo-location:hover .ninetheme-header-location-description' => 'color: {{VALUE}};'],
               'condition' => ['hide_subtitle!' => 'yes']
           ]
        );
        $this->add_control( 'title_hvrcolor',
           [
               'label' => esc_html__( 'Title Color', 'crisop' ),
               'type' => Controls_Manager::COLOR,
               'default' => '',
               'selectors' => ['{{WRAPPER}} .ninetheme-header-location.ninetheme-widget-woo-location:hover .ninetheme-header-current-location' => 'color: {{VALUE}};']
           ]
        );
        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name' => 'btn_hvrborder',
                'label' => esc_html__( 'Border', 'crisop' ),
                'selector' => '{{WRAPPER}} .ninetheme-header-location.ninetheme-widget-woo-location:hover',
            ]
        );
        $this->add_responsive_control( 'btn_border_radius',
            [
                'label' => esc_html__( 'Border Radius', 'crisop' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px' ],
                'selectors' => ['{{WRAPPER}} .ninetheme-header-location.ninetheme-widget-woo-location:hover' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};']
            ]
        );
        $this->add_group_control(
            Group_Control_Box_Shadow::get_type(),
            [
                'name' => 'btn_hvrshadow',
                'label' => esc_html__( 'Box Shadow', 'crisop' ),
                'selector' =>'{{WRAPPER}} .ninetheme-header-location.ninetheme-widget-woo-location:hover'
            ]
        );
        $this->end_controls_tab();
        $this->end_controls_tabs();
        $this->add_responsive_control( 'arrow_top_position',
            [
                'label' => esc_html__( 'Arrow Top Position ( px )', 'crisop' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => [ 'px' ],
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 100,
                        'step' => 1
                    ]
                ],
               'selectors' => [
                   '{{WRAPPER}} .ninetheme-header-location .ninetheme-header-location-trigger:after' => 'top: {{SIZE}}px;bottom:auto;'
                ]
            ]
        );
        $this->add_responsive_control( 'arrow_right_position',
            [
                'label' => esc_html__( 'Arrow Right Position ( px )', 'crisop' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => [ 'px' ],
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 100,
                        'step' => 1
                    ]
                ],
               'selectors' => [
                   '{{WRAPPER}} .ninetheme-header-location .ninetheme-header-location-trigger:after' => 'right: {{SIZE}}px;left:auto;'
                ]
            ]
        );
        $this->end_controls_section();
        /*****   END CONTROLS SECTION   ******/
        /*****   START CONTROLS SECTION   ******/
        $this->start_controls_section('popup_style_section',
            [
                'label'=> esc_html__( 'POPUP SEARCH STYLE', 'crisop' ),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );
        $this->add_control( 'inner_title_color',
           [
               'label' => esc_html__( 'Title Color', 'crisop' ),
               'type' => Controls_Manager::COLOR,
               'default' => '',
               'selectors' => ['{{WRAPPER}} .ninetheme-select-location .ninetheme-location-title' => 'color: {{VALUE}};']
           ]
        );
        $this->add_control( 'inner_desc_color',
           [
               'label' => esc_html__( 'Description Color', 'crisop' ),
               'type' => Controls_Manager::COLOR,
               'default' => '',
               'selectors' => ['{{WRAPPER}} .ninetheme-select-location .ninetheme-location-description' => 'color: {{VALUE}};']
           ]
        );
        $this->add_control( 'popup_bgcolor',
           [
               'label' => esc_html__( 'Popup Background Color', 'crisop' ),
               'type' => Controls_Manager::COLOR,
               'default' => '',
               'selectors' => ['{{WRAPPER}} .ninetheme-select-location .ninetheme-select-location-wrapper' => 'background-color: {{VALUE}};']
           ]
        );
        $this->add_responsive_control( 'popup_padding',
            [
                'label' => esc_html__( 'Padding', 'crisop' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px' ],
                'selectors' => ['{{WRAPPER}} .ninetheme-select-location .ninetheme-select-location-wrapper' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};']
            ]
        );
        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name' => 'popup_border',
                'label' => esc_html__( 'Border', 'crisop' ),
                'selector' => '{{WRAPPER}} .ninetheme-select-location .ninetheme-select-location-wrapper'
            ]
        );
        $this->add_responsive_control( 'popup_border_radius',
            [
                'label' => esc_html__( 'Border Radius', 'crisop' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px' ],
                'selectors' => [
                    '{{WRAPPER}} .ninetheme-select-location .ninetheme-select-location-wrapper'  => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};'
                ]
            ]
        );
        $this->add_control( 'option_heading_separator',
           [
               'label' => esc_html__( 'Select Option', 'crisop' ),
               'type' => Controls_Manager::HEADING,
               'separator' => 'before'
           ]
        );
        $this->add_group_control(
            Group_Control_Box_Shadow::get_type(),
            [
                'name' => 'popup_shadow',
                'label' => esc_html__( 'Box Shadow', 'crisop' ),
                'selector' =>'{{WRAPPER}} .ninetheme-select-location .ninetheme-select-location-wrapper'
            ]
        );
        $this->add_control( 'option_color',
           [
               'label' => esc_html__( 'Select Option Color', 'crisop' ),
               'type' => Controls_Manager::COLOR,
               'default' => '',
               'selectors' => ['{{WRAPPER}} .ninetheme-select-location .ninetheme-search-location .select2-container .ninetheme-location-select .select2-results .select2-results__option' => 'color: {{VALUE}};']
           ]
        );
        $this->add_control( 'option_hvrcolor',
           [
               'label' => esc_html__( 'Select Option Color ( Hover )', 'crisop' ),
               'type' => Controls_Manager::COLOR,
               'default' => '',
               'selectors' => ['{{WRAPPER}} .ninetheme-select-location .ninetheme-search-location .select2-container .ninetheme-location-select .select2-results .select2-results__option:hover' => 'color: {{VALUE}};']
           ]
        );
        $this->add_control( 'option_value_color',
           [
               'label' => esc_html__( 'Select Option Value Background Color', 'crisop' ),
               'type' => Controls_Manager::COLOR,
               'default' => '',
               'selectors' => ['{{WRAPPER}} .ninetheme-select-location .ninetheme-search-location .select2-container .ninetheme-location-select .select2-results .select2-results__option .min-price' => 'background-color: {{VALUE}};']
           ]
        );
        $this->add_control( 'option_value_color',
           [
               'label' => esc_html__( 'Select Option Value Color', 'crisop' ),
               'type' => Controls_Manager::COLOR,
               'default' => '',
               'selectors' => ['{{WRAPPER}} .ninetheme-select-location .ninetheme-search-location .select2-container .ninetheme-location-select .select2-results .select2-results__option .min-price' => 'color: {{VALUE}};']
           ]
        );
        $this->add_control( 'option_value_brdcolor',
           [
               'label' => esc_html__( 'Select Option Value Border Color ( Hover )', 'crisop' ),
               'type' => Controls_Manager::COLOR,
               'default' => '',
               'selectors' => ['{{WRAPPER}} .ninetheme-select-location .ninetheme-search-location .select2-container .ninetheme-location-select .select2-results .select2-results__option .min-price' => 'border-color: {{VALUE}};']
           ]
        );
        $this->end_controls_section();
    }

    protected function render() {
        if ( ! class_exists('WooCommerce') ) {
            return;
        }
        $settings = $this->get_settings_for_display();
        $args  = '';
        $class  = 'ninetheme-widget-woo-location';
        $class .= 'style-border' == $settings['btn_style'] ? ' style-border' : '';
        $class .= 'style-border' == $settings['btn_style'] && 'style-border' == $settings['btn_radius_style'] ? ' style-radius' : '';
        $class .= 'bottom' == $settings['subtitle_position'] ? ' subtitle-bottom' : '';
        $class .= 'yes' == $settings['hide_mobile'] ? ' hide-mobile' : '';
        $args .= 'class="'.$class.'"';
        $args .= 'yes' != $settings['hide_subtitle'] && $settings['subtitle'] ? ' subtitle="'.$settings['subtitle'].'"' : '';
        $args .= 'yes' == $settings['hide_subtitle'] ? ' hide_subtitle="yes"' : '';
        $args .= $settings['title'] ? ' title="'.$settings['title'].'"' : '';
        $args .= 'yes' != $settings['hide_inner_title'] && $settings['inner_title'] ? ' inner_title="'.$settings['inner_title'].'"' : '';
        $args .= 'yes' == $settings['hide_inner_title'] ? ' hide_inner_title="yes"' : '';
        $args .= 'yes' != $settings['hide_inner_desc'] && $settings['inner_desc'] ? ' inner_desc="'.$settings['inner_desc'].'"' : '';
        $args .= 'yes' == $settings['hide_inner_desc'] ? ' hide_inner_desc="yes"' : '';
        $args .= $settings['placeholder'] ? ' placeholder="'.$settings['placeholder'].'"' : '';
        $args .= $settings['select_text'] ? ' select_text="'.$settings['select_text'].'"' : '';
        $args .= $settings['clear_text'] ? ' clear_text="'.$settings['clear_text'].'"' : '';
        $args .= 'bottom' == $settings['subtitle_position'] ? ' subtitle_position="bottom"' : '';

        if ( shortcode_exists( 'ninetheme_location' ) ) {
            echo do_shortcode('[ninetheme_location '.$args.']');
        }
    }
}
