<?php

namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) exit; // If this file is called directly, abort.

class Ninetheme_Woo_Header_Products extends Widget_Base {
    use Ninetheme_Helper;
    public function get_name() {
        return 'ninetheme-woo-header-products';
    }
    public function get_title() {
        return 'Header Products (N)';
    }
    public function get_icon() {
        return 'eicon-gallery-grid';
    }
    public function get_categories() {
        return [ 'ninetheme-header' ];
    }
    public function get_keywords() {
        return [ 'woocommerce', 'shop', 'store', 'cat', 'wc', 'woo', 'product', 'header', 'dropdown' ];
    }
    // Registering Controls
    protected function register_controls() {
        /*****   START CONTROLS SECTION   ******/
        $this->start_controls_section( 'post_query_section',
            [
                'label' => esc_html__( 'Query', 'crisop' ),
                'tab' => Controls_Manager::TAB_CONTENT
            ]
        );
        $this->add_control( 'template',
            [
                'label' => esc_html__( 'Use Elementor Templates', 'crisop' ),
                'type' => Controls_Manager::SWITCHER,
                'default' => 'no'
            ]
        );
        $this->add_control( 'header_template',
            [
                'label' => esc_html__( 'Select Template', 'crisop' ),
                'type' => Controls_Manager::SELECT2,
                'default' => '',
                'multiple' => false,
                'options' => $this->ninetheme_get_elementor_templates('section'),
                'condition' => [ 'template' => 'yes' ]
            ]
        );
        $this->add_control( 'scenario',
            [
                'label' => esc_html__( 'Select Scenario', 'crisop' ),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'featured' => esc_html__( 'Featured', 'crisop' ),
                    'on-sale' => esc_html__( 'On Sale', 'crisop' ),
                    'best' => esc_html__( 'Best Selling', 'crisop' ),
                    'custom' => esc_html__( 'Specific Categories', 'crisop' ),
                ],
                'default' => 'custom',
                'condition' => [ 'template!' => 'yes' ]
            ]
        );
        $this->add_group_control(
            Group_Control_Image_Size::get_type(),
            [
            'name' => 'thumbnail',
            'condition' => [ 'template!' => 'yes' ]
            ]
        );
        $this->add_control( 'post_per_page',
            [
                'label' => esc_html__( 'Posts Per Page', 'crisop' ),
                'type' => Controls_Manager::NUMBER,
                'min' => 1,
                'max' => 1000,
                'default' => 20,
                'condition' => [ 'template!' => 'yes' ]
            ]
        );
        $this->add_responsive_control( 'column',
            [
                'label' => esc_html__( 'Column Width', 'crisop' ),
                'type' => Controls_Manager::NUMBER,
                'min' => 1,
                'max' => 12,
                'step' => 1,
                'default' => 3,
                'selectors' => [ '{{WRAPPER}} .grid-item' => '-ms-flex: 0 0 calc(100% / {{VALUE}} );flex: 0 0 calc(100% / {{VALUE}} );max-width: calc(100% / {{VALUE}} );' ],
                'condition' => [ 'template!' => 'yes' ]
            ]
        );
        $this->add_control( 'category_filter_heading',
            [
                'label' => esc_html__( 'CATEGORY', 'crisop' ),
                'type' => Controls_Manager::HEADING,
                'separator' => 'before',
                'condition' => [ 'template!' => 'yes' ]
            ]
        );
        $this->add_control( 'category_include',
            [
                'label' => esc_html__( 'Category', 'crisop' ),
                'type' => Controls_Manager::SELECT2,
                'multiple' => true,
                'options' => $this->ninetheme_cpt_taxonomies('product_cat'),
                'description' => 'Select Category(s)',
                'conditions' => [
                    'relation' => 'and',
                    'terms' => [
                        [
                            'name' => 'template',
                            'operator' => '!=',
                            'value' => 'yes'
                        ],
                        [
                            'name' => 'scenario',
                            'operator' => '==',
                            'value' => 'custom'
                        ]
                    ]
                ]
            ]
        );
        $this->add_control( 'post_filter_heading',
            [
                'label' => esc_html__( 'POST', 'crisop' ),
                'type' => Controls_Manager::HEADING,
                'separator' => 'before',
                'condition' => [ 'template!' => 'yes' ]
            ]
        );
        $this->add_control( 'post_exclude',
            [
                'label' => esc_html__( 'Exclude Post', 'crisop' ),
                'type' => Controls_Manager::SELECT2,
                'multiple' => true,
                'options' => $this->get_all_posts_by_type('product'),
                'description' => 'Select Post(s) to Exclude',
                'condition' => [ 'template!' => 'yes' ]
            ]
        );
        $this->add_control( 'post_other_heading',
            [
                'label' => esc_html__( 'OTHER FILTER', 'crisop' ),
                'type' => Controls_Manager::HEADING,
                'separator' => 'before',
                'condition' => [ 'template!' => 'yes' ]
            ]
        );
        $this->add_control( 'order',
            [
                'label' => esc_html__( 'Select Order', 'crisop' ),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'ASC' => esc_html__( 'Ascending', 'crisop' ),
                    'DESC' => esc_html__( 'Descending', 'crisop' )
                ],
                'default' => 'DESC',
                'condition' => [ 'template!' => 'yes' ]
            ]
        );
        $this->add_control( 'orderby',
            [
                'label' => esc_html__( 'Order By', 'crisop' ),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'id' => esc_html__( 'Post ID', 'crisop' ),
                    'menu_order' => esc_html__( 'Menu Order', 'crisop' ),
                    'rand' => esc_html__( 'Random', 'crisop' ),
                    'date' => esc_html__( 'Date', 'crisop' ),
                    'title' => esc_html__( 'Title', 'crisop' ),
                ],
                'default' => 'id',
                'condition' => [ 'template!' => 'yes' ]
            ]
        );
        $this->add_control( 'bannerimg_heading',
            [
                'label' => esc_html__( 'BANNER IMAGE', 'crisop' ),
                'type' => Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );
        $this->add_control( 'subtitle',
            [
                'label' => esc_html__( 'Mini title', 'crisop' ),
                'type' => Controls_Manager::TEXT,
                'default' => 'Only this weekend',
                'label_block' => true
            ]
        );
        $this->add_control( 'title',
            [
                'label' => esc_html__( 'Title', 'crisop' ),
                'type' => Controls_Manager::TEXT,
                'default' => 'Super Discount',
                'label_block' => true
            ]
        );
        $this->add_control( 'inner_title',
            [
                'label' => esc_html__( 'Content Title', 'crisop' ),
                'type' => Controls_Manager::TEXT,
                'default' => 'Items on sale this week',
                'label_block' => true,
                'condition' => [ 'template!' => 'yes' ]
            ]
        );
        $this->add_control( 'inner_text',
            [
                'label' => esc_html__( 'Content Text', 'crisop' ),
                'type' => Controls_Manager::TEXTAREA,
                'default' => 'Top picks this week. Up to 50% off the best selling products.',
                'label_block' => true,
                'condition' => [ 'template!' => 'yes' ]
            ]
        );
        $this->add_control( 'icon',
            [
                'label' => esc_html__( 'Icon', 'crisop' ),
                'type' => Controls_Manager::ICONS,
                'condition' => [ 'template!' => 'yes' ]
            ]
        );
        $this->end_controls_section();
        /*****   END CONTROLS SECTION   ******/
        /*****   START CONTROLS SECTION   ******/
        $this->start_controls_section('style_section',
            [
                'label' => esc_html__( 'STYLE', 'crisop' ),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
        $this->add_control( 'minititle_heading',
            [
                'label' => esc_html__( 'MINI TITLE', 'crisop' ),
                'type' => Controls_Manager::HEADING
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'minititle_typo',
                'label' => esc_html__( 'Typography', 'crisop' ),
                'selector' => '{{WRAPPER}} .ninetheme-discount-products-wrapper .ninetheme-header-discount-subtitle',
            ]
        );
        $this->add_control( 'minititle_color',
            [
                'label' => esc_html__( 'Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => ['{{WRAPPER}} .ninetheme-discount-products-wrapper .ninetheme-header-discount-subtitle' => 'color: {{VALUE}};' ]
            ]
        );
        $this->add_control( 'minititle_hvrcolor',
            [
                'label' => esc_html__( 'Hover Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => ['{{WRAPPER}} .ninetheme-discount-products-wrapper:hover .ninetheme-header-discount-subtitle' => 'color: {{VALUE}};' ]
            ]
        );
        $this->add_control( 'title_heading',
            [
                'label' => esc_html__( 'TITLE', 'crisop' ),
                'type' => Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'title_typo',
                'label' => esc_html__( 'Typography', 'crisop' ),
                'selector' => '{{WRAPPER}} .ninetheme-discount-products-wrapper .ninetheme-header-discount-title',
            ]
        );
        $this->add_control( 'title_color',
            [
                'label' => esc_html__( 'Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => ['{{WRAPPER}} .ninetheme-discount-products-wrapper .ninetheme-header-discount-title' => 'color: {{VALUE}};' ]
            ]
        );
        $this->add_control( 'title_hvrcolor',
            [
                'label' => esc_html__( 'Hover Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => ['{{WRAPPER}} .ninetheme-discount-products-wrapper:hover .ninetheme-header-discount-title' => 'color: {{VALUE}};' ]
            ]
        );
        $this->add_control( 'inner_title_heading',
            [
                'label' => esc_html__( 'CONTENT TITLE', 'crisop' ),
                'type' => Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'inner_title_typo',
                'label' => esc_html__( 'Typography', 'crisop' ),
                'selector' => '{{WRAPPER}} .ninetheme-discount-products-wrapper .ninetheme-header-products-discount-title',
            ]
        );
        $this->add_control( 'inner_title_color',
            [
                'label' => esc_html__( 'Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => ['{{WRAPPER}} .ninetheme-discount-products-wrapper .ninetheme-header-products-discount-title' => 'color: {{VALUE}};' ]
            ]
        );
        $this->add_control( 'inner_text_heading',
            [
                'label' => esc_html__( 'CONTENT TEXT', 'crisop' ),
                'type' => Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'inner_text_typo',
                'label' => esc_html__( 'Typography', 'crisop' ),
                'selector' => '{{WRAPPER}} .ninetheme-discount-products-wrapper .ninetheme-header-products-discount-text',
            ]
        );
        $this->add_control( 'inner_text_color',
            [
                'label' => esc_html__( 'Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => ['{{WRAPPER}} .ninetheme-discount-products-wrapper .ninetheme-header-products-discount-text' => 'color: {{VALUE}};' ]
            ]
        );
        $this->add_control( 'box_heading',
            [
                'label' => esc_html__( 'CONTENT BOX', 'crisop' ),
                'type' => Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );
        $this->add_control( 'box_bgcolor',
            [
                'label' => esc_html__( 'Background Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => ['{{WRAPPER}} .ninetheme-discount-products-wrapper .ninetheme-discount-items' => 'background-color: {{VALUE}};' ]
            ]
        );
        $this->add_responsive_control( 'box_padding',
            [
                'label' => esc_html__( 'Padding', 'crisop' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px' ],
                'selectors' => ['{{WRAPPER}} .ninetheme-discount-products-wrapper .ninetheme-discount-items' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};'],
                'separator' => 'before'
            ]
        );
        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name' => 'box_border',
                'label' => esc_html__( 'Border', 'crisop' ),
                'selector' => '{{WRAPPER}} .ninetheme-discount-products-wrapper .ninetheme-discount-items',
            ]
        );
        $this->add_responsive_control( 'box_border_radius',
            [
                'label' => esc_html__( 'Border Radius', 'crisop' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px' ],
                'selectors' => ['{{WRAPPER}} .ninetheme-discount-products-wrapper .ninetheme-discount-items' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};'],
            ]
        );
        $this->add_group_control(
            Group_Control_Box_Shadow::get_type(),
            [
                'name' => 'box_shadow',
                'label' => esc_html__( 'Border', 'crisop' ),
                'selector' => '{{WRAPPER}} .ninetheme-discount-products-wrapper .ninetheme-discount-items',
            ]
        );
        $this->end_controls_section();
        /*****   END CONTROLS SECTION   ******/
    }

    public function thumb_size() {
        $settings = $this->get_settings_for_display();
        $size = $settings['thumbnail_size'] ? $settings['thumbnail_size'] : 'full';
        if ( 'custom' == $size ) {
            $sizew = $settings['thumbnail_custom_dimension']['width'];
            $sizeh = $settings['thumbnail_custom_dimension']['height'];
            $size = [ $sizew, $sizeh ];
        }
        return $size;
    }
    protected function render() {
        if ( ! class_exists('WooCommerce') ) {
            return;
        }
        //global $wp_query;
        $settings = $this->get_settings_for_display();
        $elementid = $this->get_id();

        $args = array(
            'post_type' => 'product',
            'posts_per_page' => $settings['post_per_page'],
            'post__not_in' => $settings['post_exclude'],
            'order' => $settings['order']
        );

        if ( 'featured' == $settings['scenario'] ) {
           $args['tax_query'] = array(
                array(
                    'taxonomy' => 'product_visibility',
                    'field' => 'name',
                    'terms' => 'featured',
                )
            );

        } elseif( 'on-sale' == $settings['scenario'] ) {

            $args['meta_query'] = array(
                'relation' => 'OR',
                array( // Simple products type
                    'key' => '_sale_price',
                    'value' => 0,
                    'compare' => '>',
                    'type' => 'numeric'
                ),
                array( // Variable products type
                    'key' => '_min_variation_sale_price',
                    'value' => 0,
                    'compare' => '>',
                    'type' => 'numeric'
                )
            );

        } elseif( 'best' == $settings['scenario'] ) {

            $args['orderby'] = 'meta_value_num';
            $args['meta_key'] = 'total_sales';

        } else {

            $args['orderby'] = $settings['orderby'];

        }

        if ( $settings['category_include'] ) {
            $args['tax_query'] = array(
                array(
                    'taxonomy' => 'product_cat',
                    'field' => 'id',
                    'terms' => $settings['category_include'],
                    'operator' => 'IN'
                )
            );
        }

        $product_cat_args = array (
            'taxonomy' => 'product_cat',
            'order' => $settings['order'],
            'orderby' => $settings['orderby'],
            'hide_empty' => true,
            'parent' => 0,
            'include' => $settings['category_include'],
        );

        add_filter( 'single_product_archive_thumbnail_size', [ $this, 'thumb_size' ] );

        $the_query = new \WP_Query( $args );
        if( $the_query->have_posts() ) {
            echo '<div class="ninetheme-discount-products-wrapper">';
                echo '<div class="ninetheme-header-discount-trigger">';
                    if ( !empty( $settings['icon']['value'] ) ) { 
                        Icons_Manager::render_icon( $settings['icon'], [ 'aria-hidden' => 'true' ] );
                    } else {
                        $img = get_template_directory_uri().'/images/discount.png';
                        echo '<img src="'.esc_url( $img ).'" alt="featured">';
                    }
                    echo '<div class="ninetheme-header-discount-trigger-text">';
                        echo '<div class="ninetheme-header-discount-subtitle">'.$settings['subtitle'].'</div>';
                        echo '<div class="ninetheme-header-discount-title">'.$settings['subtitle'].'</div>';
                    echo '</div>';
                echo '</div>';
                
                echo '<div class="ninetheme-discount-items ninetheme-scrollbar">';
                    
                    if ( 'yes' == $settings['template'] && !empty( $settings['header_template'] ) ) {
                        
                            $style = \Elementor\Plugin::$instance->editor->is_edit_mode() ? true : false;
                            $template_id = $settings['header_template'];
                            $header_content = new Frontend;
                            echo $header_content->get_builder_content_for_display($template_id, $style );
                        
                    } else {
                        
                        echo '<div class="ninetheme-discount-products-header">';
                            echo '<h5 class="ninetheme-header-products-discount-title">'.$settings['inner_title'].'</h5>';
                            echo '<p class="ninetheme-header-discount-text">'.$settings['inner_text'].'</p>';
                        echo '</div>';
                        echo '<div class="products row row-cols-lg-6">';
                        $the_query = new WP_Query( $args );
                        if ( $the_query->have_posts() ) {
    
                            while ( $the_query->have_posts() ) {
                                $the_query->the_post();
                                wc_get_template_part( 'content', 'product' );
                            }
                        }
                    }
                    echo '</div>';
                echo '</div>';
            echo '</div>';
        }
        wp_reset_postdata();
        remove_filter( 'single_product_archive_thumbnail_size', [ $this, 'thumb_size' ] );
    }
}
