<?php
namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) exit; // If this file is called directly, abort.

class Ninetheme_WC_Page_Title extends Widget_Base {

	public function get_name() {
		return 'ninetheme-wc-page-title';
	}

	public function get_title() {
		return __( 'Woo Archive Title', 'crisop' );
	}

	public function get_icon() {
		return 'eicon-product-description';
	}

	public function get_keywords() {
		return [ 'woocommerce', 'woo','title','heading','wc', 'shop', 'store', 'text', 'description', 'category', 'product', 'archive' ];
	}

    public function get_categories() {
		return [ 'ninetheme-woo' ];
	}

	protected function register_controls() {

		$this->start_controls_section(
			'section_product_title_style',
			[
				'label' => __( 'Style', 'crisop' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
        $this->add_control( 'tag',
            [
                'label' => esc_html__( 'Title Tag for SEO', 'crisop' ),
                'type' => Controls_Manager::SELECT,
                'default' => 'h2',
                'options' => [
                    'h1' => esc_html__( 'H1', 'crisop' ),
                    'h2' => esc_html__( 'H2', 'crisop' ),
                    'h3' => esc_html__( 'H3', 'crisop' ),
                    'h4' => esc_html__( 'H4', 'crisop' ),
                    'h5' => esc_html__( 'H5', 'crisop' ),
                    'h6' => esc_html__( 'H6', 'crisop' ),
                    'div' => esc_html__( 'div', 'crisop' ),
                    'p' => esc_html__( 'p', 'crisop' )
                ]
            ]
        );
		$this->add_responsive_control(
			'text_align',
			[
				'label' => __( 'Alignment', 'crisop' ),
				'type' => Controls_Manager::CHOOSE,
				'options' => [
					'left' => [
						'title' => __( 'Left', 'crisop' ),
						'icon' => 'eicon-text-align-left',
					],
					'center' => [
						'title' => __( 'Center', 'crisop' ),
						'icon' => 'eicon-text-align-center'
					],
					'right' => [
						'title' => __( 'Right', 'crisop' ),
						'icon' => 'eicon-text-align-right'
					],
					'justify' => [
						'title' => __( 'Justified', 'crisop' ),
						'icon' => 'eicon-text-align-justify'
					]
				],
				'selectors' => ['{{WRAPPER}} .ninetheme-page-title' => 'text-align: {{VALUE}}']
			]
		);

		$this->add_control(
			'text_color',
			[
				'label' => __( 'Text Color', 'crisop' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [ '{{WRAPPER}} .ninetheme-page-title' => 'color: {{VALUE}}' ]
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'text_typography',
				'label' => __( 'Typography', 'crisop' ),
				'selector' => '{{WRAPPER}} .ninetheme-page-title'
			]
		);

		$this->end_controls_section();
	}

	protected function render() {
	    $settings = $this->get_settings_for_display();
        global $post;
        $post_type = get_post_type( $post->ID );
        if ( $post_type == 'elementor_library' ) {
            echo '<'.$settings['tag'].' class="ninetheme-page-title">'.get_the_title().'</'.$settings['tag'].'>';
        } else {
            echo '<'.$settings['tag'].' class="ninetheme-page-title">'.get_the_archive_title().'</'.$settings['tag'].'>';
        }
	}
}
