<?php

namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) exit; // If this file is called directly, abort.

class Ninetheme_Woo_Shop_Filter extends Widget_Base {
    //use Ninetheme_Helper;
    public function get_name() {
        return 'ninetheme-woo-shop-filter';
    }
    public function get_title() {
        return 'WC Shop Archive Filters (N)';
    }
    public function get_icon() {
        return 'eicon-product-breadcrumbs';
    }
    public function get_categories() {
        return [ 'ninetheme-header' ];
    }
    public function get_keywords() {
        return [ 'woocommerce', 'shop', 'store', 'filter', 'internal','links' ];
    }
    // Registering Controls
    protected function register_controls() {

        /* HEADER MINICART SETTINGS */
        $this->start_controls_section( 'general_section',
            [
                'label' => esc_html__( 'Header Actions', 'crisop' ),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );
        $this->add_control( 'trigger',
            [
                'label' => esc_html__( 'Action', 'crisop' ),
                'type' => Controls_Manager::SELECT,
                'default' => 'ordering',
                'options' => [
                    'result-count' => esc_html__( 'Result Count', 'crisop' ),
                    'per-page' => esc_html__( 'Per Page Selection', 'crisop' ),
                    'column-select' => esc_html__( 'Column Selection', 'crisop' ),
                    'ordering' => esc_html__( 'Catalog Ordering', 'crisop' ),
                ]
            ]
        );
        $this->add_responsive_control( 'icon_size',
            [
                'label' => esc_html__( 'SVG Icon Size', 'crisop' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'range' => [
                    'px' => [
                        'max' => 100,
                        'min' => 0
                    ],
                ],
                'selectors' => [ '{{WRAPPER}} .ninetheme-shop-filter-top-area .ninetheme-svg-icon' => 'max-width:{{SIZE}}px;max-height:{{SIZE}}px;' ],
                'condition' => [ 'trigger' => 'column-select' ]
            ]
        );
        $this->add_control( 'icon_color',
           [
               'label' => esc_html__( 'Color', 'crisop' ),
               'type' => Controls_Manager::COLOR,
               'default' => '',
               'selectors' => [ '{{WRAPPER}} .ninetheme-shop-filter-top-area .ninetheme-svg-icon' => 'fill: {{VALUE}};' ],
               'condition' => [ 'trigger' => 'column-select' ]
           ]
        );
        $this->add_control( 'icon_hvrcolor',
           [
               'label' => esc_html__( 'Color ( Active )', 'crisop' ),
               'type' => Controls_Manager::COLOR,
               'default' => '',
               'selectors' => [ '{{WRAPPER}} .ninetheme-shop-filter-top-area li.active svg' => 'fill: {{VALUE}};' ],
               'condition' => [ 'trigger' => 'column-select' ]
           ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'text_typo',
                'label' => esc_html__( 'Typography', 'crisop' ),
                'selector' => '{{WRAPPER}} .ninetheme-woo-result-count .woocommerce-result-count',
                'condition' => [ 'trigger' => 'result-count' ]
            ]
        );
        $this->add_control( 'text_color',
           [
               'label' => esc_html__( 'Text Color', 'crisop' ),
               'type' => Controls_Manager::COLOR,
               'default' => '',
               'selectors' => ['{{WRAPPER}} .ninetheme-woo-result-count .woocommerce-result-count' => 'color: {{VALUE}};'],
               'condition' => [ 'trigger' => 'result-count' ]
           ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'perpage_typo',
                'label' => esc_html__( 'Typography', 'crisop' ),
                'selector' => '{{WRAPPER}} .ninetheme-filter-per-page-area ul li a',
                'condition' => [ 'trigger' => 'per-page' ]
            ]
        );
        $this->add_control( 'perpage_color',
           [
               'label' => esc_html__( 'Color', 'crisop' ),
               'type' => Controls_Manager::COLOR,
               'default' => '',
               'selectors' => ['{{WRAPPER}} .ninetheme-filter-per-page-area ul li a' => 'color: {{VALUE}};'],
               'condition' => [ 'trigger' => 'per-page' ]
           ]
        );
        $this->add_control( 'perpage_hvrcolor',
           [
               'label' => esc_html__( 'Color ( Active )', 'crisop' ),
               'type' => Controls_Manager::COLOR,
               'default' => '',
               'selectors' => ['{{WRAPPER}} .ninetheme-filter-per-page-area ul li.active a' => 'color: {{VALUE}};'],
               'condition' => [ 'trigger' => 'per-page' ]
           ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'ordering_typo',
                'label' => esc_html__( 'Typography', 'crisop' ),
                'selector' => '{{WRAPPER}} .nice-select span.current, {{WRAPPER}} .nice-select .option',
                'condition' => [ 'trigger' => 'ordering' ]
            ]
        );
        $this->add_control( 'ordering_color',
           [
               'label' => esc_html__( 'Color', 'crisop' ),
               'type' => Controls_Manager::COLOR,
               'default' => '',
               'selectors' => ['{{WRAPPER}} .ninetheme-shop-filter-top-area .nice-select .option' => 'color: {{VALUE}};'],
               'condition' => [ 'trigger' => 'ordering' ]
           ]
        );
        $this->add_control( 'ordering_hvrcolor',
           [
               'label' => esc_html__( 'Background Color ( Hover )', 'crisop' ),
               'type' => Controls_Manager::COLOR,
               'default' => '',
               'selectors' => ['{{WRAPPER}} .nice-select .option:hover' => 'background-color: {{VALUE}};'],
               'condition' => [ 'trigger' => 'ordering' ]
           ]
        );
        $this->end_controls_section();
    }

    protected function render() {
        if ( ! class_exists('WooCommerce') ) {
            return;
        }
        $settings = $this->get_settings_for_display();

		 echo '<div class="ninetheme-elementor-widget ninetheme-shop-filter-top-area">';
			if ( 'result-count' == $settings['trigger'] ) {
                echo '<div class="ninetheme-woo-result-count">';
                    if ( \Elementor\Plugin::$instance->editor->is_edit_mode() ) {
                            echo '<p class="woocommerce-result-count">Showing <span>X</span>–<span>Y</span> of <span>Z</span> results</p>';
                    } else {
                        woocommerce_result_count();
                    }
                echo '</div>';
			}
			if ( 'per-page' == $settings['trigger'] ) {
                echo '<div class="ninetheme-shop-filter-area ninetheme-filter-per-page-area">';
                    ninetheme_wc_per_page_select();
                echo '</div>';
			}
			if ( 'column-select' == $settings['trigger'] ) {
                echo '<div class="ninetheme-shop-filter-area ninetheme-filter-column-select-area">';
                    ninetheme_wc_column_select();
                echo '</div>';
			}
			if ( 'ordering' == $settings['trigger'] && woocommerce_product_loop() ) {
                echo '<div class="ninetheme-shop-filter-area ninetheme-filter-ordering-area">';
                    if ( \Elementor\Plugin::$instance->editor->is_edit_mode() ) {
                        echo '<form class="woocommerce-ordering-editor">';
                        echo '<select name="orderby" class="orderby" aria-label="Shop order">';
                        echo '<option value="popularity">Sort by popularity</option>';
                        echo '<option value="rating">Sort by average rating</option>';
                        echo '<option value="date" selected="selected">Sort by latest</option>';
                        echo '<option value="price">Sort by price: low to high</option>';
                        echo '<option value="price-desc">Sort by price: high to low</option>';
                        echo '</select>';
                        echo '</form>';
                        ?>
                        <script>
                        jQuery( document ).ready( function($) {
                            $('.woocommerce-ordering-editor').niceSelect();
                        });
                        </script>
                        <?php
                    } else {
                        woocommerce_catalog_ordering();
                    }
                echo '</div>';
			}
		echo '</div>';

    }
}
