<?php

namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) exit; // If this file is called directly, abort.

class Ninetheme_Woo_Special_Offer extends Widget_Base {
    use Ninetheme_Helper;
    public function get_name() {
        return 'ninetheme-woo-special-offer';
    }
    public function get_title() {
        return 'WC Special Offer (N)';
    }
    public function get_icon() {
        return 'eicon-slider-push';
    }
    public function get_categories() {
        return [ 'ninetheme-woo' ];
    }
    public function get_keywords() {
        return [ 'woocommerce', 'shop', 'store', 'cat', 'wc', 'woo', 'product', 'slider' ];
    }
    public function get_style_depends() {
        return [ 'ninetheme-swiper' ];
    }
    public function get_script_depends() {
        return [ 'ninetheme-swiper', 'jquery-countdown' ];
    }
    // Registering Controls
    protected function register_controls() {

        /*****   START CONTROLS SECTION   ******/
        $this->start_controls_section( 'post_query_section',
            [
                'label' => esc_html__( 'Query', 'crisop' ),
                'tab' => Controls_Manager::TAB_CONTENT
            ]
        );
        $this->add_control( 'box_style',
            [
                'label' => esc_html__( 'Box Style', 'crisop' ),
                'type' => Controls_Manager::SELECT,
                'default' => 'style-1',
                'options' => [
                    'style-1' => esc_html__( 'Style 1', 'crisop' ),
                    'style-2' => esc_html__( 'Style 2', 'crisop' )
                ]
            ]
        );
        $this->add_control( 'scenario',
            [
                'label' => esc_html__( 'Select Scenario', 'crisop' ),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    '' => esc_html__( 'Newest', 'crisop' ),
                    'featured' => esc_html__( 'Featured', 'crisop' ),
                    'on-sale' => esc_html__( 'On Sale', 'crisop' ),
                    'best' => esc_html__( 'Best Selling', 'crisop' ),
                    'custom' => esc_html__( 'Specific Categories', 'crisop' ),
                ],
                'default' => ''
            ]
        );
        $this->add_control( 'post_per_page',
            [
                'label' => esc_html__( 'Posts Per Page', 'crisop' ),
                'type' => Controls_Manager::NUMBER,
                'min' => 1,
                'max' => 1000,
                'default' => 20
            ]
        );
        $this->add_control( 'category_filter_heading',
            [
                'label' => esc_html__( 'Category Filter', 'crisop' ),
                'type' => Controls_Manager::HEADING
            ]
        );
        $this->add_control( 'category_include',
            [
                'label' => esc_html__( 'Category', 'crisop' ),
                'type' => Controls_Manager::SELECT2,
                'multiple' => true,
                'options' => $this->ninetheme_cpt_taxonomies('product_cat'),
                'description' => 'Select Category(s)',
                'condition' => [ 'scenario' => 'custom' ]
            ]
        );
        $this->add_control( 'category_exclude',
            [
                'label' => esc_html__( 'Exclude Category', 'crisop' ),
                'type' => Controls_Manager::SELECT2,
                'multiple' => true,
                'options' => $this->ninetheme_cpt_taxonomies('product_cat'),
                'description' => 'Select Category(s) to Exclude'
            ]
        );
        $this->add_control( 'post_filter_heading',
            [
                'label' => esc_html__( 'Post Filter', 'crisop' ),
                'type' => Controls_Manager::HEADING,
                'separator' => 'before'
            ]
        );
        $this->add_control( 'post_include',
            [
                'label' => esc_html__( 'Specific Post(s)', 'crisop' ),
                'type' => Controls_Manager::SELECT2,
                'multiple' => true,
                'options' => $this->get_all_posts_by_type('product'),
                'description' => 'Select Specific Post(s)',
                'condition' => [ 'scenario' => 'custom' ]
            ]
        );
        $this->add_control( 'post_exclude',
            [
                'label' => esc_html__( 'Exclude Post', 'crisop' ),
                'type' => Controls_Manager::SELECT2,
                'multiple' => true,
                'options' => $this->get_all_posts_by_type('product'),
                'description' => 'Select Post(s) to Exclude',
            ]
        );
        $this->add_control( 'post_other_heading',
            [
                'label' => esc_html__( 'Other Filter', 'crisop' ),
                'type' => Controls_Manager::HEADING,
                'separator' => 'before'
            ]
        );
        $this->add_control( 'order',
            [
                'label' => esc_html__( 'Select Order', 'crisop' ),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'ASC' => esc_html__( 'Ascending', 'crisop' ),
                    'DESC' => esc_html__( 'Descending', 'crisop' )
                ],
                'default' => 'DESC'
            ]
        );
        $this->add_control( 'orderby',
            [
                'label' => esc_html__( 'Order By', 'crisop' ),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'id' => esc_html__( 'Post ID', 'crisop' ),
                    'menu_order' => esc_html__( 'Menu Order', 'crisop' ),
                    'rand' => esc_html__( 'Random', 'crisop' ),
                    'date' => esc_html__( 'Date', 'crisop' ),
                    'title' => esc_html__( 'Title', 'crisop' ),
                ],
                'default' => 'id',
            ]
        );
        $this->add_control( 'product_box_min_height',
            [
                'label' => esc_html__( 'Product Box Min Height', 'crisop' ),
                'type' => Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'max' => 500
                    ]
                ],
                'selectors' => [
                    '{{WRAPPER}} .ninetheme-loop-product' => 'min-height: {{SIZE}}px;',
                ],
                'default' => [
                    'unit' => 'px',
                    'size' => ''
                ]
            ]
        );
        $this->add_group_control(
            Group_Control_Image_Size::get_type(),
            [
                'name' => 'thumbnail',
                'default' => 'ninetheme-mini',
            ]
        );
        $this->add_control( 'slider_title',
            [
                'label' => esc_html__( 'Slider Title', 'crisop' ),
                'type' => Controls_Manager::TEXTAREA,
                'separator' => 'before'
            ]
        );
        $this->add_control( 'title_tag',
            [
                'label' => esc_html__( 'Title Tag', 'crisop' ),
                'type' => Controls_Manager::SELECT,
                'default' => 'h3',
                'options' => [
                    'h1' => esc_html__( 'H1', 'crisop' ),
                    'h2' => esc_html__( 'H2', 'crisop' ),
                    'h3' => esc_html__( 'H3', 'crisop' ),
                    'h4' => esc_html__( 'H4', 'crisop' ),
                    'h5' => esc_html__( 'H5', 'crisop' ),
                    'h6' => esc_html__( 'H6', 'crisop' ),
                    'div' => esc_html__( 'div', 'crisop' ),
                    'p' => esc_html__( 'p', 'crisop' )
                ],
                'condition' => [ 'slider_title!' => '' ]
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'slider_title_typo',
                'label' => esc_html__( 'Typography', 'crisop' ),
                'selector' => '{{WRAPPER}} .ninetheme-slider-nav-title',
                'condition' => [ 'slider_title!' => '' ]
            ]
        );
        $this->add_control( 'slider_title_color',
            [
                'label' => esc_html__( 'Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [ '{{WRAPPER}} .ninetheme-slider-nav-title' => 'color:{{VALUE}};' ],
                'condition' => [ 'slider_title!' => '' ]
            ]
        );
        $this->add_responsive_control( 'title_spacing',
            [
                'label' => esc_html__( 'Title Spacing ( px )', 'crisop' ),
                'type' => Controls_Manager::SLIDER,
                'range' => [
                    'px' => ['max' => 300]
                ],
				'default' => [
					'unit' => 'px',
					'size' => 30
				],
                'selectors' => [
                    '{{WRAPPER}} .ninetheme-swiper-theme-style .ninetheme-slider-title-wrapper.nav-top' => 'margin-bottom: {{SIZE}}px;'
                ],
                'condition' => [ 'slider_title!' => '' ]
            ]
        );
        $this->end_controls_section();
        /*****   END CONTROLS SECTION   ******/
        /*****   START CONTROLS SECTION   ******/
        $this->start_controls_section('product_style_section',
            [
                'label'=> esc_html__( 'PRODUCT STYLE', 'crisop' ),
                'tab' => Controls_Manager::TAB_CONTENT
            ]
        );
        $this->add_responsive_control( 'post_padding',
            [
                'label' => esc_html__( 'Padding', 'crisop' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px' ],
                'selectors' => ['{{WRAPPER}} .woocommerce .ninetheme-type-product .ninetheme-loop-product' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};']
            ]
        );
        $this->add_control( 'post_bgcolor',
            [
                'label' => esc_html__( 'Background Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [ '{{WRAPPER}} .woocommerce .ninetheme-type-product .ninetheme-loop-product' => 'background-color: {{VALUE}};' ]
            ]
        );
        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name' => 'post_border',
                'label' => esc_html__( 'Border', 'crisop' ),
                'selector' => '{{WRAPPER}} .woocommerce .ninetheme-type-product .ninetheme-loop-product'
            ]
        );
        $this->add_group_control(
            Group_Control_Box_Shadow::get_type(),
            [
                'name' => 'post_item_box_shadow',
                'label' => esc_html__( 'Box Shadow', 'crisop' ),
                'selector' => '{{WRAPPER}} .woocommerce .ninetheme-type-product .ninetheme-loop-product, {{WRAPPER}} .woocommerce .ninetheme-type-product .ninetheme-loop-product:before'
            ]
        );
        $this->add_control( 'stock_heading',
            [
                'label' => esc_html__( 'STOCK STATUS', 'crisop' ),
                'type' => Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );
        $this->add_control( 'instock_color',
            [
                'label' => esc_html__( 'In Stock Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => ['{{WRAPPER}} .ninetheme-loop-product .ninetheme-stock-status.ninetheme-instock' => 'color: {{VALUE}};']
            ]
        );
        $this->add_control( 'outofstock_color',
            [
                'label' => esc_html__( 'Out of Stock Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => ['{{WRAPPER}} .ninetheme-loop-product .ninetheme-stock-status.ninetheme-outofstock' => 'color: {{VALUE}};']
            ]
        );
        $this->add_control( 'labels_heading',
            [
                'label' => esc_html__( 'LABELS', 'crisop' ),
                'type' => Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );
        $this->add_control( 'deflabel_color',
            [
                'label' => esc_html__( 'Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => ['{{WRAPPER}} .ninetheme-label,{{WRAPPER}} .ninetheme-label.ninetheme-bg-default' => 'color: {{VALUE}};']
            ]
        );
        $this->add_control( 'deflabel_bgcolor',
            [
                'label' => esc_html__( 'Background Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => ['{{WRAPPER}} .ninetheme-label,{{WRAPPER}} .ninetheme-label.ninetheme-bg-default' => 'background-color: {{VALUE}};']
            ]
        );
        $this->add_control( 'discount_color',
            [
                'label' => esc_html__( 'Discount Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => ['{{WRAPPER}} .ninetheme-loop-product .ninetheme-label.ninetheme-discount' => 'color: {{VALUE}};']
            ]
        );
        $this->add_control( 'discount_bgcolor',
            [
                'label' => esc_html__( 'Discount Background Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => ['{{WRAPPER}} .ninetheme-loop-product .ninetheme-label.ninetheme-discount' => 'background-color: {{VALUE}};']
            ]
        );
        $this->add_control( 'addtocart_heading',
            [
                'label' => esc_html__( 'ADD TO CART', 'crisop' ),
                'type' => Controls_Manager::HEADING,
                'separator' => 'before'
            ]
        );
        $this->add_control( 'addtocarticon_color',
            [
                'label' => esc_html__( 'Add To Cart Color ( Type Icon )', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => ['{{WRAPPER}} .ninetheme-loop-product .ninetheme-product-button.btn-type-icon .ninetheme-svg-icon' => 'fill: {{VALUE}};']
            ]
        );
        $this->add_control( 'addtocarticon_bgcolor',
            [
                'label' => esc_html__( 'Add To Cart Background Color ( Type Icon )', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => ['{{WRAPPER}} .ninetheme-loop-product .ninetheme-product-button.btn-type-icon' => 'background-color: {{VALUE}};']
            ]
        );
        $this->add_control( 'title_heading',
            [
                'label' => esc_html__( 'TITLE', 'crisop' ),
                'type' => Controls_Manager::HEADING,
                'separator' => 'before'
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'title_typo',
                'label' => esc_html__( 'Typography', 'crisop' ),
                'selector' => '{{WRAPPER}} .woocommerce .ninetheme-type-product .ninetheme-loop-product-name'
            ]
        );
        $this->add_control( 'title_color',
            [
                'label' => esc_html__( 'Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => ['{{WRAPPER}} .woocommerce .ninetheme-type-product .ninetheme-loop-product-name' => 'color: {{VALUE}};']
            ]
        );
        $this->add_control( 'price_heading',
            [
                'label' => esc_html__( 'PRICE', 'crisop' ),
                'type' => Controls_Manager::HEADING,
                'separator' => 'before'
            ]
        );
        $this->add_control( 'price_color',
            [
                'label' => esc_html__( 'Price Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => ['{{WRAPPER}} .woocommerce .ninetheme-type-product span.del > span' => 'color: {{VALUE}};']
            ]
        );
        $this->add_control( 'price_color2',
            [
                'label' => esc_html__( 'Price Color 2', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => ['{{WRAPPER}}  .woocommerce .ninetheme-type-product .ninetheme-price' => 'color: {{VALUE}};']
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'price_typo',
                'label' => esc_html__( 'Typography', 'crisop' ),
                'selector' => '{{WRAPPER}} .woocommerce .ninetheme-type-product .ninetheme-price'
            ]
        );
        $this->end_controls_section();
        /*****   END CONTROLS SECTION   ******/
       /*****   START CONTROLS SECTION   ******/
        $this->start_controls_section('slider_options_section',
            [
                'label'=> esc_html__( 'SLIDER OPTIONS', 'crisop' ),
                'tab' => Controls_Manager::TAB_CONTENT
            ]
        );
        $this->add_control( 'loop',
            [
                'label' => esc_html__( 'Infinite', 'crisop' ),
                'type' => Controls_Manager::SWITCHER,
                'default' => 'no'
            ]
        );
        $this->add_control( 'loop_count',
            [
                'label' => esc_html__( 'Looped Slides Items', 'crisop' ),
                'type' => Controls_Manager::NUMBER,
                'min' => 0,
                'max' => 100,
                'step' => 1,
                'default' => 1,
                'condition' => [ 'loop' => 'yes' ]
            ]
        );
        $this->add_control( 'autoplay',
            [
                'label' => esc_html__( 'Autoplay', 'crisop' ),
                'type' => Controls_Manager::SWITCHER,
                'default' => 'yes'
            ]
        );
        $this->add_control( 'centermode',
            [
                'label' => esc_html__( 'Center Mode', 'crisop' ),
                'type' => Controls_Manager::SWITCHER,
                'default' => 'no'
            ]
        );
        $this->add_control( 'nav',
            [
                'label' => esc_html__( 'Navigation', 'crisop' ),
                'type' => Controls_Manager::SWITCHER,
                'default' => 'yes'
            ]
        );
        $this->add_control( 'dots',
            [
                'label' => esc_html__( 'Dots', 'crisop' ),
                'type' => Controls_Manager::SWITCHER,
                'default' => 'yes'
            ]
        );
        $this->add_control( 'space',
            [
                'label' => esc_html__( 'Space Between Items', 'crisop' ),
                'type' => Controls_Manager::NUMBER,
                'min' => 0,
                'max' => 100,
                'step' => 1,
                'default' => 30
            ]
        );
        $this->add_control( 'speed',
            [
                'label' => esc_html__( 'Speed', 'crisop' ),
                'type' => Controls_Manager::NUMBER,
                'min' => 100,
                'max' => 10000,
                'step' => 100,
                'default' => 1000
            ]
        );
        $this->add_control( 'mditems',
            [
                'label' => esc_html__( 'Items', 'crisop' ),
                'type' => Controls_Manager::NUMBER,
                'min' => 1,
                'max' => 20,
                'step' => 1,
                'default' => 5
            ]
        );
        $this->add_control( 'mditems_group',
            [
                'label' => esc_html__( 'Items Per Group', 'crisop' ),
                'type' => Controls_Manager::NUMBER,
                'min' => 1,
                'max' => 20,
                'step' => 1,
                'default' => 5
            ]
        );
        $this->add_control( 'mditems2',
            [
                'label' => esc_html__( 'Items Laptop', 'crisop' ),
                'type' => Controls_Manager::NUMBER,
                'min' => 1,
                'max' => 20,
                'step' => 1,
                'default' => 4
            ]
        );
        $this->add_control( 'mditems2_group',
            [
                'label' => esc_html__( 'Items Per Group Laptop', 'crisop' ),
                'type' => Controls_Manager::NUMBER,
                'min' => 1,
                'max' => 20,
                'step' => 1,
                'default' => 4
            ]
        );
        $this->add_control( 'smitems',
            [
                'label' => esc_html__( 'Items Tablet', 'crisop' ),
                'type' => Controls_Manager::NUMBER,
                'min' => 1,
                'max' => 20,
                'step' => 1,
                'default' => 3
            ]
        );
        $this->add_control( 'smitems_group',
            [
                'label' => esc_html__( 'Items Per Group Tablet', 'crisop' ),
                'type' => Controls_Manager::NUMBER,
                'min' => 1,
                'max' => 20,
                'step' => 1,
                'default' => 3
            ]
        );
        $this->add_control( 'xsitems',
            [
                'label' => esc_html__( 'Items Phone', 'crisop' ),
                'type' => Controls_Manager::NUMBER,
                'min' => 1,
                'max' => 20,
                'step' => 1,
                'default' => 2
            ]
        );
        $this->add_control( 'xsitems_group',
            [
                'label' => esc_html__( 'Items Per Group Phone', 'crisop' ),
                'type' => Controls_Manager::NUMBER,
                'min' => 1,
                'max' => 20,
                'step' => 1,
                'default' => 2
            ]
        );
        $this->add_control( 'navs_type',
            [
                'label' => esc_html__( 'Navs Type', 'crisop' ),
                'type' => Controls_Manager::SELECT,
                'default' => 'both',
                'options' => [
                    'both' => esc_html__( 'Both Nav and Dots', 'crisop' ),
                    'default' => esc_html__( 'Nav Center + Dots Bottom', 'crisop' )
                ]
            ]
        );
        $this->add_responsive_control( 'navs_horizontal_pos',
            [
                'label' => esc_html__( 'Nav Horizontal Alignment', 'crisop' ),
                'type' => Controls_Manager::CHOOSE,
                'options' => [
                    'flex-start' => [
                        'title' => esc_html__( 'Left', 'crisop' ),
                        'icon' => 'eicon-h-align-left'
                    ],
                    'center' => [
                        'title' => esc_html__( 'Center', 'crisop' ),
                        'icon' => 'eicon-h-align-center'
                    ],
                    'flex-end' => [
                        'title' => esc_html__( 'Right', 'crisop' ),
                        'icon' => 'eicon-h-align-right'
                    ]
                ],
                'toggle' => true,
                'default' => '',
                'selectors' => [ '{{WRAPPER}} .ninetheme-swiper-theme-style .ninetheme-slider-nav' => 'justify-content:{{VALUE}};' ],
                'condition' => [ 'slider_title' => '' ]
            ]
        );
        $this->add_responsive_control( 'navs_vertical_pos',
            [
                'label' => esc_html__( 'Nav Vertical Position', 'crisop' ),
                'type' => Controls_Manager::CHOOSE,
                'options' => [
                    'top' => [
                        'title' => esc_html__( 'Top', 'crisop' ),
                        'icon' => 'eicon-v-align-top'
                    ],
                    'bottom' => [
                        'title' => esc_html__( 'Bottom', 'crisop' ),
                        'icon' => 'eicon-v-align-bottom'
                    ]
                ],
                'toggle' => true,
                'default' => 'top',
                'condition' => [
                    'navs_type' => 'both'
                ]
            ]
        );
        $this->add_responsive_control( 'navs_horizontal_pos2',
            [
                'label' => esc_html__( 'Nav Horizontal Alignment', 'crisop' ),
                'type' => Controls_Manager::CHOOSE,
                'options' => [
                    'flex-start' => [
                        'title' => esc_html__( 'Left', 'crisop' ),
                        'icon' => 'eicon-h-align-left'
                    ],
                    'center' => [
                        'title' => esc_html__( 'Center', 'crisop' ),
                        'icon' => 'eicon-h-align-center'
                    ],
                    'flex-end' => [
                        'title' => esc_html__( 'Right', 'crisop' ),
                        'icon' => 'eicon-h-align-right'
                    ]
                ],
                'toggle' => true,
                'default' => '',
                'selectors' => [ '{{WRAPPER}} .ninetheme-swiper-theme-style .ninetheme-slider-nav.nav-bottom' => 'justify-content:{{VALUE}};' ],
                'condition' => [
                    'slider_title!' => '',
                    'navs_type' => 'both',
                    'navs_vertical_pos' => 'bottom'
                ]
            ]
        );
        $this->add_responsive_control( 'navs_spacing',
            [
                'label' => esc_html__( 'Nav Spacing ( px )', 'crisop' ),
                'type' => Controls_Manager::SLIDER,
                'range' => [
                    'px' => ['max' => 300]
                ],
				'default' => [
					'unit' => 'px',
					'size' => 30,
				],
                'selectors' => [
                    '{{WRAPPER}} .ninetheme-swiper-theme-style.nav-type-both .ninetheme-slider-nav.nav-bottom' => 'margin-top: {{SIZE}}px;',
                    '{{WRAPPER}} .ninetheme-swiper-theme-style.nav-type-both .ninetheme-slider-nav.nav-top' => 'margin-bottom: {{SIZE}}px;',
                ],
                'condition' => [
                    'navs_type' => 'both'
                ]
            ]
        );
        $this->end_controls_section();
        /*****   END CONTROLS SECTION   ******/

        /*****   START CONTROLS SECTION   ******/
        $this->start_controls_section('navs_style_section',
            [
                'label'=> esc_html__( 'SLIDER NAV STYLE', 'crisop' ),
                'tab' => Controls_Manager::TAB_CONTENT,
                'condition' => [ 'nav' => 'yes' ]
            ]
        );
        $this->add_control( 'navs_size',
            [
                'label' => esc_html__( 'Size', 'crisop' ),
                'type' => Controls_Manager::NUMBER,
                'min' => 0,
                'max' => 100,
                'step' => 1,
                'default' => '',
                'selectors' => [ '{{WRAPPER}} .ninetheme-swiper-theme-style .swiper-button-prev:after,{{WRAPPER}} .ninetheme-swiper-theme-style .swiper-button-next:after' => 'font-size:{{SIZE}}px;' ]
            ]
        );
        $this->add_control( 'navs_color',
            [
                'label' => esc_html__( 'Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => ['{{WRAPPER}} .ninetheme-swiper-theme-style .swiper-button-prev:after,{{WRAPPER}} .ninetheme-swiper-theme-style .swiper-button-next:after' => 'color:{{VALUE}};' ]
            ]
        );
        $this->add_control( 'navs_hvrcolor',
            [
                'label' => esc_html__( 'Hover Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => ['{{WRAPPER}} .ninetheme-swiper-theme-style .swiper-button-prev:hover:after,{{WRAPPER}} .ninetheme-swiper-theme-style .swiper-button-next:hover:after' => 'color:{{VALUE}};' ]
            ]
        );
        $this->add_control( 'navs_bgcolor',
            [
                'label' => esc_html__( 'Background olor', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => ['{{WRAPPER}} .ninetheme-swiper-theme-style .swiper-button-prev,{{WRAPPER}} .ninetheme-swiper-theme-style .swiper-button-next' => 'background-color:{{VALUE}};' ]
            ]
        );
        $this->add_control( 'navs_bghvrcolor',
            [
                'label' => esc_html__( 'Hover Background Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => ['{{WRAPPER}} .ninetheme-swiper-theme-style .swiper-button-prev:hover,{{WRAPPER}} .ninetheme-swiper-theme-style .swiper-button-next:hover' => 'background-color:{{VALUE}};' ]
            ]
        );
        $this->add_control( 'navs_brdcolor',
            [
                'label' => esc_html__( 'Border olor', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => ['{{WRAPPER}} .ninetheme-swiper-theme-style .swiper-button-prev,{{WRAPPER}} .ninetheme-swiper-theme-style .swiper-button-next' => 'border-color:{{VALUE}};' ]
            ]
        );
        $this->add_control( 'navs_brdhvrcolor',
            [
                'label' => esc_html__( 'Hover Border Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => ['{{WRAPPER}} .ninetheme-swiper-theme-style .swiper-button-prev:hover,{{WRAPPER}} .ninetheme-swiper-theme-style .swiper-button-next:hover' => 'border-color:{{VALUE}};' ]
            ]
        );

        $this->end_controls_section();
        /*****   END CONTROLS SECTION   ******/
        /*****   START CONTROLS SECTION   ******/
        $this->start_controls_section('dots_style_section',
            [
                'label'=> esc_html__( 'SLIDER DOTS STYLE', 'crisop' ),
                'tab' => Controls_Manager::TAB_CONTENT,
                'condition' => [ 'dots' => 'yes' ]
            ]
        );
        $this->add_responsive_control( 'dots_spacing',
            [
                'label' => esc_html__( 'Top Offset ( px )', 'crisop' ),
                'type' => Controls_Manager::SLIDER,
                'range' => [
                    'px' => ['max' => 300]
                ],
				'default' => [
					'unit' => 'px',
					'size' => 30
				],
                'selectors' => [
                    '{{WRAPPER}} .ninetheme-swiper-theme-style.nav-type-default .swiper-pagination' => 'margin-top: {{SIZE}}px;',
                ],
                'condition' => [
                    'navs_type' => 'default'
                ]
            ]
        );
        $this->add_responsive_control( 'dots_horizontal_pos',
            [
                'label' => esc_html__( 'Horizontal Alignment', 'crisop' ),
                'type' => Controls_Manager::CHOOSE,
                'options' => [
                    'left' => [
                        'title' => esc_html__( 'Left', 'crisop' ),
                        'icon' => 'eicon-h-align-left'
                    ],
                    'center' => [
                        'title' => esc_html__( 'Center', 'crisop' ),
                        'icon' => 'eicon-h-align-center'
                    ],
                    'right' => [
                        'title' => esc_html__( 'Right', 'crisop' ),
                        'icon' => 'eicon-h-align-right'
                    ]
                ],
                'toggle' => true,
                'default' => '',
                'selectors' => [ '{{WRAPPER}} .ninetheme-swiper-theme-style .swiper-pagination' => 'text-align:{{VALUE}};' ],
                'condition' => [
                    'navs_type' => 'default'
                ]
            ]
        );
        $this->add_control( 'dots_size',
            [
                'label' => esc_html__( 'Size', 'crisop' ),
                'type' => Controls_Manager::NUMBER,
                'min' => 0,
                'max' => 100,
                'step' => 1,
                'default' => '',
                'selectors' => [ '{{WRAPPER}} .swiper-pagination-bullets .swiper-pagination-bullet:before' => 'width:{{SIZE}}px;height:{{SIZE}}px;' ]
            ]
        );
        $this->add_control( 'dots_space',
            [
                'label' => esc_html__( 'Space', 'crisop' ),
                'type' => Controls_Manager::NUMBER,
                'min' => 0,
                'max' => 100,
                'step' => 1,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .swiper-horizontal > .swiper-pagination-bullets .swiper-pagination-bullet + .swiper-pagination-bullet' => 'margin: 0;margin-left: {{SIZE}}px;',
                    '{{WRAPPER}} .swiper-pagination-horizontal.swiper-pagination-bullets .swiper-pagination-bullet + .swiper-pagination-bullet' => 'margin: 0;margin-left: {{SIZE}}px;',
                ]
            ]
        );
        $this->start_controls_tabs( 'dots_nav_tabs');
        $this->start_controls_tab( 'dots_normal_tab',
            [ 'label' => esc_html__( 'Normal', 'crisop' ) ]
        );
        $this->add_control( 'dots_bgcolor',
            [
                'label' => esc_html__( 'Background', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => ['{{WRAPPER}} .swiper-pagination-bullets .swiper-pagination-bullet:before' => 'background-color:{{VALUE}};' ]
            ]
        );
        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name' => 'dots_border',
                'label' => esc_html__( 'Border', 'crisop' ),
                'selector' => '{{WRAPPER}} .swiper-pagination-bullets .swiper-pagination-bullet',
            ]
        );
        $this->add_responsive_control( 'dots_border_radius',
            [
                'label' => esc_html__( 'Border Radius', 'crisop' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px' ],
                'selectors' => [
                    '{{WRAPPER}} .swiper-pagination-bullets .swiper-pagination-bullet:before,{{WRAPPER}} .swiper-pagination-bullets .swiper-pagination-bullet' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};'
                ]
            ]
        );
        $this->end_controls_tab();
        $this->start_controls_tab( 'dots_hover_tab',
            [ 'label' => esc_html__( 'Active', 'crisop' ) ]
        );
        $this->add_control( 'dots_hvrbgcolor',
            [
                'label' => esc_html__( 'Color', 'crisop' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [ '{{WRAPPER}} .swiper-pagination-bullet.swiper-pagination-bullet-active:before' => 'background-color:{{VALUE}};' ]
            ]
        );
        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name' => 'dots_hvrborder',
                'label' => esc_html__( 'Border', 'crisop' ),
                'selector' => '{{WRAPPER}} .swiper-pagination-bullet.swiper-pagination-bullet-active'
            ]
        );
        $this->add_responsive_control( 'dots_hvrborder_radius',
            [
                'label' => esc_html__( 'Border Radius', 'crisop' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px' ],
                'selectors' => [
                    '{{WRAPPER}} .swiper-pagination-bullets .swiper-pagination-bullet.swiper-pagination-bullet-active:before,{{WRAPPER}} .swiper-pagination-bullets .swiper-pagination-bullet.swiper-pagination-bullet-active' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};'
                ]
            ]
        );
        $this->end_controls_tab();
        $this->end_controls_tabs();
        $this->end_controls_section();
        /*****   END CONTROLS SECTION   ******/
    }
    public function image_custom_size() {
        $settings = $this->get_settings_for_display();
        $size = $settings['thumbnail_size'] ? $settings['thumbnail_size'] : ninetheme_settings('product_imgsize','ninetheme-mini');
        if ( 'custom' == $size ) {
            $sizew = $settings['thumbnail_custom_dimension']['width'];
            $sizeh = $settings['thumbnail_custom_dimension']['height'];
            $size = [ $sizew, $sizeh ];
        }
        return $size;
    }
    protected function render() {
        if ( ! class_exists('WooCommerce') ) {
            return;
        }
        global $wp_query;
        $settings = $this->get_settings_for_display();
        $id = $this->get_id();

        $args = array(
            'post_type'      => 'product',
            'posts_per_page' => $settings['post_per_page'],
            'post__in'       => $settings['post_include'],
            'post__not_in'   => $settings['post_exclude'],
            'order'          => $settings['order']
        );

        if ( 'featured' == $settings['scenario'] ) {
           $args['tax_query'] = array(
                array(
                    'taxonomy' => 'product_visibility',
                    'field' => 'name',
                    'terms' => 'featured'
                )
            );

        } elseif('on-sale' == $settings['scenario']) {

            $args['meta_query'] = array(
                'relation' => 'OR',
                array( // Simple products type
                    'key' => '_sale_price',
                    'value' => 0,
                    'compare' => '>',
                    'type' => 'numeric'
                ),
                array( // Variable products type
                    'key' => '_min_variation_sale_price',
                    'value' => 0,
                    'compare' => '>',
                    'type' => 'numeric'
                )
            );

        } elseif('best' == $settings['scenario']) {

            $args['orderby'] = 'meta_value_num';
            $args['meta_key'] = 'total_sales';

        } else {

            $args['orderby'] = $settings['orderby'];

        }

        if ( $settings['category_include'] ) {
            $args['tax_query'] = array(
                array(
                    'taxonomy' => 'product_cat',
                    'field' => 'id',
                    'terms' => $settings['category_include'],
                    'operator' => 'IN'
                )
            );
        }
        if ( $settings['category_exclude'] ) {
            $args['tax_query'] = array(
                array(
                    'taxonomy' => 'product_cat',
                    'field' => 'id',
                    'terms' => $settings['category_exclude'],
                    'operator' => 'NOT IN'
                )
            );
        }

        $editmode   = \Elementor\Plugin::$instance->editor->is_edit_mode() ? '-'.$id: '';
        $box_style  = $settings['box_style'];
        $space      = $settings['space'] ? $settings['space'] : 30;
        $space_item = 'style-2' == $box_style ? 0 : $space;
        $dots_none  = 'yes' != $settings['dots'] ? ' dots-none' : '';
        
        $slider_options = json_encode( array(
                "slidesPerView" => 1,
                "loop"          => 'yes' == $settings['loop'] ? true : false,
                "loopedSlides"  => 'yes' == $settings['loop'] ? $settings['loop_count'] : null,
                "autoHeight"    => false,
                "autoplay"      => 'yes' == $settings['autoplay'] ? [ "pauseOnMouseEnter" => true,"disableOnInteraction" => false ] : false,
                "centeredSlides"=> 'yes' == $settings['centermode'] ? true : false,
                "speed"         => $settings['speed'],
                "spaceBetween"  => $space_item,
                "direction"     => "horizontal",
                "watchSlidesProgress" => true,
                "navigation" => [
                    "nextEl" => ".ninetheme-products-widget-slider .slide-next-$id",
                    "prevEl" => ".ninetheme-products-widget-slider .slide-prev-$id"
                ],
                "pagination" => [
                    "el" => ".ninetheme-products-widget-slider .ninetheme-pagination-$id",
                    "type" => "bullets",
                    "clickable" => true
                ],
                "breakpoints" => [
                    "0" => [
                        "slidesPerView" => $settings['xsitems'],
                        "slidesPerGroup" => $settings['xsitems_group']
                    ],
                    "768" => [
                        "slidesPerView" => $settings['smitems'],
                        "slidesPerGroup" => $settings['smitems_group']
                    ],
                    "992" => [
                        "slidesPerView" => $settings['mditems2'],
                        "slidesPerGroup" => $settings['mditems2_group']
                    ],
                    "1280" => [
                        "slidesPerView" => $settings['mditems'],
                        "slidesPerGroup" => $settings['mditems_group']
                    ]
                ]
            )
        );
        
        add_filter( 'single_product_archive_thumbnail_size', [$this, 'image_custom_size' ] );

        $the_query = new \WP_Query( $args );
        if ( $the_query->have_posts() ) {
            echo '<div class="ninetheme-products-widget-slider ninetheme-swiper-theme-style nav-type-'.$settings['navs_type'].$dots_none.' '.$box_style.'">';
            
                if ( $settings['slider_title'] ) {
                    echo '<div class="ninetheme-slider-title-wrapper nav-top">';
                        echo '<'.$settings['title_tag'].' class="ninetheme-slider-nav-title'.$has_timer.'">'.$settings['slider_title'].'</'.$settings['title_tag'].'>';
                }
                        if ( 'both' == $settings['navs_type'] ) {
                            if ( 'bottom' != $settings['navs_vertical_pos'] && ( 'yes' == $settings['dots'] || 'yes' == $settings['nav'] ) ) {
                                $top = '' == $settings['slider_title'] ? ' nav-top' : '';
                                echo '<div class="ninetheme-slider-nav'.$top.'">';
                                    if ( 'yes' == $settings['nav'] ) {
                                        echo '<div class="swiper-button-prev slide-prev-'.$id.'"></div>';
                                    }
                                    if ( 'yes' == $settings['dots'] ) {
                                        echo '<div class="swiper-pagination ninetheme-pagination-'.$id.'"></div>';
                                    }
                                    if ( 'yes' == $settings['nav'] ) {
                                        echo '<div class="swiper-button-next slide-next-'.$id.'"></div>';
                                    }
                                echo '</div>';
                            }
                        }
                if ( $settings['slider_title'] ) {
                    echo '</div>';
                }
                
                add_action( 'ninetheme_shop_loop_after_content', 'ninetheme_loop_product_progressbar' );
                
                echo '<div class="swiper-container ninetheme-swiper-slider'.$editmode.'" data-swiper-options=\''.$slider_options.'\'>';
                    echo '<div class="swiper-wrapper">';
                        while ( $the_query->have_posts() ) {
                            $the_query->the_post();
                            global $product;
                            $visibility = $product->get_catalog_visibility();
                            
                            if ( $visibility != 'hidden' ) {
                                echo '<div class="swiper-slide product_item visibility-'.$visibility.'">';
                                    wc_get_template_part( 'content', 'product' );
                                echo '</div>';
                            }
                        }
                    echo '</div>';
                echo '</div>';
                
                remove_action( 'ninetheme_shop_loop_after_content', 'ninetheme_loop_product_progressbar' );
                
                if ( 'both' == $settings['navs_type'] ) {
                    if ( 'bottom' == $settings['navs_vertical_pos'] && ( 'yes' == $settings['dots'] || 'yes' == $settings['nav'] ) ) {
                        echo '<div class="ninetheme-slider-nav nav-bottom">';
                            if ( 'yes' == $settings['nav'] ) {
                                echo '<div class="swiper-button-prev slide-prev-'.$id.'"></div>';
                            }
                            if ( 'yes' == $settings['dots'] ) {
                                echo '<div class="swiper-pagination ninetheme-pagination-'.$id.'"></div>';
                            }
                            if ( 'yes' == $settings['nav'] ) {
                                echo '<div class="swiper-button-next slide-next-'.$id.'"></div>';
                            }
                        echo '</div>';
                    }
                }
                if ( 'default' == $settings['navs_type'] ) {
                    if ( 'yes' == $settings['dots'] ) {
                        echo '<div class="swiper-pagination ninetheme-pagination-'.$id.'"></div>';
                    }
                    if ( 'yes' == $settings['nav'] ) {
                        echo '<div class="swiper-button-prev slide-prev-'.$id.'"></div>';
                        echo '<div class="swiper-button-next slide-next-'.$id.'"></div>';
                    }
                }
            echo '</div>';
        }
        wp_reset_postdata();

        remove_filter( 'single_product_archive_thumbnail_size', [$this, 'image_custom_size' ] );

        if ( \Elementor\Plugin::$instance->editor->is_edit_mode() ) { ?>
            <script>
            jQuery( document ).ready( function($) {
                $('.ninetheme-swiper-slider-<?php echo $id ?>').each(function (i, el) {
                    var options = $(el).data('swiper-options')
                    const mySlider = new NTSwiper(el, options);
                });
            });
            </script>
            <?php
        }
    }
}
