<?php
/**
 * What the class handles.
 *
 */
class Ninetheme_Widget_Product_Categories_Slider extends WP_Widget {

    // Widget Settings
    function __construct() {
        $control_ops = array( 'width' => 300, 'height' => 350, 'id_base' => 'ninetheme_product_categories_slider' );
        parent::__construct( 'ninetheme_product_categories_slider', esc_html__('Crisop Product Categories Slider','crisop'), $widget_ops, $control_ops );
    }

    // Widget Output
    function widget( $args, $instance )
    {
        extract( $args );
        $id = $this->number;
        $options = '"loop":false,
        "autoplay":false,
        "spaceBetween":1,
        "speed":1000,
        "slidesPerView":1,
        "rewind":true,
        "navigation": {"nextEl":".nav-next-'.$id.'","prevEl":".nav-prev-'.$id.'"}';
        
        $title       = apply_filters( 'widget_title', empty($instance['title'] ) ? '' : $instance['title'], $instance );
        $cats        = $instance['cats'];
        $hide_empty  = $instance['hide_empty'];
        $only_parent = $instance['only_parent'];
        $filter_type = $instance['filter_type'];
        $perpage     = $instance['perpage'];

        if ( 'include' ==  $filter_type ) {
            $categories = get_terms( 'product_cat', array(
                'orderby'    => 'name',
                'order'      => 'asc',
                'number'     => $perpage,
                'parent'     => null == $only_parent ? '' : 0,
                'hide_empty' => '' == $hide_empty ? 0 : 1,
                'include'    => $cats
            ));
        } else {
            $categories = get_terms( 'product_cat', array(
                'orderby'    => 'name',
                'order'      => 'asc',
                'number'     => $perpage,
                'parent'     => null == $only_parent ? '' : 0,
                'hide_empty' => '' == $hide_empty ? 0 : 1,
                'exclude'    => $cats
            ));
        }
        
        echo $before_widget;

        if ( $title ) {
            echo $before_title . $title . $after_title;
        }

        if ( !empty( $categories ) ) {
            ?>
            <div class="ninetheme-widget-product-categories-slider widget-body <?php echo esc_attr( $id ); ?>">
                <div class="ninetheme-widget-category-slider ninetheme-swiper-theme-style ninetheme-swiper-slider swiper-container" data-swiper-options='{<?php echo esc_attr( $options ); ?>}'>
                    <div class="swiper-wrapper">
                        <?php
                        foreach ( $categories as $category ) {
                            $thumbnail_id = get_term_meta( $category->term_id, 'thumbnail_id', true );
                            $catcounts = $cat->count > 0 && $cat->count == 1 ? esc_html__('Product', 'crisop') : esc_html__('Products', 'crisop');
                            ?>
                            <div class="ninetheme-category-slide-item swiper-slide">
                                <a href="<?php echo esc_url( get_term_link( $category ) ); ?>" class="cat-link">
                                    <?php 
                                    if ( !empty( $thumbnail_id ) ) {
                                        echo wp_get_attachment_image( $thumbnail_id, 'medium', true );
                                    }
                                    ?>
                                    <div class="category-details">
                                        <span class="category-title"><?php echo esc_html( $category->name ); ?></span>
                                        <span class="category-count"><?php echo esc_html( $category->count ); ?> <?php echo esc_html( $catcounts ); ?></span>
                                    </div>
                                </a>
                            </div>
                            <?php
                        }
                        ?>
                    </div>
                    <div class="ninetheme-slide-btn swiper-button-prev nav-small nav-prev-<?php echo esc_attr( $id ); ?>"></div>
                    <div class="ninetheme-slide-btn swiper-button-next nav-small nav-next-<?php echo esc_attr( $id ); ?>"></div>
                </div>
            </div>
            <?php
        }

        echo $after_widget;
                
    }

    // Update
    function update( $new_instance, $old_instance )
    {
        $instance = $old_instance;

        $instance['title']       = strip_tags($new_instance['title']);
        $instance['hide_empty']  = !empty( $new_instance['hide_empty'] ) ? $new_instance['hide_empty'] : '';
        $instance['cats']        = $new_instance['cats'];
        $instance['filter_type'] = $new_instance['filter_type'];
        $instance['only_parent'] = $new_instance['only_parent'];
        $instance['perpage'] = $new_instance['perpage'];

        return $instance;
    }

    // Backend Form
    function form( $instance )
    {
        $defaults   = array( 
            'title' => 'Product Categories Slider',
            'cats' => array(),
            'filter_type' => '',
            'perpage' => '',
            'hide_empty' => '',
            'only_parent' => ''
        );
        $instance    = wp_parse_args(( array ) $instance, $defaults );
        $select      = is_array( $instance['cats'] ) ? $instance['cats'] : array();
        $hide_empty  = $instance['hide_empty'] ? 1 : 0;
        $only_parent = $instance['only_parent'] ? 1 : 0;
        $filter_type = $instance['filter_type'];
        $perpage     = $instance['perpage'];

        $terms = get_terms( array(
            'taxonomy'   => 'product_cat',
            'hide_empty' => $hide_empty,
            'parent'     => 0
        ));
        wp_enqueue_style( 'select2-full' );
        wp_enqueue_script( 'select2-full' );
        ?>
        <p>
            <label for="<?php echo $this->get_field_id('title'); ?>"><?php esc_html_e('Title:','crisop'); ?></label>
            <input class="widefat" id="<?php echo $this->get_field_id('title'); ?>" name="<?php echo $this->get_field_name('title'); ?>" value="<?php echo $instance['title']; ?>" />
        </p>
        <p>
            <label for="<?php echo $this->get_field_id('hide_empty'); ?>"><?php esc_html_e( 'Hide if empty','crisop' ); ?></label>
            <input type="checkbox" class="widefat" id="<?php echo $this->get_field_id('hide_empty'); ?>" name="<?php echo $this->get_field_name('hide_empty'); ?>" value="1" <?php checked( $instance['hide_empty'], 1 ); ?> />
        </p>
        <p>
            <label for="<?php echo $this->get_field_id('only_parent'); ?>"><?php esc_html_e( 'Only Parent','crisop' ); ?></label>
            <input type="checkbox" class="widefat" id="<?php echo $this->get_field_id('only_parent'); ?>" name="<?php echo $this->get_field_name('only_parent'); ?>" value="1" <?php checked( $instance['only_parent'], 1 ); ?> />
        </p>
        <p>
            <label for="<?php echo $this->get_field_id('perpage'); ?>"><?php esc_html_e( 'Per Page','crisop' ); ?></label>
            <input type="number" class="widefat" id="<?php echo $this->get_field_id('perpage'); ?>" name="<?php echo $this->get_field_name('perpage'); ?>" value="<?php echo $instance['perpage']; ?>" min="1" />
        </p>
        <p class="ninetheme-select-wrapper">
            <label for="<?php echo $this->get_field_id('filter_type'); ?>"><?php esc_html_e( 'Category Filter Type','crisop' ); ?></label>
            <select class="ninetheme-select" id="<?php echo $this->get_field_id('filter_type'); ?>" name="<?php echo $this->get_field_name('filter_type'); ?>">
                <option value="include" <?php echo 'include' == $filter_type ? 'selected="selected"' : ''; ?>><?php esc_html_e( 'Include','crisop' ); ?></option>
                <option value="exclude" <?php echo 'exclude' == $filter_type ? 'selected="selected"' : ''; ?>><?php esc_html_e( 'Exclude','crisop' ); ?></option>
            </select>
        </p>
        <p class="ninetheme-select2-wrapper">
            <label for="<?php echo $this->get_field_id('cats'); ?>"><?php esc_html_e( 'Select Category(s):','crisop' ); ?></label>
            <select class="ninetheme-select2" id="<?php echo $this->get_field_id('cats'); ?>" name="<?php echo $this->get_field_name('cats'); ?>[]" multiple="multiple">
                <?php foreach ( $terms as $term ) {
                    $selected = in_array( $term->term_id, $select) ? 'selected="selected"' : '';
                    ?>
                    <option value="<?php echo $term->term_id; ?>" <?php echo $selected; ?>><?php echo $term->name; ?></option>
                <?php } ?>
            </select>
        </p>
        
        <?php
    }
}

// Add Widget
function ninetheme_widget_product_categories_slider_init() {
    register_widget('Ninetheme_Widget_Product_Categories_Slider');
}
add_action('widgets_init', 'ninetheme_widget_product_categories_slider_init');

?>
